@@ -21,23 +21,11 @@
 
 RETRO_BEGIN_DECLS
 
-#define AUDIO_CHUNK_SIZE_BLOCKING      512
-
-/* So we don't get complete line-noise when fast-forwarding audio. */
-#define AUDIO_CHUNK_SIZE_NONBLOCKING   2048
-
-#define AUDIO_MAX_RATIO                16
-#define AUDIO_MIN_RATIO                0.0625
-
 #define AUDIO_MIXER_MAX_STREAMS        16
 
 #define AUDIO_MIXER_MAX_SYSTEM_STREAMS (AUDIO_MIXER_MAX_STREAMS + 8)
 
-/* Fastforward timing calculations running average samples. Helps with a
-consistent pitch when fast-forwarding. */
-#define AUDIO_FF_EXP_AVG_SAMPLES       16
-
-/* do not define more than (MAX_SYSTEM_STREAMS - MAX_STREAMS) */
+/* Do not define more than (MAX_SYSTEM_STREAMS - MAX_STREAMS) */
 enum audio_mixer_system_slot
 {
    AUDIO_MIXER_SYSTEM_SLOT_OK = AUDIO_MIXER_MAX_STREAMS,
@@ -161,7 +149,13 @@ enum audio_driver_state_flags
     * @see audio_driver_t::write_avail
     * @see audio_driver_t::buffer_size
     */
-   AUDIO_FLAG_CONTROL      = (1 << 5)
+   AUDIO_FLAG_CONTROL      = (1 << 5),
+
+   /**
+    * Indicates that the audio driver is forcing gain to 0.
+    * Used for temporary rewind and fast-forward muting.
+    */
+   AUDIO_FLAG_MUTED        = (1 << 6)
 };
 
 typedef struct audio_statistics
