@@ -44,11 +44,11 @@ int alsa_init_pcm(snd_pcm_t **pcm,
    const char *alsa_dev           = device ? device : "default";
    int errnum                     = 0;
 
-   RARCH_DBG("[ALSA]: Requesting device \"%s\" for %s stream\n", alsa_dev, snd_pcm_stream_name(stream));
+   RARCH_DBG("[ALSA] Requesting device \"%s\" for %s stream...\n", alsa_dev, snd_pcm_stream_name(stream));
 
    if ((errnum = snd_pcm_open(pcm, alsa_dev, stream, mode)) < 0)
    {
-      RARCH_ERR("[ALSA]: Failed to open %s stream on device \"%s\": %s\n",
+      RARCH_ERR("[ALSA] Failed to open %s stream on device \"%s\": %s.\n",
             snd_pcm_stream_name(stream),
             alsa_dev,
             snd_strerror(errnum));
@@ -58,7 +58,7 @@ int alsa_init_pcm(snd_pcm_t **pcm,
 
    if ((errnum = snd_pcm_hw_params_malloc(&params)) < 0)
    {
-      RARCH_ERR("[ALSA]: Failed to allocate hardware parameters: %s\n",
+      RARCH_ERR("[ALSA] Failed to allocate hardware parameters: %s.\n",
             snd_strerror(errnum));
 
       goto error;
@@ -66,7 +66,7 @@ int alsa_init_pcm(snd_pcm_t **pcm,
 
    if ((errnum = snd_pcm_hw_params_any(*pcm, params)) < 0)
    {
-      RARCH_ERR("[ALSA]: Failed to query hardware parameters from %s device \"%s\": %s\n",
+      RARCH_ERR("[ALSA] Failed to query hardware parameters from %s device \"%s\": %s.\n",
             snd_pcm_stream_name(stream),
             snd_pcm_name(*pcm),
             snd_strerror(errnum));
@@ -78,7 +78,7 @@ int alsa_init_pcm(snd_pcm_t **pcm,
          ? SND_PCM_FORMAT_FLOAT : SND_PCM_FORMAT_S16;
    stream_info->has_float = (format == SND_PCM_FORMAT_FLOAT);
 
-   RARCH_LOG("[ALSA]: Using %s sample format for %s device \"%s\"\n",
+   RARCH_LOG("[ALSA] Using %s sample format for %s device \"%s\".\n",
          snd_pcm_format_name(format),
          snd_pcm_stream_name(stream),
          snd_pcm_name(*pcm)
@@ -86,7 +86,7 @@ int alsa_init_pcm(snd_pcm_t **pcm,
 
    if ((errnum = snd_pcm_hw_params_set_access(*pcm, params, SND_PCM_ACCESS_RW_INTERLEAVED)) < 0)
    {
-      RARCH_ERR("[ALSA]: Failed to set %s access for %s device \"%s\": %s\n",
+      RARCH_ERR("[ALSA] Failed to set %s access for %s device \"%s\": %s.\n",
             snd_pcm_access_name(SND_PCM_ACCESS_RW_INTERLEAVED),
             snd_pcm_stream_name(stream),
             snd_pcm_name(*pcm),
@@ -98,7 +98,7 @@ int alsa_init_pcm(snd_pcm_t **pcm,
 
    if ((errnum = snd_pcm_hw_params_set_format(*pcm, params, format)) < 0)
    {
-      RARCH_ERR("[ALSA]: Failed to set %s format for %s device \"%s\": %s\n",
+      RARCH_ERR("[ALSA] Failed to set %s format for %s device \"%s\": %s.\n",
             snd_pcm_format_name(format),
             snd_pcm_stream_name(stream),
             snd_pcm_name(*pcm),
@@ -109,7 +109,7 @@ int alsa_init_pcm(snd_pcm_t **pcm,
 
    if ((errnum = snd_pcm_hw_params_set_channels(*pcm, params, channels)) < 0)
    {
-      RARCH_ERR("[ALSA]: Failed to set %u-channel audio for %s device \"%s\": %s\n",
+      RARCH_ERR("[ALSA] Failed to set %u-channel audio for %s device \"%s\": %s.\n",
             channels,
             snd_pcm_stream_name(stream),
             snd_pcm_name(*pcm),
@@ -121,7 +121,7 @@ int alsa_init_pcm(snd_pcm_t **pcm,
    /* Don't allow rate resampling when probing for the default rate (but ignore if this call fails) */
    if ((errnum = snd_pcm_hw_params_set_rate_resample(*pcm, params, false)) < 0)
    {
-      RARCH_WARN("[ALSA]: Failed to request a default unsampled rate for %s device \"%s\": %s\n",
+      RARCH_WARN("[ALSA] Failed to request a default unsampled rate for %s device \"%s\": %s.\n",
             snd_pcm_stream_name(stream),
             snd_pcm_name(*pcm),
             snd_strerror(errnum));
@@ -129,7 +129,7 @@ int alsa_init_pcm(snd_pcm_t **pcm,
 
    if ((errnum = snd_pcm_hw_params_set_rate_near(*pcm, params, &rate, 0)) < 0)
    {
-      RARCH_ERR("[ALSA]: Failed to request a rate near %uHz for %s device \"%s\": %s\n",
+      RARCH_ERR("[ALSA] Failed to request a rate near %uHz for %s device \"%s\": %s.\n",
             rate,
             snd_pcm_stream_name(stream),
             snd_pcm_name(*pcm),
@@ -143,7 +143,7 @@ int alsa_init_pcm(snd_pcm_t **pcm,
 
    if ((snd_pcm_hw_params_set_buffer_time_near(*pcm, params, &latency_usec, NULL)) < 0)
    {
-      RARCH_ERR("[ALSA]: Failed to request a buffer time near %uus for %s device \"%s\": %s\n",
+      RARCH_ERR("[ALSA] Failed to request a buffer time near %uus for %s device \"%s\": %s.\n",
             latency_usec,
             snd_pcm_stream_name(stream),
             snd_pcm_name(*pcm),
@@ -155,7 +155,7 @@ int alsa_init_pcm(snd_pcm_t **pcm,
 
    if ((errnum = snd_pcm_hw_params_set_periods_near(*pcm, params, &periods, NULL)) < 0)
    {
-      RARCH_ERR("[ALSA]: Failed to request %u periods per buffer for %s device \"%s\": %s\n",
+      RARCH_ERR("[ALSA] Failed to request %u periods per buffer for %s device \"%s\": %s.\n",
             periods,
             snd_pcm_stream_name(stream),
             snd_pcm_name(*pcm),
@@ -166,7 +166,7 @@ int alsa_init_pcm(snd_pcm_t **pcm,
 
    if ((errnum = snd_pcm_hw_params(*pcm, params)) < 0)
    { /* This calls snd_pcm_prepare() under the hood */
-      RARCH_ERR("[ALSA]: Failed to install hardware parameters for %s device \"%s\": %s\n",
+      RARCH_ERR("[ALSA] Failed to install hardware parameters for %s device \"%s\": %s.\n",
             snd_pcm_stream_name(stream),
             snd_pcm_name(*pcm),
             snd_strerror(errnum));
@@ -178,15 +178,15 @@ int alsa_init_pcm(snd_pcm_t **pcm,
     * but some drivers are apparently broken. */
    if ((errnum = snd_pcm_hw_params_get_period_size(params, &stream_info->period_frames, NULL)) < 0)
    {
-      RARCH_WARN("[ALSA]: Failed to get an exact period size from %s device \"%s\": %s\n",
+      RARCH_WARN("[ALSA] Failed to get an exact period size from %s device \"%s\": %s.\n",
             snd_pcm_stream_name(stream),
             snd_pcm_name(*pcm),
             snd_strerror(errnum));
-      RARCH_WARN("[ALSA]: Trying the minimum period size instead\n");
+      RARCH_WARN("[ALSA] Trying the minimum period size instead.\n");
 
       if ((errnum = snd_pcm_hw_params_get_period_size_min(params, &stream_info->period_frames, NULL)) < 0)
       {
-         RARCH_ERR("[ALSA]: Failed to get min period size from %s device \"%s\": %s\n",
+         RARCH_ERR("[ALSA] Failed to get min period size from %s device \"%s\": %s.\n",
                snd_pcm_stream_name(stream),
                snd_pcm_name(*pcm),
                snd_strerror(errnum));
@@ -197,28 +197,28 @@ int alsa_init_pcm(snd_pcm_t **pcm,
    stream_info->period_size = snd_pcm_frames_to_bytes(*pcm, stream_info->period_frames);
    if (stream_info->period_size < 0)
    {
-      RARCH_ERR("[ALSA]: Failed to convert a period size of %lu frames to bytes: %s\n",
+      RARCH_ERR("[ALSA] Failed to convert a period size of %lu frames to bytes: %s.\n",
             stream_info->period_frames,
             snd_strerror(stream_info->period_frames));
       goto error;
    }
 
-   RARCH_LOG("[ALSA]: Period: %u periods per buffer (%lu frames, %lu bytes)\n",
+   RARCH_LOG("[ALSA] Period: %u periods per buffer (%lu frames, %lu bytes).\n",
          periods,
          stream_info->period_frames,
          stream_info->period_size);
 
    if ((errnum = snd_pcm_hw_params_get_buffer_size(params, &buffer_size)) < 0)
    {
-      RARCH_WARN("[ALSA]: Failed to get exact buffer size from %s device \"%s\": %s\n",
+      RARCH_WARN("[ALSA] Failed to get exact buffer size from %s device \"%s\": %s.\n",
             snd_pcm_stream_name(stream),
             snd_pcm_name(*pcm),
             snd_strerror(errnum));
-      RARCH_WARN("[ALSA]: Trying the maximum buffer size instead\n");
+      RARCH_WARN("[ALSA] Trying the maximum buffer size instead.\n");
 
       if ((errnum = snd_pcm_hw_params_get_buffer_size_max(params, &buffer_size)) < 0)
       {
-         RARCH_ERR("[ALSA]: Failed to get max buffer size from %s device \"%s\": %s\n",
+         RARCH_ERR("[ALSA] Failed to get max buffer size from %s device \"%s\": %s.\n",
                snd_pcm_stream_name(stream),
                snd_pcm_name(*pcm),
                snd_strerror(errnum));
@@ -230,20 +230,20 @@ int alsa_init_pcm(snd_pcm_t **pcm,
    stream_info->buffer_size = snd_pcm_frames_to_bytes(*pcm, buffer_size);
    if (stream_info->buffer_size < 0)
    {
-      RARCH_ERR("[ALSA]: Failed to convert a buffer size of %lu frames to bytes: %s\n",
+      RARCH_ERR("[ALSA] Failed to convert a buffer size of %lu frames to bytes: %s.\n",
             buffer_size,
             snd_strerror(buffer_size));
       goto error;
    }
-   RARCH_LOG("[ALSA]: Buffer size: %lu frames (%lu bytes)\n", buffer_size, stream_info->buffer_size);
+   RARCH_LOG("[ALSA] Buffer size: %lu frames (%lu bytes).\n", buffer_size, stream_info->buffer_size);
 
    stream_info->can_pause = snd_pcm_hw_params_can_pause(params);
 
-   RARCH_LOG("[ALSA]: Can pause: %s.\n", stream_info->can_pause ? "yes" : "no");
+   RARCH_LOG("[ALSA] Can pause: %s.\n", stream_info->can_pause ? "yes" : "no");
 
    if ((errnum = snd_pcm_sw_params_malloc(&sw_params)) < 0)
    {
-      RARCH_ERR("[ALSA]: Failed to allocate software parameters: %s\n",
+      RARCH_ERR("[ALSA] Failed to allocate software parameters: %s.\n",
             snd_strerror(errnum));
 
       goto error;
@@ -251,7 +251,7 @@ int alsa_init_pcm(snd_pcm_t **pcm,
 
    if ((errnum = snd_pcm_sw_params_current(*pcm, sw_params)) < 0)
    {
-      RARCH_ERR("[ALSA]: Failed to query current software parameters for %s device \"%s\": %s\n",
+      RARCH_ERR("[ALSA] Failed to query current software parameters for %s device \"%s\": %s.\n",
             snd_pcm_stream_name(stream),
             snd_pcm_name(*pcm),
             snd_strerror(errnum));
@@ -261,7 +261,7 @@ int alsa_init_pcm(snd_pcm_t **pcm,
 
    if ((errnum = snd_pcm_sw_params_set_start_threshold(*pcm, sw_params, buffer_size / 2)) < 0)
    {
-      RARCH_ERR("[ALSA]: Failed to set start %lu-frame threshold for %s device \"%s\": %s\n",
+      RARCH_ERR("[ALSA] Failed to set start %lu-frame threshold for %s device \"%s\": %s.\n",
             buffer_size / 2,
             snd_pcm_stream_name(stream),
             snd_pcm_name(*pcm),
@@ -272,7 +272,7 @@ int alsa_init_pcm(snd_pcm_t **pcm,
 
    if ((errnum = snd_pcm_sw_params(*pcm, sw_params)) < 0)
    {
-      RARCH_ERR("[ALSA]: Failed to install software parameters for %s device \"%s\": %s\n",
+      RARCH_ERR("[ALSA] Failed to install software parameters for %s device \"%s\": %s.\n",
             snd_pcm_stream_name(stream),
             snd_pcm_name(*pcm),
             snd_strerror(errnum));
@@ -283,11 +283,12 @@ int alsa_init_pcm(snd_pcm_t **pcm,
    snd_pcm_hw_params_free(params);
    snd_pcm_sw_params_free(sw_params);
 
-   RARCH_LOG("[ALSA]: Initialized %s device \"%s\"\n",
+   RARCH_LOG("[ALSA] Initialized %s device \"%s\".\n",
          snd_pcm_stream_name(stream),
          snd_pcm_name(*pcm));
 
    return 0;
+
 error:
    if (params)
       snd_pcm_hw_params_free(params);
@@ -312,7 +313,7 @@ void alsa_free_pcm(snd_pcm_t *pcm)
 
       if ((errnum = snd_pcm_drop(pcm)) < 0)
       {
-         RARCH_WARN("[ALSA]: Failed to drop remaining samples in %s stream \"%s\": %s\n",
+         RARCH_WARN("[ALSA] Failed to drop remaining samples in %s stream \"%s\": %s.\n",
                snd_pcm_stream_name(snd_pcm_stream(pcm)),
                snd_pcm_name(pcm),
                snd_strerror(errnum));
@@ -320,7 +321,7 @@ void alsa_free_pcm(snd_pcm_t *pcm)
 
       if ((errnum = snd_pcm_close(pcm)) < 0)
       {
-         RARCH_WARN("[ALSA]: Failed to close %s stream \"%s\": %s\n",
+         RARCH_WARN("[ALSA] Failed to close %s stream \"%s\": %s.\n",
                snd_pcm_stream_name(snd_pcm_stream(pcm)),
                snd_pcm_name(pcm),
                snd_strerror(errnum));
@@ -351,19 +352,19 @@ bool alsa_start_pcm(snd_pcm_t *pcm)
 
          break;
       case SND_PCM_STATE_RUNNING:
-         RARCH_DBG("[ALSA]: %s stream \"%s\" is already running, no action needed.\n",
+         RARCH_DBG("[ALSA] %s stream \"%s\" is already running, no action needed.\n",
             snd_pcm_stream_name(snd_pcm_stream(pcm)),
             snd_pcm_name(pcm));
          return true;
       default:
-         RARCH_ERR("[ALSA]: Failed to start %s stream \"%s\" in unexpected state %s\n",
+         RARCH_ERR("[ALSA] Failed to start %s stream \"%s\" in unexpected state %s.\n",
                    snd_pcm_stream_name(snd_pcm_stream(pcm)),
                    snd_pcm_name(pcm),
                    snd_pcm_state_name(pcm_state));
          return false;
    }
 
-   RARCH_DBG("[ALSA]: Started %s stream \"%s\", transitioning from %s to %s\n",
+   RARCH_DBG("[ALSA] Started %s stream \"%s\", transitioning from %s to %s.\n",
              snd_pcm_stream_name(snd_pcm_stream(pcm)),
              snd_pcm_name(pcm),
              snd_pcm_state_name(pcm_state),
@@ -372,7 +373,7 @@ bool alsa_start_pcm(snd_pcm_t *pcm)
    return true;
 
 error:
-   RARCH_ERR("[ALSA]: Failed to start %s stream \"%s\" in state %s: %s\n",
+   RARCH_ERR("[ALSA] Failed to start %s stream \"%s\" in state %s: %s.\n",
              snd_pcm_stream_name(snd_pcm_stream(pcm)),
              snd_pcm_name(pcm),
              snd_pcm_state_name(pcm_state),
@@ -393,12 +394,12 @@ bool alsa_stop_pcm(snd_pcm_t *pcm)
    switch (pcm_state)
    {
       case SND_PCM_STATE_PAUSED:
-         RARCH_DBG("[ALSA]: %s stream \"%s\" is already paused, no action needed.\n",
+         RARCH_DBG("[ALSA] %s stream \"%s\" is already paused, no action needed.\n",
             snd_pcm_stream_name(snd_pcm_stream(pcm)),
             snd_pcm_name(pcm));
          return true;
       case SND_PCM_STATE_PREPARED:
-         RARCH_DBG("[ALSA]: %s stream \"%s\" is prepared but not running, no action needed.\n",
+         RARCH_DBG("[ALSA] %s stream \"%s\" is prepared but not running, no action needed.\n",
             snd_pcm_stream_name(snd_pcm_stream(pcm)),
             snd_pcm_name(pcm));
          return true;
@@ -409,7 +410,7 @@ bool alsa_stop_pcm(snd_pcm_t *pcm)
 
          break;
       default:
-         RARCH_ERR("[ALSA]: Failed to stop %s stream \"%s\" in unexpected state %s\n",
+         RARCH_ERR("[ALSA] Failed to stop %s stream \"%s\" in unexpected state %s.\n",
                    snd_pcm_stream_name(snd_pcm_stream(pcm)),
                    snd_pcm_name(pcm),
                    snd_pcm_state_name(pcm_state));
@@ -417,7 +418,7 @@ bool alsa_stop_pcm(snd_pcm_t *pcm)
          return false;
    }
 
-   RARCH_DBG("[ALSA]: Stopped %s stream \"%s\", transitioning from %s to %s\n",
+   RARCH_DBG("[ALSA] Stopped %s stream \"%s\", transitioning from %s to %s.\n",
              snd_pcm_stream_name(snd_pcm_stream(pcm)),
              snd_pcm_name(pcm),
              snd_pcm_state_name(pcm_state),
@@ -426,7 +427,7 @@ bool alsa_stop_pcm(snd_pcm_t *pcm)
    return true;
 
 error:
-   RARCH_ERR("[ALSA]: Failed to stop %s stream \"%s\" in state %s: %s\n",
+   RARCH_ERR("[ALSA] Failed to stop %s stream \"%s\" in state %s: %s.\n",
              snd_pcm_stream_name(snd_pcm_stream(pcm)),
              snd_pcm_name(pcm),
              snd_pcm_state_name(pcm_state),
