@@ -64,14 +64,14 @@ static void *alsa_qsa_init(const char *device,
    if ((err = snd_pcm_open_preferred(&alsa->pcm, &card, &dev,
                SND_PCM_OPEN_PLAYBACK)) < 0)
    {
-      RARCH_ERR("[ALSA QSA]: Audio open error: %s\n",
+      RARCH_ERR("[ALSA QSA] Audio open error: %s.\n",
             snd_strerror(err));
       goto error;
    }
 
    if ((err = snd_pcm_nonblock_mode(alsa->pcm, 1)) < 0)
    {
-      RARCH_ERR("[ALSA QSA]: Can't set blocking mode: %s\n",
+      RARCH_ERR("[ALSA QSA] Can't set blocking mode: %s.\n",
             snd_strerror(err));
       goto error;
    }
@@ -80,7 +80,7 @@ static void *alsa_qsa_init(const char *device,
    pi.channel = SND_PCM_CHANNEL_PLAYBACK;
    if ((err = snd_pcm_channel_info(alsa->pcm, &pi)) < 0)
    {
-      RARCH_ERR("[ALSA QSA]: snd_pcm_channel_info failed: %s\n",
+      RARCH_ERR("[ALSA QSA] snd_pcm_channel_info failed: %s.\n",
             snd_strerror(err));
       goto error;
    }
@@ -88,27 +88,27 @@ static void *alsa_qsa_init(const char *device,
    memset(&params, 0, sizeof(params));
 
    params.channel = SND_PCM_CHANNEL_PLAYBACK;
-   params.mode = SND_PCM_MODE_BLOCK;
+   params.mode    = SND_PCM_MODE_BLOCK;
 
    params.format.interleave = 1;
-   params.format.format = SND_PCM_SFMT_S16_LE;
-   params.format.rate = DEFAULT_RATE;
-   params.format.voices = 2;
+   params.format.format     = SND_PCM_SFMT_S16_LE;
+   params.format.rate       = DEFAULT_RATE;
+   params.format.voices     = 2;
 
    params.start_mode = SND_PCM_START_FULL;
-   params.stop_mode = SND_PCM_STOP_STOP;
+   params.stop_mode  = SND_PCM_STOP_STOP;
 
    params.buf.block.frag_size = pi.max_fragment_size;
    params.buf.block.frags_min = 2;
    params.buf.block.frags_max = 8;
 
-   RARCH_LOG("Fragment size: %d\n", params.buf.block.frag_size);
-   RARCH_LOG("Min Fragment size: %d\n", params.buf.block.frags_min);
-   RARCH_LOG("Max Fragment size: %d\n", params.buf.block.frags_max);
+   RARCH_LOG("[ALSA QSA] Fragment size: %d.\n", params.buf.block.frag_size);
+   RARCH_LOG("[ALSA QSA] Min Fragment size: %d.\n", params.buf.block.frags_min);
+   RARCH_LOG("[ALSA QSA] Max Fragment size: %d.\n", params.buf.block.frags_max);
 
    if ((err = snd_pcm_channel_params(alsa->pcm, &params)) < 0)
    {
-      RARCH_ERR("[ALSA QSA]: Channel Parameter Error: %s\n",
+      RARCH_ERR("[ALSA QSA] Channel Parameter Error: %s.\n",
             snd_strerror(err));
       goto error;
    }
@@ -117,7 +117,7 @@ static void *alsa_qsa_init(const char *device,
 
    if ((err = snd_pcm_channel_setup(alsa->pcm, &setup)) < 0)
    {
-      RARCH_ERR("[ALSA QSA]: Channel Parameter Read Back Error: %s\n",
+      RARCH_ERR("[ALSA QSA] Channel Parameter Read Back Error: %s.\n",
             snd_strerror(err));
       goto error;
    }
@@ -127,7 +127,7 @@ static void *alsa_qsa_init(const char *device,
    else
       alsa->buf_size = next_pow2(32 * latency);
 
-   RARCH_LOG("[ALSA QSA]: buffer size: %u bytes\n", alsa->buf_size);
+   RARCH_LOG("[ALSA QSA] Buffer size: %u bytes.\n", alsa->buf_size);
 
    alsa->buf_count = (latency * 4 * rate + 500) / 1000;
    alsa->buf_count = (alsa->buf_count + alsa->buf_size / 2) / alsa->buf_size;
@@ -135,7 +135,7 @@ static void *alsa_qsa_init(const char *device,
    if ((err = snd_pcm_channel_prepare(alsa->pcm,
                SND_PCM_CHANNEL_PLAYBACK)) < 0)
    {
-      RARCH_ERR("[ALSA QSA]: Channel Prepare Error: %s\n",
+      RARCH_ERR("[ALSA QSA] Channel Prepare Error: %s.\n",
             snd_strerror(err));
       goto error;
    }
@@ -153,7 +153,7 @@ static void *alsa_qsa_init(const char *device,
 
    alsa->has_float = false;
    alsa->can_pause = true;
-   RARCH_LOG("[ALSA QSA]: Can pause: %s.\n",
+   RARCH_LOG("[ALSA QSA] Can pause: %s.\n",
          alsa->can_pause ? "yes" : "no");
 
    return alsa;
@@ -175,35 +175,35 @@ static int check_pcm_status(void *data, int channel_type)
    {
       if (status.status == SND_PCM_STATUS_UNSECURE)
       {
-         RARCH_ERR("check_pcm_status got SND_PCM_STATUS_UNSECURE, aborting playback\n");
+         RARCH_ERR("[ALSA QSA] check_pcm_status got SND_PCM_STATUS_UNSECURE, aborting playback.\n");
          ret = -EPROTO;
       }
       else if (status.status == SND_PCM_STATUS_UNDERRUN)
       {
-         RARCH_LOG("check_pcm_status: SNDP_CM_STATUS_UNDERRUN.\n");
+         RARCH_LOG("[ALSA QSA] check_pcm_status: SNDP_CM_STATUS_UNDERRUN.\n");
          if ((ret = snd_pcm_channel_prepare(alsa->pcm, channel_type)) < 0)
          {
-            RARCH_ERR("Invalid state detected for underrun on snd_pcm_channel_prepare: %s\n",
+            RARCH_ERR("[ALSA QSA] Invalid state detected for underrun on snd_pcm_channel_prepare: %s.\n",
                   snd_strerror(ret));
             ret = -EPROTO;
          }
       }
       else if (status.status == SND_PCM_STATUS_OVERRUN)
       {
-         RARCH_LOG("check_pcm_status: SNDP_CM_STATUS_OVERRUN.\n");
+         RARCH_LOG("[ALSA QSA] check_pcm_status: SNDP_CM_STATUS_OVERRUN.\n");
          if ((ret = snd_pcm_channel_prepare(alsa->pcm, channel_type)) < 0)
          {
-            RARCH_ERR("Invalid state detected for overrun on snd_pcm_channel_prepare: %s\n",
+            RARCH_ERR("[ALSA QSA] Invalid state detected for overrun on snd_pcm_channel_prepare: %s.\n",
                   snd_strerror(ret));
             ret = -EPROTO;
          }
       }
       else if (status.status == SND_PCM_STATUS_CHANGE)
       {
-         RARCH_LOG("check_pcm_status: SNDP_CM_STATUS_CHANGE.\n");
+         RARCH_LOG("[ALSA QSA] check_pcm_status: SNDP_CM_STATUS_CHANGE.\n");
          if ((ret = snd_pcm_channel_prepare(alsa->pcm, channel_type)) < 0)
          {
-            RARCH_ERR("Invalid state detected for change on snd_pcm_channel_prepare: %s\n",
+            RARCH_ERR("[ALSA QSA] Invalid state detected for change on snd_pcm_channel_prepare: %s.\n",
                   snd_strerror(ret));
             ret = -EPROTO;
          }
@@ -211,7 +211,7 @@ static int check_pcm_status(void *data, int channel_type)
    }
    else
    {
-      RARCH_ERR("check_pcm_status failed: %s\n", snd_strerror(ret));
+      RARCH_ERR("[ALSA QSA] check_pcm_status failed: %s.\n", snd_strerror(ret));
       if (ret == -ESRCH)
          ret = -EBADF;
    }
@@ -219,24 +219,24 @@ static int check_pcm_status(void *data, int channel_type)
    return ret;
 }
 
-static ssize_t alsa_qsa_write(void *data, const void *buf, size_t size)
+static ssize_t alsa_qsa_write(void *data, const void *buf, size_t len)
 {
-   alsa_qsa_t          *alsa = (alsa_qsa_t*)data;
-   snd_pcm_sframes_t written = 0;
+   ssize_t _len = 0;
+   alsa_qsa_t *alsa = (alsa_qsa_t*)data;
 
    while (size)
    {
-      size_t avail_write = MIN(alsa->buf_size - alsa->buffer_ptr, size);
+      size_t avail_write = MIN(alsa->buf_size - alsa->buffer_ptr, len);
 
       if (avail_write)
       {
          memcpy(alsa->buffer[alsa->buffer_index] +
                alsa->buffer_ptr, buf, avail_write);
 
-         alsa->buffer_ptr      += avail_write;
-         buf                    = (void*)((uint8_t*)buf + avail_write);
-         size                  -= avail_write;
-         written               += avail_write;
+         alsa->buffer_ptr   += avail_write;
+         buf                 = (void*)((uint8_t*)buf + avail_write);
+         len                -= avail_write;
+         _len               += avail_write;
       }
 
       if (alsa->buffer_ptr >= alsa->buf_size)
@@ -260,10 +260,9 @@ static ssize_t alsa_qsa_write(void *data, const void *buf, size_t size)
                return -1;
          }
       }
-
    }
 
-   return written;
+   return _len;
 }
 
 static bool alsa_qsa_stop(void *data)
@@ -300,7 +299,7 @@ static bool alsa_qsa_start(void *data, bool is_shutdown)
 
       if (ret < 0)
       {
-         RARCH_ERR("[ALSA QSA]: Failed to unpause: %s.\n",
+         RARCH_ERR("[ALSA QSA] Failed to unpause: %s.\n",
                snd_strerror(ret));
          return false;
       }
@@ -318,7 +317,7 @@ static void alsa_qsa_set_nonblock_state(void *data, bool state)
 
    if ((err = snd_pcm_nonblock_mode(alsa->pcm, state)) < 0)
    {
-      RARCH_ERR("Can't set blocking mode to %d: %s\n", state,
+      RARCH_ERR("[ALSA QSA] Can't set blocking mode to %d: %s.\n", state,
             snd_strerror(err));
       return;
    }
