@@ -16,11 +16,13 @@
 #include <3ds.h>
 #include <string.h>
 #include <malloc.h>
+#include <math.h>
 #include <queues/fifo_queue.h>
 #include <rthreads/rthreads.h>
 
 #include "../audio_driver.h"
 #include "../../ctr/ctr_debug.h"
+#include "../../verbosity.h"
 
 typedef struct
 {
@@ -43,7 +45,7 @@ typedef struct
    uint32_t pos;
 } ctr_dsp_thread_audio_t;
 
-// PCM16 stereo
+/* PCM16 stereo */
 #define DSP_BYTES_TO_SAMPLES(bytes) (bytes / (2 * sizeof(uint16_t)))
 #define DSP_SAMPLES_TO_BYTES(samples) (samples * 2 * sizeof(uint16_t))
 
@@ -148,7 +150,7 @@ static void *ctr_dsp_thread_audio_init(const char *device, unsigned rate, unsign
        || !(ctr->fifo_done = scond_new())
        || !(ctr->thread = sthread_create(ctr_dsp_audio_loop, ctr)))
    {
-      RARCH_LOG("[Audio]: thread creation failed.\n");
+      RARCH_LOG("[Audio] Thread creation failed.\n");
       ctr->running = false;
       ctr_dsp_thread_audio_free(ctr);
       return NULL;
@@ -198,9 +200,9 @@ static void ctr_dsp_thread_audio_free(void *data)
    ctr = NULL;
 }
 
-static ssize_t ctr_dsp_thread_audio_write(void *data, const void *buf, size_t size)
+static ssize_t ctr_dsp_thread_audio_write(void *data, const void *buf, size_t len)
 {
-   size_t avail, written;
+   size_t avail, _len;
    ctr_dsp_thread_audio_t * ctr = (ctr_dsp_thread_audio_t*)data;
 
    if (!ctr || !ctr->running)
@@ -210,18 +212,18 @@ static ssize_t ctr_dsp_thread_audio_write(void *data, const void *buf, size_t si
    {
       slock_lock(ctr->fifo_lock);
       avail = FIFO_WRITE_AVAIL(ctr->fifo);
-      written = MIN(avail, size);
-      if (written > 0)
+      _len  = MIN(avail, len);
+      if (_len > 0)
       {
-         fifo_write(ctr->fifo, buf, written);
+         fifo_write(ctr->fifo, buf, _len);
          scond_signal(ctr->fifo_avail);
       }
       slock_unlock(ctr->fifo_lock);
    }
    else
    {
-      written = 0;
-      while (written < size && ctr->running)
+      _len = 0;
+      while (_len < len && ctr->running)
       {
          slock_lock(ctr->fifo_lock);
          avail = FIFO_WRITE_AVAIL(ctr->fifo);
@@ -240,16 +242,16 @@ static ssize_t ctr_dsp_thread_audio_write(void *data, const void *buf, size_t si
          }
          else
          {
-            size_t write_amt = MIN(size - written, avail);
-            fifo_write(ctr->fifo, (const char*)buf + written, write_amt);
+            size_t write_amt = MIN(len - _len, avail);
+            fifo_write(ctr->fifo, (const char*)buf + _len, write_amt);
             scond_signal(ctr->fifo_avail);
             slock_unlock(ctr->fifo_lock);
-            written += write_amt;
+            _len += write_amt;
          }
       }
    }
 
-   return written;
+   return _len;
 }
 
 static bool ctr_dsp_thread_audio_stop(void *data)
