@@ -52,6 +52,10 @@
 #include "streams/chd_stream.h"
 #endif
 
+#ifdef HAVE_CHEEVOS_RVZ
+#include "cheevos_rvz.h"
+#endif
+
 #include "cheevos.h"
 #include "cheevos_client.h"
 #include "cheevos_menu.h"
@@ -87,7 +91,6 @@ static rcheevos_locals_t rcheevos_locals =
    {{0}},/* memory */
 #ifdef HAVE_THREADS
    CMD_EVENT_NONE, /* queued_command */
-   false, /* game_placard_requested */
 #endif
    "",   /* user_agent_prefix */
    "",   /* user_agent_core */
@@ -97,6 +100,7 @@ static rcheevos_locals_t rcheevos_locals =
    0,    /* menuitem_count */
 #endif
    true, /* hardcore_allowed */
+   false,/* hardcore_requires_reload */
    false,/* hardcore_being_enabled */
    true  /* core_supports */
 };
@@ -112,8 +116,8 @@ rcheevos_locals_t* get_rcheevos_locals(void)
 Supporting functions.
 *****************************************************************************/
 
-#define CMD_CHEEVOS_NON_COMMAND -1
-static void rcheevos_show_game_placard(void);
+#define CMD_CHEEVOS_FINALIZE_LOAD -1
+static void rcheevos_finalize_game_load_on_ui_thread(void);
 
 #ifndef CHEEVOS_VERBOSE
 void rcheevos_log(const char* fmt, ...)
@@ -243,7 +247,7 @@ static void rcheevos_show_mastery_placard(void)
          char msg[128];
          char badge_name[32];
          const char* displayname = rc_client_get_user_info(rcheevos_locals.client)->display_name;
-         const bool content_runtime_log = settings->bools.content_runtime_log;
+         const bool content_runtime_log      = settings->bools.content_runtime_log;
          const bool content_runtime_log_aggr = settings->bools.content_runtime_log_aggregate;
          size_t __len = strlcpy(msg, displayname, sizeof(msg));
 
@@ -310,7 +314,7 @@ static void rcheevos_award_achievement(const rc_client_achievement_t* cheevo)
             strlcpy(title,
                msg_hash_to_str(MSG_ACHIEVEMENT_UNLOCKED), sizeof(title));
 
-         snprintf(subtitle, sizeof(subtitle), "%s (%d)", cheevo->title, cheevo->points);
+         snprintf(subtitle, sizeof(subtitle), "%s (%lu)", cheevo->title, (unsigned long)cheevo->points);
 
          gfx_widgets_push_achievement(title, subtitle, cheevo->badge_name);
       }
@@ -345,17 +349,19 @@ static void rcheevos_award_achievement(const rc_client_achievement_t* cheevo)
 
       if (shotname)
       {
+         const char *path_directory_screenshot = settings->paths.directory_screenshot;
          video_driver_state_t* video_st = video_state_get_ptr();;
          snprintf(shotname, shotname_len, "%s/%s-cheevo-%u",
-            settings->paths.directory_screenshot,
+            path_directory_screenshot,
             path_basename(path_get(RARCH_PATH_BASENAME)),
             (unsigned)cheevo->id);
          shotname[shotname_len - 1] = '\0';
 
-         if (take_screenshot(settings->paths.directory_screenshot,
+         if (take_screenshot(path_directory_screenshot,
             shotname,
             true,
-            video_st->frame_cache_data && (video_st->frame_cache_data == RETRO_HW_FRAME_BUFFER_VALID),
+            video_st->frame_cache_data
+            && (video_st->frame_cache_data == RETRO_HW_FRAME_BUFFER_VALID),
             false,
             true))
             CHEEVOS_LOG(RCHEEVOS_TAG
@@ -372,7 +378,8 @@ static void rcheevos_award_achievement(const rc_client_achievement_t* cheevo)
 #endif
 }
 
-static void rcheevos_lboard_submitted(const rc_client_leaderboard_t* lboard, const rc_client_leaderboard_scoreboard_t* scoreboard)
+static void rcheevos_lboard_submitted(const rc_client_leaderboard_t* lboard,
+      const rc_client_leaderboard_scoreboard_t* scoreboard)
 {
    const settings_t* settings = config_get_ptr();
    if (lboard && settings->bools.cheevos_visibility_lboard_submit)
@@ -402,8 +409,9 @@ static void rcheevos_lboard_submitted(const rc_client_leaderboard_t* lboard, con
 
 static void rcheevos_lboard_canceled(const rc_client_leaderboard_t* lboard)
 {
-   const settings_t* settings = config_get_ptr();
-   if (lboard && settings->bools.cheevos_visibility_lboard_cancel)
+   const settings_t* settings            = config_get_ptr();
+   bool cheevos_visibility_lboard_cancel = settings->bools.cheevos_visibility_lboard_cancel;
+   if (cheevos_visibility_lboard_cancel)
    {
       char buffer[256];
       size_t _len = strlcpy(buffer, msg_hash_to_str(MSG_LEADERBOARD_FAILED), sizeof(buffer));
@@ -416,8 +424,9 @@ static void rcheevos_lboard_canceled(const rc_client_leaderboard_t* lboard)
 
 static void rcheevos_lboard_started(const rc_client_leaderboard_t* lboard)
 {
-   const settings_t* settings = config_get_ptr();
-   if (settings->bools.cheevos_visibility_lboard_start)
+   const settings_t *settings           = config_get_ptr();
+   bool cheevos_visibility_lboard_start = settings->bools.cheevos_visibility_lboard_start;
+   if (cheevos_visibility_lboard_start)
    {
       char buffer[256];
       size_t _len = strlcpy(buffer, msg_hash_to_str(MSG_LEADERBOARD_STARTED),
@@ -465,7 +474,9 @@ static void rcheevos_progress_updated(rcheevos_locals_t* locals,
    const rc_client_achievement_t* cheevo)
 {
    settings_t* settings = config_get_ptr();
-   if (cheevo && gfx_widgets_ready() && settings->bools.cheevos_visibility_progress_tracker)
+   if (     cheevo
+         && gfx_widgets_ready()
+         && settings->bools.cheevos_visibility_progress_tracker)
       gfx_widget_set_achievement_progress(cheevo->badge_name, cheevo->measured_progress);
 }
 
@@ -674,7 +685,6 @@ void rcheevos_pause_hardcore(void)
 
 bool rcheevos_unload(void)
 {
-   settings_t* settings  = config_get_ptr();
    const bool was_loaded = rcheevos_is_game_loaded();
 
 #ifdef HAVE_GFX_WIDGETS
@@ -686,7 +696,6 @@ bool rcheevos_unload(void)
 
 #ifdef HAVE_THREADS
    rcheevos_locals.queued_command = CMD_EVENT_NONE;
-   rcheevos_locals.game_placard_requested = false;
 #endif
 
    if (rcheevos_locals.memory.count > 0)
@@ -711,7 +720,7 @@ bool rcheevos_unload(void)
    rcheevos_locals.queued_command = CMD_EVENT_NONE;
 #endif
 
-   if (!settings->arrays.cheevos_token[0])
+   if (!config_get_ptr()->arrays.cheevos_token[0])
    {
       /* If the config-level token has been cleared, we need to re-login on
        * loading the next game. Easiest way to do that is to destroy the client */
@@ -727,31 +736,26 @@ bool rcheevos_unload(void)
 void rcheevos_leaderboard_trackers_visibility_changed(void)
 {
 #if defined(HAVE_GFX_WIDGETS)
-   const settings_t* settings = config_get_ptr();
-   if (!settings->bools.cheevos_visibility_lboard_trackers)
-   {
-      /* Hide any visible trackers */
+   bool cheevos_visibility_lboard_trackers = config_get_ptr()->bools.cheevos_visibility_lboard_trackers;
+   /* Hide any visible trackers */
+   if (!cheevos_visibility_lboard_trackers)
       gfx_widgets_clear_leaderboard_displays();
-   }
-   else
-   {
-      /* No way to immediately request trackers be reshown, but they
-       * will reappear the next time they're updated */
-   }
 #endif
 }
 
+/* Disable slowdown */
 static void rcheevos_enforce_hardcore_settings(void)
 {
-   /* disable slowdown */
    runloop_state_get_ptr()->flags &= ~RUNLOOP_FLAG_SLOWMOTION;
 }
 
 static void rcheevos_toggle_hardcore_active(rcheevos_locals_t* locals)
 {
-   settings_t* settings = config_get_ptr();
-   bool rewind_enable   = settings->bools.rewind_enable;
-   const bool was_enabled = rcheevos_hardcore_active();
+   settings_t* settings                  = config_get_ptr();
+   bool rewind_enable                    = settings->bools.rewind_enable;
+   const bool was_enabled                = rcheevos_hardcore_active();
+   bool notification_show_cheats_applied =
+      settings->bools.notification_show_cheats_applied;
 
    if (!was_enabled)
    {
@@ -768,7 +772,7 @@ static void rcheevos_toggle_hardcore_active(rcheevos_locals_t* locals)
 
 #ifdef HAVE_CHEATS
       /* If one or more emulator managed cheats is active, abort */
-      cheat_manager_apply_cheats();
+      cheat_manager_apply_cheats(notification_show_cheats_applied);
       if (!locals->hardcore_allowed)
       {
          locals->hardcore_being_enabled = false;
@@ -827,13 +831,17 @@ static void rcheevos_toggle_hardcore_active(rcheevos_locals_t* locals)
             command_event(CMD_EVENT_REWIND_INIT, NULL);
       }
    }
+
+#ifdef HAVE_NETWORKING
+   /* force sending a savestate to clients so they'll drop out of hardcore too */
+   netplay_force_send_savestate();
+#endif
 }
 
 void rcheevos_toggle_hardcore_paused(void)
 {
-   settings_t* settings = config_get_ptr();
    /* if hardcore mode is not enabled, we can't toggle whether its active */
-   if (settings->bools.cheevos_hardcore_mode_enable)
+   if (config_get_ptr()->bools.cheevos_hardcore_mode_enable)
       rcheevos_toggle_hardcore_active(&rcheevos_locals);
 }
 
@@ -863,13 +871,13 @@ void rcheevos_hardcore_enabled_changed(void)
 void rcheevos_validate_config_settings(void)
 {
    int i;
+   unsigned console_id;
    const rc_disallowed_setting_t
       *disallowed_settings           = NULL;
    core_option_manager_t* coreopts   = NULL;
    struct retro_system_info *sysinfo =
       &runloop_state_get_ptr()->system.info;
    const settings_t* settings = config_get_ptr();
-   unsigned console_id;
 
    if (!rcheevos_hardcore_active())
       return;
@@ -880,10 +888,13 @@ void rcheevos_validate_config_settings(void)
     * it'll wait for the next vsync event, effectively halfing the fps. the
     * auto setting should achieve the most accurate frame rate anyway, so
     * disallow any manual values */
-   if (!settings->bools.video_frame_delay_auto && settings->uints.video_frame_delay != 0)
+   if (    !settings->bools.video_frame_delay_auto
+         && settings->uints.video_frame_delay != 0)
    {
-      const char* error = msg_hash_to_str(MSG_CHEEVOS_HARDCORE_PAUSED_MANUAL_FRAME_DELAY);
-      CHEEVOS_LOG(RCHEEVOS_TAG "%s\n", msg_hash_to_str_us(MSG_CHEEVOS_HARDCORE_PAUSED_MANUAL_FRAME_DELAY));
+      const char* error = msg_hash_to_str(
+            MSG_CHEEVOS_HARDCORE_PAUSED_MANUAL_FRAME_DELAY);
+      CHEEVOS_LOG(RCHEEVOS_TAG "%s\n",
+            msg_hash_to_str_us(MSG_CHEEVOS_HARDCORE_PAUSED_MANUAL_FRAME_DELAY));
       rcheevos_pause_hardcore();
 
       runloop_msg_queue_push(error, strlen(error), 0, 4 * 60, false, NULL,
@@ -901,8 +912,10 @@ void rcheevos_validate_config_settings(void)
     * wouldn't know how to change it to auto. */
    if (settings->uints.video_swap_interval > 1)
    {
-      const char* error = msg_hash_to_str(MSG_CHEEVOS_HARDCORE_PAUSED_VSYNC_SWAP_INTERVAL);
-      CHEEVOS_LOG(RCHEEVOS_TAG "%s\n", msg_hash_to_str_us(MSG_CHEEVOS_HARDCORE_PAUSED_VSYNC_SWAP_INTERVAL));
+      const char* error = msg_hash_to_str(
+            MSG_CHEEVOS_HARDCORE_PAUSED_VSYNC_SWAP_INTERVAL);
+      CHEEVOS_LOG(RCHEEVOS_TAG "%s\n",
+            msg_hash_to_str_us(MSG_CHEEVOS_HARDCORE_PAUSED_VSYNC_SWAP_INTERVAL));
       rcheevos_pause_hardcore();
 
       runloop_msg_queue_push(error, strlen(error), 0, 4 * 60, false, NULL,
@@ -914,8 +927,10 @@ void rcheevos_validate_config_settings(void)
     * can slow down the actual number of rendered frames per second. */
    if (settings->uints.video_black_frame_insertion > 0)
    {
-      const char* error = msg_hash_to_str(MSG_CHEEVOS_HARDCORE_PAUSED_BLACK_FRAME_INSERTION);
-      CHEEVOS_LOG(RCHEEVOS_TAG "%s\n", msg_hash_to_str_us(MSG_CHEEVOS_HARDCORE_PAUSED_BLACK_FRAME_INSERTION));
+      const char* error = msg_hash_to_str(
+            MSG_CHEEVOS_HARDCORE_PAUSED_BLACK_FRAME_INSERTION);
+      CHEEVOS_LOG(RCHEEVOS_TAG "%s\n",
+            msg_hash_to_str_us(MSG_CHEEVOS_HARDCORE_PAUSED_BLACK_FRAME_INSERTION));
       rcheevos_pause_hardcore();
 
       runloop_msg_queue_push(error, strlen(error), 0, 4 * 60, false, NULL,
@@ -927,7 +942,8 @@ void rcheevos_validate_config_settings(void)
       return;
 
    disallowed_settings = rc_libretro_get_disallowed_settings(sysinfo->library_name);
-   if (disallowed_settings && retroarch_ctl(RARCH_CTL_CORE_OPTIONS_LIST_GET, &coreopts))
+   if (     disallowed_settings
+         && retroarch_ctl(RARCH_CTL_CORE_OPTIONS_LIST_GET, &coreopts))
    {
       for (i = 0; i < (int)coreopts->size; i++)
       {
@@ -935,12 +951,14 @@ void rcheevos_validate_config_settings(void)
          const char* val = core_option_manager_get_val(coreopts, i);
          if (!rc_libretro_is_setting_allowed(disallowed_settings, key, val))
          {
+            size_t _len;
             char buffer[128];
-            size_t _len = snprintf(buffer, sizeof(buffer),
+            snprintf(buffer, sizeof(buffer),
                      msg_hash_to_str_us(MSG_CHEEVOS_HARDCORE_PAUSED_SETTING_NOT_ALLOWED), key, val);
             CHEEVOS_LOG(RCHEEVOS_TAG "%s\n", buffer);
             _len = snprintf(buffer, sizeof(buffer),
                      msg_hash_to_str(MSG_CHEEVOS_HARDCORE_PAUSED_SETTING_NOT_ALLOWED), key, val);
+            rcheevos_locals.hardcore_requires_reload = true;
             rcheevos_pause_hardcore();
 
             runloop_msg_queue_push(buffer, _len, 0, 4 * 60, false, NULL,
@@ -955,7 +973,8 @@ void rcheevos_validate_config_settings(void)
       console_id = game ? game->console_id : 0;
    }
 
-   if (console_id && !rc_libretro_is_system_allowed(sysinfo->library_name, console_id))
+   if (      console_id
+         && !rc_libretro_is_system_allowed(sysinfo->library_name, console_id))
    {
       char buffer[256];
       size_t _len = snprintf(buffer, sizeof(buffer),
@@ -978,16 +997,12 @@ void rcheevos_test(void)
 #ifdef HAVE_THREADS
    if (rcheevos_locals.queued_command != CMD_EVENT_NONE)
    {
-      if ((int)rcheevos_locals.queued_command != CMD_CHEEVOS_NON_COMMAND)
+      if (rcheevos_locals.queued_command == CMD_CHEEVOS_FINALIZE_LOAD)
+         rcheevos_finalize_game_load_on_ui_thread();
+      else
          command_event(rcheevos_locals.queued_command, NULL);
 
       rcheevos_locals.queued_command = CMD_EVENT_NONE;
-
-      if (rcheevos_locals.game_placard_requested)
-      {
-         rcheevos_locals.game_placard_requested = false;
-         rcheevos_show_game_placard();
-      }
    }
 #endif
 
@@ -1146,32 +1161,24 @@ static void rc_hash_handle_chd_close_track(void* track_handle)
 
 #endif
 
-static void rc_hash_reset_cdreader_hooks(void);
-
 static void* rc_hash_handle_cd_open_track(
-      const char* path, uint32_t track)
+      const char* path, uint32_t track, const rc_hash_iterator_t* iterator)
 {
-   struct rc_hash_filereader filereader;
-   struct rc_hash_cdreader cdreader;
-
-   memset(&filereader, 0, sizeof(filereader));
-   filereader.open = rc_hash_handle_file_open;
-   filereader.seek = rc_hash_handle_file_seek;
-   filereader.tell = rc_hash_handle_file_tell;
-   filereader.read = rc_hash_handle_file_read;
-   filereader.close = rc_hash_handle_file_close;
-   rc_hash_init_custom_filereader(&filereader);
+   rc_hash_callbacks_t* callbacks = (rc_hash_callbacks_t*)&iterator->callbacks;
+   callbacks->filereader.open = rc_hash_handle_file_open;
+   callbacks->filereader.seek = rc_hash_handle_file_seek;
+   callbacks->filereader.tell = rc_hash_handle_file_tell;
+   callbacks->filereader.read = rc_hash_handle_file_read;
+   callbacks->filereader.close = rc_hash_handle_file_close;
 
    if (string_is_equal_noncase(path_get_extension(path), "chd"))
    {
 #ifdef HAVE_CHD
       /* special handlers for CHD file */
-      memset(&cdreader, 0, sizeof(cdreader));
-      cdreader.open_track = rc_hash_handle_cd_open_track;
-      cdreader.read_sector = rc_hash_handle_chd_read_sector;
-      cdreader.close_track = rc_hash_handle_chd_close_track;
-      cdreader.first_track_sector = rc_hash_handle_chd_first_track_sector;
-      rc_hash_init_custom_cdreader(&cdreader);
+      callbacks->cdreader.open_track_iterator = rc_hash_handle_cd_open_track;
+      callbacks->cdreader.read_sector = rc_hash_handle_chd_read_sector;
+      callbacks->cdreader.close_track = rc_hash_handle_chd_close_track;
+      callbacks->cdreader.first_track_sector = rc_hash_handle_chd_first_track_sector;
 
       return rc_hash_handle_chd_open_track(path, track);
 #else
@@ -1182,9 +1189,9 @@ static void* rc_hash_handle_cd_open_track(
    else
    {
       /* not a CHD file, use the default handlers */
+      struct rc_hash_cdreader cdreader;
       rc_hash_get_default_cdreader(&cdreader);
-      rc_hash_reset_cdreader_hooks();
-      return cdreader.open_track(path, track);
+      return cdreader.open_track_iterator(path, track, iterator);
    }
 }
 
@@ -1192,7 +1199,7 @@ static void rc_hash_reset_cdreader_hooks(void)
 {
    struct rc_hash_cdreader cdreader;
    rc_hash_get_default_cdreader(&cdreader);
-   cdreader.open_track = rc_hash_handle_cd_open_track;
+   cdreader.open_track_iterator = rc_hash_handle_cd_open_track;
    rc_hash_init_custom_cdreader(&cdreader);
 }
 
@@ -1203,7 +1210,8 @@ static void rcheevos_show_game_placard(void)
    size_t _len;
    char msg[256];
    rc_client_user_game_summary_t summary;
-   const settings_t* settings   = config_get_ptr();
+   const settings_t* settings          = config_get_ptr();
+   unsigned cheevos_visibility_summary = settings->uints.cheevos_visibility_summary;
    const rc_client_game_t* game = rc_client_get_game_info(rcheevos_locals.client);
    if (!game) /* Make sure there's actually a game loaded */
       return;
@@ -1213,7 +1221,8 @@ static void rcheevos_show_game_placard(void)
    if (summary.num_core_achievements == 0)
    {
       if (summary.num_unofficial_achievements == 0)
-         _len = snprintf(msg, sizeof(msg), "%s", msg_hash_to_str(MSG_CHEEVOS_GAME_HAS_NO_ACHIEVEMENTS));
+         _len = strlcpy(msg, msg_hash_to_str(MSG_CHEEVOS_GAME_HAS_NO_ACHIEVEMENTS),
+               sizeof(msg));
       else
          _len = snprintf(msg, sizeof(msg),
                         msg_hash_to_str(MSG_CHEEVOS_UNOFFICIAL_ACHIEVEMENTS_ACTIVATED),
@@ -1251,8 +1260,8 @@ static void rcheevos_show_game_placard(void)
    msg[sizeof(msg) - 1] = 0;
    CHEEVOS_LOG(RCHEEVOS_TAG "%s\n", msg);
 
-   if (   settings->uints.cheevos_visibility_summary == RCHEEVOS_SUMMARY_ALLGAMES
-      || (settings->uints.cheevos_visibility_summary == RCHEEVOS_SUMMARY_HASCHEEVOS
+   if (   cheevos_visibility_summary == RCHEEVOS_SUMMARY_ALLGAMES
+      || (cheevos_visibility_summary == RCHEEVOS_SUMMARY_HASCHEEVOS
       && (summary.num_core_achievements || summary.num_unofficial_achievements)))
    {
 #if defined (HAVE_GFX_WIDGETS)
@@ -1260,7 +1269,7 @@ static void rcheevos_show_game_placard(void)
       {
          char badge_name[32];
          size_t __len = strlcpy(badge_name, "i", sizeof(badge_name));
-         __len       += strlcpy(badge_name + __len, game->badge_name,
+         strlcpy(badge_name + __len, game->badge_name,
                sizeof(badge_name) - __len);
          gfx_widgets_push_achievement(game->title, msg, badge_name);
       }
@@ -1269,6 +1278,13 @@ static void rcheevos_show_game_placard(void)
          runloop_msg_queue_push(msg, _len, 0, 3 * 60, false, NULL,
                MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
    }
+
+   if (summary.num_unsupported_achievements)
+   {
+      const char* warning = msg_hash_to_str(MSG_CHEEVOS_UNSUPPORTED_WARNING);
+      runloop_msg_queue_push(warning, strlen(warning), 0, 3 * 60, false, NULL,
+         MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_WARNING);
+   }
 }
 
 static uint32_t rcheevos_client_read_memory(uint32_t address,
@@ -1328,13 +1344,28 @@ static void rcheevos_client_login_callback(int result,
 
    if (result != RC_OK)
    {
+      settings_t* settings = config_get_ptr();
       char msg[256];
       size_t _len = strlcpy(msg, "RetroAchievements login failed: ",
             sizeof(msg));
       _len += strlcpy(msg + _len, error_message, sizeof(msg) - _len);
       CHEEVOS_LOG(RCHEEVOS_TAG "%s\n", msg);
+
+      if (result == RC_EXPIRED_TOKEN || /* token expired */
+          (result == RC_INVALID_CREDENTIALS && settings->arrays.cheevos_token[0])) /* token invalid */
+      {
+         /* expired token, clear it out */
+         settings->arrays.cheevos_token[0] = '\0';
+
+         /* the server message says to log in again. RetroArch doesn't really
+            have a login form, so use a custom message (that's translated) to
+            tell them to re-enter their password and restart the game. */
+         _len = strlcpy(msg, msg_hash_to_str(MSG_CHEEVOS_LOGIN_TOKEN_EXPIRED),
+               sizeof(msg));
+      }
+
       runloop_msg_queue_push(msg, _len, 0, 2 * 60, false, NULL,
-         MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+            MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_ERROR);
       return;
    }
 
@@ -1346,7 +1377,6 @@ static void rcheevos_client_login_callback(int result,
    else
    {
       settings_t* settings = config_get_ptr();
-
       if (user->token[0])
       {
          /* store the token, clear the password */
@@ -1373,7 +1403,16 @@ static void rcheevos_client_login_callback(int result,
 
 static void rcheevos_finalize_game_load(rc_client_t* client)
 {
-   rcheevos_client_download_achievement_badges(client);
+   settings_t* settings = config_get_ptr();
+   bool want_badges     = settings->bools.cheevos_badges_enable;
+#if !defined(HAVE_GFX_WIDGETS)
+   /* Then badges are only needed for xmb and ozone menus */
+   want_badges          = want_badges &&
+      (        string_is_equal(settings->arrays.menu_driver, "xmb")
+            || string_is_equal(settings->arrays.menu_driver, "ozone"));
+#endif
+   if (want_badges)
+         rcheevos_client_download_achievement_badges(client);
 
    if (!rc_client_is_processing_required(client))
    {
@@ -1382,12 +1421,31 @@ static void rcheevos_finalize_game_load(rc_client_t* client)
    }
 }
 
+static void rcheevos_finalize_game_load_on_ui_thread(void)
+{
+   rcheevos_show_game_placard();
+
+#if HAVE_REWIND
+   if (!rcheevos_hardcore_active())
+   {
+      /* Re-enable rewind. Additional space will be
+       * allocated for the achievement state data */
+      if (config_get_ptr()->bools.rewind_enable)
+         command_event(CMD_EVENT_REWIND_REINIT, NULL);
+   }
+#endif
+
+#ifdef HAVE_NETWORKING
+   netplay_reinit_serialization();
+#endif
+}
+
 static void rcheevos_client_load_game_callback(int result,
    const char* error_message, rc_client_t* client, void* userdata)
 {
-   const settings_t* settings = config_get_ptr();
-   const rc_client_game_t* game = rc_client_get_game_info(client);
    char msg[256];
+   const settings_t *settings   = config_get_ptr();
+   const rc_client_game_t *game = rc_client_get_game_info(client);
 
 #if defined(HAVE_GFX_WIDGETS)
    gfx_widget_set_cheevos_set_loading(false);
@@ -1405,18 +1463,29 @@ static void rcheevos_client_load_game_callback(int result,
             return;
 
          _len = strlcpy(msg, msg_hash_to_str(MSG_CHEEVOS_GAME_NOT_IDENTIFIED), sizeof(msg));
+
+         runloop_msg_queue_push(msg, _len, 0, 2 * 60, false, NULL,
+            MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
       }
       else
       {
          if (!error_message)
             error_message = "Unknown error";
 
-         _len = snprintf(msg, sizeof(msg), msg_hash_to_str(MSG_CHEEVOS_GAME_LOAD_FAILED), error_message);
          CHEEVOS_LOG(RCHEEVOS_TAG "Game load failed: %s\n", error_message);
+
+         if (result == RC_LOGIN_REQUIRED)
+         {
+            /* assume error already reported by rcheevos_client_login_callback */
+         }
+         else
+         {
+            _len = snprintf(msg, sizeof(msg), msg_hash_to_str(MSG_CHEEVOS_GAME_LOAD_FAILED), error_message);
+            runloop_msg_queue_push(msg, _len, 0, 2 * 60, false, NULL,
+               MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_ERROR);
+         }
       }
 
-      runloop_msg_queue_push(msg, _len, 0, 2 * 60, false, NULL,
-         MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
       return;
    }
 
@@ -1431,7 +1500,8 @@ static void rcheevos_client_load_game_callback(int result,
 
          if (settings && settings->bools.cheevos_verbose_enable)
          {
-            const char *_msg = msg_hash_to_str(MENU_ENUM_LABEL_VALUE_CANNOT_ACTIVATE_ACHIEVEMENTS_WITH_THIS_CORE);
+            const char *_msg = msg_hash_to_str(
+                  MENU_ENUM_LABEL_VALUE_CANNOT_ACTIVATE_ACHIEVEMENTS_WITH_THIS_CORE);
             runloop_msg_queue_push(_msg, strlen(_msg),
                   0, 4 * 60, false, NULL,
                   MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_WARNING);
@@ -1446,47 +1516,26 @@ static void rcheevos_client_load_game_callback(int result,
       rc_client_set_read_memory_function(client, rcheevos_client_read_memory);
    }
 
-#ifdef HAVE_THREADS
-   if (!video_driver_is_threaded() && !task_is_on_main_thread())
-   {
-      /* have to "schedule" this. game image should not be loaded on background thread */
-      rcheevos_locals.queued_command = CMD_CHEEVOS_NON_COMMAND;
-      rcheevos_locals.game_placard_requested = true;
-   }
-   else
-#endif
-      rcheevos_show_game_placard();
-
    rcheevos_finalize_game_load(client);
 
+   /* Hardcore is active. we're going to start processing
+    * achievements. make sure restrictions are enforced */
    if (rcheevos_hardcore_active())
    {
-      /* hardcore is active. we're going to start processing
-       * achievements. make sure restrictions are enforced */
       rcheevos_validate_config_settings();
       rcheevos_enforce_hardcore_settings();
    }
-   else
-   {
-#if HAVE_REWIND
-      /* Re-enable rewind. Additional space will be allocated for the achievement state data */
-      if (settings->bools.rewind_enable)
-      {
-#ifdef HAVE_THREADS
-         if (!task_is_on_main_thread())
-         {
-            /* Have to "schedule" this. CMD_EVENT_REWIND_REINIT should
-             * only be called on the main thread */
-            rcheevos_locals.queued_command = CMD_EVENT_REWIND_REINIT;
-         }
-         else
-#endif
-            command_event(CMD_EVENT_REWIND_REINIT, NULL);
-      }
-#endif
-   }
 
    rcheevos_spectating_changed(); /* synchronize spectating state */
+
+#ifdef HAVE_THREADS
+   /* Have to "schedule" this. Game image should not be
+    * loaded into memory on background thread */
+   if (!task_is_on_main_thread())
+      rcheevos_locals.queued_command = (enum event_command)CMD_CHEEVOS_FINALIZE_LOAD;
+   else
+#endif
+      rcheevos_finalize_game_load_on_ui_thread();
 }
 
 static rc_clock_t rcheevos_client_get_time_millisecs(const rc_client_t* client)
@@ -1494,8 +1543,6 @@ static rc_clock_t rcheevos_client_get_time_millisecs(const rc_client_t* client)
    return cpu_features_get_time_usec() / 1000;
 }
 
-
-
 bool rcheevos_load(const void *data)
 {
    const struct retro_game_info *info = (const struct retro_game_info*)data;
@@ -1533,9 +1580,7 @@ bool rcheevos_load(const void *data)
       sizeof(rcheevos_locals.user_agent_core));
 
    if (rcheevos_locals.client)
-   {
       rc_client_unload_game(rcheevos_locals.client);
-   }
    else
    {
       rcheevos_locals.client = rc_client_create(rcheevos_client_read_memory, rcheevos_client_server_call);
@@ -1566,6 +1611,7 @@ bool rcheevos_load(const void *data)
    rc_client_set_spectator_mode_enabled(rcheevos_locals.client, !rcheevos_is_player_active());
    rc_client_set_read_memory_function(rcheevos_locals.client, rcheevos_client_read_memory_uninitialized);
 
+   rcheevos_locals.hardcore_requires_reload = false;
    rcheevos_validate_config_settings();
 
    CHEEVOS_LOG(RCHEEVOS_TAG "Load started, hardcore %sactive\n", rcheevos_hardcore_active() ? "" : "not ");
@@ -1574,23 +1620,17 @@ bool rcheevos_load(const void *data)
    {
       /* user not logged in, do so now */
       if (settings->arrays.cheevos_token[0])
-      {
          rc_client_begin_login_with_token(rcheevos_locals.client,
             settings->arrays.cheevos_username, settings->arrays.cheevos_token,
             rcheevos_client_login_callback, NULL);
-      }
       else
-      {
          rc_client_begin_login_with_password(rcheevos_locals.client,
             settings->arrays.cheevos_username, settings->arrays.cheevos_password,
             rcheevos_client_login_callback, NULL);
-      }
    }
 
    if (rcheevos_hardcore_active())
-   {
       rcheevos_enforce_hardcore_settings();
-   }
 
    /* provide hooks for reading files */
    rc_hash_reset_cdreader_hooks();
@@ -1600,10 +1640,33 @@ bool rcheevos_load(const void *data)
       gfx_widget_set_cheevos_set_loading(true);
 #endif
 
-   rc_client_begin_identify_and_load_game(rcheevos_locals.client, RC_CONSOLE_UNKNOWN,
-      info->path, (const uint8_t*)info->data, info->size, rcheevos_client_load_game_callback, NULL);
+   /* Detect RVZ files and determine console type (GameCube or Wii) */
+   {
+      uint32_t console_id = RC_CONSOLE_UNKNOWN;
 
+#ifdef HAVE_CHEEVOS_RVZ
+      if (string_is_equal_noncase(path_get_extension(info->path), "rvz"))
+      {
+         console_id = rcheevos_rvz_get_console_id(info->path);
 
+         /* Only register custom file reader for valid RVZ files */
+         if (console_id != RC_CONSOLE_UNKNOWN)
+         {
+            struct rc_hash_filereader filereader;
+
+            filereader.open  = rcheevos_rvz_open;
+            filereader.seek  = rcheevos_rvz_seek;
+            filereader.tell  = rcheevos_rvz_tell;
+            filereader.read  = rcheevos_rvz_read;
+            filereader.close = rcheevos_rvz_close;
+            rc_hash_init_custom_filereader(&filereader);
+         }
+      }
+#endif
+
+      rc_client_begin_identify_and_load_game(rcheevos_locals.client, console_id,
+         info->path, (const uint8_t*)info->data, info->size, rcheevos_client_load_game_callback, NULL);
+   }
 
    return true;
 }
@@ -1639,7 +1702,7 @@ void rcheevos_change_disc(const char* new_disc_path, bool initial_disc)
 {
    if (rcheevos_locals.client)
    {
-      rc_client_begin_change_media(rcheevos_locals.client, new_disc_path,
+      rc_client_begin_identify_and_change_media(rcheevos_locals.client, new_disc_path,
          NULL, 0, rcheevos_client_change_media_callback, NULL);
    }
 }
