@@ -42,7 +42,7 @@ RETRO_BEGIN_DECLS
 /* Define this macro to get extra-verbose log for cheevos. */
 #define CHEEVOS_VERBOSE
 
-#define RCHEEVOS_TAG "[RCHEEVOS]: "
+#define RCHEEVOS_TAG "[RCHEEVOS] "
 #define CHEEVOS_FREE(p) do { void* q = (void*)p; if (q) free(q); } while (0)
 
 #ifdef CHEEVOS_VERBOSE
@@ -70,7 +70,7 @@ enum rcheevos_summary_notif
 
 typedef struct rcheevos_menuitem_t
 {
-   rc_client_achievement_t* achievement;
+   const rc_client_achievement_t* achievement;
    uintptr_t menu_badge_texture;
    uint32_t subset_id;
    uint8_t menu_badge_grayscale;
@@ -86,7 +86,6 @@ typedef struct rcheevos_locals_t
 
 #ifdef HAVE_THREADS
    enum event_command queued_command; /* action queued by background thread to be run on main thread */
-   bool game_placard_requested;       /* request to display game placard */
 #endif
 
    char user_agent_prefix[128];       /* RetroArch/OS version information */
@@ -99,6 +98,7 @@ typedef struct rcheevos_locals_t
 #endif
 
    bool hardcore_allowed;             /* prevents enabling hardcore if illegal settings detected */
+   bool hardcore_requires_reload;     /* prevents enabling hardcore until the core is reloaded */
    bool hardcore_being_enabled;       /* allows callers to detect hardcore mode while it's being enabled */
 
    bool core_supports;                /* false if core explicitly disables achievements */
