@@ -45,55 +45,49 @@
 
 #if HAVE_MENU
 
-bool rcheevos_menu_get_state(unsigned menu_offset, char* buffer, size_t buffer_size)
+size_t rcheevos_menu_get_state(unsigned menu_offset, char *s, size_t len)
 {
    const rcheevos_locals_t* rcheevos_locals = get_rcheevos_locals();
    if (menu_offset < rcheevos_locals->menuitem_count)
    {
-      const rcheevos_menuitem_t* menuitem = &rcheevos_locals->menuitems[menu_offset];
+      const rcheevos_menuitem_t* menuitem   = &rcheevos_locals->menuitems[menu_offset];
       const rc_client_achievement_t* cheevo = menuitem->achievement;
       if (cheevo)
       {
+         size_t _len;
          if (cheevo->state != RC_CLIENT_ACHIEVEMENT_STATE_ACTIVE)
-            strlcpy(buffer, msg_hash_to_str(menuitem->state_label_idx), buffer_size);
+            _len = strlcpy(s, msg_hash_to_str(menuitem->state_label_idx), len);
          else
          {
-            const char* missable = cheevo->type == RC_CLIENT_ACHIEVEMENT_TYPE_MISSABLE ? "[m] " : "";
-            size_t _len = strlcpy(buffer, missable, buffer_size);
-            _len += strlcpy(buffer + _len, msg_hash_to_str(menuitem->state_label_idx), buffer_size - _len);
+            const char* missable = (cheevo->type == RC_CLIENT_ACHIEVEMENT_TYPE_MISSABLE) ? "[m] " : "";
+            _len  = strlcpy(s, missable, len);
+            _len += strlcpy(s + _len, msg_hash_to_str(menuitem->state_label_idx), len - _len);
             if (cheevo->measured_progress[0])
             {
-               _len += strlcpy(buffer + _len, " - ", buffer_size - _len);
-               strlcpy(buffer + _len, cheevo->measured_progress, buffer_size - _len);
+               _len += strlcpy(s + _len, " - ", len - _len);
+               _len += strlcpy(s + _len, cheevo->measured_progress, len - _len);
             }
          }
-         return true;
+         return _len;
       }
    }
-
-   if (buffer)
-      buffer[0] = '\0';
-
-   return false;
+   if (s)
+      s[0] = '\0';
+   return 0;
 }
 
-bool rcheevos_menu_get_sublabel(unsigned menu_offset, char* buffer, size_t buffer_size)
+size_t rcheevos_menu_get_sublabel(unsigned menu_offset, char *s, size_t len)
 {
    const rcheevos_locals_t* rcheevos_locals = get_rcheevos_locals();
-   if (menu_offset < rcheevos_locals->menuitem_count && buffer)
+   if (menu_offset < rcheevos_locals->menuitem_count && s)
    {
       const rcheevos_menuitem_t* menuitem = &rcheevos_locals->menuitems[menu_offset];
       if (menuitem->achievement)
-      {
-         strlcpy(buffer, menuitem->achievement->description, buffer_size);
-         return true;
-      }
+         return strlcpy(s, menuitem->achievement->description, len);
    }
-
-   if (buffer)
-      buffer[0] = '\0';
-
-   return false;
+   if (s)
+      s[0] = '\0';
+   return 0;
 }
 
 void rcheevos_menu_reset_badges(void)
@@ -250,12 +244,10 @@ uintptr_t rcheevos_menu_get_badge_texture(unsigned menu_offset)
    return 0;
 }
 
-void rcheevos_menu_populate_hardcore_pause_submenu(void* data)
+void rcheevos_menu_populate_hardcore_pause_submenu(void* data, bool cheevos_hardcore_mode_enable)
 {
    const rcheevos_locals_t* rcheevos_locals = get_rcheevos_locals();
-   menu_displaylist_info_t* info = (menu_displaylist_info_t*)data;
-   const settings_t* settings = config_get_ptr();
-   const bool cheevos_hardcore_mode_enable = settings->bools.cheevos_hardcore_mode_enable;
+   menu_displaylist_info_t* info            = (menu_displaylist_info_t*)data;
 
    if (cheevos_hardcore_mode_enable && rc_client_get_game_info(rcheevos_locals->client))
    {
@@ -272,6 +264,14 @@ void rcheevos_menu_populate_hardcore_pause_submenu(void* data)
             MENU_ENUM_LABEL_ACHIEVEMENT_PAUSE,
             MENU_SETTING_ACTION_PAUSE_ACHIEVEMENTS, 0, 0, NULL);
       }
+      else if (rcheevos_locals->hardcore_requires_reload)
+      {
+         menu_entries_append(info->list,
+            msg_hash_to_str(MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_RESUME_REQUIRES_RELOAD),
+            msg_hash_to_str(MENU_ENUM_LABEL_ACHIEVEMENT_RESUME_REQUIRES_RELOAD),
+            MENU_ENUM_LABEL_ACHIEVEMENT_RESUME_REQUIRES_RELOAD,
+            MENU_SETTING_ACTION_CLOSE, 0, 0, NULL);
+      }
       else
       {
          menu_entries_append(info->list,
@@ -288,12 +288,12 @@ void rcheevos_menu_populate_hardcore_pause_submenu(void* data)
    }
 }
 
-void rcheevos_menu_populate(void* data)
+void rcheevos_menu_populate(void* data, bool cheevos_enable,
+      bool cheevos_hardcore_mode_enable)
 {
    menu_displaylist_info_t* info = (menu_displaylist_info_t*)data;
    rcheevos_locals_t* rcheevos_locals = get_rcheevos_locals();
    const rc_client_game_t* game = rc_client_get_game_info(rcheevos_locals->client);
-   const settings_t* settings = config_get_ptr();
 
    rc_client_achievement_list_t* list = rc_client_create_achievement_list(rcheevos_locals->client,
       RC_CLIENT_ACHIEVEMENT_CATEGORY_CORE_AND_UNOFFICIAL,
@@ -303,7 +303,7 @@ void rcheevos_menu_populate(void* data)
    rcheevos_menu_reset_badges();
    rcheevos_locals->menuitem_count = 0;
 
-   if (rcheevos_locals->client->state.disconnect)
+   if (rcheevos_locals->client && rcheevos_locals->client->state.disconnect)
    {
       menu_entries_append(info->list,
          msg_hash_to_str(MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_SERVER_UNREACHABLE),
@@ -314,8 +314,10 @@ void rcheevos_menu_populate(void* data)
 
    if (game && game->id != 0)
    {
-      /* first menu item is the Pause/Resume Hardcore option (unless hardcore is completely disabled) */
-      if (settings->bools.cheevos_enable && settings->bools.cheevos_hardcore_mode_enable)
+      /* First menu item is the Pause/Resume Hardcore option
+       * (unless hardcore is completely disabled) */
+      if (     cheevos_enable
+            && cheevos_hardcore_mode_enable)
       {
          if (rc_client_get_hardcore_enabled(rcheevos_locals->client))
             menu_entries_append(info->list,
@@ -516,6 +518,47 @@ void rcheevos_menu_populate(void* data)
 
 #endif /* HAVE_MENU */
 
+static void rcheevos_client_download_achievement_badge(const char* badge_name, bool locked)
+{
+   /* have to find the achievement associated to badge_name, then fetch either badge_url
+    * or badge_locked_url based on the locked parameter */
+   rcheevos_locals_t* rcheevos_locals = get_rcheevos_locals();
+   rc_client_achievement_list_t* list = rc_client_create_achievement_list(rcheevos_locals->client,
+      RC_CLIENT_ACHIEVEMENT_CATEGORY_CORE_AND_UNOFFICIAL,
+      RC_CLIENT_ACHIEVEMENT_LIST_GROUPING_PROGRESS);
+   if (list)
+   {
+      const char* url = NULL;
+      uint32_t i, j;
+      for (i = 0; i < list->num_buckets && !url; i++)
+      {
+         for (j = 0; j < list->buckets[i].num_achievements; j++)
+         {
+            const rc_client_achievement_t* achievement = list->buckets[i].achievements[j];
+            if (achievement && strcmp(achievement->badge_name, badge_name) == 0)
+            {
+               url = locked ? achievement->badge_locked_url : achievement->badge_url;
+               break;
+            }
+         }
+      }
+
+      if (url)
+      {
+         char locked_badge_name[32];
+         if (locked)
+         {
+            snprintf(locked_badge_name, sizeof(locked_badge_name), "%s_lock", badge_name);
+            badge_name = locked_badge_name;
+         }
+
+         rcheevos_client_download_badge_from_url(url, badge_name);
+      }
+
+      rc_client_destroy_achievement_list(list);
+   }
+}
+
 uintptr_t rcheevos_get_badge_texture(const char* badge, bool locked, bool download_if_missing)
 {
    size_t _len;
@@ -548,21 +591,13 @@ uintptr_t rcheevos_get_badge_texture(const char* badge, bool locked, bool downlo
    {
       if (download_if_missing)
       {
+         const rcheevos_locals_t* rcheevos_locals = get_rcheevos_locals();
+
          if (badge[0] == 'i')
          {
-            /* rcheevos_client_download_game_badge expects a rc_client_game_t, not the badge name.
-             * call rc_api_init_fetch_image_request directly */
-            rc_api_fetch_image_request_t image_request;
-            rc_api_request_t request;
-            int result;
-
-            memset(&image_request, 0, sizeof(image_request));
-            image_request.image_type = RC_IMAGE_TYPE_GAME;
-            image_request.image_name = &badge[1];
-            result = rc_api_init_fetch_image_request(&request, &image_request);
-
-            if (result == RC_OK)
-               rcheevos_client_download_badge_from_url(request.url, badge);
+            const rc_client_game_t* game = rc_client_get_game_info(rcheevos_locals->client);
+            if (game && strcmp(game->badge_name, &badge[1]) == 0)
+               rcheevos_client_download_badge_from_url(game->badge_url, badge);
          }
          else
          {
