@@ -24,6 +24,7 @@
 #include <boolean.h>
 #include <retro_common_api.h>
 #include <retro_miscellaneous.h>
+#include <file/config_file.h>
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -88,6 +89,13 @@ enum override_type
    OVERRIDE_GAME
 };
 
+enum cloud_sync_mode_type
+{
+   CLOUD_SYNC_MODE_AUTOMATIC = 0,
+   CLOUD_SYNC_MODE_MANUAL,
+   CLOUD_SYNC_MODE_LAST
+};
+
 enum settings_glob_flags
 {
    SETTINGS_FLG_MODIFIED              = (1 << 0),
@@ -114,6 +122,8 @@ typedef struct settings
       int replay_slot;
       int crt_switch_center_adjust;
       int crt_switch_porch_adjust;
+      int crt_switch_vertical_adjust;
+      int video_max_frame_latency;
 #ifdef HAVE_VULKAN
       int vulkan_gpu_index;
 #endif
@@ -144,6 +154,7 @@ typedef struct settings
 #ifdef HAVE_OVERLAY
       int input_overlay_lightgun_port;
 #endif
+      int input_turbo_bind;
    } ints;
 
    struct
@@ -194,7 +205,7 @@ typedef struct settings
       unsigned input_turbo_period;
       unsigned input_turbo_duty_cycle;
       unsigned input_turbo_mode;
-      unsigned input_turbo_default_button;
+      unsigned input_turbo_button;
 
       unsigned input_bind_timeout;
       unsigned input_bind_hold;
@@ -234,6 +245,7 @@ typedef struct settings
       unsigned network_cmd_port;
       unsigned network_remote_base_port;
       unsigned keymapper_port;
+      unsigned cloud_sync_sync_mode;
       unsigned video_window_opacity;
       unsigned crt_switch_resolution;
       unsigned crt_switch_resolution_super;
@@ -245,7 +257,6 @@ typedef struct settings
       unsigned video_scale_integer_axis;
       unsigned video_scale_integer_scaling;
       unsigned video_max_swapchain_images;
-      unsigned video_max_frame_latency;
       unsigned video_swap_interval;
       unsigned video_hard_sync_frames;
       unsigned video_frame_delay;
@@ -303,6 +314,8 @@ typedef struct settings
       unsigned menu_materialui_thumbnail_view_landscape;
       unsigned menu_materialui_landscape_layout_optimization;
       unsigned menu_ozone_color_theme;
+      unsigned menu_ozone_header_separator;
+      unsigned menu_ozone_font_scale;
       unsigned menu_font_color_red;
       unsigned menu_font_color_green;
       unsigned menu_font_color_blue;
@@ -317,6 +330,7 @@ typedef struct settings
       unsigned menu_screensaver_timeout;
       unsigned menu_screensaver_animation;
       unsigned menu_remember_selection;
+      unsigned menu_startup_page;
 
       unsigned playlist_entry_remove_enable;
       unsigned playlist_show_inline_core_name;
@@ -415,7 +429,15 @@ typedef struct settings
       float menu_ticker_speed;
       float menu_rgui_particle_effect_speed;
       float menu_screensaver_animation_speed;
+      float ozone_padding_factor;
       float ozone_thumbnail_scale_factor;
+      float ozone_font_scale_factor_global;
+      float ozone_font_scale_factor_title;
+      float ozone_font_scale_factor_sidebar;
+      float ozone_font_scale_factor_label;
+      float ozone_font_scale_factor_sublabel;
+      float ozone_font_scale_factor_time;
+      float ozone_font_scale_factor_footer;
 
       float cheevos_appearance_padding_h;
       float cheevos_appearance_padding_v;
@@ -449,6 +471,8 @@ typedef struct settings
       float input_analog_deadzone;
       float input_axis_threshold;
       float input_analog_sensitivity;
+      float input_sensor_accelerometer_sensitivity;
+      float input_sensor_gyroscope_sensitivity;
 #ifdef _3DS
       float bottom_font_scale;
 #endif
@@ -574,6 +598,7 @@ typedef struct settings
       char bundle_assets_src[PATH_MAX_LENGTH];
       char bundle_assets_dst[PATH_MAX_LENGTH];
       char path_menu_xmb_font[PATH_MAX_LENGTH];
+      char path_menu_ozone_font[PATH_MAX_LENGTH];
       char path_cheat_database[PATH_MAX_LENGTH];
       char path_content_database[PATH_MAX_LENGTH];
       char path_overlay[PATH_MAX_LENGTH];
@@ -646,6 +671,7 @@ typedef struct settings
       bool video_notch_write_over_enable;
       bool video_hdr_enable;
       bool video_hdr_expand_gamut;
+      bool video_use_metal_arg_buffers;
 
       /* Accessibility */
       bool accessibility_enable;
@@ -662,6 +688,7 @@ typedef struct settings
       bool audio_rate_control;
       bool audio_fastforward_mute;
       bool audio_fastforward_speedup;
+      bool audio_rewind_mute;
 #ifdef IOS
       bool audio_respect_silent_mode;
 #endif
@@ -702,6 +729,8 @@ typedef struct settings
       bool input_descriptor_label_show;
       bool input_descriptor_hide_unbound;
       bool input_all_users_control_menu;
+      bool input_menu_singleclick_playlists;
+      bool input_menu_allow_tabs_back;
       bool input_menu_swap_ok_cancel_buttons;
       bool input_menu_swap_scroll_buttons;
       bool input_backtouch_enable;
@@ -709,8 +738,10 @@ typedef struct settings
       bool input_small_keyboard_enable;
       bool input_keyboard_gamepad_enable;
       bool input_auto_mouse_grab;
-      bool input_allow_turbo_dpad;
+      bool input_turbo_enable;
+      bool input_turbo_allow_dpad;
       bool input_hotkey_device_merge;
+      bool input_hotkey_follows_player1;
 #if defined(HAVE_DINPUT) || defined(HAVE_WINRAWINPUT)
       bool input_nowinkey_enable;
 #endif
@@ -728,10 +759,10 @@ typedef struct settings
       bool frame_time_counter_reset_after_save_state;
 
       /* Menu */
-      bool filter_by_current_core;
       bool menu_enable_widgets;
       bool menu_show_load_content_animation;
       bool notification_show_autoconfig;
+      bool notification_show_autoconfig_fails;
       bool notification_show_cheats_applied;
       bool notification_show_patch_applied;
       bool notification_show_remap_load;
@@ -799,6 +830,7 @@ typedef struct settings
       bool menu_materialui_auto_rotate_nav_bar;
       bool menu_materialui_dual_thumbnail_list_view_enable;
       bool menu_materialui_thumbnail_background_enable;
+      bool menu_thumbnail_background_enable;
       bool menu_rgui_background_filler_thickness_enable;
       bool menu_rgui_border_filler_thickness_enable;
       bool menu_rgui_border_filler_enable;
@@ -816,13 +848,14 @@ typedef struct settings
       bool menu_xmb_vertical_thumbnails;
       bool menu_content_show_settings;
       bool menu_content_show_favorites;
+      bool menu_content_show_favorites_first;
       bool menu_content_show_images;
       bool menu_content_show_music;
       bool menu_content_show_video;
       bool menu_content_show_netplay;
       bool menu_content_show_history;
-      bool menu_content_show_add;
       bool menu_content_show_playlists;
+      bool menu_content_show_playlist_tabs;
       bool menu_content_show_explore;
       bool menu_use_preferred_system_color_theme;
       bool menu_preferred_system_color_theme_set;
@@ -832,6 +865,7 @@ typedef struct settings
       bool menu_disable_left_analog;
       bool menu_disable_right_analog;
       bool menu_ticker_smooth;
+      bool menu_ignore_missing_assets;
       bool settings_show_drivers;
       bool settings_show_video;
       bool settings_show_audio;
@@ -1030,8 +1064,11 @@ typedef struct settings
       bool sort_screenshots_by_content_enable;
       bool config_save_on_exit;
       bool remap_save_on_exit;
+
       bool show_hidden_files;
+      bool filter_by_current_core;
       bool use_last_start_directory;
+      bool core_suggest_always;
 
       bool savefiles_in_content_dir;
       bool savestates_in_content_dir;
@@ -1083,6 +1120,10 @@ typedef struct settings
       bool ai_service_pause;
 
       bool gamemode_enable;
+#ifdef HAVE_BSV_MOVIE
+      bool replay_checkpoint_deserialize;
+#endif
+
 #ifdef _3DS
       bool new3ds_speedup_enable;
       bool bottom_font_enable;
@@ -1095,6 +1136,14 @@ typedef struct settings
 #if defined(HAVE_COCOATOUCH)
       bool gcdwebserver_alert;
 #endif
+
+#ifdef HAVE_GAME_AI
+      bool quick_menu_show_game_ai;
+      bool game_ai_override_p1;
+      bool game_ai_override_p2;
+      bool game_ai_show_debug;
+#endif
+
    } bools;
 
    uint8_t flags;
@@ -1261,8 +1310,7 @@ bool config_load_remap(const char *directory_input_remapping,
  **/
 
 void config_get_autoconf_profile_filename(
-      const char *device_name, unsigned user,
-      char *buf, size_t len_buf);
+      const char *device_name, unsigned user, char *s, size_t len);
 /**
  * config_save_autoconf_profile:
  * @device_name       : Input device name
@@ -1296,6 +1344,8 @@ int8_t config_save_overrides(enum override_type type,
  * another one. Will load a dummy core to flush state
  * properly. */
 bool config_replace(bool config_save_on_exit, char *path);
+
+config_file_t *open_default_config_file(void);
 #endif
 
 bool config_overlay_enable_default(void);
