@@ -100,11 +100,11 @@ static core_info_state_t core_info_st = {
 /* JSON Handlers START */
 
 static bool CCJSONObjectMemberHandler(void *context,
-      const char *pValue, size_t length)
+      const char *pValue, size_t len)
 {
    CCJSONContext *pCtx = (CCJSONContext *)context;
 
-   if (length)
+   if (len)
    {
       switch (pCtx->array_depth)
       {
@@ -262,12 +262,12 @@ static bool CCJSONObjectMemberHandler(void *context,
 }
 
 static bool CCJSONStringHandler(void *context,
-      const char *pValue, size_t length)
+      const char *pValue, size_t len)
 {
    CCJSONContext *pCtx = (CCJSONContext*)context;
 
    if (     pCtx->current_string_val
-         && length
+         && len
          && !string_is_empty(pValue))
    {
       if (*pCtx->current_string_val)
@@ -290,7 +290,7 @@ static bool CCJSONStringHandler(void *context,
 }
 
 static bool CCJSONNumberHandler(void *context,
-      const char *pValue, size_t length)
+      const char *pValue, size_t len)
 {
    CCJSONContext *pCtx              = (CCJSONContext*)context;
 
@@ -602,18 +602,20 @@ static void core_info_cache_list_free(
    if (!core_info_cache_list)
       return;
 
-   for (i = 0; i < core_info_cache_list->length; i++)
+   if (core_info_cache_list->items)
    {
-      core_info_t* info = (core_info_t*)&core_info_cache_list->items[i];
-      core_info_free(info);
+      for (i = 0; i < core_info_cache_list->length; i++)
+      {
+         core_info_t* info = (core_info_t*)&core_info_cache_list->items[i];
+         core_info_free(info);
+      }
+      free(core_info_cache_list->items);
    }
-
-   free(core_info_cache_list->items);
+   core_info_cache_list->items = NULL;
 
    if (core_info_cache_list->version)
       free(core_info_cache_list->version);
-
-   free(core_info_cache_list);
+   core_info_cache_list->version = NULL;
 }
 
 static core_info_t *core_info_cache_find(
@@ -692,14 +694,19 @@ static core_info_cache_list_t *core_info_cache_list_new(void)
    if (!core_info_cache_list)
       return NULL;
 
-   core_info_cache_list->length = 0;
-   core_info_cache_list->items  = (core_info_t *)
+   core_info_cache_list->items    = (core_info_t *)
       calloc(CORE_INFO_CACHE_DEFAULT_CAPACITY,
             sizeof(core_info_t));
+   core_info_cache_list->length   = 0;
+   core_info_cache_list->capacity = 0;
+   core_info_cache_list->version  = NULL;
+   core_info_cache_list->refresh  = false;
 
    if (!core_info_cache_list->items)
    {
       core_info_cache_list_free(core_info_cache_list);
+      free(core_info_cache_list);
+      core_info_cache_list = NULL;
       return NULL;
    }
 
@@ -754,7 +761,7 @@ static core_info_cache_list_t *core_info_cache_read(const char *info_dir)
    /* Parse info cache file */
    if (!(parser = rjson_open_stream(file)))
    {
-      RARCH_ERR("[Core Info]: Failed to create JSON parser.\n");
+      RARCH_ERR("[Core info] Failed to create JSON parser.\n");
       goto end;
    }
 
@@ -776,10 +783,10 @@ static core_info_cache_list_t *core_info_cache_read(const char *info_dir)
          NULL) /* Unused null handler */
          != RJSON_DONE)
    {
-      RARCH_WARN("[Core Info]: Error parsing chunk:\n---snip---\n%.*s\n---snip---\n",
+      RARCH_WARN("[Core info] Error parsing chunk:\n---snip---\n%.*s\n---snip---\n",
             rjson_get_source_context_len(parser),
             rjson_get_source_context_buf(parser));
-      RARCH_WARN("[Core Info]: Error: Invalid JSON at line %d, column %d - %s.\n",
+      RARCH_WARN("[Core info] Error: Invalid JSON at line %d, column %d - %s.\n",
             (int)rjson_get_source_line(parser),
             (int)rjson_get_source_column(parser),
             (*rjson_get_error(parser)
@@ -812,7 +819,7 @@ static core_info_cache_list_t *core_info_cache_read(const char *info_dir)
        || !string_is_equal(core_info_cache_list->version,
             CORE_INFO_CACHE_VERSION))
    {
-      RARCH_WARN("[Core Info]: Core info cache has invalid version"
+      RARCH_WARN("[Core info] Core info cache has invalid version"
             " - forcing refresh (required v%s, found v%s).\n",
             CORE_INFO_CACHE_VERSION,
             core_info_cache_list->version);
@@ -849,8 +856,7 @@ static bool core_info_cache_write(core_info_cache_list_t *list, const char *info
             sizeof(file_path));
 
 #if defined(CORE_INFO_CACHE_COMPRESS)
-   file = intfstream_open_rzip_file(file_path,
-         RETRO_VFS_FILE_ACCESS_WRITE);
+   file = intfstream_open_rzip_file(file_path, RETRO_VFS_FILE_ACCESS_WRITE);
 #else
    file = intfstream_open_file(file_path,
          RETRO_VFS_FILE_ACCESS_WRITE,
@@ -859,14 +865,14 @@ static bool core_info_cache_write(core_info_cache_list_t *list, const char *info
 
    if (!file)
    {
-      RARCH_ERR("[Core Info]: Failed to write core info cache file: \"%s\".\n", file_path);
+      RARCH_ERR("[Core info] Failed to write core info cache file: \"%s\".\n", file_path);
       return false;
    }
 
    /* Write info cache */
    if (!(writer = rjsonwriter_open_stream(file)))
    {
-      RARCH_ERR("[Core Info]: Failed to create JSON writer.\n");
+      RARCH_ERR("[Core info] Failed to create JSON writer.\n");
       goto end;
    }
 
@@ -1189,7 +1195,7 @@ static bool core_info_cache_write(core_info_cache_list_t *list, const char *info
    rjsonwriter_raw(writer, "\n", 1);
    rjsonwriter_free(writer);
 
-   RARCH_LOG("[Core Info]: Wrote to cache file: \"%s\".\n", file_path);
+   RARCH_LOG("[Core info] Wrote to cache file: \"%s\".\n", file_path);
    success = true;
 
    /* Remove 'force refresh' file, if required */
@@ -1255,10 +1261,8 @@ bool core_info_cache_force_refresh(const char *path_info)
     * if required */
    if (!path_is_valid(file_path))
    {
-      RFILE *refresh_file = filestream_open(
-            file_path,
-            RETRO_VFS_FILE_ACCESS_WRITE,
-            RETRO_VFS_FILE_ACCESS_HINT_NONE);
+      RFILE *refresh_file = filestream_open(file_path,
+            RETRO_VFS_FILE_ACCESS_WRITE, RETRO_VFS_FILE_ACCESS_HINT_NONE);
 
       if (!refresh_file)
          return false;
@@ -1402,8 +1406,7 @@ static core_path_list_t *core_info_path_list_new(const char *core_dir,
 
    /* Fetch core directory listing */
    dir_list_ok = dir_list_append(path_list->dir_list,
-         core_dir, exts, false, show_hidden_files,
-               false, false);
+         core_dir, exts, false, show_hidden_files, false, false);
 
 #if defined(__WINRT__) || defined(WINAPI_FAMILY) && WINAPI_FAMILY == WINAPI_FAMILY_PHONE_APP
    {
@@ -1497,18 +1500,15 @@ static bool core_info_path_is_locked(
       core_aux_file_path_list_t *lock_list,
       const char *core_file_name)
 {
-   size_t i, len;
+   size_t i;
    uint32_t hash;
    char lock_filename[NAME_MAX_LENGTH];
 
    if (lock_list->size < 1)
       return false;
 
-   len = strlcpy(lock_filename, core_file_name,
-         sizeof(lock_filename));
-   strlcpy(lock_filename       + len,
-         ".lck",
-         sizeof(lock_filename) - len);
+   fill_pathname(lock_filename, core_file_name,
+         ".lck", sizeof(lock_filename));
 
    hash = core_info_hash_string(lock_filename);
 
@@ -1528,18 +1528,15 @@ static bool core_info_path_is_standalone_exempt(
       core_aux_file_path_list_t *exempt_list,
       const char *core_file_name)
 {
-   size_t i, len;
+   size_t i;
    uint32_t hash;
    char exempt_filename[NAME_MAX_LENGTH];
 
    if (exempt_list->size < 1)
       return false;
 
-   len = strlcpy(exempt_filename, core_file_name,
-         sizeof(exempt_filename));
-   strlcpy(exempt_filename       + len,
-         ".lsae",
-         sizeof(exempt_filename) - len);
+   fill_pathname(exempt_filename, core_file_name,
+         ".lsae", sizeof(exempt_filename));
 
    hash = core_info_hash_string(exempt_filename);
 
@@ -1581,7 +1578,7 @@ static size_t core_info_get_file_id(const char *core_filename,
        && !string_is_equal(last_underscore, "_libretro"))
    {
       *last_underscore = '\0';
-      _len = strlen(s); /* TODO/FIXME - make this unnecessary later on */
+      _len = last_underscore - s;
    }
    return _len;
 }
@@ -1888,9 +1885,10 @@ static void core_info_parse_config_file(
    list->info_count++;
 }
 
-static void core_info_list_resolve_all_extensions(
+static size_t core_info_list_resolve_all_extensions(
       core_info_list_t *core_info_list)
 {
+   size_t _len;
    size_t i              = 0;
    size_t all_ext_len    = 0;
    char *all_ext         = NULL;
@@ -1904,26 +1902,29 @@ static void core_info_list_resolve_all_extensions(
 
    all_ext_len       += STRLEN_CONST("7z|") + STRLEN_CONST("zip|");
    if (!(all_ext      = (char*)calloc(1, all_ext_len)))
-      return;
+      return 0;
 
    core_info_list->all_ext = all_ext;
+   _len                    = strlen(all_ext);
 
    for (i = 0; i < core_info_list->count; i++)
    {
-      size_t _len;
       if (!core_info_list->list[i].supported_extensions)
          continue;
 
-      _len = strlcat(core_info_list->all_ext,
-            core_info_list->list[i].supported_extensions, all_ext_len);
-      strlcpy(core_info_list->all_ext + _len, "|", all_ext_len - _len);
+      _len += strlcpy(core_info_list->all_ext + _len,
+            core_info_list->list[i].supported_extensions,
+                      all_ext_len - _len);
+      _len += strlcpy(core_info_list->all_ext + _len, "|",
+                      all_ext_len - _len);
    }
 #ifdef HAVE_7ZIP
-   strlcat(core_info_list->all_ext, "7z|", all_ext_len);
+   _len += strlcpy(core_info_list->all_ext + _len, "7z|", all_ext_len - _len);
 #endif
 #ifdef HAVE_ZLIB
-   strlcat(core_info_list->all_ext, "zip|", all_ext_len);
+   _len += strlcpy(core_info_list->all_ext + _len, "zip|", all_ext_len - _len);
 #endif
+   return _len;
 }
 
 static void core_info_free(core_info_t* info)
@@ -1971,20 +1972,26 @@ static void core_info_free(core_info_t* info)
 
 static void core_info_list_free(core_info_list_t *core_info_list)
 {
-   size_t i;
-
    if (!core_info_list)
       return;
 
-   for (i = 0; i < core_info_list->count; i++)
+   if (core_info_list->list)
    {
-      core_info_t *info = (core_info_t*)&core_info_list->list[i];
-      core_info_free(info);
+      size_t i;
+      for (i = 0; i < core_info_list->count; i++)
+      {
+         core_info_t *info = (core_info_t*)&core_info_list->list[i];
+         core_info_free(info);
+      }
    }
 
-   free(core_info_list->all_ext);
-   free(core_info_list->list);
-   free(core_info_list);
+   if (core_info_list->all_ext)
+      free(core_info_list->all_ext);
+   core_info_list->all_ext = NULL;
+
+   if (core_info_list->list)
+      free(core_info_list->list);
+   core_info_list->list = NULL;
 }
 
 static core_info_list_t *core_info_list_new(const char *path,
@@ -2002,10 +2009,13 @@ static core_info_list_t *core_info_list_new(const char *path,
    core_path_list_t *path_list                  = core_info_path_list_new(
          path, exts, dir_show_hidden_files);
    if (!path_list)
-      goto error;
+      return NULL;
 
    if (!(core_info_list = (core_info_list_t*)malloc(sizeof(*core_info_list))))
-      goto error;
+   {
+      core_info_path_list_free(path_list);
+      return NULL;
+   }
 
    core_info_list->list       = NULL;
    core_info_list->count      = 0;
@@ -2016,7 +2026,11 @@ static core_info_list_t *core_info_list_new(const char *path,
          sizeof(*core_info))))
    {
       core_info_list_free(core_info_list);
-      goto error;
+      core_info_path_list_free(path_list);
+      free(core_info_list);
+      core_info_list = NULL;
+      path_list      = NULL;
+      return NULL;
    }
 
    core_info_list->list  = core_info;
@@ -2024,10 +2038,14 @@ static core_info_list_t *core_info_list_new(const char *path,
 
 #ifdef HAVE_CORE_INFO_CACHE
    /* Read core info cache, if enabled */
-   if (enable_cache)
+   if (enable_cache && !(core_info_cache_list = core_info_cache_read(info_dir)))
    {
-      if (!(core_info_cache_list = core_info_cache_read(info_dir)))
-         goto error;
+      core_info_list_free(core_info_list);
+      core_info_path_list_free(path_list);
+      free(core_info_list);
+      core_info_list = NULL;
+      path_list      = NULL;
+      return NULL;
    }
 #endif
 
@@ -2107,6 +2125,11 @@ static core_info_list_t *core_info_list_new(const char *path,
          config_file_free(conf);
       }
 
+      /* Start with 'full' savestate support when info is missing */
+      if (!conf)
+         info->savestate_support_level =
+               CORE_INFO_SAVESTATE_DETERMINISTIC;
+
       /* Get fallback display name, if required */
       if (!info->display_name)
          info->display_name = strdup(core_filename);
@@ -2148,14 +2171,12 @@ static core_info_list_t *core_info_list_new(const char *path,
                core_info_cache_list, info_dir);
 
       core_info_cache_list_free(core_info_cache_list);
+      free(core_info_cache_list);
+      core_info_cache_list = NULL;
    }
 
    core_info_path_list_free(path_list);
    return core_info_list;
-
-error:
-   core_info_path_list_free(path_list);
-   return NULL;
 }
 
 /* Shallow-copies internal state.
@@ -2170,10 +2191,9 @@ bool core_info_list_get_info(core_info_list_t *core_info_list,
       core_info_t *info = core_info_find_internal(
             core_info_list, core_path);
 
-      memset(out_info, 0, sizeof(*out_info));
-
       if (info)
       {
+         memset(out_info, 0, sizeof(*out_info));
          *out_info = *info;
          return true;
       }
@@ -2202,19 +2222,15 @@ static bool core_info_does_support_file(
       const core_info_t *core, const char *path)
 {
    const char *basename, *ext;
-
    if (!core || !core->supported_extensions_list)
       return false;
    if (string_is_empty(path))
       return false;
-
    basename = path_basename(path);
-
    /* if a core has / in its list of supported extensions, the core
       supports loading of directories on the host file system */
    if (string_is_empty(basename))
       return string_list_find_elem(core->supported_extensions_list, "/");
-
    ext = strrchr(basename, '.');
    return string_list_find_elem_prefix(
          core->supported_extensions_list, ".", (ext ? ext + 1 : ""));
@@ -2232,12 +2248,11 @@ static int core_info_qsort_cmp(const void *a_, const void *b_)
    int support_b                 = core_info_does_support_file(b,
          p_coreinfo->tmp_path);
 #ifdef HAVE_COMPRESSION
-   support_a            = support_a ||
-      core_info_does_support_any_file(a, p_coreinfo->tmp_list);
-   support_b            = support_b ||
-      core_info_does_support_any_file(b, p_coreinfo->tmp_list);
+   support_a            = support_a
+      || core_info_does_support_any_file(a, p_coreinfo->tmp_list);
+   support_b            = support_b
+      || core_info_does_support_any_file(b, p_coreinfo->tmp_list);
 #endif
-
    if (support_a != support_b)
       return support_b - support_a;
    return strcasecmp(a->display_name, b->display_name);
@@ -2799,72 +2814,64 @@ void core_info_qsort(core_info_list_t *core_info_list,
 
 bool core_info_current_supports_savestate(void)
 {
-   core_info_state_t *p_coreinfo = &core_info_st;
-   settings_t        *settings   = config_get_ptr();
-
-   if (settings->bools.core_info_savestate_bypass)
+   core_info_state_t *p_coreinfo   = &core_info_st;
+   settings_t        *settings     = config_get_ptr();
+   bool core_info_savestate_bypass = settings->bools.core_info_savestate_bypass;
+   if (core_info_savestate_bypass)
       return true;
-
    /* If no core is currently loaded, assume
     * by default that all savestate functionality
     * is supported */
    if (!p_coreinfo->current)
       return true;
-
    return p_coreinfo->current->savestate_support_level >=
          CORE_INFO_SAVESTATE_BASIC;
 }
 
 bool core_info_current_supports_rewind(void)
 {
-   core_info_state_t *p_coreinfo = &core_info_st;
-   settings_t        *settings   = config_get_ptr();
-
-   if (settings->bools.core_info_savestate_bypass)
+   core_info_state_t *p_coreinfo   = &core_info_st;
+   settings_t        *settings     = config_get_ptr();
+   bool core_info_savestate_bypass = settings->bools.core_info_savestate_bypass;
+   if (core_info_savestate_bypass)
       return true;
-
    /* If no core is currently loaded, assume
     * by default that all savestate functionality
     * is supported */
    if (!p_coreinfo->current)
       return true;
-
    return p_coreinfo->current->savestate_support_level >=
          CORE_INFO_SAVESTATE_SERIALIZED;
 }
 
 bool core_info_current_supports_netplay(void)
 {
-   core_info_state_t *p_coreinfo = &core_info_st;
-   settings_t        *settings   = config_get_ptr();
-
-   if (settings->bools.core_info_savestate_bypass)
+   core_info_state_t *p_coreinfo   = &core_info_st;
+   settings_t        *settings     = config_get_ptr();
+   bool core_info_savestate_bypass = settings->bools.core_info_savestate_bypass;
+   if (core_info_savestate_bypass)
       return true;
-
    /* If no core is currently loaded, assume
     * by default that all savestate functionality
     * is supported */
    if (!p_coreinfo->current)
       return true;
-
    return p_coreinfo->current->savestate_support_level >=
          CORE_INFO_SAVESTATE_DETERMINISTIC;
 }
 
 bool core_info_current_supports_runahead(void)
 {
-   core_info_state_t *p_coreinfo = &core_info_st;
-   settings_t        *settings   = config_get_ptr();
-
-   if (settings->bools.core_info_savestate_bypass)
+   core_info_state_t *p_coreinfo   = &core_info_st;
+   settings_t        *settings     = config_get_ptr();
+   bool core_info_savestate_bypass = settings->bools.core_info_savestate_bypass;
+   if (core_info_savestate_bypass)
       return true;
-
    /* If no core is currently loaded, assume
     * by default that all savestate functionality
     * is supported */
    if (!p_coreinfo->current)
       return true;
-
    return p_coreinfo->current->savestate_support_level >=
          CORE_INFO_SAVESTATE_DETERMINISTIC;
 }
@@ -2912,7 +2919,6 @@ static bool core_info_update_core_aux_file(const char *path, bool create)
  *   core info list this is *not* thread safe */
 bool core_info_set_core_lock(const char *core_path, bool lock)
 {
-   size_t _len;
    core_info_t *core_info = NULL;
    char lock_file_path[PATH_MAX_LENGTH];
 
@@ -2931,11 +2937,8 @@ bool core_info_set_core_lock(const char *core_path, bool lock)
       return false;
 
    /* Get lock file path */
-   _len  = strlcpy(lock_file_path, core_info->path,
-          sizeof(lock_file_path));
-   strlcpy(lock_file_path       + _len,
-         ".lck",
-         sizeof(lock_file_path) - _len);
+   fill_pathname(lock_file_path, core_info->path,
+         ".lck", sizeof(lock_file_path));
 
    /* Create or delete lock file, as required */
    if (!core_info_update_core_aux_file(lock_file_path, lock))
@@ -2959,7 +2962,6 @@ bool core_info_set_core_lock(const char *core_path, bool lock)
  *   must be checked externally */
 bool core_info_get_core_lock(const char *core_path, bool validate_path)
 {
-   size_t _len;
    core_info_t *core_info     = NULL;
    const char *core_file_path = NULL;
    bool is_locked             = false;
@@ -2990,11 +2992,8 @@ bool core_info_get_core_lock(const char *core_path, bool validate_path)
       return false;
 
    /* Get lock file path */
-   _len = strlcpy(lock_file_path, core_file_path,
-         sizeof(lock_file_path));
-   strlcpy(lock_file_path       + _len,
-         ".lck",
-         sizeof(lock_file_path) - _len);
+   fill_pathname(lock_file_path, core_file_path,
+         ".lck", sizeof(lock_file_path));
 
    /* Check whether lock file exists */
    is_locked = path_is_valid(lock_file_path);
@@ -3022,7 +3021,6 @@ bool core_info_set_core_standalone_exempt(const char *core_path, bool exempt)
    /* Static platforms do not support the contentless
     * cores menu */
 #if defined(HAVE_DYNAMIC)
-   size_t _len;
    core_info_t *core_info = NULL;
    char exempt_file_path[PATH_MAX_LENGTH];
 
@@ -3034,11 +3032,8 @@ bool core_info_set_core_standalone_exempt(const char *core_path, bool exempt)
       return false;
 
    /* Get 'standalone exempt' file path */
-   _len = strlcpy(exempt_file_path, core_info->path,
-         sizeof(exempt_file_path));
-   strlcpy(exempt_file_path       + _len,
-         ".lsae",
-         sizeof(exempt_file_path) - _len);
+   fill_pathname(exempt_file_path, core_info->path,
+         ".lsae", sizeof(exempt_file_path));
 
    /* Create or delete 'standalone exempt' file, as required */
    if (core_info_update_core_aux_file(exempt_file_path, exempt))
@@ -3062,7 +3057,6 @@ bool core_info_get_core_standalone_exempt(const char *core_path)
    /* Static platforms do not support the contentless
     * cores menu */
 #if defined(HAVE_DYNAMIC)
-   size_t _len;
    core_info_t *core_info = NULL;
    char exempt_file_path[PATH_MAX_LENGTH];
 
@@ -3074,11 +3068,8 @@ bool core_info_get_core_standalone_exempt(const char *core_path)
       return false;
 
    /* Get 'standalone exempt' file path */
-   _len = strlcpy(exempt_file_path, core_info->path,
-         sizeof(exempt_file_path));
-   strlcpy(exempt_file_path       + _len,
-         ".lsae",
-         sizeof(exempt_file_path) - _len);
+   fill_pathname(exempt_file_path, core_info->path,
+         ".lsae", sizeof(exempt_file_path));
 
    /* Check whether 'standalone exempt' file exists */
    if (path_is_valid(exempt_file_path))
