@@ -236,29 +236,28 @@ bool core_updater_list_get_filename(
       const char *remote_filename,
       const core_updater_list_entry_t **entry)
 {
-   size_t num_entries;
-   size_t i;
 
-   if (!core_list || !entry || string_is_empty(remote_filename))
-      return false;
-
-   num_entries = RBUF_LEN(core_list->entries);
-
-   if (num_entries < 1)
-      return false;
-
-   /* Search for specified filename */
-   for (i = 0; i < num_entries; i++)
+   if (core_list && entry && !string_is_empty(remote_filename))
    {
-      core_updater_list_entry_t *current_entry = &core_list->entries[i];
+      size_t num_entries = RBUF_LEN(core_list->entries);
 
-      if (string_is_empty(current_entry->remote_filename))
-         continue;
-
-      if (string_is_equal(remote_filename, current_entry->remote_filename))
+      if (num_entries >= 1)
       {
-         *entry = current_entry;
-         return true;
+         size_t i;
+         /* Search for specified filename */
+         for (i = 0; i < num_entries; i++)
+         {
+            core_updater_list_entry_t *current_entry = &core_list->entries[i];
+
+            if (string_is_empty(current_entry->remote_filename))
+               continue;
+
+            if (string_is_equal(remote_filename, current_entry->remote_filename))
+            {
+               *entry = current_entry;
+               return true;
+            }
+         }
       }
    }
 
@@ -330,7 +329,7 @@ bool core_updater_list_get_core(
 static bool core_updater_list_set_date(
       core_updater_list_entry_t *entry, const char *date_str)
 {
-   char *tok, *save;
+   char *tok, *save   = NULL;
    char *elem0        = NULL;
    char *elem1        = NULL;
    char *elem2        = NULL;
@@ -784,7 +783,7 @@ bool core_updater_list_parse_network_data(
       const char *network_buildbot_url,
       const char *data, size_t len)
 {
-   char *tok, *save;
+   char *tok, *save   = NULL;
    unsigned list_size = 0;
    char *data_buf     = NULL;
 
@@ -817,12 +816,12 @@ bool core_updater_list_parse_network_data(
    for (tok = strtok_r(data_buf, "\n", &save); tok;
         tok = strtok_r(NULL, "\n", &save))
    {
-      char *tok2, *save2;
-      char *elem0      = NULL;
-      char *elem1      = NULL;
-      char *elem2      = NULL;
-      char *line_cpy   = NULL;
-      const char *line = tok;
+      char *tok2, *save2 = NULL;
+      char *elem0        = NULL;
+      char *elem1        = NULL;
+      char *elem2        = NULL;
+      char *line_cpy     = NULL;
+      const char *line   = tok;
 
       if (string_is_empty(line))
          continue;
