@@ -44,6 +44,7 @@ enum database_type
    DATABASE_TYPE_ITERATE_ARCHIVE,
    DATABASE_TYPE_ITERATE_LUTRO,
    DATABASE_TYPE_SERIAL_LOOKUP,
+   DATABASE_TYPE_SERIAL_LOOKUP_SIZEHINT,
    DATABASE_TYPE_CRC_LOOKUP
 };
 
@@ -67,7 +68,9 @@ enum database_query_type
    DATABASE_QUERY_ENTRY_FAMITSU_MAGAZINE_RATING,
    DATABASE_QUERY_ENTRY_RELEASEDATE_MONTH,
    DATABASE_QUERY_ENTRY_RELEASEDATE_YEAR,
-   DATABASE_QUERY_ENTRY_MAX_USERS
+   DATABASE_QUERY_ENTRY_MAX_USERS,
+   DATABASE_QUERY_ENTRY_GENRE,
+   DATABASE_QUERY_ENTRY_REGION
 };
 
 typedef struct
@@ -120,7 +123,7 @@ typedef struct
    int rumble_supported;
    int coop_supported;
    uint32_t crc32;
-   unsigned size;
+   uint64_t size;
    unsigned famitsu_magazine_rating;
    unsigned edge_magazine_rating;
    unsigned edge_magazine_issue;
