@@ -10,8 +10,6 @@ RC_BEGIN_C_DECLS
 
 #ifndef RC_RUNTIME_H /* prevents pedantic redefiniton error */
 
-typedef struct lua_State lua_State;
-
 typedef struct rc_trigger_t rc_trigger_t;
 typedef struct rc_lboard_t rc_lboard_t;
 typedef struct rc_richpresence_t rc_richpresence_t;
@@ -29,7 +27,7 @@ typedef struct rc_value_t rc_value_t;
  * num_bytes is greater than 1, the value is read in little-endian from
  * memory.
  */
-typedef uint32_t(RC_CCONV *rc_peek_t)(uint32_t address, uint32_t num_bytes, void* ud);
+typedef uint32_t(RC_CCONV* rc_peek_t)(uint32_t address, uint32_t num_bytes, void* ud);
 
 /*****************************************************************************\
 | Memory References                                                           |
@@ -70,15 +68,14 @@ typedef struct rc_memref_value_t {
   /* The last differing value of this memory reference. */
   uint32_t prior;
 
-  /* The size of the value. */
+  /* The size of the value. (RC_MEMSIZE_*) */
   uint8_t size;
   /* True if the value changed this frame. */
   uint8_t changed;
-  /* The value type of the value (for variables) */
+  /* The value type of the value. (RC_VALUE_TYPE_*) */
   uint8_t type;
-  /* True if the reference will be used in indirection.
-   * NOTE: This is actually a property of the rc_memref_t, but we put it here to save space */
-  uint8_t is_indirect;
+  /* The type of memref (RC_MEMREF_TYPE_*) */
+  uint8_t memref_type;
 }
 rc_memref_value_t;
 
@@ -88,9 +85,6 @@ struct rc_memref_t {
 
   /* The memory address of this variable. */
   uint32_t address;
-
-  /* The next memory reference in the chain. */
-  rc_memref_t* next;
 };
 
 /*****************************************************************************\
@@ -103,10 +97,11 @@ enum {
   RC_OPERAND_DELTA,          /* The value last known at this address. */
   RC_OPERAND_CONST,          /* A 32-bit unsigned integer. */
   RC_OPERAND_FP,             /* A floating point value. */
-  RC_OPERAND_LUA,            /* A Lua function that provides the value. */
+  RC_OPERAND_FUNC,           /* A function that provides the value. */
   RC_OPERAND_PRIOR,          /* The last differing value at this address. */
   RC_OPERAND_BCD,            /* The BCD-decoded value of a live address in RAM. */
-  RC_OPERAND_INVERTED        /* The twos-complement value of a live address in RAM. */
+  RC_OPERAND_INVERTED,       /* The twos-complement value of a live address in RAM. */
+  RC_OPERAND_RECALL          /* The value captured by the last RC_CONDITION_REMEMBER condition */
 };
 
 typedef struct rc_operand_t {
@@ -119,16 +114,19 @@ typedef struct rc_operand_t {
 
     /* A floating point value. */
     double dbl;
-
-    /* A reference to the Lua function that provides the value. */
-    int luafunc;
   } value;
 
-  /* specifies which member of the value union is being used */
+  /* specifies which member of the value union is being used (RC_OPERAND_*) */
   uint8_t type;
 
-  /* the actual RC_MEMSIZE of the operand - memref.size may differ */
+  /* the RC_MEMSIZE of the operand specified in the condition definition - memref.size may differ */
   uint8_t size;
+
+  /* specifies how to read the memref for some types (RC_OPERAND_*) */
+  uint8_t memref_access_type;
+
+  /* if set, this operand is combining the current condition with the previous one */
+  uint8_t is_combining;
 }
 rc_operand_t;
 
@@ -140,22 +138,16 @@ RC_EXPORT int RC_CCONV rc_operand_is_memref(const rc_operand_t* operand);
 
 /* types */
 enum {
-  /* NOTE: this enum is ordered to optimize the switch statements in rc_test_condset_internal. the values may change between releases */
-
-  /* non-combining conditions (third switch) */
   RC_CONDITION_STANDARD, /* this should always be 0 */
   RC_CONDITION_PAUSE_IF,
   RC_CONDITION_RESET_IF,
   RC_CONDITION_MEASURED_IF,
   RC_CONDITION_TRIGGER,
-  RC_CONDITION_MEASURED, /* measured also appears in the first switch, so place it at the border between them */
-
-  /* modifiers (first switch) */
-  RC_CONDITION_ADD_SOURCE, /* everything from this point on affects the condition after it */
+  RC_CONDITION_MEASURED,
+  RC_CONDITION_ADD_SOURCE,
   RC_CONDITION_SUB_SOURCE,
   RC_CONDITION_ADD_ADDRESS,
-
-  /* logic flags (second switch) */
+  RC_CONDITION_REMEMBER,
   RC_CONDITION_ADD_HITS,
   RC_CONDITION_SUB_HITS,
   RC_CONDITION_RESET_NEXT_IF,
@@ -176,7 +168,12 @@ enum {
   RC_OPERATOR_DIV,
   RC_OPERATOR_AND,
   RC_OPERATOR_XOR,
-  RC_OPERATOR_MOD
+  RC_OPERATOR_MOD,
+  RC_OPERATOR_ADD,
+  RC_OPERATOR_SUB,
+
+  RC_OPERATOR_SUB_PARENT, /* internal use */
+  RC_OPERATOR_INDIRECT_READ /* internal use */
 };
 
 typedef struct rc_condition_t rc_condition_t;
@@ -200,10 +197,15 @@ struct rc_condition_t {
   /* The comparison operator to use. (RC_OPERATOR_*) */
   uint8_t oper; /* operator is a reserved word in C++. */
 
-  /* Set if the condition needs to processed as part of the "check if paused" pass. (bool) */
-  uint8_t pause;
-
-  /* Whether or not the condition evaluated true on the last check. (bool) */
+  /* Will be non-zero if the condition evaluated true on the last check.
+   * - The lowest bit indicates whether the condition itself was true.
+   * - The second lowest bit will only ever be set on ResetIf conditions.
+   *   If set, it indicates that the condition was responsible for resetting the
+   *   trigger. A reset clears all hit counts, so the condition may not appear to
+   *   be true just from looking at it (in which case the lower bit will be 0).
+   *   Also, the condition might have only met its required_hits target though
+   *   an AddHits chain which will have also been reset.
+   */
   uint8_t is_true;
 
   /* Unique identifier of optimized comparator to use. (RC_PROCESSING_COMPARE_*) */
@@ -220,17 +222,32 @@ struct rc_condset_t {
   /* The next condition set in the chain. */
   rc_condset_t* next;
 
-  /* The list of conditions in this condition set. */
+  /* The first condition in this condition set. Then follow ->next chain. */
   rc_condition_t* conditions;
 
-  /* True if any condition in the set is a pause condition. */
-  uint8_t has_pause;
+  /* The number of pause conditions in this condition set. */
+  /* The first pause condition is at "this + RC_ALIGN(sizeof(this)). */
+  uint16_t num_pause_conditions;
 
+  /* The number of reset conditions in this condition set. */
+  uint16_t num_reset_conditions;
+
+  /* The number of hittarget conditions in this condition set. */
+  uint16_t num_hittarget_conditions;
+
+  /* The number of non-hittarget measured conditions in this condition set. */
+  uint16_t num_measured_conditions;
+
+  /* The number of other conditions in this condition set. */
+  uint16_t num_other_conditions;
+
+  /* The number of indirect conditions in this condition set. */
+  uint16_t num_indirect_conditions;
+
+  /* True if any condition in the set is a pause condition. */
+  uint8_t has_pause; /* DEPRECATED - just check num_pause_conditions != 0 */
   /* True if the set is currently paused. */
   uint8_t is_paused;
-
-  /* True if the set has indirect memory references. */
-  uint8_t has_indirect_memrefs;
 };
 
 /*****************************************************************************\
@@ -255,9 +272,6 @@ struct rc_trigger_t {
   /* The list of sub condition sets in this test. */
   rc_condset_t* alternative;
 
-  /* The memory references required by the trigger. */
-  rc_memref_t* memrefs;
-
   /* The current state of the MEASURED condition. */
   uint32_t measured_value;
 
@@ -270,32 +284,34 @@ struct rc_trigger_t {
   /* True if at least one condition has a non-zero hit count */
   uint8_t has_hits;
 
-  /* True if at least one condition has a non-zero required hit count */
-  uint8_t has_required_hits;
-
   /* True if the measured value should be displayed as a percentage */
   uint8_t measured_as_percent;
+
+  /* True if the trigger has its own rc_memrefs_t */
+  uint8_t has_memrefs;
 };
 
 RC_EXPORT int RC_CCONV rc_trigger_size(const char* memaddr);
-RC_EXPORT rc_trigger_t* RC_CCONV rc_parse_trigger(void* buffer, const char* memaddr, lua_State* L, int funcs_ndx);
-RC_EXPORT int RC_CCONV rc_evaluate_trigger(rc_trigger_t* trigger, rc_peek_t peek, void* ud, lua_State* L);
-RC_EXPORT int RC_CCONV rc_test_trigger(rc_trigger_t* trigger, rc_peek_t peek, void* ud, lua_State* L);
+RC_EXPORT rc_trigger_t* RC_CCONV rc_parse_trigger(void* buffer, const char* memaddr, void* unused_L, int unused_funcs_idx);
+RC_EXPORT int RC_CCONV rc_evaluate_trigger(rc_trigger_t* trigger, rc_peek_t peek, void* ud, void* unused_L);
+RC_EXPORT int RC_CCONV rc_test_trigger(rc_trigger_t* trigger, rc_peek_t peek, void* ud, void* unused_L);
 RC_EXPORT void RC_CCONV rc_reset_trigger(rc_trigger_t* self);
 
 /*****************************************************************************\
 | Values                                                                      |
 \*****************************************************************************/
 
+#define RC_VALUE_MAX_NAME_LENGTH 15
+
 struct rc_value_t {
   /* The current value of the variable. */
   rc_memref_value_t value;
 
-  /* The list of conditions to evaluate. */
-  rc_condset_t* conditions;
+  /* True if the value has its own rc_memrefs_t */
+  uint8_t has_memrefs;
 
-  /* The memory references required by the variable. */
-  rc_memref_t* memrefs;
+  /* The list of possible values (traverse next chain, pick max). */
+  rc_condset_t* conditions;
 
   /* The name of the variable. */
   const char* name;
@@ -305,8 +321,8 @@ struct rc_value_t {
 };
 
 RC_EXPORT int RC_CCONV rc_value_size(const char* memaddr);
-RC_EXPORT rc_value_t* RC_CCONV rc_parse_value(void* buffer, const char* memaddr, lua_State* L, int funcs_ndx);
-RC_EXPORT int32_t RC_CCONV rc_evaluate_value(rc_value_t* value, rc_peek_t peek, void* ud, lua_State* L);
+RC_EXPORT rc_value_t* RC_CCONV rc_parse_value(void* buffer, const char* memaddr, void* unused_L, int unused_funcs_idx);
+RC_EXPORT int32_t RC_CCONV rc_evaluate_value(rc_value_t* value, rc_peek_t peek, void* ud, void* unused_L);
 
 /*****************************************************************************\
 | Leaderboards                                                                |
@@ -329,14 +345,14 @@ struct rc_lboard_t {
   rc_trigger_t cancel;
   rc_value_t value;
   rc_value_t* progress;
-  rc_memref_t* memrefs;
 
   uint8_t state;
+  uint8_t has_memrefs;
 };
 
 RC_EXPORT int RC_CCONV rc_lboard_size(const char* memaddr);
-RC_EXPORT rc_lboard_t* RC_CCONV rc_parse_lboard(void* buffer, const char* memaddr, lua_State* L, int funcs_ndx);
-RC_EXPORT int RC_CCONV rc_evaluate_lboard(rc_lboard_t* lboard, int32_t* value, rc_peek_t peek, void* peek_ud, lua_State* L);
+RC_EXPORT rc_lboard_t* RC_CCONV rc_parse_lboard(void* buffer, const char* memaddr, void* unused_L, int unused_funcs_idx);
+RC_EXPORT int RC_CCONV rc_evaluate_lboard(rc_lboard_t* lboard, int32_t* value, rc_peek_t peek, void* peek_ud, void* unused_L);
 RC_EXPORT void RC_CCONV rc_reset_lboard(rc_lboard_t* lboard);
 
 /*****************************************************************************\
@@ -364,7 +380,8 @@ enum {
   RC_FORMAT_TENS,
   RC_FORMAT_HUNDREDS,
   RC_FORMAT_THOUSANDS,
-  RC_FORMAT_UNSIGNED_VALUE
+  RC_FORMAT_UNSIGNED_VALUE,
+  RC_FORMAT_UNFORMATTED
 };
 
 RC_EXPORT int RC_CCONV rc_parse_format(const char* format_str);
@@ -400,7 +417,7 @@ struct rc_richpresence_display_part_t {
   rc_richpresence_display_part_t* next;
   const char* text;
   rc_richpresence_lookup_t* lookup;
-  rc_memref_value_t *value;
+  rc_operand_t value;
   uint8_t display_type;
 };
 
@@ -410,21 +427,22 @@ struct rc_richpresence_display_t {
   rc_trigger_t trigger;
   rc_richpresence_display_t* next;
   rc_richpresence_display_part_t* display;
+  uint8_t has_required_hits;
 };
 
 struct rc_richpresence_t {
   rc_richpresence_display_t* first_display;
   rc_richpresence_lookup_t* first_lookup;
-  rc_memref_t* memrefs;
-  rc_value_t* variables;
+  rc_value_t* values;
+  uint8_t has_memrefs;
 };
 
 RC_EXPORT int RC_CCONV rc_richpresence_size(const char* script);
 RC_EXPORT int RC_CCONV rc_richpresence_size_lines(const char* script, int* lines_read);
-RC_EXPORT rc_richpresence_t* RC_CCONV rc_parse_richpresence(void* buffer, const char* script, lua_State* L, int funcs_ndx);
-RC_EXPORT int RC_CCONV rc_evaluate_richpresence(rc_richpresence_t* richpresence, char* buffer, size_t buffersize, rc_peek_t peek, void* peek_ud, lua_State* L);
-RC_EXPORT void RC_CCONV rc_update_richpresence(rc_richpresence_t* richpresence, rc_peek_t peek, void* peek_ud, lua_State* L);
-RC_EXPORT int RC_CCONV rc_get_richpresence_display_string(rc_richpresence_t* richpresence, char* buffer, size_t buffersize, rc_peek_t peek, void* peek_ud, lua_State* L);
+RC_EXPORT rc_richpresence_t* RC_CCONV rc_parse_richpresence(void* buffer, const char* script, void* unused_L, int unused_funcs_idx);
+RC_EXPORT int RC_CCONV rc_evaluate_richpresence(rc_richpresence_t* richpresence, char* buffer, size_t buffersize, rc_peek_t peek, void* peek_ud, void* unused_L);
+RC_EXPORT void RC_CCONV rc_update_richpresence(rc_richpresence_t* richpresence, rc_peek_t peek, void* peek_ud, void* unused_L);
+RC_EXPORT int RC_CCONV rc_get_richpresence_display_string(rc_richpresence_t* richpresence, char* buffer, size_t buffersize, rc_peek_t peek, void* peek_ud, void* unused_L);
 RC_EXPORT void RC_CCONV rc_reset_richpresence(rc_richpresence_t* self);
 
 RC_END_C_DECLS
