@@ -6,41 +6,232 @@
 
 #define MEMREF_PLACEHOLDER_ADDRESS 0xFFFFFFFF
 
-rc_memref_t* rc_alloc_memref(rc_parse_state_t* parse, uint32_t address, uint8_t size, uint8_t is_indirect) {
-  rc_memref_t** next_memref;
-  rc_memref_t* memref;
+rc_memref_t* rc_alloc_memref(rc_parse_state_t* parse, uint32_t address, uint8_t size) {
+  rc_memref_list_t* memref_list = NULL;
+  rc_memref_t* memref = NULL;
+  int i;
 
-  if (!is_indirect) {
-    /* attempt to find an existing memref that can be shared */
-    next_memref = parse->first_memref;
-    while (*next_memref) {
-      memref = *next_memref;
-      if (!memref->value.is_indirect && memref->address == address && memref->value.size == size)
-        return memref;
+  for (i = 0; i < 2; i++) {
+    if (i == 0) {
+      if (!parse->existing_memrefs)
+        continue;
 
-      next_memref = &memref->next;
+      memref_list = &parse->existing_memrefs->memrefs;
+    }
+    else {
+      memref_list = &parse->memrefs->memrefs;
     }
 
-    /* no match found, create a new entry */
-    memref = RC_ALLOC_SCRATCH(rc_memref_t, parse);
-    *next_memref = memref;
+    do
+    {
+      const rc_memref_t* memref_stop;
+
+      memref = memref_list->items;
+      memref_stop = memref + memref_list->count;
+
+      for (; memref < memref_stop; ++memref) {
+        if (memref->address == address && memref->value.size == size)
+          return memref;
+      }
+
+      if (!memref_list->next)
+        break;
+
+      memref_list = memref_list->next;
+    } while (1);
   }
-  else {
-    /* indirect references always create a new entry because we can't guarantee that the 
-     * indirection amount will be the same between references. because they aren't shared,
-     * don't bother putting them in the chain.
-     */
-    memref = RC_ALLOC(rc_memref_t, parse);
+
+  /* no match found, find a place to put the new entry */
+  memref_list = &parse->memrefs->memrefs;
+  while (memref_list->count == memref_list->capacity && memref_list->next)
+    memref_list = memref_list->next;
+
+  /* create a new entry */
+  if (memref_list->count < memref_list->capacity) {
+    memref = &memref_list->items[memref_list->count++];
+  } else {
+    const int32_t old_offset = parse->offset;
+
+    if (memref_list->capacity != 0) {
+      memref_list = memref_list->next = RC_ALLOC_SCRATCH(rc_memref_list_t, parse);
+      memref_list->next = NULL;
+    }
+
+    memref_list->items = RC_ALLOC_ARRAY_SCRATCH(rc_memref_t, 8, parse);
+    memref_list->count = 1;
+    memref_list->capacity = 8;
+    memref_list->allocated = 0;
+
+    memref = memref_list->items;
+
+    /* in preparse mode, don't count this memory, we'll do a single allocation once we have
+     * the final total */
+    if (!parse->buffer)
+      parse->offset = old_offset;
   }
 
   memset(memref, 0, sizeof(*memref));
-  memref->address = address;
+  memref->value.memref_type = RC_MEMREF_TYPE_MEMREF;
+  memref->value.type = RC_VALUE_TYPE_UNSIGNED;
   memref->value.size = size;
-  memref->value.is_indirect = is_indirect;
+  memref->address = address;
 
   return memref;
 }
 
+rc_modified_memref_t* rc_alloc_modified_memref(rc_parse_state_t* parse, uint8_t size, const rc_operand_t* parent,
+                                               uint8_t modifier_type, const rc_operand_t* modifier) {
+  rc_modified_memref_list_t* modified_memref_list = NULL;
+  rc_modified_memref_t* modified_memref = NULL;
+  int i = 0;
+
+  for (i = 0; i < 2; i++) {
+    if (i == 0) {
+      if (!parse->existing_memrefs)
+        continue;
+
+      modified_memref_list = &parse->existing_memrefs->modified_memrefs;
+    }
+    else {
+      modified_memref_list = &parse->memrefs->modified_memrefs;
+    }
+
+    do {
+      const rc_modified_memref_t* memref_stop;
+
+      modified_memref = modified_memref_list->items;
+      memref_stop = modified_memref + modified_memref_list->count;
+
+      for (; modified_memref < memref_stop; ++modified_memref) {
+        if (modified_memref->memref.value.size == size &&
+            modified_memref->modifier_type == modifier_type &&
+            rc_operands_are_equal(&modified_memref->parent, parent) &&
+            rc_operands_are_equal(&modified_memref->modifier, modifier)) {
+          return modified_memref;
+        }
+      }
+
+      if (!modified_memref_list->next)
+        break;
+
+      modified_memref_list = modified_memref_list->next;
+    } while (1);
+  }
+
+  /* no match found, find a place to put the new entry */
+  modified_memref_list = &parse->memrefs->modified_memrefs;
+  while (modified_memref_list->count == modified_memref_list->capacity && modified_memref_list->next)
+    modified_memref_list = modified_memref_list->next;
+
+  /* create a new entry */
+  if (modified_memref_list->count < modified_memref_list->capacity) {
+    modified_memref = &modified_memref_list->items[modified_memref_list->count++];
+  } else {
+    const int32_t old_offset = parse->offset;
+
+    if (modified_memref_list->capacity != 0) {
+      modified_memref_list = modified_memref_list->next = RC_ALLOC_SCRATCH(rc_modified_memref_list_t, parse);
+      modified_memref_list->next = NULL;
+    }
+
+    modified_memref_list->items = RC_ALLOC_ARRAY_SCRATCH(rc_modified_memref_t, 8, parse);
+    modified_memref_list->count = 1;
+    modified_memref_list->capacity = 8;
+    modified_memref_list->allocated = 0;
+
+    modified_memref = modified_memref_list->items;
+
+    /* in preparse mode, don't count this memory, we'll do a single allocation once we have
+     * the final total */
+    if (!parse->buffer)
+      parse->offset = old_offset;
+  }
+
+  memset(modified_memref, 0, sizeof(*modified_memref));
+  modified_memref->memref.value.memref_type = RC_MEMREF_TYPE_MODIFIED_MEMREF;
+  modified_memref->memref.value.size = size;
+  modified_memref->memref.value.type = rc_memsize_is_float(size) ? RC_VALUE_TYPE_FLOAT : RC_VALUE_TYPE_UNSIGNED;
+  memcpy(&modified_memref->parent, parent, sizeof(modified_memref->parent));
+  memcpy(&modified_memref->modifier, modifier, sizeof(modified_memref->modifier));
+  modified_memref->modifier_type = modifier_type;
+  modified_memref->memref.address = rc_operand_is_memref(modifier) ? modifier->value.memref->address : modifier->value.num;
+
+  return modified_memref;
+}
+
+void rc_memrefs_init(rc_memrefs_t* memrefs)
+{
+  memset(memrefs, 0, sizeof(*memrefs));
+
+  memrefs->memrefs.capacity = 32;
+  memrefs->memrefs.items =
+    (rc_memref_t*)malloc(memrefs->memrefs.capacity * sizeof(rc_memref_t));
+  memrefs->memrefs.allocated = 1;
+
+  memrefs->modified_memrefs.capacity = 16;
+  memrefs->modified_memrefs.items =
+    (rc_modified_memref_t*)malloc(memrefs->modified_memrefs.capacity * sizeof(rc_modified_memref_t));
+  memrefs->modified_memrefs.allocated = 1;
+}
+
+void rc_memrefs_destroy(rc_memrefs_t* memrefs)
+{
+  rc_memref_list_t* memref_list = &memrefs->memrefs;
+  rc_modified_memref_list_t* modified_memref_list = &memrefs->modified_memrefs;
+
+  do {
+    rc_memref_list_t* current_memref_list = memref_list;
+    memref_list = memref_list->next;
+
+    if (current_memref_list->allocated) {
+      if (current_memref_list->items)
+        free(current_memref_list->items);
+
+      if (current_memref_list != &memrefs->memrefs)
+        free(current_memref_list);
+    }
+  } while (memref_list);
+
+  do {
+    rc_modified_memref_list_t* current_modified_memref_list = modified_memref_list;
+    modified_memref_list = modified_memref_list->next;
+
+    if (current_modified_memref_list->allocated) {
+      if (current_modified_memref_list->items)
+        free(current_modified_memref_list->items);
+
+      if (current_modified_memref_list != &memrefs->modified_memrefs)
+        free(current_modified_memref_list);
+    }
+  } while (modified_memref_list);
+
+  free(memrefs);
+}
+
+uint32_t rc_memrefs_count_memrefs(const rc_memrefs_t* memrefs)
+{
+  uint32_t count = 0;
+  const rc_memref_list_t* memref_list = &memrefs->memrefs;
+  while (memref_list) {
+    count += memref_list->count;
+    memref_list = memref_list->next;
+  }
+
+  return count;
+}
+
+uint32_t rc_memrefs_count_modified_memrefs(const rc_memrefs_t* memrefs)
+{
+  uint32_t count = 0;
+  const rc_modified_memref_list_t* modified_memref_list = &memrefs->modified_memrefs;
+  while (modified_memref_list) {
+    count += modified_memref_list->count;
+    modified_memref_list = modified_memref_list->next;
+  }
+
+  return count;
+}
+
 int rc_parse_memref(const char** memaddr, uint8_t* size, uint32_t* address) {
   const char* aux = *memaddr;
   char* end;
@@ -77,7 +268,12 @@ int rc_parse_memref(const char** memaddr, uint8_t* size, uint32_t* address) {
       /* case 'y': case 'Y': 64 bit? */
       /* case 'z': case 'Z': 128 bit? */
 
-      case '0': case '1': case '2': case '3': case '4':
+      case '0':
+        if (*aux == 'x') /* user mistyped an extra 0x: 0x0xabcd */
+          return RC_INVALID_MEMORY_OPERAND;
+        /* fallthrough */
+
+      case '1': case '2': case '3': case '4':
       case '5': case '6': case '7': case '8': case '9':
       case 'a': case 'b': case 'c': case 'd': case 'e': case 'f':
       case 'A': case 'B': case 'C': case 'D': case 'E': case 'F':
@@ -132,7 +328,7 @@ static float rc_build_float(uint32_t mantissa_bits, int32_t exponent, int sign)
     if (mantissa_bits == 0) {
       /* infinity */
 #ifdef INFINITY /* INFINITY and NAN #defines require C99 */
-      dbl = INFINITY;
+      dbl = (double)INFINITY;
 #else
       dbl = -log(0.0);
 #endif
@@ -485,19 +681,12 @@ void rc_update_memref_value(rc_memref_value_t* memref, uint32_t new_value) {
   }
 }
 
-void rc_update_memref_values(rc_memref_t* memref, rc_peek_t peek, void* ud) {
-  while (memref) {
-    /* indirect memory references are not shared and will be updated in rc_get_memref_value */
-    if (!memref->value.is_indirect)
-      rc_update_memref_value(&memref->value, rc_peek_value(memref->address, memref->value.size, peek, ud));
+void rc_init_parse_state_memrefs(rc_parse_state_t* parse, rc_memrefs_t* memrefs)
+{
+  if (memrefs)
+    memset(memrefs, 0, sizeof(*memrefs));
 
-    memref = memref->next;
-  }
-}
-
-void rc_init_parse_state_memrefs(rc_parse_state_t* parse, rc_memref_t** memrefs) {
-  parse->first_memref = memrefs;
-  *memrefs = 0;
+  parse->memrefs = memrefs;
 }
 
 static uint32_t rc_get_memref_value_value(const rc_memref_value_t* memref, int operand_type) {
@@ -520,12 +709,68 @@ static uint32_t rc_get_memref_value_value(const rc_memref_value_t* memref, int o
   }
 }
 
-uint32_t rc_get_memref_value(rc_memref_t* memref, int operand_type, rc_eval_state_t* eval_state) {
-  /* if this is an indirect reference, handle the indirection. */
-  if (memref->value.is_indirect) {
-    const uint32_t new_address = memref->address + eval_state->add_address;
-    rc_update_memref_value(&memref->value, rc_peek_value(new_address, memref->value.size, eval_state->peek, eval_state->peek_userdata));
+void rc_get_memref_value(rc_typed_value_t* value, rc_memref_t* memref, int operand_type) {
+  value->type = memref->value.type;
+  value->value.u32 = rc_get_memref_value_value(&memref->value, operand_type);
+}
+
+uint32_t rc_get_modified_memref_value(const rc_modified_memref_t* memref, rc_peek_t peek, void* ud) {
+  rc_typed_value_t value, modifier;
+
+  rc_evaluate_operand(&value, &memref->parent, NULL);
+  rc_evaluate_operand(&modifier, &memref->modifier, NULL);
+
+  switch (memref->modifier_type) {
+    case RC_OPERATOR_INDIRECT_READ:
+      rc_typed_value_add(&value, &modifier);
+      rc_typed_value_convert(&value, RC_VALUE_TYPE_UNSIGNED);
+      value.value.u32 = rc_peek_value(value.value.u32, memref->memref.value.size, peek, ud);
+      value.type = memref->memref.value.type;
+      break;
+
+    case RC_OPERATOR_SUB_PARENT:
+      rc_typed_value_negate(&value);
+      rc_typed_value_add(&value, &modifier);
+      rc_typed_value_convert(&value, memref->memref.value.type);
+      break;
+
+    default:
+      rc_typed_value_combine(&value, &modifier, memref->modifier_type);
+      rc_typed_value_convert(&value, memref->memref.value.type);
+      break;
   }
 
-  return rc_get_memref_value_value(&memref->value, operand_type);
+  return value.value.u32;
+}
+
+void rc_update_memref_values(rc_memrefs_t* memrefs, rc_peek_t peek, void* ud) {
+  rc_memref_list_t* memref_list;
+  rc_modified_memref_list_t* modified_memref_list;
+
+  memref_list = &memrefs->memrefs;
+  do
+  {
+    rc_memref_t* memref = memref_list->items;
+    const rc_memref_t* memref_stop = memref + memref_list->count;
+
+    for (; memref < memref_stop; ++memref) {
+      if (memref->value.type != RC_VALUE_TYPE_NONE)
+        rc_update_memref_value(&memref->value, rc_peek_value(memref->address, memref->value.size, peek, ud));
+    }
+
+    memref_list = memref_list->next;
+  } while (memref_list);
+
+  modified_memref_list = &memrefs->modified_memrefs;
+  if (modified_memref_list->count) {
+    do {
+      rc_modified_memref_t* modified_memref = modified_memref_list->items;
+      const rc_modified_memref_t* modified_memref_stop = modified_memref + modified_memref_list->count;
+
+      for (; modified_memref < modified_memref_stop; ++modified_memref)
+        rc_update_memref_value(&modified_memref->memref.value, rc_get_modified_memref_value(modified_memref, peek, ud));
+
+      modified_memref_list = modified_memref_list->next;
+    } while (modified_memref_list);
+  }
 }
