@@ -16,21 +16,20 @@ void rc_parse_trigger_internal(rc_trigger_t* self, const char** memaddr, rc_pars
   parse->measured_as_percent = 0;
 
   if (*aux == 's' || *aux == 'S') {
-    self->requirement = 0;
+    self->requirement = NULL;
   }
   else {
-    self->requirement = rc_parse_condset(&aux, parse, 0);
+    self->requirement = rc_parse_condset(&aux, parse);
 
-    if (parse->offset < 0) {
+    if (parse->offset < 0)
       return;
-    }
 
-    self->requirement->next = 0;
+    self->requirement->next = NULL;
   }
 
   while (*aux == 's' || *aux == 'S') {
     aux++;
-    *next = rc_parse_condset(&aux, parse, 0);
+    *next = rc_parse_condset(&aux, parse);
 
     if (parse->offset < 0) {
       return;
@@ -39,7 +38,7 @@ void rc_parse_trigger_internal(rc_trigger_t* self, const char** memaddr, rc_pars
     next = &(*next)->next;
   }
 
-  *next = 0;
+  *next = NULL;
   *memaddr = aux;
 
   self->measured_target = parse->measured_target;
@@ -47,39 +46,49 @@ void rc_parse_trigger_internal(rc_trigger_t* self, const char** memaddr, rc_pars
   self->measured_as_percent = parse->measured_as_percent;
   self->state = RC_TRIGGER_STATE_WAITING;
   self->has_hits = 0;
-  self->has_required_hits = parse->has_required_hits;
+  self->has_memrefs = 0;
 }
 
 int rc_trigger_size(const char* memaddr) {
-  rc_trigger_t* self;
-  rc_parse_state_t parse;
-  rc_memref_t* memrefs;
-  rc_init_parse_state(&parse, 0, 0, 0);
-  rc_init_parse_state_memrefs(&parse, &memrefs);
+  rc_trigger_with_memrefs_t* trigger;
+  rc_preparse_state_t preparse;
+  rc_init_preparse_state(&preparse);
 
-  self = RC_ALLOC(rc_trigger_t, &parse);
-  rc_parse_trigger_internal(self, &memaddr, &parse);
+  trigger = RC_ALLOC(rc_trigger_with_memrefs_t, &preparse.parse);
+  rc_parse_trigger_internal(&trigger->trigger, &memaddr, &preparse.parse);
+  rc_preparse_alloc_memrefs(NULL, &preparse);
 
-  rc_destroy_parse_state(&parse);
-  return parse.offset;
+  rc_destroy_preparse_state(&preparse);
+  return preparse.parse.offset;
 }
 
-rc_trigger_t* rc_parse_trigger(void* buffer, const char* memaddr, lua_State* L, int funcs_ndx) {
-  rc_trigger_t* self;
-  rc_parse_state_t parse;
+rc_trigger_t* rc_parse_trigger(void* buffer, const char* memaddr, void* unused_L, int unused_funcs_idx) {
+  rc_trigger_with_memrefs_t* trigger;
+  rc_preparse_state_t preparse;
+  const char* preparse_memaddr = memaddr;
+
+  (void)unused_L;
+  (void)unused_funcs_idx;
 
   if (!buffer || !memaddr)
     return NULL;
 
-  rc_init_parse_state(&parse, buffer, L, funcs_ndx);
+  /* first pass : determine how many memrefs are needed */
+  rc_init_preparse_state(&preparse);
+  trigger = RC_ALLOC(rc_trigger_with_memrefs_t, &preparse.parse);
+  rc_parse_trigger_internal(&trigger->trigger, &preparse_memaddr, &preparse.parse);
 
-  self = RC_ALLOC(rc_trigger_t, &parse);
-  rc_init_parse_state_memrefs(&parse, &self->memrefs);
+  /* allocate the trigger and memrefs */
+  rc_reset_parse_state(&preparse.parse, buffer);
+  trigger = RC_ALLOC(rc_trigger_with_memrefs_t, &preparse.parse);
+  rc_preparse_alloc_memrefs(&trigger->memrefs, &preparse);
 
-  rc_parse_trigger_internal(self, &memaddr, &parse);
+  /* parse the trigger */
+  rc_parse_trigger_internal(&trigger->trigger, &memaddr, &preparse.parse);
+  trigger->trigger.has_memrefs = 1;
 
-  rc_destroy_parse_state(&parse);
-  return (parse.offset >= 0) ? self : NULL;
+  rc_destroy_preparse_state(&preparse);
+  return (preparse.parse.offset >= 0) ? &trigger->trigger : NULL;
 }
 
 int rc_trigger_state_active(int state)
@@ -124,13 +133,33 @@ static void rc_reset_trigger_hitcounts(rc_trigger_t* self) {
   }
 }
 
-int rc_evaluate_trigger(rc_trigger_t* self, rc_peek_t peek, void* ud, lua_State* L) {
+static void rc_update_trigger_memrefs(rc_trigger_t* self, rc_peek_t peek, void* ud) {
+  if (self->has_memrefs) {
+    rc_trigger_with_memrefs_t* trigger = (rc_trigger_with_memrefs_t*)self;
+    rc_update_memref_values(&trigger->memrefs, peek, ud);
+  }
+}
+
+rc_memrefs_t* rc_trigger_get_memrefs(rc_trigger_t* self) {
+  if (self->has_memrefs) {
+    rc_trigger_with_memrefs_t* trigger = (rc_trigger_with_memrefs_t*)self;
+    return &trigger->memrefs;
+  }
+
+  return NULL;
+}
+
+int rc_evaluate_trigger(rc_trigger_t* self, rc_peek_t peek, void* ud, void* unused_L) {
   rc_eval_state_t eval_state;
   rc_condset_t* condset;
+  rc_typed_value_t measured_value;
+  int measured_from_hits = 0;
   int ret;
   char is_paused;
   char is_primed;
 
+  (void)unused_L;
+
   switch (self->state)
   {
     case RC_TRIGGER_STATE_TRIGGERED:
@@ -143,7 +172,7 @@ int rc_evaluate_trigger(rc_trigger_t* self, rc_peek_t peek, void* ud, lua_State*
 
     case RC_TRIGGER_STATE_INACTIVE:
       /* not yet active. update the memrefs so deltas are correct when it becomes active, then return INACTIVE */
-      rc_update_memref_values(self->memrefs, peek, ud);
+      rc_update_trigger_memrefs(self, peek, ud);
       return RC_TRIGGER_STATE_INACTIVE;
 
     default:
@@ -151,18 +180,24 @@ int rc_evaluate_trigger(rc_trigger_t* self, rc_peek_t peek, void* ud, lua_State*
   }
 
   /* update the memory references */
-  rc_update_memref_values(self->memrefs, peek, ud);
+  rc_update_trigger_memrefs(self, peek, ud);
 
   /* process the trigger */
   memset(&eval_state, 0, sizeof(eval_state));
   eval_state.peek = peek;
   eval_state.peek_userdata = ud;
-  eval_state.L = L;
+
+  measured_value.type = RC_VALUE_TYPE_NONE;
 
   if (self->requirement != NULL) {
     ret = rc_test_condset(self->requirement, &eval_state);
-    is_paused = self->requirement->is_paused;
-    is_primed = eval_state.primed;
+    is_paused = eval_state.is_paused;
+    is_primed = eval_state.is_primed;
+
+    if (eval_state.measured_value.type != RC_VALUE_TYPE_NONE) {
+      memcpy(&measured_value, &eval_state.measured_value, sizeof(measured_value));
+      measured_from_hits = eval_state.measured_from_hits;
+    }
   } else {
     ret = 1;
     is_paused = 0;
@@ -177,8 +212,17 @@ int rc_evaluate_trigger(rc_trigger_t* self, rc_peek_t peek, void* ud, lua_State*
 
     do {
       sub |= rc_test_condset(condset, &eval_state);
-      sub_paused &= condset->is_paused;
-      sub_primed |= eval_state.primed;
+      sub_paused &= eval_state.is_paused;
+      sub_primed |= eval_state.is_primed;
+
+      if (eval_state.measured_value.type != RC_VALUE_TYPE_NONE) {
+        /* if no previous Measured value was captured, or the new one is greater, keep the new one */
+        if (measured_value.type == RC_VALUE_TYPE_NONE ||
+            rc_typed_value_compare(&eval_state.measured_value, &measured_value, RC_OPERATOR_GT)) {
+          memcpy(&measured_value, &eval_state.measured_value, sizeof(measured_value));
+          measured_from_hits = eval_state.measured_from_hits;
+        }
+      }
 
       condset = condset->next;
     } while (condset);
@@ -193,15 +237,15 @@ int rc_evaluate_trigger(rc_trigger_t* self, rc_peek_t peek, void* ud, lua_State*
 
   /* if paused, the measured value may not be captured, keep the old value */
   if (!is_paused) {
-    rc_typed_value_convert(&eval_state.measured_value, RC_VALUE_TYPE_UNSIGNED);
-    self->measured_value = eval_state.measured_value.value.u32;
+    rc_typed_value_convert(&measured_value, RC_VALUE_TYPE_UNSIGNED);
+    self->measured_value = measured_value.value.u32;
   }
 
   /* if any ResetIf condition was true, reset the hit counts */
   if (eval_state.was_reset) {
     /* if the measured value came from a hit count, reset it. do this before calling
      * rc_reset_trigger_hitcounts in case we need to call rc_condset_is_measured_from_hitcount */
-    if (eval_state.measured_from_hits) {
+    if (measured_from_hits) {
       self->measured_value = 0;
     }
     else if (is_paused && self->measured_value) {
@@ -272,11 +316,11 @@ int rc_evaluate_trigger(rc_trigger_t* self, rc_peek_t peek, void* ud, lua_State*
   return self->state;
 }
 
-int rc_test_trigger(rc_trigger_t* self, rc_peek_t peek, void* ud, lua_State* L) {
+int rc_test_trigger(rc_trigger_t* self, rc_peek_t peek, void* ud, void* unused_L) {
   /* for backwards compatibilty, rc_test_trigger always assumes the achievement is active */
   self->state = RC_TRIGGER_STATE_ACTIVE;
 
-  return (rc_evaluate_trigger(self, peek, ud, L) == RC_TRIGGER_STATE_TRIGGERED);
+  return (rc_evaluate_trigger(self, peek, ud, unused_L) == RC_TRIGGER_STATE_TRIGGERED);
 }
 
 void rc_reset_trigger(rc_trigger_t* self) {
