@@ -5,8 +5,6 @@
 #include <float.h> /* FLT_EPSILON */
 #include <math.h> /* fmod */
 
-
-
 int rc_is_valid_variable_character(char ch, int is_first) {
   if (is_first) {
     if (!isalpha((unsigned char)ch))
@@ -27,7 +25,7 @@ static void rc_parse_cond_value(rc_value_t* self, const char** memaddr, rc_parse
   do
   {
     parse->measured_target = 0; /* passing is_value=1 should prevent any conflicts, but clear it out anyway */
-    *next_clause = rc_parse_condset(memaddr, parse, 1);
+    *next_clause = rc_parse_condset(memaddr, parse);
     if (parse->offset < 0) {
       return;
     }
@@ -52,182 +50,263 @@ static void rc_parse_cond_value(rc_value_t* self, const char** memaddr, rc_parse
   (*next_clause)->next = 0;
 }
 
-void rc_parse_legacy_value(rc_value_t* self, const char** memaddr, rc_parse_state_t* parse) {
+static void rc_parse_legacy_value(rc_value_t* self, const char** memaddr, rc_parse_state_t* parse) {
+  rc_condset_with_trailing_conditions_t* condset_with_conditions;
   rc_condition_t** next;
   rc_condset_t** next_clause;
+  rc_condset_t* condset;
+  rc_condition_t local_cond;
   rc_condition_t* cond;
+  uint32_t num_measured_conditions;
   char buffer[64] = "A:";
   const char* buffer_ptr;
   char* ptr;
+  int done;
 
   /* convert legacy format into condset */
-  self->conditions = RC_ALLOC(rc_condset_t, parse);
-  memset(self->conditions, 0, sizeof(rc_condset_t));
-
-  next = &self->conditions->conditions;
-  next_clause = &self->conditions->next;
-
-  for (;; ++(*memaddr)) {
-    buffer[0] = 'A'; /* reset to AddSource */
-    ptr = &buffer[2];
-
-    /* extract the next clause */
-    for (;; ++(*memaddr)) {
-      switch (**memaddr) {
+  next_clause = &self->conditions;
+  do {
+    /* count the number of joiners and add one to determine the number of clauses.  */
+    done = 0;
+    num_measured_conditions = 1;
+    buffer_ptr = *memaddr;
+    do {
+      switch (*buffer_ptr++) {
         case '_': /* add next */
-        case '$': /* maximum of */
-        case '\0': /* end of string */
-        case ':': /* end of leaderboard clause */
-        case ')': /* end of rich presence macro */
-          *ptr = '\0';
+          ++num_measured_conditions;
+          buffer[0] = 'A'; /* reset to AddSource */
           break;
 
-        case '*':
-          *ptr++ = '*';
-
-          buffer_ptr = *memaddr + 1;
+        case '*': /* multiply */
           if (*buffer_ptr == '-') {
-            buffer[0] = 'B'; /* change to SubSource */
-            ++(*memaddr); /* don't copy sign */
-            ++buffer_ptr; /* ignore sign when doing floating point check */
-          }
-          else if (*buffer_ptr == '+') {
-            ++buffer_ptr; /* ignore sign when doing floating point check  */
-          }
-
-          /* if it looks like a floating point number, add the 'f' prefix */
-          while (isdigit((unsigned char)*buffer_ptr))
+            /* multiplication by a negative number will convert to SubSource */
             ++buffer_ptr;
-          if (*buffer_ptr == '.')
-            *ptr++ = 'f';
-          continue;
+            buffer[0] = 'B';
+          }
+          break;
 
-        default:
-          *ptr++ = **memaddr;
-          continue;
+        case '\0': /* end of string */
+        case '$': /* maximum of */
+        case ':': /* end of leaderboard clause */
+        case ')': /* end of rich presence macro */
+          done = 1;
+          break;
+
+        default: /* assume everything else is valid - bad stuff will be filtered out later */
+          break;
       }
+    } while (!done);
 
-      break;
-    }
+    /* if last condition is SubSource, we'll need to add a dummy condition for the Measured */
+    if (buffer[0] == 'B')
+      ++num_measured_conditions;
 
-    /* process the clause */
-    buffer_ptr = buffer;
-    cond = rc_parse_condition(&buffer_ptr, parse, 0);
+    condset_with_conditions = RC_ALLOC_WITH_TRAILING(rc_condset_with_trailing_conditions_t,
+                                                     rc_condition_t, conditions, num_measured_conditions, parse);
     if (parse->offset < 0)
       return;
 
-    if (*buffer_ptr) {
-      /* whatever we copied as a single condition was not fully consumed */
-      parse->offset = RC_INVALID_COMPARISON;
-      return;
-    }
+    condset = (rc_condset_t*)condset_with_conditions;
+    memset(condset, 0, sizeof(*condset));
+    condset->num_measured_conditions = num_measured_conditions;
+    cond = &condset_with_conditions->conditions[0];
+
+    next = &condset->conditions;
+
+    for (;; ++(*memaddr)) {
+      buffer[0] = 'A'; /* reset to AddSource */
+      ptr = &buffer[2];
+
+      /* extract the next clause */
+      for (;; ++(*memaddr)) {
+        switch (**memaddr) {
+          case '_': /* add next */
+          case '$': /* maximum of */
+          case '\0': /* end of string */
+          case ':': /* end of leaderboard clause */
+          case ')': /* end of rich presence macro */
+            *ptr = '\0';
+            break;
+
+          case '*':
+            *ptr++ = '*';
+
+            buffer_ptr = *memaddr + 1;
+            if (*buffer_ptr == '-') {
+              buffer[0] = 'B'; /* change to SubSource */
+              ++(*memaddr); /* don't copy sign */
+              ++buffer_ptr; /* ignore sign when doing floating point check */
+            }
+            else if (*buffer_ptr == '+') {
+              ++buffer_ptr; /* ignore sign when doing floating point check  */
+            }
+
+            /* if it looks like a floating point number, add the 'f' prefix */
+            while (isdigit((unsigned char)*buffer_ptr))
+              ++buffer_ptr;
+            if (*buffer_ptr == '.')
+              *ptr++ = 'f';
+            continue;
+
+          default:
+            *ptr++ = **memaddr;
+            continue;
+        }
 
-    switch (cond->oper) {
-      case RC_OPERATOR_MULT:
-      case RC_OPERATOR_DIV:
-      case RC_OPERATOR_AND:
-      case RC_OPERATOR_XOR:
-      case RC_OPERATOR_MOD:
-      case RC_OPERATOR_ADD:
-      case RC_OPERATOR_SUB:
-      case RC_OPERATOR_NONE:
         break;
+      }
 
-      default:
+      /* process the clause */
+      if (!parse->buffer)
+        cond = &local_cond;
+
+      buffer_ptr = buffer;
+      rc_parse_condition_internal(cond, &buffer_ptr, parse);
+      if (parse->offset < 0)
+        return;
+
+      if (*buffer_ptr) {
+        /* whatever we copied as a single condition was not fully consumed */
+        parse->offset = RC_INVALID_COMPARISON;
+        return;
+      }
+
+      if (!rc_operator_is_modifying(cond->oper)) {
         parse->offset = RC_INVALID_OPERATOR;
         return;
-    }
+      }
 
-    *next = cond;
-
-    if (**memaddr == '_') {
-      /* add next */
+      *next = cond;
       next = &cond->next;
-      continue;
+
+      if (**memaddr != '_') /* add next */
+        break;
+
+      rc_condition_update_parse_state(cond, parse);
+      ++cond;
     }
 
+    /* end of clause */
     if (cond->type == RC_CONDITION_SUB_SOURCE) {
       /* cannot change SubSource to Measured. add a dummy condition */
-      next = &cond->next;
+      rc_condition_update_parse_state(cond, parse);
+      if (parse->buffer)
+        ++cond;
+
       buffer_ptr = "A:0";
-      cond = rc_parse_condition(&buffer_ptr, parse, 0);
+      rc_parse_condition_internal(cond, &buffer_ptr, parse);
       *next = cond;
+      next = &cond->next;
     }
 
     /* convert final AddSource condition to Measured */
     cond->type = RC_CONDITION_MEASURED;
-    cond->next = 0;
+    cond->next = NULL;
+    rc_condition_update_parse_state(cond, parse);
+
+    /* finalize clause */
+    *next_clause = condset;
+    next_clause = &condset->next;
 
     if (**memaddr != '$') {
       /* end of valid string */
-      *next_clause = 0;
+      *next_clause = NULL;
       break;
     }
 
     /* max of ($), start a new clause */
-    *next_clause = RC_ALLOC(rc_condset_t, parse);
-
-    if (parse->buffer) /* don't clear in sizing mode or pointer will break */
-      memset(*next_clause, 0, sizeof(rc_condset_t));
-
-    next = &(*next_clause)->conditions;
-    next_clause = &(*next_clause)->next;
-  }
+    ++(*memaddr);
+  } while (1);
 }
 
 void rc_parse_value_internal(rc_value_t* self, const char** memaddr, rc_parse_state_t* parse) {
+  const uint8_t was_value = parse->is_value;
+  const rc_condition_t* condition;
+  parse->is_value = 1;
+
   /* if it starts with a condition flag (M: A: B: C:), parse the conditions */
-  if ((*memaddr)[1] == ':') {
+  if ((*memaddr)[1] == ':')
     rc_parse_cond_value(self, memaddr, parse);
-  }
-  else {
+  else
     rc_parse_legacy_value(self, memaddr, parse);
+
+  if (parse->offset >= 0 && parse->buffer) {
+    self->name = "(unnamed)";
+    self->value.value = self->value.prior = 0;
+    self->value.memref_type = RC_MEMREF_TYPE_VALUE;
+    self->value.changed = 0;
+    self->has_memrefs = 0;
+
+    for (condition = self->conditions->conditions; condition; condition = condition->next) {
+      if (condition->type == RC_CONDITION_MEASURED) {
+        if (rc_operand_is_float(&condition->operand1)) {
+          self->value.size = RC_MEMSIZE_FLOAT;
+          self->value.type = RC_VALUE_TYPE_FLOAT;
+        }
+        else {
+          self->value.size = RC_MEMSIZE_32_BITS;
+          self->value.type = RC_VALUE_TYPE_UNSIGNED;
+        }
+        break;
+      }
+    }
   }
 
-  self->name = "(unnamed)";
-  self->value.value = self->value.prior = 0;
-  self->value.changed = 0;
-  self->next = 0;
+  parse->is_value = was_value;
 }
 
 int rc_value_size(const char* memaddr) {
-  rc_value_t* self;
-  rc_parse_state_t parse;
-  rc_memref_t* first_memref;
-  rc_init_parse_state(&parse, 0, 0, 0);
-  rc_init_parse_state_memrefs(&parse, &first_memref);
+  rc_value_with_memrefs_t* value;
+  rc_preparse_state_t preparse;
+  rc_init_preparse_state(&preparse);
 
-  self = RC_ALLOC(rc_value_t, &parse);
-  rc_parse_value_internal(self, &memaddr, &parse);
+  value = RC_ALLOC(rc_value_with_memrefs_t, &preparse.parse);
+  rc_parse_value_internal(&value->value, &memaddr, &preparse.parse);
+  rc_preparse_alloc_memrefs(NULL, &preparse);
 
-  rc_destroy_parse_state(&parse);
-  return parse.offset;
+  rc_destroy_preparse_state(&preparse);
+  return preparse.parse.offset;
 }
 
-rc_value_t* rc_parse_value(void* buffer, const char* memaddr, lua_State* L, int funcs_ndx) {
-  rc_value_t* self;
-  rc_parse_state_t parse;
+rc_value_t* rc_parse_value(void* buffer, const char* memaddr, void* unused_L, int unused_funcs_idx) {
+  rc_value_with_memrefs_t* value;
+  rc_preparse_state_t preparse;
+  const char* preparse_memaddr = memaddr;
+
+  (void)unused_L;
+  (void)unused_funcs_idx;
 
   if (!buffer || !memaddr)
     return NULL;
 
-  rc_init_parse_state(&parse, buffer, L, funcs_ndx);
+  rc_init_preparse_state(&preparse);
+  value = RC_ALLOC(rc_value_with_memrefs_t, &preparse.parse);
+  rc_parse_value_internal(&value->value, &preparse_memaddr, &preparse.parse);
 
-  self = RC_ALLOC(rc_value_t, &parse);
-  rc_init_parse_state_memrefs(&parse, &self->memrefs);
+  rc_reset_parse_state(&preparse.parse, buffer);
+  value = RC_ALLOC(rc_value_with_memrefs_t, &preparse.parse);
+  rc_preparse_alloc_memrefs(&value->memrefs, &preparse);
 
-  rc_parse_value_internal(self, &memaddr, &parse);
+  rc_parse_value_internal(&value->value, &memaddr, &preparse.parse);
+  value->value.has_memrefs = 1;
 
-  rc_destroy_parse_state(&parse);
-  return (parse.offset >= 0) ? self : NULL;
+  rc_destroy_preparse_state(&preparse);
+  return (preparse.parse.offset >= 0) ? &value->value : NULL;
 }
 
-int rc_evaluate_value_typed(rc_value_t* self, rc_typed_value_t* value, rc_peek_t peek, void* ud, lua_State* L) {
+static void rc_update_value_memrefs(rc_value_t* self, rc_peek_t peek, void* ud) {
+  if (self->has_memrefs) {
+    rc_value_with_memrefs_t* value = (rc_value_with_memrefs_t*)self;
+    rc_update_memref_values(&value->memrefs, peek, ud);
+  }
+}
+
+int rc_evaluate_value_typed(rc_value_t* self, rc_typed_value_t* value, rc_peek_t peek, void* ud) {
   rc_eval_state_t eval_state;
   rc_condset_t* condset;
   int valid = 0;
 
-  rc_update_memref_values(self->memrefs, peek, ud);
+  rc_update_value_memrefs(self, peek, ud);
 
   value->value.i32 = 0;
   value->type = RC_VALUE_TYPE_SIGNED;
@@ -236,7 +315,6 @@ int rc_evaluate_value_typed(rc_value_t* self, rc_typed_value_t* value, rc_peek_t
     memset(&eval_state, 0, sizeof(eval_state));
     eval_state.peek = peek;
     eval_state.peek_userdata = ud;
-    eval_state.L = L;
 
     rc_test_condset(condset, &eval_state);
 
@@ -248,34 +326,32 @@ int rc_evaluate_value_typed(rc_value_t* self, rc_typed_value_t* value, rc_peek_t
        * NOTE: ResetIf only affects the current condset when used in values!
        */
       rc_reset_condset(condset);
-
-      /* if the measured value came from a hit count, reset it too */
-      if (eval_state.measured_from_hits) {
-        eval_state.measured_value.value.u32 = 0;
-        eval_state.measured_value.type = RC_VALUE_TYPE_UNSIGNED;
-      }
     }
 
-    if (!valid) {
-      /* capture the first valid measurement */
-      memcpy(value, &eval_state.measured_value, sizeof(*value));
-      valid = 1;
-    }
-    else {
-      /* multiple condsets are currently only used for the MAX_OF operation.
-       * only keep the condset's value if it's higher than the current highest value.
-       */
-      if (rc_typed_value_compare(&eval_state.measured_value, value, RC_OPERATOR_GT))
+    if (eval_state.measured_value.type != RC_VALUE_TYPE_NONE) {
+      if (!valid) {
+        /* capture the first valid measurement, which may be negative */
         memcpy(value, &eval_state.measured_value, sizeof(*value));
+        valid = 1;
+      }
+      else {
+        /* multiple condsets are currently only used for the MAX_OF operation.
+         * only keep the condset's value if it's higher than the current highest value.
+         */
+        if (rc_typed_value_compare(&eval_state.measured_value, value, RC_OPERATOR_GT))
+          memcpy(value, &eval_state.measured_value, sizeof(*value));
+      }
     }
   }
 
   return valid;
 }
 
-int32_t rc_evaluate_value(rc_value_t* self, rc_peek_t peek, void* ud, lua_State* L) {
+int32_t rc_evaluate_value(rc_value_t* self, rc_peek_t peek, void* ud, void* unused_L) {
   rc_typed_value_t result;
-  int valid = rc_evaluate_value_typed(self, &result, peek, ud, L);
+  int valid = rc_evaluate_value_typed(self, &result, peek, ud);
+
+  (void)unused_L;
 
   if (valid) {
     /* if not paused, store the value so that it's available when paused. */
@@ -317,84 +393,81 @@ int rc_value_from_hits(rc_value_t* self)
   return 0;
 }
 
-void rc_init_parse_state_variables(rc_parse_state_t* parse, rc_value_t** variables) {
-  parse->variables = variables;
-  *variables = 0;
-}
-
-rc_value_t* rc_alloc_helper_variable(const char* memaddr, size_t memaddr_len, rc_parse_state_t* parse)
-{
-  rc_value_t** variables = parse->variables;
+rc_value_t* rc_alloc_variable(const char* memaddr, size_t memaddr_len, rc_parse_state_t* parse) {
+  rc_value_t** value_ptr = parse->variables;
   rc_value_t* value;
   const char* name;
   uint32_t measured_target;
 
-  while ((value = *variables) != NULL) {
+  if (!value_ptr)
+    return NULL;
+
+  while (*value_ptr) {
+    value = *value_ptr;
     if (strncmp(value->name, memaddr, memaddr_len) == 0 && value->name[memaddr_len] == 0)
       return value;
 
-    variables = &value->next;
+    value_ptr = &value->next;
   }
 
-  value = RC_ALLOC_SCRATCH(rc_value_t, parse);
-  memset(&value->value, 0, sizeof(value->value));
-  value->value.size = RC_MEMSIZE_VARIABLE;
-  value->memrefs = NULL;
-
   /* capture name before calling parse as parse will update memaddr pointer */
   name = rc_alloc_str(parse, memaddr, memaddr_len);
   if (!name)
     return NULL;
 
+  /* no match found, create a new entry */
+  value = RC_ALLOC_SCRATCH(rc_value_t, parse);
+  memset(value, 0, sizeof(value->value));
+  value->value.size = RC_MEMSIZE_VARIABLE;
+  value->next = NULL;
+
   /* the helper variable likely has a Measured condition. capture the current measured_target so we can restore it
    * after generating the variable so the variable's Measured target doesn't conflict with the rest of the trigger. */
   measured_target = parse->measured_target;
-
-  /* disable variable resolution when defining a variable to prevent infinite recursion */
-  variables = parse->variables;
-  parse->variables = NULL;
   rc_parse_value_internal(value, &memaddr, parse);
-  parse->variables = variables;
-
-  /* restore the measured target */
   parse->measured_target = measured_target;
 
   /* store name after calling parse as parse will set name to (unnamed) */
   value->name = name;
 
-  /* append the new variable to the end of the list (have to re-evaluate in case any others were added) */
-  while (*variables != NULL)
-    variables = &(*variables)->next;
-  *variables = value;
-
+  *value_ptr = value;
   return value;
 }
 
-void rc_update_variables(rc_value_t* variable, rc_peek_t peek, void* ud, lua_State* L) {
+uint32_t rc_count_values(const rc_value_t* values) {
+  uint32_t count = 0;
+  while (values) {
+    ++count;
+    values = values->next;
+  }
+
+  return count;
+}
+
+void rc_update_values(rc_value_t* values, rc_peek_t peek, void* ud) {
   rc_typed_value_t result;
 
-  while (variable) {
-    if (rc_evaluate_value_typed(variable, &result, peek, ud, L)) {
+  rc_value_t* value = values;
+  for (; value; value = value->next) {
+    if (rc_evaluate_value_typed(value, &result, peek, ud)) {
       /* store the raw bytes and type to be restored by rc_typed_value_from_memref_value  */
-      rc_update_memref_value(&variable->value, result.value.u32);
-      variable->value.type = result.type;
+      rc_update_memref_value(&value->value, result.value.u32);
+      value->value.type = result.type;
     }
-
-    variable = variable->next;
   }
 }
 
-void rc_typed_value_from_memref_value(rc_typed_value_t* value, const rc_memref_value_t* memref) {
-  value->value.u32 = memref->value;
+void rc_reset_values(rc_value_t* values) {
+  rc_value_t* value = values;
 
-  if (memref->size == RC_MEMSIZE_VARIABLE) {
-    /* a variable can be any of the supported types, but the raw data was copied into u32 */
-    value->type = memref->type;
-  }
-  else {
-    /* not a variable, only u32 is supported */
-    value->type = RC_VALUE_TYPE_UNSIGNED;
-  }
+  for (; value; value = value->next)
+    rc_reset_value(value);
+}
+
+void rc_typed_value_from_memref_value(rc_typed_value_t* value, const rc_memref_value_t* memref) {
+  /* raw value is always u32, type can mark it as something else */
+  value->value.u32 = memref->value;
+  value->type = memref->type;
 }
 
 void rc_typed_value_convert(rc_typed_value_t* value, char new_type) {
@@ -483,8 +556,12 @@ void rc_typed_value_negate(rc_typed_value_t* value) {
 void rc_typed_value_add(rc_typed_value_t* value, const rc_typed_value_t* amount) {
   rc_typed_value_t converted;
 
-  if (amount->type != value->type && value->type != RC_VALUE_TYPE_NONE)
-    amount = rc_typed_value_convert_into(&converted, amount, value->type);
+  if (amount->type != value->type && value->type != RC_VALUE_TYPE_NONE) {
+    if (amount->type == RC_VALUE_TYPE_FLOAT)
+      rc_typed_value_convert(value, RC_VALUE_TYPE_FLOAT);
+    else
+      amount = rc_typed_value_convert_into(&converted, amount, value->type);
+  }
 
   switch (value->type)
   {
@@ -651,56 +728,56 @@ void rc_typed_value_modulus(rc_typed_value_t* value, const rc_typed_value_t* amo
 
   switch (amount->type)
   {
-  case RC_VALUE_TYPE_UNSIGNED:
-    if (amount->value.u32 == 0) { /* divide by zero */
-      value->type = RC_VALUE_TYPE_NONE;
-      return;
-    }
+    case RC_VALUE_TYPE_UNSIGNED:
+      if (amount->value.u32 == 0) { /* divide by zero */
+        value->type = RC_VALUE_TYPE_NONE;
+        return;
+      }
 
-    switch (value->type) {
-    case RC_VALUE_TYPE_UNSIGNED: /* integer math */
-      value->value.u32 %= amount->value.u32;
-      return;
-    case RC_VALUE_TYPE_SIGNED: /* integer math */
-      value->value.i32 %= (int)amount->value.u32;
-      return;
-    case RC_VALUE_TYPE_FLOAT:
-      amount = rc_typed_value_convert_into(&converted, amount, RC_VALUE_TYPE_FLOAT);
+      switch (value->type) {
+        case RC_VALUE_TYPE_UNSIGNED: /* integer math */
+          value->value.u32 %= amount->value.u32;
+          return;
+        case RC_VALUE_TYPE_SIGNED: /* integer math */
+          value->value.i32 %= (int)amount->value.u32;
+          return;
+        case RC_VALUE_TYPE_FLOAT:
+          amount = rc_typed_value_convert_into(&converted, amount, RC_VALUE_TYPE_FLOAT);
+          break;
+        default:
+          value->type = RC_VALUE_TYPE_NONE;
+          return;
+      }
       break;
+
+    case RC_VALUE_TYPE_SIGNED:
+      if (amount->value.i32 == 0) { /* divide by zero */
+        value->type = RC_VALUE_TYPE_NONE;
+        return;
+      }
+
+      switch (value->type) {
+        case RC_VALUE_TYPE_SIGNED: /* integer math */
+          value->value.i32 %= amount->value.i32;
+          return;
+        case RC_VALUE_TYPE_UNSIGNED: /* integer math */
+          value->value.u32 %= (unsigned)amount->value.i32;
+          return;
+        case RC_VALUE_TYPE_FLOAT:
+          amount = rc_typed_value_convert_into(&converted, amount, RC_VALUE_TYPE_FLOAT);
+          break;
+        default:
+          value->type = RC_VALUE_TYPE_NONE;
+          return;
+      }
+      break;
+
+    case RC_VALUE_TYPE_FLOAT:
+      break;
+
     default:
       value->type = RC_VALUE_TYPE_NONE;
       return;
-    }
-    break;
-
-  case RC_VALUE_TYPE_SIGNED:
-    if (amount->value.i32 == 0) { /* divide by zero */
-      value->type = RC_VALUE_TYPE_NONE;
-      return;
-    }
-
-    switch (value->type) {
-    case RC_VALUE_TYPE_SIGNED: /* integer math */
-      value->value.i32 %= amount->value.i32;
-      return;
-    case RC_VALUE_TYPE_UNSIGNED: /* integer math */
-      value->value.u32 %= (unsigned)amount->value.i32;
-      return;
-    case RC_VALUE_TYPE_FLOAT:
-      amount = rc_typed_value_convert_into(&converted, amount, RC_VALUE_TYPE_FLOAT);
-      break;
-    default:
-      value->type = RC_VALUE_TYPE_NONE;
-      return;
-    }
-    break;
-
-  case RC_VALUE_TYPE_FLOAT:
-    break;
-
-  default:
-    value->type = RC_VALUE_TYPE_NONE;
-    return;
   }
 
   if (amount->value.f32 == 0.0) { /* divide by zero */
@@ -712,6 +789,44 @@ void rc_typed_value_modulus(rc_typed_value_t* value, const rc_typed_value_t* amo
   value->value.f32 = (float)fmod(value->value.f32, amount->value.f32);
 }
 
+void rc_typed_value_combine(rc_typed_value_t* value, rc_typed_value_t* amount, uint8_t oper) {
+  switch (oper) {
+    case RC_OPERATOR_MULT:
+      rc_typed_value_multiply(value, amount);
+      break;
+
+    case RC_OPERATOR_DIV:
+      rc_typed_value_divide(value, amount);
+      break;
+
+    case RC_OPERATOR_AND:
+      rc_typed_value_convert(value, RC_VALUE_TYPE_UNSIGNED);
+      rc_typed_value_convert(amount, RC_VALUE_TYPE_UNSIGNED);
+      value->value.u32 &= amount->value.u32;
+      break;
+
+    case RC_OPERATOR_XOR:
+      rc_typed_value_convert(value, RC_VALUE_TYPE_UNSIGNED);
+      rc_typed_value_convert(amount, RC_VALUE_TYPE_UNSIGNED);
+      value->value.u32 ^= amount->value.u32;
+      break;
+
+    case RC_OPERATOR_MOD:
+      rc_typed_value_modulus(value, amount);
+      break;
+
+    case RC_OPERATOR_ADD:
+      rc_typed_value_add(value, amount);
+      break;
+
+    case RC_OPERATOR_SUB:
+      rc_typed_value_negate(amount);
+      rc_typed_value_add(value, amount);
+      break;
+  }
+}
+
+
 static int rc_typed_value_compare_floats(float f1, float f2, char oper) {
   if (f1 == f2) {
     /* exactly equal */
