@@ -16,6 +16,7 @@
 #include <cstring>
 #include <getopt.h>
 #include "switchres.h"
+#include "switchres_defines.h"
 #include "log.h"
 
 using namespace std;
@@ -25,7 +26,42 @@ int show_usage();
 
 enum
  {
-	OPT_MODELINE = 128
+	OPT_CRT_RANGE0 = 128,
+	OPT_CRT_RANGE1,
+	OPT_CRT_RANGE2,
+	OPT_CRT_RANGE3,
+	OPT_CRT_RANGE4,
+	OPT_CRT_RANGE5,
+	OPT_CRT_RANGE6,
+	OPT_CRT_RANGE7,
+	OPT_CRT_RANGE8,
+	OPT_CRT_RANGE9,
+	OPT_LCD_RANGE,
+	OPT_MODELINE,
+	OPT_USER_MODE,
+	OPT_API,
+	OPT_LOCK_UNSUPPORTED_MODES,
+	OPT_LOCK_SYSTEM_MODES,
+	OPT_REFRESH_DONT_CARE,
+	OPT_KEEP_CHANGES,
+	OPT_MODELINE_GENERATION,
+	OPT_INTERLACE,
+	OPT_DOUBLESCAN,
+	OPT_DOTCLOCK_MIN,
+	OPT_SYNC_REFRESH_TOLERANCE,
+	OPT_SUPER_WIDTH,
+	OPT_V_SHIFT_CORRECT,
+	OPT_H_SIZE,
+	OPT_H_SHIFT,
+	OPT_V_SHIFT,
+	OPT_PIXEL_PRECISION,
+	OPT_INTERLACE_FORCE_EVEN,
+	OPT_SCALE_PROPORTIONAL,
+	OPT_SCREEN_COMPOSITING,
+	OPT_SCREEN_REORDERING,
+	OPT_ALLOW_HARDWARE_REFRESH,
+	OPT_CUSTOM_TIMING,
+	OPT_VERBOSITY
  };
 
 //============================================================
@@ -68,28 +104,65 @@ int main(int argc, char **argv)
 	{
 		static struct option long_options[] =
 		{
+			// Options unique to standalone Switchres
 			{"version",     no_argument,       &version_flag, '1'},
 			{"help",        no_argument,       0, 'h'},
 			{"calc",        no_argument,       0, 'c'},
 			{"switch",      no_argument,       0, 's'},
 			{"launch",      required_argument, 0, 'l'},
-			{"monitor",     required_argument, 0, 'm'},
-			{"aspect",      required_argument, 0, 'a'},
 			{"edid",        no_argument,       0, 'e'},
 			{"rotated",     no_argument,       0, 'r'},
-			{"display",     required_argument, 0, 'd'},
-			{"force",       required_argument, 0, 'f'},
+			{"force",       required_argument, 0, 'f'}, // equ. --user_mode
 			{"ini",         required_argument, 0, 'i'},
-			{"verbose",     no_argument,       0, 'v'},
-			{"backend",     required_argument, 0, 'b'},
-			{"keep",        no_argument,       0, 'k'},
+			{"keep",        no_argument,       0, 'k'}, // equ. --keep_changes
 			{"geometry",    required_argument, 0, 'g'},
-			{"modeline",    required_argument, 0, OPT_MODELINE},
+			// Options available in short and long forms
+			{SR_OPT_VERBOSE,                no_argument,       0, 'v'},
+			{SR_OPT_DISPLAY,                required_argument, 0, 'd'},
+			{SR_OPT_MONITOR,                required_argument, 0, 'm'},
+			{SR_OPT_ASPECT,                 required_argument, 0, 'a'},
+			// Long options, from switchres.ini
+			{SR_OPT_CRT_RANGE0,             required_argument, 0, OPT_CRT_RANGE0},
+			{SR_OPT_CRT_RANGE1,             required_argument, 0, OPT_CRT_RANGE1},
+			{SR_OPT_CRT_RANGE2,             required_argument, 0, OPT_CRT_RANGE2},
+			{SR_OPT_CRT_RANGE3,             required_argument, 0, OPT_CRT_RANGE3},
+			{SR_OPT_CRT_RANGE4,             required_argument, 0, OPT_CRT_RANGE4},
+			{SR_OPT_CRT_RANGE5,             required_argument, 0, OPT_CRT_RANGE5},
+			{SR_OPT_CRT_RANGE6,             required_argument, 0, OPT_CRT_RANGE6},
+			{SR_OPT_CRT_RANGE7,             required_argument, 0, OPT_CRT_RANGE7},
+			{SR_OPT_CRT_RANGE8,             required_argument, 0, OPT_CRT_RANGE8},
+			{SR_OPT_CRT_RANGE9,             required_argument, 0, OPT_CRT_RANGE9},
+			{SR_OPT_LCD_RANGE,              required_argument, 0, OPT_LCD_RANGE},
+			{SR_OPT_MODELINE,               required_argument, 0, OPT_MODELINE},
+			{SR_OPT_USER_MODE,              required_argument, 0, OPT_USER_MODE},
+			{SR_OPT_API,                    required_argument, 0, OPT_API},
+			{SR_OPT_LOCK_UNSUPPORTED_MODES, required_argument, 0, OPT_LOCK_UNSUPPORTED_MODES},
+			{SR_OPT_LOCK_SYSTEM_MODES,      required_argument, 0, OPT_LOCK_SYSTEM_MODES},
+			{SR_OPT_REFRESH_DONT_CARE,      required_argument, 0, OPT_REFRESH_DONT_CARE},
+			{SR_OPT_KEEP_CHANGES,           required_argument, 0, OPT_KEEP_CHANGES},
+			{SR_OPT_MODELINE_GENERATION,    required_argument, 0, OPT_MODELINE_GENERATION},
+			{SR_OPT_INTERLACE,              required_argument, 0, OPT_INTERLACE},
+			{SR_OPT_DOUBLESCAN,             required_argument, 0, OPT_DOUBLESCAN},
+			{SR_OPT_DOTCLOCK_MIN,           required_argument, 0, OPT_DOTCLOCK_MIN},
+			{SR_OPT_SYNC_REFRESH_TOLERANCE, required_argument, 0, OPT_SYNC_REFRESH_TOLERANCE},
+			{SR_OPT_SUPER_WIDTH,            required_argument, 0, OPT_SUPER_WIDTH},
+			{SR_OPT_V_SHIFT_CORRECT,        required_argument, 0, OPT_V_SHIFT_CORRECT},
+			{SR_OPT_H_SIZE,                 required_argument, 0, OPT_H_SIZE},
+			{SR_OPT_H_SHIFT,                required_argument, 0, OPT_H_SHIFT},
+			{SR_OPT_V_SHIFT,                required_argument, 0, OPT_V_SHIFT},
+			{SR_OPT_PIXEL_PRECISION,        required_argument, 0, OPT_PIXEL_PRECISION},
+			{SR_OPT_INTERLACE_FORCE_EVEN,   required_argument, 0, OPT_INTERLACE_FORCE_EVEN},
+			{SR_OPT_SCALE_PROPORTIONAL,     required_argument, 0, OPT_SCALE_PROPORTIONAL},
+			{SR_OPT_SCREEN_COMPOSITING,     required_argument, 0, OPT_SCREEN_COMPOSITING},
+			{SR_OPT_SCREEN_REORDERING,      required_argument, 0, OPT_SCREEN_REORDERING},
+			{SR_OPT_ALLOW_HARDWARE_REFRESH, required_argument, 0, OPT_ALLOW_HARDWARE_REFRESH},
+			{SR_OPT_CUSTOM_TIMING,          required_argument, 0, OPT_CUSTOM_TIMING},
+			{SR_OPT_VERBOSITY,              required_argument, 0, OPT_VERBOSITY},
 			{0, 0, 0, 0}
 		};
 
 		int option_index = 0;
-		int c = getopt_long(argc, argv, "vhcsl:m:a:erd:f:i:b:kg:", long_options, &option_index);
+		int c = getopt_long(argc, argv, "vhcsl:m:a:erd:f:i:kg:", long_options, &option_index);
 
 		if (c == -1)
 			break;
@@ -102,10 +175,6 @@ int main(int argc, char **argv)
 
 		switch (c)
 		{
-			case OPT_MODELINE:
-				df->set_modeline(optarg);
-				break;
-
 			case 'v':
 				switchres.set_log_level(3);
 				switchres.set_log_error_fn((void*)printf);
@@ -142,7 +211,8 @@ int main(int argc, char **argv)
 				// Add new display in multi-monitor case
 				if (index > 0) switchres.add_display();
 				index ++;
-				df->set_screen(optarg);
+				switchres.set_current_display(-1);
+				switchres.set_option(SR_OPT_DISPLAY, optarg);
 				break;
 
 			case 'a':
@@ -154,9 +224,10 @@ int main(int argc, char **argv)
 				break;
 
 			case 'f':
+			case OPT_USER_MODE:
 				force_flag = true;
 				if (sscanf(optarg, "%dx%d@%d", &user_mode.width, &user_mode.height, &user_mode.refresh) < 1)
-					log_error("Error: use format --force <w>x<h>@<r>\n");
+					log_error("Error: use format <w>x<h>@<r>\n");
 				break;
 
 			case 'i':
@@ -183,6 +254,45 @@ int main(int argc, char **argv)
 				df->set_v_shift(v_shift);
 				break;
 
+			// Long options
+			case OPT_CRT_RANGE0:
+			case OPT_CRT_RANGE1:
+			case OPT_CRT_RANGE2:
+			case OPT_CRT_RANGE3:
+			case OPT_CRT_RANGE4:
+			case OPT_CRT_RANGE5:
+			case OPT_CRT_RANGE6:
+			case OPT_CRT_RANGE7:
+			case OPT_CRT_RANGE8:
+			case OPT_CRT_RANGE9:
+			case OPT_LCD_RANGE:
+			case OPT_MODELINE:
+			case OPT_API:
+			case OPT_LOCK_UNSUPPORTED_MODES:
+			case OPT_LOCK_SYSTEM_MODES:
+			case OPT_REFRESH_DONT_CARE:
+			case OPT_KEEP_CHANGES:
+			case OPT_MODELINE_GENERATION:
+			case OPT_INTERLACE:
+			case OPT_DOUBLESCAN:
+			case OPT_DOTCLOCK_MIN:
+			case OPT_SYNC_REFRESH_TOLERANCE:
+			case OPT_SUPER_WIDTH:
+			case OPT_V_SHIFT_CORRECT:
+			case OPT_H_SIZE:
+			case OPT_H_SHIFT:
+			case OPT_V_SHIFT:
+			case OPT_PIXEL_PRECISION:
+			case OPT_INTERLACE_FORCE_EVEN:
+			case OPT_SCALE_PROPORTIONAL:
+			case OPT_SCREEN_COMPOSITING:
+			case OPT_SCREEN_REORDERING:
+			case OPT_ALLOW_HARDWARE_REFRESH:
+			case OPT_CUSTOM_TIMING:
+			case OPT_VERBOSITY:
+				switchres.set_option(long_options[option_index].name, optarg);
+				break;
+
 			default:
 				return 0;
 		}
@@ -265,7 +375,7 @@ int main(int argc, char **argv)
 				monitor_range *range = &switchres.display()->range[mode->range];
 				edid_from_modeline(mode, range, switchres.display()->monitor(), &edid);
 
-				char file_name[strlen(switchres.display()->monitor()) + 4];
+				char file_name[strlen(switchres.display()->monitor()) + 5];
 				sprintf(file_name, "%s.bin", switchres.display()->monitor());
 
 				FILE *file = fopen(file_name, "wb");
@@ -313,7 +423,7 @@ int show_version()
 	{
 		"Switchres " SWITCHRES_VERSION "\n"
 		"Modeline generation engine for emulation\n"
-		"Copyright (C) 2010-2021 - Chris Kennedy, Antonio Giner, Alexandre Wodarczyk, Gil Delescluse\n"
+		"Copyright (C) 2010-2024 - Chris Kennedy, Antonio Giner, Alexandre Wodarczyk, Gil Delescluse\n"
 		"License GPL-2.0+\n"
 		"This is free software: you are free to change and redistribute it.\n"
 		"There is NO WARRANTY, to the extent permitted by law.\n"
@@ -338,15 +448,17 @@ int show_usage()
 		"  -l, --launch <command>            Launch <command>\n"
 		"  -m, --monitor <preset>            Monitor preset (generic_15, arcade_15, pal, ntsc, etc.)\n"
 		"  -a, --aspect <num:den>            Monitor aspect ratio\n"
-		"  -r, --rotated                     Original mode's native orientation is rotated\n"
-		"  -d, --display <OS_display_name>   Use target display (Windows: \\\\.\\DISPLAY1, ... Linux: VGA-0, ...)\n"
+		"  -r, --rotated                     Rotate axes, preserving aspect ratio.\n"
+		"  -d, --display <display_index>     Use target display (index = 0, 1, 2...)\n"
 		"  -f, --force <w>x<h>@<r>           Force a specific video mode from display mode list\n"
 		"  -i, --ini <file.ini>              Specify an ini file\n"
-		"  -b, --backend <api_name>          Specify the api name\n"
 		"  -e, --edid                        Create an EDID binary with calculated video modes\n"
 		"  -k, --keep                        Keep changes on exit (warning: this disables cleanup)\n"
-		"  -g, --geometry <h_size>:<h_shift>:<v_shift>  Adjust geometry of generated modeline\n"
-		"  --modeline <\"pclk hdisp hsst hsend htot vdisp vsst vsend vtot flags\">  Force an XFree86 modeline\n"
+		"  -g, --geometry <adjustment>       Adjust geometry of generated modeline\n"
+		"                                    adjustment = <h_size>:<h_shift>:<v_shift>\n"
+		"                                    e.g. switchres 640 480 60 -c -g 1.1:-1:2\n\n"
+		"For more options, refer to switchres.ini. All options in switchres.ini can be applied in\n"
+		"command line as long options, e.g.: switchres 256 224 57.55 -c --dotclock_min 8.0\n\n"
 	};
 
 	log_info("%s", usage);
