@@ -192,6 +192,14 @@ struct android_app
    uint16_t rumble_last_strength_weak[MAX_USERS];
    uint16_t rumble_last_strength[MAX_USERS];
    int id[MAX_USERS];
+
+   bool is_play_store_build;
+
+#ifdef HAVE_SAF
+   jmethodID requestOpenDocumentTree;
+   jmethodID getPersistedSafTrees;
+   bool have_saf;
+#endif
 };
 
 enum
@@ -369,6 +377,10 @@ extern struct android_app *g_android;
 
 bool is_screen_reader_enabled(void);
 
+#ifdef HAVE_SAF
+void android_show_saf_tree_picker(void);
+#endif
+
 #endif
 
 #endif
