@@ -269,7 +269,7 @@ static void frontend_xdk_exec(const char *path, bool should_load_content)
    memset(&ptr, 0, sizeof(ptr));
 
    if (should_load_content && !path_is_empty(RARCH_PATH_CONTENT))
-      snprintf((char*)ptr.Data, sizeof(ptr.Data), "%s", path_get(RARCH_PATH_CONTENT));
+      strlcpy((char*)ptr.Data, path_get(RARCH_PATH_CONTENT), sizeof(ptr.Data));
 
    if (!string_is_empty(path))
       XLaunchNewImage(path, !string_is_empty((const char*)ptr.Data) ? &ptr : NULL);
