@@ -180,7 +180,7 @@ size_t frontend_driver_get_core_extension(char *s, size_t len)
 #ifdef HAVE_DYNAMIC
 #ifdef _WIN32
    return strlcpy(s, "dll", len);
-#elif defined(IOS) || (defined(OSX) && defined(HAVE_APPLE_STORE))
+#elif (defined(IOS) && defined(HAVE_FRAMEWORKS)) || (defined(OSX) && defined(HAVE_APPLE_STORE))
    return strlcpy(s, "framework", len);
 #elif defined(__APPLE__) || defined(__MACH__)
    return strlcpy(s, "dylib" ,len);
@@ -212,6 +212,9 @@ size_t frontend_driver_get_core_extension(char *s, size_t len)
    if (envIsHomebrew())
       return strlcpy(s, "3dsx", len);
    return strlcpy(s, "cia", len);
+#elif defined(EMSCRIPTEN)
+   /* may not contain the core */
+   return strlcpy(s, "core", len);
 #else
    return 0;
 #endif
@@ -388,8 +391,7 @@ enum frontend_architecture frontend_driver_get_cpu_architecture(void)
    return FRONTEND_ARCH_NONE;
 }
 
-const void *frontend_driver_get_cpu_architecture_str(
-      char *s, size_t len)
+const void *frontend_driver_get_cpu_architecture_str(char *s, size_t len)
 {
    frontend_state_t *frontend_st   = &frontend_driver_st;
    frontend_ctx_driver_t *frontend = frontend_st->current_frontend_ctx;
