@@ -115,30 +115,33 @@ HRESULT WINAPI
 }
 #endif
 
-bool d3d_compile(const char* src, size_t size,
+bool d3d_compile(const char* src, size_t len,
       LPCSTR src_name, LPCSTR entrypoint, LPCSTR target, D3DBlob* out)
 {
-   D3DBlob error_msg;
+   D3DBlob err = NULL;
 #ifdef DEBUG
-   UINT compileflags    = D3DCOMPILE_DEBUG | D3DCOMPILE_SKIP_OPTIMIZATION;
+   UINT compileflags = D3DCOMPILE_DEBUG | D3DCOMPILE_SKIP_OPTIMIZATION;
 #else
-   UINT compileflags    = 0;
+   UINT compileflags = 0;
 #endif
 
-   if (!size)
-      size = strlen(src);
+   if (!len)
+      len = strlen(src);
 
    if (FAILED(D3DCompile(
-             src, size, src_name, NULL, NULL,
-             entrypoint, target, compileflags, 0, out, &error_msg)))
+             src, len, src_name, NULL, NULL,
+             entrypoint, target, compileflags, 0, out, &err)))
    {
-      if (error_msg)
+      if (err)
       {
-         const char* msg = (const char*)error_msg->lpVtbl->GetBufferPointer(error_msg);
-         RARCH_ERR("D3DCompile failed :\n%s\n", msg);
-         /* Place a breakpoint here, if you want, 
-            to see shader compilation issues */
-         Release(error_msg);
+         const char* msg = (const char*)err->lpVtbl->GetBufferPointer(err);
+         if (msg)
+         {
+            RARCH_ERR("D3DCompile failed: %s.\n", msg);
+            /* Place a breakpoint here, if you want,
+               to see shader compilation issues */
+         }
+         Release(err);
       }
       return false;
    }
@@ -149,22 +152,23 @@ bool d3d_compile(const char* src, size_t size,
 bool d3d_compile_from_file(LPCWSTR filename,
       LPCSTR entrypoint, LPCSTR target, D3DBlob* out)
 {
-   D3DBlob error_msg;
+   D3DBlob err = NULL;
 #ifdef DEBUG
-   UINT compileflags    = D3DCOMPILE_DEBUG | D3DCOMPILE_SKIP_OPTIMIZATION;
+   UINT compileflags = D3DCOMPILE_DEBUG | D3DCOMPILE_SKIP_OPTIMIZATION;
 #else
-   UINT compileflags    = 0;
+   UINT compileflags = 0;
 #endif
 
    if (FAILED(D3DCompileFromFile(
              filename, NULL, NULL, entrypoint,
-             target, compileflags, 0, out, &error_msg)))
+             target, compileflags, 0, out, &err)))
    {
-      if (error_msg)
+      if (err)
       {
-         RARCH_ERR("D3DCompile failed :\n%s\n",
-               (const char*)error_msg->lpVtbl->GetBufferPointer(error_msg));
-         Release(error_msg);
+         const char* msg = (const char*)err->lpVtbl->GetBufferPointer(err);
+         if (msg)
+            RARCH_ERR("D3DCompile failed: %s.\n", msg);
+         Release(err);
       }
       return false;
    }
