@@ -19,7 +19,6 @@
 
 #include <stdlib.h>
 
-#include <retro_assert.h>
 #include <string/stdstring.h>
 
 #ifdef HAVE_CONFIG_H
@@ -34,15 +33,24 @@
 #include "../../verbosity.h"
 #include "../../frontend/frontend_driver.h"
 
+#ifndef EGL_OPENGL_ES3_BIT_KHR
+#define EGL_OPENGL_ES3_BIT_KHR 0x0040
+#endif
+
 /* TODO/FIXME - globals */
 bool g_egl_inited    = false;
 
 unsigned g_egl_major = 0;
 unsigned g_egl_minor = 0;
 
-#if defined(HAVE_DYLIB) && defined(HAVE_DYNAMIC_EGL)
+#ifdef HAVE_DYLIB
 #include <dynamic/dylib.h>
 
+static dylib_t g_egl_gl_dll = NULL;
+static EGLint g_egl_gl_dll_version = 0;
+#endif
+
+#if defined(HAVE_DYLIB) && defined(HAVE_DYNAMIC_EGL)
 typedef EGLBoolean(* PFN_EGL_QUERY_SURFACE)(
       EGLDisplay dpy,
       EGLSurface surface,
@@ -126,11 +134,9 @@ bool egl_init_dll(void)
 {
 #if defined(HAVE_DYLIB) && defined(HAVE_DYNAMIC_EGL)
    static dylib_t egl_dll;
-
    if (!egl_dll)
    {
-      egl_dll = dylib_load("libEGL.dll");
-      if (egl_dll)
+      if ((egl_dll = dylib_load("libEGL.dll")))
       {
          /* Setup function callbacks once */
          _egl_query_surface         = (PFN_EGL_QUERY_SURFACE)dylib_proc(
@@ -182,9 +188,9 @@ bool egl_init_dll(void)
 
 void egl_report_error(void)
 {
-   EGLint    error = _egl_get_error();
+   EGLint      err = _egl_get_error();
    const char *str = NULL;
-   switch (error)
+   switch (err)
    {
       case EGL_SUCCESS:
          str = "EGL_SUCCESS";
@@ -243,12 +249,39 @@ void egl_report_error(void)
          break;
    }
 
-   RARCH_ERR("[EGL]: #0x%x, %s\n", (unsigned)error, str);
+   RARCH_ERR("[EGL] #0x%x, %s.\n", (unsigned)err, str);
 }
 
 gfx_ctx_proc_t egl_get_proc_address(const char *symbol)
 {
-   return _egl_get_proc_address(symbol);
+   gfx_ctx_proc_t proc = _egl_get_proc_address(symbol);
+   if (proc)
+      return proc;
+
+#ifdef HAVE_DYLIB
+   /* EGL versions older than 1.5 cannot get OpenGL functions that are required
+    * to be implemented (i.e. functions that are not extensions), so we may also
+    * need to check the OpenGL library directly for the symbol if EGL failed to
+    * find it. */
+   if (g_egl_gl_dll_version)
+   {
+      if (g_egl_gl_dll_version == EGL_OPENGL_ES3_BIT_KHR)
+         g_egl_gl_dll = dylib_load("libGLESv3.so");
+      else if (g_egl_gl_dll_version == EGL_OPENGL_ES2_BIT)
+         g_egl_gl_dll = dylib_load("libGLESv2.so");
+      else if (g_egl_gl_dll_version == EGL_OPENGL_BIT)
+         g_egl_gl_dll = dylib_load("libGL.so");
+      g_egl_gl_dll_version = 0;
+   }
+   if (g_egl_gl_dll)
+   {
+      proc = (gfx_ctx_proc_t)dylib_proc(g_egl_gl_dll, symbol);
+      if (proc)
+         return proc;
+   }
+#endif
+
+   return NULL;
 }
 
 void egl_terminate(EGLDisplay dpy)
@@ -272,6 +305,18 @@ bool egl_bind_api(EGLenum egl_api)
    return _egl_bind_api(egl_api);
 }
 
+void egl_destroy_gl_dll(void)
+{
+#ifdef HAVE_DYLIB
+   if (g_egl_gl_dll)
+   {
+      dylib_close(g_egl_gl_dll);
+      g_egl_gl_dll = NULL;
+   }
+   g_egl_gl_dll_version = 0;
+#endif
+}
+
 void egl_destroy(egl_ctx_data_t *egl)
 {
    if (egl->dpy)
@@ -299,15 +344,17 @@ void egl_destroy(egl_ctx_data_t *egl)
       egl_terminate(egl->dpy);
    }
 
+   egl_destroy_gl_dll();
+
    /* Be as careful as possible in deinit.
     * If we screw up, any TTY will not restore.
     */
 
-   egl->ctx     = EGL_NO_CONTEXT;
-   egl->hw_ctx  = EGL_NO_CONTEXT;
-   egl->surf    = EGL_NO_SURFACE;
-   egl->dpy     = EGL_NO_DISPLAY;
-   egl->config  = 0;
+   egl->ctx      = EGL_NO_CONTEXT;
+   egl->hw_ctx   = EGL_NO_CONTEXT;
+   egl->surf     = EGL_NO_SURFACE;
+   egl->dpy      = EGL_NO_DISPLAY;
+   egl->config   = 0;
    g_egl_inited  = false;
 
    frontend_driver_destroy_signal_handler_state();
@@ -315,13 +362,12 @@ void egl_destroy(egl_ctx_data_t *egl)
 
 void egl_bind_hw_render(egl_ctx_data_t *egl, bool enable)
 {
-   egl->use_hw_ctx = enable;
+   egl->use_hw_ctx     = enable;
 
    if (egl->dpy  == EGL_NO_DISPLAY)
       return;
    if (egl->surf == EGL_NO_SURFACE)
       return;
-
    _egl_make_current(egl->dpy, egl->surf,
          egl->surf,
          enable ? egl->hw_ctx : egl->ctx);
@@ -330,9 +376,9 @@ void egl_bind_hw_render(egl_ctx_data_t *egl, bool enable)
 void egl_swap_buffers(void *data)
 {
    egl_ctx_data_t *egl = (egl_ctx_data_t*)data;
-   if (  egl                         &&
-         egl->dpy  != EGL_NO_DISPLAY &&
-         egl->surf != EGL_NO_SURFACE
+   if (     (egl)
+         && (egl->dpy  != EGL_NO_DISPLAY)
+         && (egl->surf != EGL_NO_SURFACE)
          )
       _egl_swap_buffers(egl->dpy, egl->surf);
 }
@@ -345,14 +391,14 @@ void egl_set_swap_interval(egl_ctx_data_t *egl, int interval)
     */
    egl->interval = interval;
 
-   if (egl->dpy  == EGL_NO_DISPLAY)
+   if (egl->dpy == EGL_NO_DISPLAY)
       return;
    if (!_egl_get_current_context())
       return;
 
    if (!_egl_swap_interval(egl->dpy, interval))
    {
-      RARCH_ERR("[EGL]: eglSwapInterval(%i) failed.\n", interval);
+      RARCH_ERR("[EGL] eglSwapInterval(%i) failed.\n", interval);
       egl_report_error();
    }
 }
@@ -373,51 +419,54 @@ void egl_get_video_size(egl_ctx_data_t *egl, unsigned *width, unsigned *height)
    }
 }
 
+#if defined(EGL_VERSION_1_5)
 static bool check_egl_version(int min_major_version, int min_minor_version)
 {
-   int major, minor;
    const char *str = _egl_query_string(EGL_NO_DISPLAY, EGL_VERSION);
 
-   if (!str)
-      return false;
-
-   if (sscanf(str, "%d.%d", &major, &minor) != 2)
-      return false;
-
-   if (major < min_major_version)
-      return false;
-
-   if (major > min_major_version)
-      return true;
-
-   if (minor >= min_minor_version)
-      return true;
+   if (str)
+   {
+      int major, minor;
+      if (sscanf(str, "%d.%d", &major, &minor) == 2)
+      {
+         if (major >= min_major_version)
+         {
+            if (major > min_major_version)
+               return true;
+            else if (minor >= min_minor_version)
+               return true;
+         }
+      }
+   }
 
    return false;
 }
+#endif
 
+#if defined(EGL_EXT_platform_base)
 static bool check_egl_client_extension(const char *name, size_t name_len)
 {
    const char *str = _egl_query_string(EGL_NO_DISPLAY, EGL_EXTENSIONS);
 
    /* The EGL implementation doesn't support client extensions at all. */
-   if (!str)
-      return false;
-
-   while (*str != '\0')
+   if (str)
    {
-      /* Use strspn and strcspn to find the start position and length of each
-       * token in the extension string. Using strtok could also work, but
-       * that would require allocating a copy of the string. */
-      size_t len = strcspn(str, " ");
-      if (len == name_len && strncmp(str, name, name_len) == 0)
-         return true;
-      str += len;
-      str += strspn(str, " ");
+      while (*str != '\0')
+      {
+         /* Use strspn and strcspn to find the start position and length of each
+          * token in the extension string. Using strtok could also work, but
+          * that would require allocating a copy of the string. */
+         size_t _len = strcspn(str, " ");
+         if (_len == name_len && strncmp(str, name, name_len) == 0)
+            return true;
+         str       += _len;
+         str       += strspn(str, " ");
+      }
    }
 
    return false;
 }
+#endif
 
 static EGLDisplay get_egl_display(EGLenum platform, void *native)
 {
@@ -433,9 +482,9 @@ static EGLDisplay get_egl_display(EGLenum platform, void *native)
             (EGLenum platform, void *native_display, const EGLAttrib *attrib_list);
          pfn_eglGetPlatformDisplay ptr_eglGetPlatformDisplay;
 
-         RARCH_LOG("[EGL] Found EGL client version >= 1.5, trying eglGetPlatformDisplay\n");
+         RARCH_LOG("[EGL] Found EGL client version >= 1.5, trying eglGetPlatformDisplay.\n");
          ptr_eglGetPlatformDisplay = (pfn_eglGetPlatformDisplay)
-            egl_get_proc_address("eglGetPlatformDisplay");
+            _egl_get_proc_address("eglGetPlatformDisplay");
 
          if (ptr_eglGetPlatformDisplay)
          {
@@ -451,9 +500,9 @@ static EGLDisplay get_egl_display(EGLenum platform, void *native)
       {
          PFNEGLGETPLATFORMDISPLAYEXTPROC ptr_eglGetPlatformDisplayEXT;
 
-         RARCH_LOG("[EGL] Found EGL_EXT_platform_base, trying eglGetPlatformDisplayEXT\n");
+         RARCH_LOG("[EGL] Found EGL_EXT_platform_base, trying eglGetPlatformDisplayEXT.\n");
          ptr_eglGetPlatformDisplayEXT = (PFNEGLGETPLATFORMDISPLAYEXTPROC)
-            egl_get_proc_address("eglGetPlatformDisplayEXT");
+            _egl_get_proc_address("eglGetPlatformDisplayEXT");
 
          if (ptr_eglGetPlatformDisplayEXT)
          {
@@ -468,7 +517,7 @@ static EGLDisplay get_egl_display(EGLenum platform, void *native)
    /* Either the caller didn't provide a platform type, or the EGL
     * implementation doesn't support eglGetPlatformDisplay. In this case, try
     * eglGetDisplay and hope for the best. */
-   RARCH_LOG("[EGL] Falling back to eglGetDisplay\n");
+   RARCH_LOG("[EGL] Falling back to eglGetDisplay.\n");
    return _egl_get_display((EGLNativeDisplayType) native);
 }
 
@@ -477,7 +526,7 @@ bool egl_get_native_visual_id(egl_ctx_data_t *egl, EGLint *value)
    if (!egl_get_config_attrib(egl->dpy, egl->config,
          EGL_NATIVE_VISUAL_ID, value))
    {
-      RARCH_ERR("[EGL]: egl_get_native_visual_id failed.\n");
+      RARCH_ERR("[EGL] egl_get_native_visual_id failed.\n");
       return false;
    }
 
@@ -515,7 +564,7 @@ bool egl_init_context_common(
 
    if (!_egl_get_configs(egl->dpy, NULL, 0, count) || *count < 1)
    {
-      RARCH_ERR("[EGL]: No configs to choose from.\n");
+      RARCH_ERR("[EGL] No configs to choose from.\n");
       return false;
    }
 
@@ -526,7 +575,7 @@ bool egl_init_context_common(
    if (!_egl_choose_config(egl->dpy, attrib_ptr,
             configs, *count, &matched) || !matched)
    {
-      RARCH_ERR("[EGL]: No EGL configs with appropriate attributes.\n");
+      RARCH_ERR("[EGL] No EGL configs with appropriate attributes.\n");
       return false;
    }
 
@@ -543,7 +592,7 @@ bool egl_init_context_common(
 
    if (i == *count)
    {
-      RARCH_ERR("[EGL]: No EGL config found which satifies requirements.\n");
+      RARCH_ERR("[EGL] No EGL config found which satisfies requirements.\n");
       return false;
    }
 
@@ -561,11 +610,17 @@ bool egl_init_context(egl_ctx_data_t *egl,
       EGLint *count, const EGLint *attrib_ptr,
       egl_accept_config_cb_t cb)
 {
-   EGLDisplay dpy     = get_egl_display(platform, display_data);
+#ifdef HAVE_DYLIB
+   bool gles3_attrib_found = false;
+   bool gles2_attrib_found = false;
+   bool gl_attrib_found = false;
+#endif
+
+   EGLDisplay dpy = get_egl_display(platform, display_data);
 
    if (dpy == EGL_NO_DISPLAY)
    {
-      RARCH_ERR("[EGL]: Couldn't get EGL display.\n");
+      RARCH_ERR("[EGL] Couldn't get EGL display.\n");
       return false;
    }
 
@@ -574,10 +629,32 @@ bool egl_init_context(egl_ctx_data_t *egl,
    if (!egl_initialize(egl->dpy, major, minor))
       return false;
 
-   RARCH_LOG("[EGL]: EGL version: %d.%d\n", *major, *minor);
+   RARCH_LOG("[EGL] EGL version: %d.%d.\n", *major, *minor);
 
-   return egl_init_context_common(egl, count, attrib_ptr, cb,
-         display_data);
+   if (!egl_init_context_common(egl, count, attrib_ptr, cb,
+         display_data))
+      return false;
+
+#ifdef HAVE_DYLIB
+   for (; *attrib_ptr != EGL_NONE; ++attrib_ptr)
+   {
+      if (*attrib_ptr == EGL_OPENGL_ES3_BIT_KHR)
+         gles3_attrib_found = true;
+      else if (*attrib_ptr == EGL_OPENGL_ES2_BIT)
+         gles2_attrib_found = true;
+      else if (*attrib_ptr == EGL_OPENGL_BIT)
+         gl_attrib_found = true;
+   }
+
+   if (gles3_attrib_found)
+      g_egl_gl_dll_version = EGL_OPENGL_ES3_BIT_KHR;
+   else if (gles2_attrib_found)
+      g_egl_gl_dll_version = EGL_OPENGL_ES2_BIT;
+   else if (gl_attrib_found)
+      g_egl_gl_dll_version = EGL_OPENGL_BIT;
+#endif
+
+   return true;
 }
 
 bool egl_create_context(egl_ctx_data_t *egl, const EGLint *egl_attribs)
@@ -595,7 +672,7 @@ bool egl_create_context(egl_ctx_data_t *egl, const EGLint *egl_attribs)
    {
       egl->hw_ctx = _egl_create_context(egl->dpy, egl->config, egl->ctx,
             egl_attribs);
-      RARCH_LOG("[EGL]: Created shared context: %p.\n", (void*)egl->hw_ctx);
+      RARCH_LOG("[EGL] Created shared context: %p.\n", (void*)egl->hw_ctx);
 
       if (egl->hw_ctx == EGL_NO_CONTEXT)
          return false;
@@ -620,17 +697,7 @@ bool egl_create_surface(egl_ctx_data_t *egl, void *native_window)
    if (!_egl_make_current(egl->dpy, egl->surf, egl->surf, egl->ctx))
       return false;
 
-   RARCH_LOG("[EGL]: Current context: %p.\n", (void*)_egl_get_current_context());
+   RARCH_LOG("[EGL] Current context: %p.\n", (void*)_egl_get_current_context());
 
    return true;
 }
-
-bool egl_has_config(egl_ctx_data_t *egl)
-{
-   if (!egl->config)
-   {
-      RARCH_ERR("[EGL]: No EGL configurations available.\n");
-      return false;
-   }
-   return true;
-}
