@@ -47,12 +47,8 @@
 #define VK_USE_PLATFORM_XLIB_KHR
 #endif
 
-#if defined(HAVE_COCOA) || defined(HAVE_COCOA_METAL)
-#define VK_USE_PLATFORM_MACOS_MVK
-#endif
-
-#ifdef HAVE_COCOATOUCH
-#define VK_USE_PLATFORM_IOS_MVK
+#if defined(HAVE_COCOA) || defined(HAVE_COCOA_METAL) || defined(HAVE_COCOATOUCH)
+#define VK_USE_PLATFORM_METAL_EXT
 #endif
 
 #include <vulkan/vulkan_symbol_wrapper.h>
