@@ -68,3 +68,9 @@ generate_source 'unstable/idle-inhibit' 'idle-inhibit-unstable-v1'
 generate_source 'unstable/pointer-constraints' 'pointer-constraints-unstable-v1'
 generate_source 'unstable/relative-pointer' 'relative-pointer-unstable-v1'
 generate_source 'staging/fractional-scale' 'fractional-scale-v1'
+generate_source 'staging/cursor-shape' 'cursor-shape-v1'
+# tablet-unstable-v1 is required by cursor-shape-v1
+generate_source 'unstable/tablet' 'tablet-unstable-v2'
+generate_source 'staging/content-type' 'content-type-v1'
+generate_source 'staging/single-pixel-buffer' 'single-pixel-buffer-v1'
+generate_source 'staging/xdg-toplevel-icon' 'xdg-toplevel-icon-v1'
