@@ -15,6 +15,8 @@
 
 #if !defined(_XBOX)
 
+#define WIN32_LEAN_AND_MEAN
+
 #ifndef _WIN32_WINNT
 #define _WIN32_WINNT 0x0601 /* Windows 7 */
 #endif
@@ -29,6 +31,7 @@
 #include <windows.h>
 #endif /* !defined(_XBOX) */
 #include <math.h>
+#include <wchar.h>
 
 #include <retro_miscellaneous.h>
 #include <string/stdstring.h>
@@ -67,11 +70,9 @@
 
 /* Assume W-functions do not work below Win2K and Xbox platforms */
 #if defined(_WIN32_WINNT) && _WIN32_WINNT < 0x0500 || defined(_XBOX)
-
 #ifndef LEGACY_WIN32
 #define LEGACY_WIN32
 #endif
-
 #endif
 
 /* For some reason this is missing from mingw winuser.h */
@@ -333,10 +334,11 @@ static INT_PTR_COMPAT CALLBACK pick_core_proc(
    {
       case WM_INITDIALOG:
          {
+            const core_info_t *info = NULL;
             HWND hwndList;
             unsigned i;
-            /* Add items to list.  */
 
+            /* Add items to list.  */
             core_info_get_list(&core_info_list);
             core_info_list_get_supported_cores(core_info_list,
                   path_get(RARCH_PATH_CONTENT), &core_info, &list_size);
@@ -349,6 +351,12 @@ static INT_PTR_COMPAT CALLBACK pick_core_proc(
                SendMessage(hwndList, LB_ADDSTRING, 0,
                      (LPARAM)info->display_name);
             }
+
+            /* Select the first item in the list */
+            SendMessage(hwndList, LB_SETCURSEL, 0, 0);
+            info = (const core_info_t*)&core_info[0];
+            path_set(RARCH_PATH_CORE, info->path);
+
             SetFocus(hwndList);
             return TRUE;
          }
@@ -610,7 +618,6 @@ static bool win32_drag_query_file(HWND hwnd, WPARAM wparam)
    {
       char szFilename[1024];
       szFilename[0]    = '\0';
-
       DragQueryFile((HDROP)wparam, 0, szFilename, sizeof(szFilename));
       return win32_load_content_from_gui(szFilename);
    }
@@ -622,16 +629,17 @@ static bool win32_drag_query_file(HWND hwnd, WPARAM wparam)
    if (DragQueryFileW((HDROP)wparam, 0xFFFFFFFF, NULL, 0))
    {
       wchar_t wszFilename[4096];
-      bool okay        = false;
+      bool ret        = false;
       char *szFilename = NULL;
       wszFilename[0]   = L'\0';
 
       DragQueryFileW((HDROP)wparam, 0, wszFilename, sizeof(wszFilename));
       szFilename = utf16_to_utf8_string_alloc(wszFilename);
-      okay = win32_load_content_from_gui(szFilename);
+      ret        = win32_load_content_from_gui(szFilename);
       if (szFilename)
          free(szFilename);
-      return okay;
+      if (ret)
+         return true;
    }
    return false;
 }
@@ -714,7 +722,6 @@ static LRESULT win32_menu_loop(HWND owner, WPARAM wparam)
             char win32_file[PATH_MAX_LENGTH] = {0};
             settings_t *settings    = config_get_ptr();
             char    *title_cp       = NULL;
-            size_t converted        = 0;
             const char *extensions  = "Libretro core (.dll)\0*.dll\0All Files\0*.*\0\0";
             const char *title       = msg_hash_to_str(MENU_ENUM_LABEL_VALUE_CORE_LIST);
             const char *initial_dir = settings->paths.directory_libretro;
@@ -753,7 +760,6 @@ static LRESULT win32_menu_loop(HWND owner, WPARAM wparam)
             char win32_file[PATH_MAX_LENGTH] = {0};
             char *title_cp          = NULL;
             wchar_t *title_wide     = NULL;
-            size_t converted        = 0;
             const char *extensions  = "All Files (*.*)\0*.*\0\0";
             const char *title       = msg_hash_to_str(
                   MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_LIST);
@@ -1079,10 +1085,7 @@ static LRESULT CALLBACK wnd_proc_common(
          }
          break;
       case WM_COMMAND:
-         {
-            settings_t *settings     = config_get_ptr();
-            win32_menu_loop(main_window.hwnd, wparam);
-         }
+         win32_menu_loop(main_window.hwnd, wparam);
          break;
    }
    return 0;
@@ -1181,16 +1184,18 @@ static LRESULT CALLBACK wnd_proc_common_internal(HWND hwnd,
             g_win32_flags |= WIN32_CMN_FLAG_TASKBAR_CREATED;
 #endif
          break;
-#ifdef HAVE_CLIP_WINDOW
       case WM_SETFOCUS:
+#ifdef HAVE_CLIP_WINDOW
          if (input_state_get_ptr()->flags & INP_FLAG_GRAB_MOUSE_STATE)
             win32_clip_window(true);
+#endif
          break;
       case WM_KILLFOCUS:
+#ifdef HAVE_CLIP_WINDOW
          if (input_state_get_ptr()->flags & INP_FLAG_GRAB_MOUSE_STATE)
             win32_clip_window(false);
-         break;
 #endif
+         break;
       case WM_DISPLAYCHANGE:  /* Fix size after display mode switch when using SR */
          {
             HMONITOR mon = MonitorFromWindow(hwnd, MONITOR_DEFAULTTONEAREST);
@@ -1325,22 +1330,22 @@ static LRESULT CALLBACK wnd_proc_common_dinput_internal(HWND hwnd,
             if (gcs)
             {
                int i;
-               wchar_t wstr[4]={0,};
-               int len1 = ImmGetCompositionStringW(hIMC, gcs, wstr, 4);
-               wstr[2]  = wstr[1];
-               wstr[1]  = 0;
-               if ((len1 <= 0) || (len1 > 4))
+               wchar_t wstr[4] = {0,};
+               LONG _len       = ImmGetCompositionStringW(hIMC, gcs, wstr, 4);
+               wstr[2]         = wstr[1];
+               wstr[1]         = 0;
+               if ((_len <= 0) || (_len > 4))
                   break;
-               for (i = 0; i < len1; i = i + 2)
+               for (i = 0; i < _len; i = i + 2)
                {
-                  size_t len2;
+                  size_t __len;
                   char *utf8   = utf16_to_utf8_string_alloc(wstr+i);
                   if (!utf8)
                      continue;
-                  len2         = strlen(utf8) + 1;
-                  if (len2 >= 1 && len2 <= 3)
+                  __len         = strlen(utf8) + 1;
+                  if (__len >= 1 && __len <= 3)
                   {
-                     if (len2 >= 2)
+                     if (__len >= 2)
                         utf8[3] = (gcs) | (gcs >> 4);
                      input_keyboard_event(true, 1, *((int*)utf8), 0, RETRO_DEVICE_KEYBOARD);
                   }
@@ -1373,8 +1378,10 @@ static LRESULT CALLBACK wnd_proc_common_dinput_internal(HWND hwnd,
                keysym |= 0x80;
 
             /* tell the driver about shift and alt key events */
-            if (keysym == 0x2A/*DIK_LSHIFT*/ || keysym == 0x36/*DIK_RSHIFT*/
-                     || keysym == 0x38/*DIK_LMENU*/ || keysym == 0xB8/*DIK_RMENU*/)
+            if (        keysym == 0x2A/*DIK_LSHIFT*/
+                     || keysym == 0x36/*DIK_RSHIFT*/
+                     || keysym == 0x38/*DIK_LMENU*/
+                     || keysym == 0xB8/*DIK_RMENU*/)
             {
                void* input_data = (void*)(LONG_PTR)GetWindowLongPtr(main_window.hwnd, GWLP_USERDATA);
                if (input_data && dinput_handle_message(input_data,
@@ -1452,16 +1459,34 @@ static LRESULT CALLBACK wnd_proc_common_dinput_internal(HWND hwnd,
             g_win32_flags |= WIN32_CMN_FLAG_TASKBAR_CREATED;
 #endif
          break;
-#ifdef HAVE_CLIP_WINDOW
       case WM_SETFOCUS:
+#ifdef HAVE_CLIP_WINDOW
          if (input_state_get_ptr()->flags & INP_FLAG_GRAB_MOUSE_STATE)
             win32_clip_window(true);
+#endif
+#if !defined(_XBOX)
+         {
+            void* input_data = (void*)(LONG_PTR)GetWindowLongPtr(main_window.hwnd, GWLP_USERDATA);
+            if (input_data && dinput_handle_message(input_data,
+                     message, wparam, lparam))
+               return 0;
+         }
+#endif
          break;
       case WM_KILLFOCUS:
+#ifdef HAVE_CLIP_WINDOW
          if (input_state_get_ptr()->flags & INP_FLAG_GRAB_MOUSE_STATE)
             win32_clip_window(false);
-         break;
 #endif
+#if !defined(_XBOX)
+         {
+            void* input_data = (void*)(LONG_PTR)GetWindowLongPtr(main_window.hwnd, GWLP_USERDATA);
+            if (input_data && dinput_handle_message(input_data,
+                     message, wparam, lparam))
+               return 0;
+         }
+#endif
+         break;
       case WM_DISPLAYCHANGE:  /* Fix size after display mode switch when using SR */
          {
             HMONITOR mon = MonitorFromWindow(hwnd, MONITOR_DEFAULTTONEAREST);
@@ -1845,7 +1870,7 @@ bool win32_window_create(void *data, unsigned style,
       main_window.hwnd, &notification_filter, DEVICE_NOTIFY_WINDOW_HANDLE);
 
    if (!notification_handler)
-      RARCH_ERR("Error registering for notifications\n");
+      RARCH_ERR("[Win32] Error registering for notifications.\n");
 #endif
 
    video_driver_display_type_set(RARCH_DISPLAY_WIN32);
@@ -2115,7 +2140,7 @@ static void win32_localize_menu(HMENU menu)
       memset(&menu_item_info, 0, sizeof(menu_item_info));
       menu_item_info.cbSize     = sizeof(menu_item_info);
       menu_item_info.dwTypeData = NULL;
-#if(WINVER >= 0x0500)
+#if (WINVER >= 0x0500)
       menu_item_info.fMask      = MIIM_STRING | MIIM_FTYPE | MIIM_ID | MIIM_STATE | MIIM_SUBMENU;
 #else
       menu_item_info.fMask      =                            MIIM_ID | MIIM_STATE | MIIM_SUBMENU;
@@ -2136,8 +2161,8 @@ static void win32_localize_menu(HMENU menu)
       label_enum = menu_id_to_label_enum(menu_item_info.wID);
       if (label_enum != MSG_UNKNOWN)
       {
-         int len;
-         size_t len2;
+         size_t ___len;
+         size_t __len;
 #ifndef LEGACY_WIN32
          wchar_t* new_label_unicode = NULL;
 #else
@@ -2156,53 +2181,53 @@ static void win32_localize_menu(HMENU menu)
                MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_LIST)
          {
             meta_key_name = "Ctrl+O";
-            len2          = STRLEN_CONST("Ctrl+O");
+            __len         = STRLEN_CONST("Ctrl+O");
          }
          else if (label_enum ==
                MENU_ENUM_LABEL_VALUE_INPUT_META_FULLSCREEN_TOGGLE_KEY)
          {
             meta_key_name = "Alt+Enter";
-            len2          = STRLEN_CONST("Alt+Enter");
+            __len        = STRLEN_CONST("Alt+Enter");
          }
          else if (meta_key != 0)
          {
             meta_key_name = win32_meta_key_to_name(meta_key);
-            len2          = strlen(meta_key_name);
+            __len        = strlen(meta_key_name);
          }
 
          /* Append localized name, tab character, and Shortcut Key */
          if (meta_key_name && string_is_not_equal(meta_key_name, "nul"))
          {
-            size_t len1     = strlen(new_label);
-            size_t buf_size = len1 + len2 + 2;
+            size_t _len     = strlen(new_label);
+            size_t buf_size = _len + __len + 2;
             new_label_text  = (char*)malloc(buf_size);
 
             if (new_label_text)
             {
-               size_t _len;
+               size_t __len;
                new_label2              = new_label_text;
-               _len                    = strlcpy(new_label_text, new_label,
+               __len                   = strlcpy(new_label_text, new_label,
                      buf_size);
-               new_label_text[  _len]  = '\t';
-               new_label_text[++_len]  = '\0';
-               strlcpy(new_label_text + _len, meta_key_name, buf_size - _len);
+               new_label_text[  __len] = '\t';
+               new_label_text[++__len] = '\0';
+               strlcpy(new_label_text + __len, meta_key_name, buf_size - __len);
                /* Make first character of shortcut name uppercase */
-               new_label_text[len1 + 1] = toupper(new_label_text[len1 + 1]);
+               new_label_text[_len + 1] = toupper(new_label_text[_len + 1]);
             }
          }
 
 #ifndef LEGACY_WIN32
          /* Convert string from UTF-8, then assign menu text */
          new_label_unicode         = utf8_to_utf16_string_alloc(new_label2);
-         len                       = wcslen(new_label_unicode);
-         menu_item_info.cch        = len;
+         ___len                    = wcslen(new_label_unicode);
+         menu_item_info.cch        = ___len;
          menu_item_info.dwTypeData = new_label_unicode;
          SetMenuItemInfoW(menu, index, true, &menu_item_info);
          free(new_label_unicode);
 #else
          new_label_ansi            = utf8_to_local_string_alloc(new_label2);
-         len                       = strlen(new_label_ansi);
-         menu_item_info.cch        = len;
+         ___len                    = strlen(new_label_ansi);
+         menu_item_info.cch        = ___len;
          menu_item_info.dwTypeData = new_label_ansi;
          SetMenuItemInfoA(menu, index, true, &menu_item_info);
          free(new_label_ansi);
@@ -2410,7 +2435,7 @@ void win32_set_style(MONITORINFOEX *current_mon, HMONITOR *hm_to_use,
          if (win32_monitor_set_fullscreen(*width, *height,
                (int)refresh_rate, false, current_mon->szDevice))
          {
-            RARCH_LOG("[Video]: Fullscreen set to %ux%u @ %uHz on device %s.\n",
+            RARCH_LOG("[Video] Fullscreen set to %ux%u @ %uHz on device %s.\n",
                   *width, *height, (int)refresh_rate, current_mon->szDevice);
          }
 
@@ -2559,7 +2584,7 @@ bool win32_set_video_mode(void *data,
    {
       if (res == -1)
       {
-         RARCH_ERR("GetMessage error code %d\n", GetLastError());
+         RARCH_ERR("[Win32] GetMessage error code %d.\n", GetLastError());
          break;
       }
 
@@ -2748,7 +2773,7 @@ bool win32_get_video_output(DEVMODE *dm, int mode, size_t len)
    return true;
 }
 
-void win32_get_video_output_size(void *data, unsigned *width, unsigned *height, char *desc, size_t desc_len)
+void win32_get_video_output_size(void *data, unsigned *width, unsigned *height, char *desc, size_t len)
 {
    DEVMODE dm;
    if (win32_get_video_output(&dm, -1, sizeof(dm)))
