@@ -283,13 +283,13 @@ static struct exynos_bo *exynos_create_mapped_buffer(
 
    if (!buf)
    {
-      RARCH_ERR("[video_exynos]: failed to create temp buffer object\n");
+      RARCH_ERR("[Exynos] Failed to create temp buffer object.\n");
       return NULL;
    }
 
    if (!exynos_bo_map(buf))
    {
-      RARCH_ERR("[video_exynos]: failed to map temp buffer object\n");
+      RARCH_ERR("[Exynos] Failed to map temp buffer object.\n");
       exynos_bo_destroy(buf);
       return NULL;
    }
@@ -312,7 +312,7 @@ static int exynos_realloc_buffer(struct exynos_data *pdata,
       unsigned i;
 
 #if (EXYNOS_GFX_DEBUG_LOG == 1)
-      RARCH_LOG("[video_exynos]: reallocating %s buffer (%u -> %u bytes)\n",
+      RARCH_LOG("[Exynos] Reallocating %s buffer (%u -> %u bytes).\n",
             exynos_buffer_name(type), buf->size, size);
 #endif
 
@@ -321,7 +321,7 @@ static int exynos_realloc_buffer(struct exynos_data *pdata,
 
       if (!buf)
       {
-         RARCH_ERR("[video_exynos]: reallocation failed\n");
+         RARCH_ERR("[Exynos] Reallocation failed.\n");
          return -1;
       }
 
@@ -347,7 +347,7 @@ static int exynos_clear_buffer(struct g2d_context *g2d, struct g2d_image *img)
       ret = g2d_exec(g2d);
 
    if (ret != 0)
-      RARCH_ERR("[video_exynos]: failed to clear buffer using G2D\n");
+      RARCH_ERR("[Exynos] Failed to clear buffer using G2D.\n");
 
    return ret;
 }
@@ -388,17 +388,17 @@ static void exynos_perf_init(struct exynos_perf *p)
 
 static void exynos_perf_finish(struct exynos_perf *p)
 {
-   RARCH_LOG("[video_exynos]: debug: total memcpy calls: %u\n", p->memcpy_calls);
-   RARCH_LOG("[video_exynos]: debug: total g2d calls: %u\n", p->g2d_calls);
+   RARCH_DBG("[Exynos] total memcpy calls: %u\n", p->memcpy_calls);
+   RARCH_DBG("[Exynos] total g2d calls: %u\n", p->g2d_calls);
 
-   RARCH_LOG("[video_exynos]: debug: total memcpy time: %f seconds\n",
+   RARCH_DBG("[Exynos] total memcpy time: %f seconds\n",
          (double)p->memcpy_time / 1000000.0);
-   RARCH_LOG("[video_exynos]: debug: total g2d time: %f seconds\n",
+   RARCH_DBG("[Exynos] total g2d time: %f seconds\n",
          (double)p->g2d_time / 1000000.0);
 
-   RARCH_LOG("[video_exynos]: debug: average time per memcpy call: %f microseconds\n",
+   RARCH_DBG("[Exynos] average time per memcpy call: %f microseconds\n",
          (double)p->memcpy_time / (double)p->memcpy_calls);
-   RARCH_LOG("[video_exynos]: debug: average time per g2d call: %f microseconds\n",
+   RARCH_DBG("[Exynos] average time per g2d call: %f microseconds\n",
          (double)p->g2d_time / (double)p->g2d_calls);
 }
 
@@ -533,7 +533,7 @@ static int exynos_open(struct exynos_data *pdata)
       snprintf(buf, sizeof(buf), "/dev/dri/card%d", devidx);
    else
    {
-      RARCH_ERR("[video_exynos]: no compatible DRM device found\n");
+      RARCH_ERR("[Exynos] No compatible DRM device found.\n");
       return -1;
    }
 
@@ -541,7 +541,7 @@ static int exynos_open(struct exynos_data *pdata)
 
    if (fd < 0)
    {
-      RARCH_ERR("[video_exynos]: can't open DRM device\n");
+      RARCH_ERR("[Exynos] Can't open DRM device.\n");
       return -1;
    }
 
@@ -563,7 +563,7 @@ static int exynos_open(struct exynos_data *pdata)
    strncpy(pdata->drmname, buf, sizeof(buf));
    g_drm_fd = fd;
 
-   RARCH_LOG("[video_exynos]: using DRM device \"%s\" with connector id %u.\n",
+   RARCH_LOG("[Exynos] using DRM device \"%s\" with connector id %u.\n",
          pdata->drmname, g_drm_connector->connector_id);
 
    return 0;
@@ -608,7 +608,7 @@ static int exynos_init(struct exynos_data *pdata, unsigned bpp)
       if (!g_drm_mode)
       {
          RARCH_ERR(
-               "[video_exynos]: requested resolution (%ux%u) not available\n",
+               "[Exynos] Requested resolution (%ux%u) not available.\n",
                video_fullscreen_x,
                video_fullscreen_y);
          goto fail;
@@ -623,7 +623,7 @@ static int exynos_init(struct exynos_data *pdata, unsigned bpp)
 
    if (g_drm_mode->hdisplay == 0 || g_drm_mode->vdisplay == 0)
    {
-      RARCH_ERR("[video_exynos]: failed to select sane resolution\n");
+      RARCH_ERR("[Exynos] Failed to select sane resolution.\n");
       goto fail;
    }
 
@@ -641,7 +641,7 @@ static int exynos_init(struct exynos_data *pdata, unsigned bpp)
    pdata->pitch      = bpp * pdata->width;
    pdata->size       = pdata->pitch * pdata->height;
 
-   RARCH_LOG("[video_exynos]: selected %ux%u resolution with %u bpp\n",
+   RARCH_LOG("[Exynos] Selected %ux%u resolution with %u bpp.\n",
          pdata->width, pdata->height, pdata->bpp);
 
    return 0;
@@ -680,7 +680,7 @@ static int exynos_alloc(struct exynos_data *pdata)
 
    if (!device)
    {
-      RARCH_ERR("[video_exynos]: failed to create device from fd\n");
+      RARCH_ERR("[Exynos] Failed to create device.\n");
       return -1;
    }
 
@@ -689,7 +689,7 @@ static int exynos_alloc(struct exynos_data *pdata)
 
    if (!pages)
    {
-      RARCH_ERR("[video_exynos]: failed to allocate pages\n");
+      RARCH_ERR("[Exynos] Failed to allocate pages.\n");
       goto fail_alloc;
    }
 
@@ -720,7 +720,7 @@ static int exynos_alloc(struct exynos_data *pdata)
       bo = exynos_bo_create(device, pdata->size, flags);
       if (!bo)
       {
-         RARCH_ERR("[video_exynos]: failed to create buffer object\n");
+         RARCH_ERR("[Exynos] Failed to create buffer object.\n");
          goto fail;
       }
 
@@ -745,7 +745,7 @@ static int exynos_alloc(struct exynos_data *pdata)
                pixel_format, handles, pitches, offsets,
                &pages[i].buf_id, flags))
       {
-         RARCH_ERR("[video_exynos]: failed to add bo %u to fb\n", i);
+         RARCH_ERR("[Exynos] Failed to add bo %u to fb.\n", i);
          goto fail;
       }
    }
@@ -755,7 +755,7 @@ static int exynos_alloc(struct exynos_data *pdata)
             pages[pdata->num_pages - 1].buf_id,
             0, 0, &g_drm_connector_id, 1, g_drm_mode))
    {
-      RARCH_ERR("[video_exynos]: initial CRTC setup failed.\n");
+      RARCH_ERR("[Exynos] Initial CRTC setup failed.\n");
       goto fail;
    }
 
@@ -781,7 +781,7 @@ static void exynos_free(struct exynos_data *pdata)
    /* Disable the CRTC. */
    if (drmModeSetCrtc(g_drm_fd, g_crtc_id, 0,
             0, 0, NULL, 0, NULL))
-      RARCH_WARN("[video_exynos]: failed to disable the CRTC.\n");
+      RARCH_WARN("[Exynos] Failed to disable the CRTC.\n");
 
    exynos_clean_up_pages(pdata->pages, pdata->num_pages);
 
@@ -804,12 +804,12 @@ static void exynos_alloc_status(struct exynos_data *pdata)
    unsigned i;
    struct exynos_page *pages = pdata->pages;
 
-   RARCH_LOG("[video_exynos]: Allocated %u pages with %u bytes each (pitch = %u bytes)\n",
+   RARCH_LOG("[Exynos] Allocated %u pages with %u bytes each (pitch = %u bytes).\n",
          pdata->num_pages, pdata->size, pdata->pitch);
 
    for (i = 0; i < pdata->num_pages; ++i)
    {
-      RARCH_LOG("[video_exynos]: page %u: BO at %p, buffer id = %u\n",
+      RARCH_LOG("[Exynos] Page %u: BO at %p, buffer id = %u.\n",
             i, pages[i].bo, pages[i].buf_id);
    }
 }
@@ -935,7 +935,7 @@ static int exynos_blit_frame(
             pdata->blit_params[2], pdata->blit_params[3], 0) ||
          g2d_exec(pdata->g2d))
    {
-      RARCH_ERR("[video_exynos]: failed to blit frame.\n");
+      RARCH_ERR("[Exynos] Failed to blit frame.\n");
       return -1;
    }
 
@@ -961,7 +961,7 @@ static int exynos_blend_menu(struct exynos_data *pdata,
             pdata->blit_params[3], G2D_OP_INTERPOLATE) ||
          g2d_exec(pdata->g2d))
    {
-      RARCH_ERR("[video_exynos]: failed to blend menu.\n");
+      RARCH_ERR("[Exynos] Failed to blend menu.\n");
       return -1;
    }
 
@@ -985,7 +985,7 @@ static int exynos_blend_font(struct exynos_data *pdata)
             G2D_OP_INTERPOLATE) ||
          g2d_exec(pdata->g2d))
    {
-      RARCH_ERR("[video_exynos]: failed to blend font\n");
+      RARCH_ERR("[Exynos] Failed to blend font.\n");
       return -1;
    }
 
@@ -1006,7 +1006,7 @@ static int exynos_flip(struct exynos_data *pdata, struct exynos_page *page)
    if (drmModePageFlip(g_drm_fd, g_crtc_id, page->buf_id,
             DRM_MODE_PAGE_FLIP_EVENT, page) != 0)
    {
-      RARCH_ERR("[video_exynos]: failed to issue page flip\n");
+      RARCH_ERR("[Exynos] Failed to issue page flip.\n");
       return -1;
    }
    else
@@ -1074,7 +1074,7 @@ static int exynos_init_font(struct exynos_video *vid)
    }
    else
    {
-      RARCH_ERR("[video_exynos]: creating font renderer failed\n");
+      RARCH_ERR("[Exynos] Creating font renderer failed.\n");
       return -1;
    }
 
@@ -1182,25 +1182,25 @@ static void *exynos_init(const video_info_t *video,
 
    if (exynos_open(vid->data) != 0)
    {
-      RARCH_ERR("[video_exynos]: opening device failed\n");
+      RARCH_ERR("[Exynos] Open device failed.\n");
       goto fail;
    }
 
    if (exynos_init(vid->data, fb_bpp) != 0)
    {
-      RARCH_ERR("[video_exynos]: initialization failed\n");
+      RARCH_ERR("[Exynos] Initialization failed.\n");
       goto fail_init;
    }
 
    if (exynos_alloc(vid->data) != 0)
    {
-      RARCH_ERR("[video_exynos]: allocation failed\n");
+      RARCH_ERR("[Exynos] Allocation failed.\n");
       goto fail_alloc;
    }
 
    if (exynos_g2d_init(vid->data) != 0)
    {
-      RARCH_ERR("[video_exynos]: G2D initialization failed\n");
+      RARCH_ERR("[Exynos] G2D initialization failed.\n");
       goto fail_g2d;
    }
 
@@ -1217,7 +1217,7 @@ static void *exynos_init(const video_info_t *video,
 
    if (exynos_init_font(vid) != 0)
    {
-      RARCH_ERR("[video_exynos]: font initialization failed\n");
+      RARCH_ERR("[Exynos] Font initialization failed.\n");
       goto fail_font;
    }
 
@@ -1296,7 +1296,7 @@ static bool exynos_frame(void *data, const void *frame, unsigned width,
          if (width == 0 || height == 0)
             return true;
 
-         RARCH_LOG("[video_exynos]: resolution changed by core: %ux%u -> %ux%u\n",
+         RARCH_LOG("[Exynos] Resolution changed by core: %ux%u -> %ux%u.\n",
                vid->width, vid->height, width, height);
          exynos_setup_scale(vid->data, width, height, vid->bytes_per_pixel);
 
