@@ -13,7 +13,8 @@
                   "#else\n" \
                   "  precision mediump float;\n" \
                   "#endif\n" #src
-#define GLSL_330(src) "#version 330 es\n" \
+#define GLSL_STANDARD_DERIVATIVES(src) "#version 130\n" \
+                  "#extension GL_OES_standard_derivatives : enable\n" \
                   "#ifdef GL_ES\n" \
                   "  #ifdef GL_FRAGMENT_PRECISION_HIGH\n" \
                   "    precision highp float;\n" \
@@ -26,8 +27,7 @@
 #else
 #define CG(src)   "" #src
 #define GLSL(src) "" #src
-#define GLSL_300(src)   "#version 300 es\n"   #src
-#define GLSL_330(src)   "#version 330 core\n"   #src
+#define GLSL_STANDARD_DERIVATIVES(src) "" #src
 #endif
 
 #endif
