@@ -100,7 +100,7 @@ static void sdl_init_font(sdl_video_t *vid,
             *path_font ? path_font : NULL,
             video_font_size))
    {
-      RARCH_LOG("[SDL]: Could not initialize fonts.\n");
+      RARCH_LOG("[SDL] Could not initialize fonts.\n");
       return;
    }
 
@@ -273,10 +273,10 @@ static void *sdl_gfx_init(const video_info_t *video,
    video_info = SDL_GetVideoInfo();
    full_x     = video_info->current_w;
    full_y     = video_info->current_h;
-   RARCH_LOG("[SDL]: Detecting desktop resolution %ux%u.\n", full_x, full_y);
+   RARCH_LOG("[SDL] Detecting desktop resolution %ux%u.\n", full_x, full_y);
 
    if (!video->fullscreen)
-      RARCH_LOG("[SDL]: Creating window @ %ux%u\n", video->width, video->height);
+      RARCH_LOG("[SDL] Creating window @ %ux%u.\n", video->width, video->height);
 
    vid->screen = SDL_SetVideoMode(video->width, video->height, 32,
          SDL_HWSURFACE | SDL_HWACCEL | SDL_DOUBLEBUF | (video->fullscreen ? SDL_FULLSCREEN : 0));
@@ -287,7 +287,7 @@ static void *sdl_gfx_init(const video_info_t *video,
 
    if (!vid->screen)
    {
-      RARCH_ERR("[SDL1]: Failed to init SDL surface: %s\n", SDL_GetError());
+      RARCH_ERR("[SDL] Failed to init SDL surface: %s.\n", SDL_GetError());
       goto error;
    }
 
@@ -332,7 +332,7 @@ static void *sdl_gfx_init(const video_info_t *video,
 
    if (!vid->menu.frame)
    {
-      RARCH_ERR("[SDL1]: Failed to init menu surface: %s\n", SDL_GetError());
+      RARCH_ERR("[SDL] Failed to init menu surface: %s.\n", SDL_GetError());
       goto error;
    }
 
