@@ -20,6 +20,7 @@
 #include <encodings/utf.h>
 #include <string/stdstring.h>
 #include <formats/image.h>
+#include <gfx/math/matrix_4x4.h>
 
 #ifdef HAVE_CONFIG_H
 #include "../../config.h"
@@ -35,14 +36,75 @@
 #include "../font_driver.h"
 #include "../video_driver.h"
 
-#include "../common/vita2d_defines.h"
+#include <defines/psp_defines.h>
+
 #include "../../driver.h"
+#include "../../retroarch.h"
 #include "../../verbosity.h"
 #include "../../configuration.h"
 
-#include <defines/psp_defines.h>
 #include <psp2/kernel/sysmem.h>
 
+typedef struct vita_menu_frame
+{
+   vita2d_texture *texture;
+   int width;
+   int height;
+   bool active;
+} vita_menu_t;
+
+#ifdef HAVE_OVERLAY
+struct vita_overlay_data
+{
+   vita2d_texture *tex;
+   float x;
+   float y;
+   float w;
+   float h;
+   float tex_x;
+   float tex_y;
+   float tex_w;
+   float tex_h;
+   float alpha_mod;
+   float width;
+   float height;
+};
+#endif
+
+typedef struct vita_video
+{
+   vita2d_texture *texture;
+   SceGxmTextureFormat format;
+   int width;
+   int height;
+   SceGxmTextureFilter tex_filter;
+
+   video_viewport_t vp;
+
+   math_matrix_4x4 mvp, mvp_no_rot;
+
+   vita_menu_t menu;
+
+#ifdef HAVE_OVERLAY
+   struct vita_overlay_data *overlay;
+   unsigned overlays;
+#endif
+   unsigned video_width;
+   unsigned video_height;
+   unsigned rotation;
+
+#ifdef HAVE_OVERLAY
+   bool overlay_enable;
+   bool overlay_full_screen;
+#endif
+   bool fullscreen;
+   bool vsync;
+   bool rgb32;
+   bool vblank_not_reached;
+   bool keep_aspect;
+   bool should_resize;
+} vita_video_t;
+
 typedef struct
 {
    vita_video_t *vita;
@@ -850,14 +912,11 @@ static void vita2d_update_viewport(vita_video_t* vita,
       video_mode_data        = vita2d_get_video_mode_data();
    unsigned temp_width       = video_mode_data.width;
    unsigned temp_height      = video_mode_data.height;
-   int x                     = 0;
-   int y                     = 0;
    float device_aspect       = ((float)temp_width) / temp_height;
    float width               = temp_width;
    float height              = temp_height;
    settings_t *settings      = config_get_ptr();
    bool video_scale_integer  = settings->bools.video_scale_integer;
-   unsigned aspect_ratio_idx = settings->uints.video_aspect_ratio_idx;
 
    if (video_scale_integer)
    {
@@ -869,23 +928,22 @@ static void vita2d_update_viewport(vita_video_t* vita,
    }
    else if (vita->keep_aspect)
    {
-      float desired_aspect = video_driver_get_aspect_ratio();
-      if ( (vita->rotation == ORIENTATION_VERTICAL) ||
-           (vita->rotation == ORIENTATION_FLIPPED_ROTATED))
+      if (    (vita->rotation == ORIENTATION_VERTICAL)
+           || (vita->rotation == ORIENTATION_FLIPPED_ROTATED))
       {
          device_aspect = 1.0 / device_aspect;
-         width = temp_height;
-         height = temp_width;
+         width         = temp_height;
+         height        = temp_width;
       }
       video_viewport_get_scaled_aspect(&vita->vp, width, height, true);
-      if ( (vita->rotation == ORIENTATION_VERTICAL) ||
-           (vita->rotation == ORIENTATION_FLIPPED_ROTATED)
+      if (    (vita->rotation == ORIENTATION_VERTICAL)
+           || (vita->rotation == ORIENTATION_FLIPPED_ROTATED)
          )
       {
-         // swap x and y
+         /* Swap x and y */
          unsigned tmp = vita->vp.x;
-         vita->vp.x = vita->vp.y;
-         vita->vp.y = tmp;
+         vita->vp.x   = vita->vp.y;
+         vita->vp.y   = tmp;
       }
    }
    else
@@ -927,7 +985,6 @@ static void vita2d_set_viewport_wrapper(void *data, unsigned vp_width,
    else if (vita->keep_aspect && !force_full)
    {
       float desired_aspect = video_driver_get_aspect_ratio();
-
 #if defined(HAVE_MENU)
       if (aspect_ratio_idx == ASPECT_RATIO_CUSTOM)
       {
@@ -980,6 +1037,9 @@ static void vita2d_set_viewport_wrapper(void *data, unsigned vp_width,
       vita->vp.height = vp_height;
    }
 
+   vita->vp.full_width  = vita->vp.width;
+   vita->vp.full_height = vita->vp.height;
+
    vita2d_set_viewport(vita->vp.x, vita->vp.y, vita->vp.width, vita->vp.height);
    vita2d_set_projection(vita, &ortho, allow_rotate);
 
