@@ -103,7 +103,7 @@ static void xv_set_nonblock_state(void *data, bool state, bool c, unsigned d)
    if (atom != None && xv->port)
       XvSetPortAttribute(g_x11_dpy, xv->port, atom, !state);
    else
-      RARCH_WARN("Failed to set SYNC_TO_VBLANK attribute.\n");
+      RARCH_WARN("[XVideo] Failed to set SYNC_TO_VBLANK attribute.\n");
 }
 
 static INLINE void xv_calculate_yuv(uint8_t *y, uint8_t *u, uint8_t *v,
@@ -173,7 +173,7 @@ static void xv_init_font(xv_t *xv, const char *font_path, unsigned font_size)
             r, g, b);
    }
    else
-      RARCH_LOG("[XVideo]: Could not initialize fonts.\n");
+      RARCH_LOG("[XVideo] Could not initialize fonts.\n");
 }
 
 /* We render @ 2x scale to combat chroma downsampling.
@@ -599,9 +599,10 @@ static void xv_calc_out_rect(bool keep_aspect,
    vp->full_width       = vp_width;
    vp->full_height      = vp_height;
 
+   /* TODO: Does xvideo have its origin in top left or bottom-left? Assuming top left. */
    if (scale_integer)
       video_viewport_get_scaled_integer(vp, vp_width, vp_height,
-            video_driver_get_aspect_ratio(), keep_aspect);
+           video_driver_get_aspect_ratio(), keep_aspect, true);
    else if (!keep_aspect)
    {
       vp->x      = 0;
@@ -610,38 +611,7 @@ static void xv_calc_out_rect(bool keep_aspect,
       vp->height = vp_height;
    }
    else
-   {
-      float desired_aspect = video_driver_get_aspect_ratio();
-      float device_aspect  = (float)vp_width / vp_height;
-
-      /* If the aspect ratios of screen and desired aspect ratio
-       * are sufficiently equal (floating point stuff),
-       * assume they are actually equal.
-       */
-      if (fabs(device_aspect - desired_aspect) < 0.0001)
-      {
-         vp->x       = 0;
-         vp->y       = 0;
-         vp->width   = vp_width;
-         vp->height  = vp_height;
-      }
-      else if (device_aspect > desired_aspect)
-      {
-         float delta = (desired_aspect / device_aspect - 1.0) / 2.0 + 0.5;
-         vp->x       = vp_width * (0.5 - delta);
-         vp->y       = 0;
-         vp->width   = 2.0 * vp_width * delta;
-         vp->height  = vp_height;
-      }
-      else
-      {
-         float delta = (device_aspect / desired_aspect - 1.0) / 2.0 + 0.5;
-         vp->x       = 0;
-         vp->y       = vp_height * (0.5 - delta);
-         vp->width   = vp_width;
-         vp->height  = 2.0 * vp_height * delta;
-      }
-   }
+      video_viewport_get_scaled_aspect(vp, vp_width, vp_height, true);
 }
 
 static void *xv_init(const video_info_t *video,
@@ -676,8 +646,8 @@ static void *xv_init(const video_info_t *video,
 
    if (!g_x11_dpy)
    {
-      RARCH_ERR("[XVideo]: Cannot connect to the X server.\n");
-      RARCH_ERR("[XVideo]: Check DISPLAY variable and if X is running.\n");
+      RARCH_ERR("[XVideo] Cannot connect to the X server.\n");
+      RARCH_ERR("[XVideo] Check DISPLAY variable and if X is running.\n");
       goto error;
    }
 
@@ -686,7 +656,7 @@ static void *xv_init(const video_info_t *video,
 
    if (!XShmQueryExtension(g_x11_dpy))
    {
-      RARCH_ERR("[XVideo]: XShm extension not found.\n");
+      RARCH_ERR("[XVideo] XShm extension not found.\n");
       goto error;
    }
 
@@ -700,18 +670,18 @@ static void *xv_init(const video_info_t *video,
    if (ret != Success)
    {
       if (ret == XvBadExtension)
-         RARCH_ERR("[XVideo]: Xv extension not found.\n");
+         RARCH_ERR("[XVideo] Xv extension not found.\n");
       else if (ret == XvBadAlloc)
-         RARCH_ERR("[XVideo]: XvQueryAdaptors() failed to allocate memory.\n");
+         RARCH_ERR("[XVideo] XvQueryAdaptors() failed to allocate memory.\n");
       else
-         RARCH_ERR("[XVideo]: Unkown error in XvQueryAdaptors().\n");
+         RARCH_ERR("[XVideo] Unknown error in XvQueryAdaptors().\n");
 
       goto error;
    }
 
    if (adaptor_count == 0)
    {
-      RARCH_ERR("[XVideo]: XvQueryAdaptors() found 0 adaptors.\n");
+      RARCH_ERR("[XVideo] XvQueryAdaptors() found 0 adaptors.\n");
       goto error;
    }
 
@@ -734,14 +704,14 @@ static void *xv_init(const video_info_t *video,
       xv->depth    = adaptor_info[i].formats->depth;
       xv->visualid = adaptor_info[i].formats->visual_id;
 
-      RARCH_LOG("[XVideo]: Found suitable XvPort #%u\n", (unsigned)xv->port);
+      RARCH_LOG("[XVideo] Found suitable XvPort #%u.\n", (unsigned)xv->port);
       break;
    }
    XvFreeAdaptorInfo(adaptor_info);
 
    if (xv->port == 0)
    {
-      RARCH_ERR("[XVideo]: Failed to find valid XvPort or format.\n");
+      RARCH_ERR("[XVideo] Failed to find valid XvPort or format.\n");
       goto error;
    }
 
@@ -757,7 +727,7 @@ static void *xv_init(const video_info_t *video,
 
    if (visualmatches < 1 || !visualinfo->visual)
    {
-      RARCH_ERR("[XVideo]: Unable to find Xv-compatible visual.\n");
+      RARCH_ERR("[XVideo] Unable to find Xv-compatible visual.\n");
       goto error;
    }
 
@@ -794,7 +764,7 @@ static void *xv_init(const video_info_t *video,
       Atom net_wm_bypass_compositor = XInternAtom(g_x11_dpy,
             "_NET_WM_BYPASS_COMPOSITOR", False);
 
-      RARCH_LOG("[XVideo]: Requesting compositor bypass.\n");
+      RARCH_LOG("[XVideo] Requesting compositor bypass.\n");
       XChangeProperty(g_x11_dpy, g_x11_win,
             net_wm_bypass_compositor, cardinal, 32,
             PropModeReplace, (const unsigned char*)&value, 1);
@@ -833,7 +803,7 @@ static void *xv_init(const video_info_t *video,
 
    if (!xv->image)
    {
-      RARCH_ERR("[XVideo]: XShmCreateImage failed.\n");
+      RARCH_ERR("[XVideo] XShmCreateImage failed.\n");
       goto error;
    }
 
@@ -845,7 +815,7 @@ static void *xv_init(const video_info_t *video,
 
    if (!XShmAttach(g_x11_dpy, &xv->shminfo))
    {
-      RARCH_ERR("[XVideo]: XShmAttach failed.\n");
+      RARCH_ERR("[XVideo] XShmAttach failed.\n");
       goto error;
    }
    XSync(g_x11_dpy, False);
@@ -907,7 +877,7 @@ static bool xv_check_resize(xv_t *xv, unsigned width, unsigned height)
 
       if (xv->image == None)
       {
-         RARCH_ERR("[XVideo]: Failed to create image.\n");
+         RARCH_ERR("[XVideo] Failed to create image.\n");
          return false;
       }
 
@@ -919,7 +889,7 @@ static bool xv_check_resize(xv_t *xv, unsigned width, unsigned height)
 
       if (xv->shminfo.shmid < 0)
       {
-         RARCH_ERR("[XVideo]: Failed to init SHM.\n");
+         RARCH_ERR("[XVideo] Failed to init SHM.\n");
          return false;
       }
 
@@ -929,7 +899,7 @@ static bool xv_check_resize(xv_t *xv, unsigned width, unsigned height)
 
       if (!XShmAttach(g_x11_dpy, &xv->shminfo))
       {
-         RARCH_ERR("[XVideo]: Failed to reattch XvShm image.\n");
+         RARCH_ERR("[XVideo] Failed to reattch XvShm image.\n");
          return false;
       }
       XSync(g_x11_dpy, False);
