@@ -80,7 +80,7 @@ static INLINE bool gfx_ctx_vc_egl_query_extension(vc_ctx_data_t *vc, const char
 {
    const char *str = (const char*)eglQueryString(vc->egl.dpy, EGL_EXTENSIONS);
    bool        ret = str && strstr(str, ext);
-   RARCH_LOG("Querying EGL extension: %s => %s\n",
+   RARCH_LOG("[VC/EGL] Querying EGL extension: %s => %s.\n",
          ext, ret ? "exists" : "doesn't exist");
 
    return ret;
@@ -236,6 +236,10 @@ static void gfx_ctx_vc_destroy(void *data)
       egl_terminate(vc->egl.dpy);
    }
 
+#ifdef HAVE_EGL
+   egl_destroy_gl_dll();
+#endif
+
    vc->egl.ctx      = NULL;
    vc->egl.hw_ctx   = NULL;
    vc->eglimage_ctx = NULL;
@@ -263,20 +267,18 @@ static void gfx_ctx_vc_destroy(void *data)
 
 static void *gfx_ctx_vc_init(void *video_driver)
 {
+   VC_RECT_T dst_rect;
+   VC_RECT_T src_rect;
    VC_DISPMANX_ALPHA_T alpha;
-   EGLint n, major, minor;
-   settings_t *settings           = config_get_ptr();
-   unsigned max_swapchain_images  = settings->uints.video_max_swapchain_images;
-
    DISPMANX_ELEMENT_HANDLE_T dispman_element;
    DISPMANX_DISPLAY_HANDLE_T dispman_display;
    DISPMANX_UPDATE_HANDLE_T dispman_update;
    DISPMANX_MODEINFO_T dispman_modeinfo;
-   VC_RECT_T dst_rect;
-   VC_RECT_T src_rect;
-
+   EGLint n, major, minor;
+   settings_t *settings                      = config_get_ptr();
+   unsigned max_swapchain_images             = settings->uints.video_max_swapchain_images;
 #ifdef HAVE_EGL
-   static const EGLint attribute_list[] =
+   static const EGLint attribute_list[]      =
    {
       EGL_RED_SIZE, 8,
       EGL_GREEN_SIZE, 8,
@@ -287,25 +289,23 @@ static void *gfx_ctx_vc_init(void *video_driver)
       EGL_NONE
    };
 
-   static const EGLint context_attributes[] =
+   static const EGLint context_attributes[]  =
    {
       EGL_CONTEXT_CLIENT_VERSION, 2,
       EGL_NONE
    };
 #endif
-   vc_ctx_data_t *vc     = NULL;
-   unsigned fullscreen_x = settings->uints.video_fullscreen_x;
-   unsigned fullscreen_y = settings->uints.video_fullscreen_y;
+   vc_ctx_data_t *vc                         = NULL;
+   unsigned fullscreen_x                     = settings->uints.video_fullscreen_x;
+   unsigned fullscreen_y                     = settings->uints.video_fullscreen_y;
 
    if (g_egl_inited)
    {
-      RARCH_ERR("[VC/EGL]: Attempted to re-initialize driver.\n");
+      RARCH_ERR("[VC/EGL] Attempted to re-initialize driver.\n");
       return NULL;
    }
 
-   vc = (vc_ctx_data_t*)calloc(1, sizeof(*vc));
-
-   if (!vc)
+   if (!(vc = (vc_ctx_data_t*)calloc(1, sizeof(*vc))))
        return NULL;
 
    bcm_host_init();
@@ -331,50 +331,50 @@ static void *gfx_ctx_vc_init(void *video_driver)
             &vc->fb_width, &vc->fb_height) < 0)
       goto error;
 
-   dst_rect.x      = 0;
-   dst_rect.y      = 0;
-   dst_rect.width  = vc->fb_width;
-   dst_rect.height = vc->fb_height;
+   dst_rect.x                                = 0;
+   dst_rect.y                                = 0;
+   dst_rect.width                            = vc->fb_width;
+   dst_rect.height                           = vc->fb_height;
 
-   src_rect.x      = 0;
-   src_rect.y      = 0;
+   src_rect.x                                = 0;
+   src_rect.y                                = 0;
 
    /* Use dispmanx upscaling if fullscreen_x
     * and fullscreen_y are set. */
-   if ((fullscreen_x != 0) &&
-       (fullscreen_y != 0))
+   if (   (fullscreen_x != 0)
+       && (fullscreen_y != 0))
    {
       /* Keep input and output aspect ratio equal.
        * There are other aspect ratio settings which can be used to stretch video output. */
 
       /* Calculate source and destination aspect ratios. */
-      float src_aspect       = (float)fullscreen_x / (float)fullscreen_y;
-      float dst_aspect       = (float)vc->fb_width / (float)vc->fb_height;
+      float src_aspect                       = (float)fullscreen_x / (float)fullscreen_y;
+      float dst_aspect                       = (float)vc->fb_width / (float)vc->fb_height;
       /* If source and destination aspect ratios are not equal correct source width. */
       if (src_aspect != dst_aspect)
-         src_rect.width      = (unsigned)(fullscreen_y * dst_aspect) << 16;
+         src_rect.width                      = (unsigned)(fullscreen_y * dst_aspect) << 16;
       else
-         src_rect.width      = fullscreen_x << 16;
-      src_rect.height        = fullscreen_y << 16;
+         src_rect.width                      = fullscreen_x << 16;
+      src_rect.height                        = fullscreen_y << 16;
    }
    else
    {
-      src_rect.width         = vc->fb_width << 16;
-      src_rect.height        = vc->fb_height << 16;
+      src_rect.width                         = vc->fb_width << 16;
+      src_rect.height                        = vc->fb_height << 16;
    }
 
-   dispman_display           = vc_dispmanx_display_open(0 /* LCD */);
-   vc->dispman_display       = dispman_display;
+   dispman_display                           = vc_dispmanx_display_open(0 /* LCD */);
+   vc->dispman_display                       = dispman_display;
 
    vc_dispmanx_display_get_info(dispman_display, &dispman_modeinfo);
 
-   dispman_update            = vc_dispmanx_update_start(0);
+   dispman_update                            = vc_dispmanx_update_start(0);
 
-   alpha.flags               = DISPMANX_FLAGS_ALPHA_FIXED_ALL_PIXELS;
-   alpha.opacity             = 255;
-   alpha.mask                = 0;
+   alpha.flags                               = DISPMANX_FLAGS_ALPHA_FIXED_ALL_PIXELS;
+   alpha.opacity                             = 255;
+   alpha.mask                                = 0;
 
-   dispman_element           = vc_dispmanx_element_add(
+   dispman_element                           = vc_dispmanx_element_add(
          dispman_update,
          dispman_display,
          0 /*layer*/,
@@ -386,32 +386,32 @@ static void *gfx_ctx_vc_init(void *video_driver)
          0 /*clamp*/,
          DISPMANX_NO_ROTATE);
 
-   vc->native_window.element = dispman_element;
+   vc->native_window.element                 = dispman_element;
 
    /* Use dispmanx upscaling if fullscreen_x and fullscreen_y are set. */
 
-   if (fullscreen_x != 0 &&
-       fullscreen_y != 0)
+   if (   (fullscreen_x != 0)
+       && (fullscreen_y != 0))
    {
       /* Keep input and output aspect ratio equal.
        * There are other aspect ratio settings which
        * can be used to stretch video output. */
 
       /* Calculate source and destination aspect ratios. */
-      float srcAspect = (float)fullscreen_x / (float)fullscreen_y;
-      float dstAspect = (float)vc->fb_width / (float)vc->fb_height;
+      float src_aspect                       = (float)fullscreen_x / (float)fullscreen_y;
+      float dst_aspect                       = (float)vc->fb_width / (float)vc->fb_height;
 
       /* If source and destination aspect ratios are not equal correct source width. */
-      if (srcAspect != dstAspect)
-         vc->native_window.width = (unsigned)(fullscreen_y * dstAspect);
+      if (src_aspect != dst_aspect)
+         vc->native_window.width             = (unsigned)(fullscreen_y * dst_aspect);
       else
-         vc->native_window.width = fullscreen_x;
-      vc->native_window.height   = fullscreen_y;
+         vc->native_window.width             = fullscreen_x;
+      vc->native_window.height               = fullscreen_y;
    }
    else
    {
-      vc->native_window.width  = vc->fb_width;
-      vc->native_window.height = vc->fb_height;
+      vc->native_window.width                = vc->fb_width;
+      vc->native_window.height               = vc->fb_height;
    }
    vc_dispmanx_update_submit_sync(dispman_update);
 
@@ -420,10 +420,10 @@ static void *gfx_ctx_vc_init(void *video_driver)
       goto error;
 #endif
 
-   /* For vsync after eglSwapBuffers when max_swapchain < 3 */
-   vc->vsync_condition       = scond_new();
-   vc->vsync_condition_mutex = slock_new();
-   vc->vsync_callback_set    = false;
+   /* For VSync after eglSwapBuffers when max_swapchain < 3 */
+   vc->vsync_condition                       = scond_new();
+   vc->vsync_condition_mutex                 = slock_new();
+   vc->vsync_callback_set                    = false;
 
    if (max_swapchain_images <= 2)
    {
@@ -468,10 +468,7 @@ static bool gfx_ctx_vc_set_video_mode(void *data,
    return true;
 }
 
-static enum gfx_ctx_api gfx_ctx_vc_get_api(void *data)
-{
-   return vc_api;
-}
+static enum gfx_ctx_api gfx_ctx_vc_get_api(void *data) { return vc_api; }
 
 static void gfx_ctx_vc_input_driver(void *data,
       const char *name,
@@ -497,7 +494,7 @@ static bool gfx_ctx_vc_image_buffer_init(void *data,
       const video_info_t *video)
 {
    EGLBoolean result;
-   vc_ctx_data_t *vc = (vc_ctx_data_t*)data;
+   vc_ctx_data_t *vc         = (vc_ctx_data_t*)data;
    EGLint pbufsurface_list[] =
    {
       EGL_WIDTH, vc->res,
@@ -509,46 +506,46 @@ static bool gfx_ctx_vc_image_buffer_init(void *data,
    if (vc_api == GFX_CTX_OPENVG_API)
       return false;
 
-   vc->peglCreateImageKHR  = (PFNEGLCREATEIMAGEKHRPROC)egl_get_proc_address("eglCreateImageKHR");
-   vc->peglDestroyImageKHR = (PFNEGLDESTROYIMAGEKHRPROC)egl_get_proc_address("eglDestroyImageKHR");
+   vc->peglCreateImageKHR    = (PFNEGLCREATEIMAGEKHRPROC)egl_get_proc_address("eglCreateImageKHR");
+   vc->peglDestroyImageKHR   = (PFNEGLDESTROYIMAGEKHRPROC)egl_get_proc_address("eglDestroyImageKHR");
 
-   if (  !vc->peglCreateImageKHR  ||
-         !vc->peglDestroyImageKHR ||
-         !gfx_ctx_vc_egl_query_extension(vc, "KHR_image")
+   if (     !vc->peglCreateImageKHR
+         || !vc->peglDestroyImageKHR
+         || !gfx_ctx_vc_egl_query_extension(vc, "KHR_image")
       )
       return false;
 
-   vc->res        = video->input_scale * RARCH_SCALE_BASE;
+   vc->res                   = video->input_scale * RARCH_SCALE_BASE;
 
    egl_bind_api(EGL_OPENVG_API);
-   vc->pbuff_surf = eglCreatePbufferSurface(
+   vc->pbuff_surf            = eglCreatePbufferSurface(
          vc->egl.dpy, vc->egl.config, pbufsurface_list);
 
    if (vc->pbuff_surf == EGL_NO_SURFACE)
    {
-      RARCH_ERR("[VideoCore:EGLImage] failed to create PbufferSurface\n");
+      RARCH_ERR("[VC/EGL] Failed to create PbufferSurface.\n");
       goto fail;
    }
 
-   vc->eglimage_ctx = eglCreateContext(vc->egl.dpy, vc->egl.config, NULL, NULL);
+   vc->eglimage_ctx          = eglCreateContext(vc->egl.dpy, vc->egl.config, NULL, NULL);
    if (vc->eglimage_ctx == EGL_NO_CONTEXT)
    {
-      RARCH_ERR("[VideoCore:EGLImage] failed to create context\n");
+      RARCH_ERR("[VC/EGL] Failed to create context.\n");
       goto fail;
    }
 
    /* Test to make sure we can switch context. */
-   result = eglMakeCurrent(vc->egl.dpy, vc->pbuff_surf, vc->pbuff_surf, vc->eglimage_ctx);
+   result                    = eglMakeCurrent(vc->egl.dpy, vc->pbuff_surf, vc->pbuff_surf, vc->eglimage_ctx);
    if (result == EGL_FALSE)
    {
-      RARCH_ERR("[VideoCore:EGLImage] failed to make context current\n");
+      RARCH_ERR("[VC/EGL] Failed to make context current.\n");
       goto fail;
    }
 
    gfx_ctx_vc_bind_api(NULL, vc_api, 0, 0);
    eglMakeCurrent(vc->egl.dpy, vc->egl.surf, vc->egl.surf, vc->egl.ctx);
 
-   vc->smooth = video->smooth;
+   vc->smooth                = video->smooth;
    return true;
 
 fail:
