@@ -29,6 +29,7 @@
 #include <string.h>
 #include <math.h>
 
+#define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 #include <commdlg.h>
 
@@ -95,9 +96,9 @@ static void gfx_ctx_w_vk_check_window(void *data, bool *quit,
     */
    if (     (win32_vk.flags & VK_DATA_FLAG_FULLSCREEN)
          && (g_win32_refresh_rate)
-         && (g_win32_refresh_rate  != refresh_rate) 
-         && (abs(g_win32_refresh_rate - refresh_rate) > 0)
-         && (g_win32_resize_width  == *width) 
+         && (g_win32_refresh_rate  != refresh_rate)
+         && (fabsf(g_win32_refresh_rate - refresh_rate) > 0.1f)
+         && (g_win32_resize_width  == *width)
          && (g_win32_resize_height == *height))
    {
       g_win32_refresh_rate = settings->floats.video_refresh_rate;
@@ -132,7 +133,7 @@ static bool gfx_ctx_w_vk_set_resize(void *data,
       return true;
    }
 
-   RARCH_ERR("[Vulkan]: Failed to update swapchain.\n");
+   RARCH_ERR("[Vulkan] Failed to update swapchain.\n");
    return false;
 }
 
@@ -224,7 +225,7 @@ static bool gfx_ctx_w_vk_set_video_mode(void *data,
       return true;
    }
 
-   RARCH_ERR("[Vulkan]: win32_set_video_mode failed.\n");
+   RARCH_ERR("[Vulkan] win32_set_video_mode failed.\n");
    gfx_ctx_w_vk_destroy(data);
    return false;
 }
@@ -233,10 +234,9 @@ static void gfx_ctx_w_vk_input_driver(void *data,
       const char *joypad_name,
       input_driver_t **input, void **input_data)
 {
-   settings_t *settings     = config_get_ptr();
-
 #if _WIN32_WINNT >= 0x0501
 #ifdef HAVE_WINRAWINPUT
+   settings_t *settings     = config_get_ptr();
    const char *input_driver = settings->arrays.input_driver;
 
    /* winraw only available since XP */
@@ -271,10 +271,24 @@ static void *gfx_ctx_w_vk_get_context_data(void *data) { return &win32_vk.contex
 
 static uint32_t gfx_ctx_w_vk_get_flags(void *data)
 {
-   uint32_t flags = 0;
+   uint32_t flags             = 0;
+   uint8_t present_mode_count = 16;
+   uint8_t i                  = 0;
+
+   /* Check for FIFO_RELAXED_KHR capability */
+   for (i = 0; i < present_mode_count; i++)
+   {
+      if (win32_vk.context.present_modes[i] == VK_PRESENT_MODE_FIFO_RELAXED_KHR)
+      {
+         BIT32_SET(flags, GFX_CTX_FLAGS_ADAPTIVE_VSYNC);
+         break;
+      }
+   }
+
 #if defined(HAVE_SLANG) && defined(HAVE_SPIRV_CROSS)
    BIT32_SET(flags, GFX_CTX_FLAGS_SHADERS_SLANG);
 #endif
+
    return flags;
 }
 
