@@ -29,6 +29,7 @@
 #include <string.h>
 #include <math.h>
 
+#define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 #include <commdlg.h>
 
@@ -55,7 +56,36 @@
 #endif
 
 #ifdef __WINRT__
-#include "../common/uwpgdi.h"
+#include <GL/gl.h>
+
+#if !defined(_GDI32_)
+#define WINGDIAPI_UWP __declspec(dllimport)
+#else
+#define WINGDIAPI_UWP __declspec(dllexport)
+#endif
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+/*
+ * Undeclared APIs exported by libgallium on UWP
+ */
+
+WINGDIAPI_UWP HGLRC WINAPI wglCreateContext(HDC);
+WINGDIAPI_UWP BOOL  WINAPI wglDeleteContext(HGLRC);
+WINGDIAPI_UWP BOOL  WINAPI wglMakeCurrent(HDC, HGLRC);
+WINGDIAPI_UWP BOOL APIENTRY wglSwapBuffers(HDC hdc);
+WINGDIAPI_UWP PROC APIENTRY wglGetProcAddress(LPCSTR lpszProc);
+WINGDIAPI_UWP BOOL APIENTRY wglShareLists(
+   HGLRC unnamedParam1,
+   HGLRC unnamedParam2
+);
+
+#ifdef __cplusplus
+}
+#endif
+
 #endif
 
 #if (defined(HAVE_OPENGL) || defined(HAVE_OPENGL1) || defined(HAVE_OPENGL_CORE)) && !defined(HAVE_OPENGLES)
@@ -197,7 +227,7 @@ void create_gl_context(HWND hwnd, bool *quit)
    if (win32_hrc)
    {
       video_state_get_ptr()->flags |= VIDEO_FLAG_CACHE_CONTEXT_ACK;
-      RARCH_LOG("[WGL]: Using cached GL context.\n");
+      RARCH_LOG("[WGL] Using cached GL context.\n");
    }
    else
    {
@@ -210,7 +240,7 @@ void create_gl_context(HWND hwnd, bool *quit)
          {
             if (!wglShareLists(win32_hrc, win32_hw_hrc))
             {
-               RARCH_LOG("[WGL]: Failed to share contexts.\n");
+               RARCH_LOG("[WGL] Failed to share contexts.\n");
                *quit    = true;
             }
          }
@@ -323,7 +353,7 @@ void create_gl_context(HWND hwnd, bool *quit)
 
                   if (!win32_hw_hrc)
                   {
-                     RARCH_ERR("[WGL]: Failed to create shared context.\n");
+                     RARCH_ERR("[WGL] Failed to create shared context.\n");
                      *quit = true;
                      break;
                   }
@@ -345,12 +375,12 @@ void create_gl_context(HWND hwnd, bool *quit)
 
          if (!context)
          {
-            RARCH_ERR("[WGL]: Failed to create core context. Falling back to legacy context.\n");
+            RARCH_ERR("[WGL] Failed to create core context. Falling back to legacy context.\n");
             *quit = true;
          }
       }
       else
-         RARCH_ERR("[WGL]: wglCreateContextAttribsARB not supported.\n");
+         RARCH_ERR("[WGL] wglCreateContextAttribsARB not supported.\n");
    }
 
    {
@@ -363,10 +393,10 @@ void create_gl_context(HWND hwnd, bool *quit)
       if (wglGetExtensionsStringARB)
       {
          exts = wglGetExtensionsStringARB(win32_hdc);
-         RARCH_LOG("[WGL]: Extensions: %s\n", exts);
+         RARCH_LOG("[WGL] Extensions: %s\n", exts);
          if (wgl_has_extension("WGL_EXT_swap_control_tear", exts))
          {
-            RARCH_LOG("[WGL]: Adaptive VSync supported.\n");
+            RARCH_LOG("[WGL] Adaptive VSync supported.\n");
             wgl_flags |= WGL_FLAG_ADAPTIVE_VSYNC;
          }
       }
@@ -438,7 +468,7 @@ static void gfx_ctx_wgl_swap_interval(void *data, int interval)
             return;
 
          if (!p_swap_interval(win32_interval))
-            RARCH_WARN("[WGL]: wglSwapInterval(%i) failed.\n", win32_interval);
+            RARCH_WARN("[WGL] wglSwapInterval(%i) failed.\n", win32_interval);
 #endif
          break;
 
@@ -613,7 +643,7 @@ static void *gfx_ctx_wgl_init(void *video_driver)
    create_gl_context(uwp_get_corewindow(), &quit);
    if (quit)
    {
-      RARCH_ERR("[UWP WGL]: create_gl_context failed.\n");
+      RARCH_ERR("[WGL UWP] create_gl_context failed.\n");
       free(wgl);
       return NULL;
    }
@@ -627,7 +657,7 @@ static bool gfx_ctx_wgl_set_video_mode(void *data,
 {
    if (!win32_set_video_mode(NULL, width, height, fullscreen))
    {
-      RARCH_ERR("[WGL]: win32_set_video_mode failed.\n");
+      RARCH_ERR("[WGL] win32_set_video_mode failed.\n");
       gfx_ctx_wgl_destroy(data);
       return false;
    }
@@ -755,14 +785,14 @@ static uint32_t gfx_ctx_wgl_get_flags(void *data)
             BIT32_SET(flags, GFX_CTX_FLAGS_GL_CORE_CONTEXT);
 
          if (string_is_equal(video_driver_get_ident(), "gl1")) { }
-         else if (string_is_equal(video_driver_get_ident(), "glcore"))
-         {
-#if defined(HAVE_SLANG) && defined(HAVE_SPIRV_CROSS)
-            BIT32_SET(flags, GFX_CTX_FLAGS_SHADERS_SLANG);
-#endif
-         }
          else
          {
+            if (string_is_equal(video_driver_get_ident(), "glcore"))
+            {
+#if defined(HAVE_SLANG) && defined(HAVE_SPIRV_CROSS)
+               BIT32_SET(flags, GFX_CTX_FLAGS_SHADERS_SLANG);
+#endif
+            }
 #ifdef HAVE_CG
             if (!(wgl_flags & WGL_FLAG_CORE_HW_CTX_ENABLE))
                BIT32_SET(flags, GFX_CTX_FLAGS_SHADERS_CG);
