@@ -199,13 +199,13 @@ static EGLint *xegl_fill_attribs(xegl_ctx_data_t *xegl, EGLint *attr)
 #ifdef EGL_KHR_create_context
       case GFX_CTX_OPENGL_API:
          {
-            unsigned 
+            unsigned
 		  version = xegl->egl.major * 1000 + xegl->egl.minor;
             bool core     = version >= 3001;
 #ifdef GL_DEBUG
             bool debug    = true;
 #else
-            struct retro_hw_render_callback 
+            struct retro_hw_render_callback
 		    *hwr  = video_driver_get_hw_context();
             bool debug    = hwr->debug_context;
 #endif
@@ -304,10 +304,10 @@ static bool gfx_ctx_xegl_set_video_mode(void *data,
    swa.colormap                      = g_x11_cmap = XCreateColormap(
 		   g_x11_dpy, RootWindow(g_x11_dpy, vi->screen),
 		   vi->visual, AllocNone);
-   swa.event_mask                    = StructureNotifyMask 
+   swa.event_mask                    = StructureNotifyMask
 	                             | KeyPressMask
-                                     | ButtonPressMask 
-				     | ButtonReleaseMask 
+                                     | ButtonPressMask
+				     | ButtonReleaseMask
 				     | KeyReleaseMask
                                      | EnterWindowMask
 				     | LeaveWindowMask;
@@ -324,11 +324,11 @@ static bool gfx_ctx_xegl_set_video_mode(void *data,
 
          if (wm_name)
          {
-            RARCH_LOG("[X/EGL]: Window manager is %s.\n", wm_name);
+            RARCH_LOG("[X/EGL] Window manager is %s.\n", wm_name);
 
             if (strcasestr(wm_name, "xfwm"))
             {
-               RARCH_LOG("[X/EGL]: Using override-redirect workaround.\n");
+               RARCH_LOG("[X/EGL] Using override-redirect workaround.\n");
                swa.override_redirect = True;
             }
             free(wm_name);
@@ -337,7 +337,7 @@ static bool gfx_ctx_xegl_set_video_mode(void *data,
             swa.override_redirect    = True;
       }
       else
-         RARCH_ERR("[X/EGL]: Entering true fullscreen failed. Will attempt windowed mode.\n");
+         RARCH_ERR("[X/EGL] Entering true fullscreen failed. Will attempt windowed mode.\n");
    }
 #endif
 
@@ -353,9 +353,9 @@ static bool gfx_ctx_xegl_set_video_mode(void *data,
 
       if (xinerama_get_coord(g_x11_dpy, g_x11_screen,
                &x_off, &y_off, &new_width, &new_height))
-         RARCH_LOG("[X/EGL]: Using Xinerama on screen #%u.\n", g_x11_screen);
+         RARCH_LOG("[X/EGL] Using Xinerama on screen #%u.\n", g_x11_screen);
       else
-         RARCH_LOG("[X/EGL]: Xinerama is not active on screen.\n");
+         RARCH_LOG("[X/EGL] Xinerama is not active on screen.\n");
 
       if (fullscreen)
       {
@@ -365,7 +365,7 @@ static bool gfx_ctx_xegl_set_video_mode(void *data,
    }
 #endif
 
-   RARCH_LOG("[X/EGL]: X = %d, Y = %d, W = %u, H = %u.\n",
+   RARCH_DBG("[X/EGL] X = %d, Y = %d, W = %u, H = %u.\n",
          x_off, y_off, width, height);
 
    g_x11_win = XCreateWindow(g_x11_dpy, RootWindow(g_x11_dpy, vi->screen),
@@ -381,7 +381,7 @@ static bool gfx_ctx_xegl_set_video_mode(void *data,
       Atom cardinal                  = XInternAtom(g_x11_dpy, "CARDINAL", False);
       Atom net_wm_bypass_compositor  = XInternAtom(g_x11_dpy, "_NET_WM_BYPASS_COMPOSITOR", False);
 
-      RARCH_LOG("[X/EGL]: Requesting compositor bypass.\n");
+      RARCH_LOG("[X/EGL] Requesting compositor bypass.\n");
       XChangeProperty(g_x11_dpy, g_x11_win, net_wm_bypass_compositor, cardinal, 32, PropModeReplace, (const unsigned char*)&value, 1);
    }
 
@@ -403,7 +403,7 @@ static bool gfx_ctx_xegl_set_video_mode(void *data,
 #ifdef HAVE_XF86VM
    if (true_full)
    {
-      RARCH_LOG("[X/EGL]: Using true fullscreen.\n");
+      RARCH_LOG("[X/EGL] Using true fullscreen.\n");
       XMapRaised(g_x11_dpy, g_x11_win);
       x11_set_net_wm_fullscreen(g_x11_dpy, g_x11_win);
    }
@@ -414,7 +414,7 @@ static bool gfx_ctx_xegl_set_video_mode(void *data,
       /* We attempted true fullscreen, but failed.
        * Attempt using windowed fullscreen. */
       XMapRaised(g_x11_dpy, g_x11_win);
-      RARCH_LOG("[X/EGL]: Using windowed fullscreen.\n");
+      RARCH_LOG("[X/EGL] Using windowed fullscreen.\n");
 
       /* We have to move the window to the screen we
        * want to go fullscreen on first.
@@ -572,10 +572,9 @@ static uint32_t gfx_ctx_xegl_get_flags(void *data)
       BIT32_SET(flags, GFX_CTX_FLAGS_SHADERS_SLANG);
 #endif
    }
-   else
-   {
-      BIT32_SET(flags, GFX_CTX_FLAGS_SHADERS_GLSL);
-   }
+#ifdef HAVE_GLSL
+   BIT32_SET(flags, GFX_CTX_FLAGS_SHADERS_GLSL);
+#endif
 
    return flags;
 }
