@@ -3,7 +3,7 @@
  *  Copyright (C) 2011-2020 - Daniel De Matteis
  *  Copyright (C) 2019-2020 - James Leaver
  *  Copyright (C)      2020 - trngaje
- * 
+ *
  *  RetroArch is free software: you can redistribute it and/or modify it under the terms
  *  of the GNU General Public License as published by the Free Software Found-
  *  ation, either version 3 of the License, or (at your option) any later version.
@@ -63,7 +63,7 @@
  * font file is missing */
 bitmapfont_lut_t *bitmapfont_10x10_load(unsigned language)
 {
-   char font_dir[PATH_MAX_LENGTH];
+   char font_dir[DIR_MAX_LENGTH];
    char font_path[PATH_MAX_LENGTH];
    const char *font_file      = NULL;
    void *bitmap_raw           = NULL;
