@@ -44,6 +44,11 @@
 #include "../../deps/xxHash/xxhash.h"
 #endif
 
+#if defined(VITA)
+#include <psp2/kernel/threadmgr/thread.h>
+#include <psp2/power.h>
+#endif
+
 #define PREV_TEXTURES (GFX_MAX_TEXTURES - 1)
 
 /* Cache the VBO. */
@@ -51,8 +56,8 @@ struct cache_vbo
 {
    GLuint vbo_primary;
    GLuint vbo_secondary;
-   size_t size_primary;
-   size_t size_secondary;
+   size_t len_primary;
+   size_t len_secondary;
    GLfloat *buffer_primary;
    GLfloat *buffer_secondary;
 };
@@ -251,7 +256,7 @@ static void gl_glsl_print_shader_log(GLuint obj)
    glGetShaderInfoLog(obj, max_len, &info_len, info_log);
 
    if (info_len > 0)
-      RARCH_LOG("Shader log: %s\n", info_log);
+      RARCH_LOG("[GLSL] Shader log: %s.\n", info_log);
 
    free(info_log);
 }
@@ -273,7 +278,7 @@ static void gl_glsl_print_linker_log(GLuint obj)
    glGetProgramInfoLog(obj, max_len, &info_len, info_log);
 
    if (info_len > 0)
-      RARCH_LOG("Linker log: %s\n", info_log);
+      RARCH_LOG("[GLSL] Linker log: %s.\n", info_log);
 
    free(info_log);
 }
@@ -314,7 +319,7 @@ static bool gl_glsl_load_binary_shader(GLuint shader, char *save_path)
       shader_size=ftell (shader_binary);
       fseek(shader_binary, 0, SEEK_SET);
 
-      shader_data = malloc(shader_size);
+      shader_data = (char*)malloc(shader_size);
       fread(shader_data, shader_size, 1, shader_binary);
       fclose(shader_binary);
 
@@ -340,7 +345,7 @@ static void gl_glsl_dump_shader(GLuint shader, char *save_path)
    glGetShaderiv(shader, 0x8b89, &length);
 
    bufferSize   = length;
-   shaderBinary = malloc(bufferSize);
+   shaderBinary = (void*)malloc(bufferSize);
 
    memset(shaderBinary, 0, bufferSize);
 
@@ -371,26 +376,31 @@ static bool gl_glsl_compile_shader(glsl_shader_data_t *glsl,
          strtoul(existing_version + 8, (char**)&program, 10);
 
 #ifdef HAVE_OPENGLES
-      if (version_no >= 130 && version_no < 330)
+      if (gl_check_capability(GL_CAPS_GLES3_SUPPORTED))
       {
-         version_extra = " es";
-         version_no    = 300;
+         if (version_no >= 130 && version_no < 330)
+         {
+            version_extra = " es";
+            version_no    = 300;
+         }
+         else if (version_no == 330)
+         {
+            version_extra = " es";
+            version_no    = 310;
+         }
+         else if (version_no > 330)
+         {
+            version_extra = " es";
+            version_no    = 320;
+         }
+         else version_no  = 100;
       }
-      else if (version_no == 330)
-      {
-         version_extra = " es";
-         version_no    = 310;
-      }
-      else if (version_no > 330)
-      {
-         version_extra = " es";
-         version_no    = 320;
-      }
-      else version_no  = 100;
+      /* Avoid versions that definitely aren't supported. */
+      else version_no     = 100;
 #endif
       snprintf(version,
             sizeof(version), "#version %u%s\n", version_no, version_extra);
-      RARCH_LOG("[GLSL]: Using GLSL version %u%s.\n", version_no, version_extra);
+      RARCH_LOG("[GLSL] Using GLSL version %u%s.\n", version_no, version_extra);
    }
    else if (glsl_core)
    {
@@ -414,7 +424,7 @@ static bool gl_glsl_compile_shader(glsl_shader_data_t *glsl,
       }
 
       snprintf(version, sizeof(version), "#version %u\n", version_no);
-      RARCH_LOG("[GLSL]: Using GLSL version %u.\n", version_no);
+      RARCH_LOG("[GLSL] Using GLSL version %u.\n", version_no);
    }
 
    source[0] = version;
@@ -440,13 +450,6 @@ static bool gl_glsl_compile_shader(glsl_shader_data_t *glsl,
    glGetShaderiv(shader, GL_COMPILE_STATUS, &status);
    gl_glsl_print_shader_log(shader);
 
-#if 0
-#if defined(ORBIS)
-   if (status == GL_TRUE)
-      gl_glsl_dump_shader(shader, save_path);
-#endif
-#endif
-
    return status == GL_TRUE;
 }
 
@@ -485,7 +488,7 @@ static bool gl_glsl_compile_program(
 
    if (program_info->vertex)
    {
-      RARCH_LOG("[GLSL]: Found GLSL vertex shader.\n");
+      RARCH_LOG("[GLSL] Found GLSL vertex shader.\n");
       program->vprg = glCreateShader(GL_VERTEX_SHADER);
 
       if (!gl_glsl_compile_shader(
@@ -494,7 +497,7 @@ static bool gl_glsl_compile_program(
                "#define VERTEX\n#define PARAMETER_UNIFORM\n#define _HAS_ORIGINALASPECT_UNIFORMS\n#define _HAS_FRAMETIME_UNIFORMS\n",
                program_info->vertex))
       {
-         RARCH_ERR("Failed to compile vertex shader #%u\n", idx);
+         RARCH_ERR("[GLSL] Failed to compile vertex shader #%u.\n", idx);
          goto error;
       }
 
@@ -503,13 +506,13 @@ static bool gl_glsl_compile_program(
 
    if (program_info->fragment)
    {
-      RARCH_LOG("[GLSL]: Found GLSL fragment shader.\n");
+      RARCH_LOG("[GLSL] Found GLSL fragment shader.\n");
       program->fprg = glCreateShader(GL_FRAGMENT_SHADER);
       if (!gl_glsl_compile_shader(glsl, program->fprg,
                "#define FRAGMENT\n#define PARAMETER_UNIFORM\n#define _HAS_ORIGINALASPECT_UNIFORMS\n#define _HAS_FRAMETIME_UNIFORMS\n",
                program_info->fragment))
       {
-         RARCH_ERR("Failed to compile fragment shader #%u\n", idx);
+         RARCH_ERR("[GLSL] Failed to compile fragment shader #%u.\n", idx);
          goto error;
       }
 
@@ -518,7 +521,7 @@ static bool gl_glsl_compile_program(
 
    if (program_info->vertex || program_info->fragment)
    {
-      RARCH_LOG("[GLSL]: Linking GLSL program.\n");
+      RARCH_LOG("[GLSL] Linking GLSL program.\n");
       if (!gl_glsl_link_program(prog))
          goto error;
 
@@ -546,7 +549,7 @@ static bool gl_glsl_compile_program(
    return true;
 
 error:
-   RARCH_ERR("Failed to link program #%u.\n", idx);
+   RARCH_ERR("[GLSL] Failed to link program #%u.\n", idx);
    program->id = 0;
    return false;
 }
@@ -606,7 +609,7 @@ static bool gl_glsl_compile_programs(
       if (     !string_is_empty(pass->source.path)
             && !gl_glsl_load_source_path(pass, pass->source.path))
       {
-         RARCH_ERR("Failed to load GLSL shader: %s.\n",
+         RARCH_ERR("[GLSL] Failed to load GLSL shader: %s.\n",
                pass->source.path);
          return false;
       }
@@ -622,7 +625,7 @@ static bool gl_glsl_compile_programs(
             &program[i],
             &shader_prog_info))
       {
-         RARCH_ERR("Failed to create GL program #%u.\n", i);
+         RARCH_ERR("[GLSL] Failed to create GL program #%u.\n", i);
          return false;
       }
    }
@@ -680,7 +683,7 @@ static INLINE void gl_glsl_set_attribs(glsl_shader_data_t *glsl,
          glsl->attribs_elems[glsl->attribs_index++] = loc;
       }
       else
-         RARCH_WARN("Attrib array buffer was overflown!\n");
+         RARCH_WARN("[GLSL] Attrib array buffer was overflown.\n");
    }
 
    glBindBuffer(GL_ARRAY_BUFFER, 0);
@@ -890,7 +893,12 @@ static void gl_glsl_init_menu_shaders(void *data)
    shader_prog_info.vertex = stock_vertex_xmb_ribbon_modern;
    shader_prog_info.fragment = stock_fragment_xmb;
 #else
-   if (gl_query_extension("GL_OES_standard_derivatives"))
+   if (gl_check_capability(GL_CAPS_GLES3_SUPPORTED))
+   {
+      shader_prog_info.vertex = stock_vertex_xmb_ribbon_modern;
+      shader_prog_info.fragment = core_stock_fragment_xmb;
+   }
+   else if (gl_query_extension("GL_OES_standard_derivatives"))
    {
       shader_prog_info.vertex = glsl_core ? stock_vertex_xmb_ribbon_modern : stock_vertex_xmb_ribbon_legacy;
       shader_prog_info.fragment = glsl_core ? core_stock_fragment_xmb : stock_fragment_xmb;
@@ -907,7 +915,7 @@ static void gl_glsl_init_menu_shaders(void *data)
 #endif
    shader_prog_info.is_file = false;
 
-   RARCH_LOG("[GLSL]: Compiling ribbon shader..\n");
+   RARCH_LOG("[GLSL] Compiling ribbon shader...\n");
    gl_glsl_compile_program(
          glsl,
          VIDEO_SHADER_MENU,
@@ -924,7 +932,7 @@ static void gl_glsl_init_menu_shaders(void *data)
    shader_prog_info.fragment = glsl_core ? stock_fragment_xmb_ribbon_simple_core : stock_fragment_xmb_ribbon_simple;
 #endif
 
-   RARCH_LOG("[GLSL]: Compiling simple ribbon shader..\n");
+   RARCH_LOG("[GLSL] Compiling simple ribbon shader...\n");
    gl_glsl_compile_program(
          glsl,
          VIDEO_SHADER_MENU_2,
@@ -942,7 +950,7 @@ static void gl_glsl_init_menu_shaders(void *data)
    shader_prog_info.fragment = glsl_core ? stock_fragment_xmb_simple_snow_core : stock_fragment_xmb_simple_snow;
 #endif
 
-   RARCH_LOG("[GLSL]: Compiling snow shader..\n");
+   RARCH_LOG("[GLSL] Compiling snow shader...\n");
    gl_glsl_compile_program(
          glsl,
          VIDEO_SHADER_MENU_3,
@@ -959,7 +967,7 @@ static void gl_glsl_init_menu_shaders(void *data)
    shader_prog_info.fragment = glsl_core ? stock_fragment_xmb_snow_core : stock_fragment_xmb_snow;
 #endif
 
-   RARCH_LOG("[GLSL]: Compiling modern snow shader..\n");
+   RARCH_LOG("[GLSL] Compiling modern snow shader...\n");
    gl_glsl_compile_program(
          glsl,
          VIDEO_SHADER_MENU_4,
@@ -976,7 +984,7 @@ static void gl_glsl_init_menu_shaders(void *data)
    shader_prog_info.fragment = glsl_core ? stock_fragment_xmb_bokeh_core : stock_fragment_xmb_bokeh;
 #endif
 
-   RARCH_LOG("[GLSL]: Compiling bokeh shader..\n");
+   RARCH_LOG("[GLSL] Compiling bokeh shader...\n");
    gl_glsl_compile_program(
          glsl,
          VIDEO_SHADER_MENU_5,
@@ -993,7 +1001,7 @@ static void gl_glsl_init_menu_shaders(void *data)
    shader_prog_info.fragment = glsl_core ? stock_fragment_xmb_snowflake_core : stock_fragment_xmb_snowflake;
 #endif
 
-   RARCH_LOG("[GLSL]: Compiling snowflake shader..\n");
+   RARCH_LOG("[GLSL] Compiling snowflake shader...\n");
    gl_glsl_compile_program(
          glsl,
          VIDEO_SHADER_MENU_6,
@@ -1011,7 +1019,7 @@ static void *gl_glsl_init(void *data, const char *path)
    struct shader_program_info shader_prog_info;
    bool shader_support        = false;
 #ifdef GLSL_DEBUG
-   char *error_string         = NULL;
+   char *err_string           = NULL;
 #endif
    const char *stock_vertex   = NULL;
    const char *stock_fragment = NULL;
@@ -1024,7 +1032,7 @@ static void *gl_glsl_init(void *data, const char *path)
    (void)shader_support;
 
 #ifndef HAVE_OPENGLES
-   RARCH_LOG("[GLSL]: Checking GLSL shader support ...\n");
+   RARCH_LOG("[GLSL] Checking GLSL shader support...\n");
    shader_support = glCreateProgram && glUseProgram && glCreateShader
       && glDeleteShader && glShaderSource && glCompileShader && glAttachShader
       && glDetachShader && glLinkProgram && glGetUniformLocation
@@ -1040,7 +1048,7 @@ static void *gl_glsl_init(void *data, const char *path)
 
    if (!shader_support)
    {
-      RARCH_ERR("GLSL shaders aren't supported by your OpenGL driver.\n");
+      RARCH_ERR("[GLSL] GLSL shaders aren't supported by your OpenGL driver.\n");
       goto error;
    }
 #endif
@@ -1056,7 +1064,7 @@ static void *gl_glsl_init(void *data, const char *path)
 
       if (!string_is_empty(path) && type != RARCH_SHADER_GLSL)
       {
-         RARCH_ERR("[GL]: Invalid shader type, falling back to stock.\n");
+         RARCH_ERR("[GLSL] Invalid shader type, falling back to stock.\n");
          path = NULL;
       }
 
@@ -1080,13 +1088,13 @@ static void *gl_glsl_init(void *data, const char *path)
 
          if (!ret)
          {
-            RARCH_ERR("[GL]: Failed to parse GLSL shader.\n");
+            RARCH_ERR("[GLSL] Failed to parse GLSL shader.\n");
             goto error;
          }
       }
       else
       {
-         RARCH_WARN("[GL]: Stock GLSL shaders will be used.\n");
+         RARCH_WARN("[GLSL] Stock GLSL shaders will be used.\n");
          glsl->shader->passes = 1;
 #if defined(VITA)
          glsl->shader->pass[0].source.string.vertex   = strdup(stock_vertex_modern);
@@ -1120,14 +1128,14 @@ static void *gl_glsl_init(void *data, const char *path)
 #ifdef HAVE_OPENGLES
    if (!(glsl->shader->flags & SHDR_FLAG_MODERN))
    {
-      RARCH_ERR("[GL]: GLES context is used, but shader is not modern. Cannot use it.\n");
+      RARCH_ERR("[GLSL] GLES context is used, but shader is not modern. Cannot use it.\n");
       goto error;
    }
 #else
    if (      glsl_core
          && (!(glsl->shader->flags & SHDR_FLAG_MODERN)))
    {
-      RARCH_ERR("[GL]: GL core context is used, but shader is not core compatible. Cannot use it.\n");
+      RARCH_ERR("[GLSL] GL core context is used, but shader is not core compatible. Cannot use it.\n");
       goto error;
    }
 #endif
@@ -1155,7 +1163,7 @@ static void *gl_glsl_init(void *data, const char *path)
 
    if (!gl_glsl_compile_program(glsl, 0, &glsl->prg[0], &shader_prog_info))
    {
-      RARCH_ERR("GLSL stock programs failed to compile.\n");
+      RARCH_ERR("[GLSL] GLSL stock programs failed to compile.\n");
       goto error;
    }
 
@@ -1164,7 +1172,7 @@ static void *gl_glsl_init(void *data, const char *path)
 
    if (!gl2_load_luts(glsl->shader, glsl->lut_textures))
    {
-      RARCH_ERR("[GL]: Failed to load LUTs.\n");
+      RARCH_ERR("[GLSL] Failed to load LUTs.\n");
       goto error;
    }
 
@@ -1172,11 +1180,11 @@ static void *gl_glsl_init(void *data, const char *path)
       gl_glsl_find_uniforms(glsl, i, glsl->prg[i].id, &glsl->uniforms[i]);
 
 #ifdef GLSL_DEBUG
-   if (!gl_check_error(&error_string))
+   if (!gl_check_error(&err_string))
    {
-      RARCH_ERR("%s\n", error_string);
-      free(error_string);
-      RARCH_WARN("Detected GL error in GLSL.\n");
+      RARCH_ERR("%s\n", err_string);
+      free(err_string);
+      RARCH_WARN("[GLSL] Detected GL error in GLSL.\n");
    }
 #endif
 
@@ -1292,9 +1300,8 @@ static void gl_glsl_set_params(void *dat, void *shader_data)
    struct glsl_attrib attribs[32];
    float input_size[2], output_size[2], texture_size[2], final_vp_size[2];
    video_shader_ctx_params_t          *params = (video_shader_ctx_params_t*)dat;
-   gl2_t                             *gl_data = (gl2_t*)params->data;
-   unsigned vp_width                          = gl_data->out_vp_width;
-   unsigned vp_height                         = gl_data->out_vp_height;
+   unsigned vp_width                          = params->vp_width;
+   unsigned vp_height                         = params->vp_height;
    unsigned width                             = params->width;
    unsigned height                            = params->height;
    unsigned tex_width                         = params->tex_width;
@@ -1368,7 +1375,7 @@ static void gl_glsl_set_params(void *dat, void *shader_data)
    }
 
   if (uni->frame_time_delta >= 0)
-      glUniform1i(uni->frame_time_delta, video_driver_get_frame_time_delta_usec());
+      glUniform1i(uni->frame_time_delta, (GLint)video_driver_get_frame_time_delta_usec());
 
   if (uni->original_fps >= 0)
       glUniform1f(uni->original_fps, video_driver_get_original_fps());
@@ -1379,13 +1386,14 @@ static void gl_glsl_set_params(void *dat, void *shader_data)
   if (uni->core_aspect >= 0)
       glUniform1f(uni->core_aspect, video_driver_get_core_aspect());
 
-  if (uni->core_aspect_rot >= 0) {
-      /* OriginalAspectRotated: return 1/aspect for 90 and 270 rotated content */
-      float core_aspect_rot = video_driver_get_core_aspect();
-      uint32_t rot = retroarch_get_rotation();
-      if (rot == 1 || rot == 3)
-         core_aspect_rot = 1/core_aspect_rot;
-      glUniform1f(uni->core_aspect_rot, core_aspect_rot);
+  if (uni->core_aspect_rot >= 0)
+  {
+     /* OriginalAspectRotated: return 1/aspect for 90 and 270 rotated content */
+     float core_aspect_rot = video_driver_get_core_aspect();
+     uint32_t rot = retroarch_get_rotation();
+     if (rot == 1 || rot == 3)
+        core_aspect_rot = 1/core_aspect_rot;
+     glUniform1f(uni->core_aspect_rot, core_aspect_rot);
   }
 
    /* Set lookup textures. */
@@ -1554,7 +1562,7 @@ static void gl_glsl_set_params(void *dat, void *shader_data)
    if (size)
       gl_glsl_set_attribs(glsl, glsl->vbo[glsl->active_idx].vbo_secondary,
             &glsl->vbo[glsl->active_idx].buffer_secondary,
-            &glsl->vbo[glsl->active_idx].size_secondary,
+            &glsl->vbo[glsl->active_idx].len_secondary,
             buffer, size, attribs, attribs_size);
 
    glActiveTexture(GL_TEXTURE0);
@@ -1686,7 +1694,7 @@ static bool gl_glsl_set_coords(void *shader_data,
       gl_glsl_set_attribs(glsl,
             glsl->vbo[glsl->active_idx].vbo_primary,
             &glsl->vbo[glsl->active_idx].buffer_primary,
-            &glsl->vbo[glsl->active_idx].size_primary,
+            &glsl->vbo[glsl->active_idx].len_primary,
             buffer, size,
             attribs, attribs_size);
 
