@@ -16,7 +16,6 @@
  */
 
 #include <retro_miscellaneous.h>
-#include <retro_inline.h>
 
 #ifdef HAVE_CONFIG_H
 #include "../config.h"
@@ -43,41 +42,13 @@
 #include "../tasks/task_content.h"
 #include "../tasks/tasks_internal.h"
 
-#define BASE_FONT_SIZE 32.0f
-
+#define BASE_FONT_SIZE      32.0f
 #define MSG_QUEUE_FONT_SIZE 20.0f
 
-/* Icons */
-static const char
-*gfx_widgets_icons_names[MENU_WIDGETS_ICON_LAST]         = {
-   "menu_pause.png",
-   "menu_frameskip.png",
-   "menu_rewind.png",
-   "resume.png",
-
-   "menu_hourglass.png",
-   "menu_check.png",
-   "menu_add.png",
-   "menu_exit.png",
-
-   "menu_info.png",
-
-   "menu_achievements.png"
-};
-
 static dispgfx_widget_t dispwidget_st = {0}; /* uint64_t alignment */
 
-static void INLINE gfx_widgets_font_free(gfx_widget_font_data_t *font_data)
-{
-   if (font_data->font)
-      font_driver_free(font_data->font);
-
-   font_data->font        = NULL;
-   font_data->usage_count = 0;
-}
-
 /* Widgets list */
-const static gfx_widget_t* const widgets[] = {
+static const gfx_widget_t* const widgets[] = {
 #ifdef HAVE_NETWORKING
    &gfx_widget_netplay_chat,
    &gfx_widget_netplay_ping,
@@ -217,6 +188,7 @@ void gfx_widgets_msg_queue_push(
 
          msg_widget->offset_y                   = 0;
          msg_widget->alpha                      = 1.0f;
+         msg_widget->alternative_look           = task && (task->flags & RETRO_TASK_FLG_ALTERNATIVE_LOOK);
 
          msg_widget->width                      = 0;
 
@@ -241,6 +213,16 @@ void gfx_widgets_msg_queue_push(
             msg_widget->unfold                  = 1.0f;
          }
 
+         if (category == MESSAGE_QUEUE_CATEGORY_WARNING)
+            msg_widget->flags                  |=  DISPWIDG_FLAG_CATEGORY_WARNING;
+         else if (category == MESSAGE_QUEUE_CATEGORY_ERROR)
+            msg_widget->flags                  |=  DISPWIDG_FLAG_CATEGORY_ERROR;
+         else if (category == MESSAGE_QUEUE_CATEGORY_SUCCESS)
+            msg_widget->flags                  |=  DISPWIDG_FLAG_CATEGORY_SUCCESS;
+
+         if (prio > 1 && category != MESSAGE_QUEUE_CATEGORY_ERROR)
+            msg_widget->flags                  |= DISPWIDG_FLAG_SMALL;
+
          if (task)
          {
             len                                 = strlen(task->title);
@@ -377,7 +359,7 @@ void gfx_widgets_msg_queue_push(
             msg_widget->msg_len                    = _len;
             msg_widget->msg_transition_animation   = 0;
 
-            if (!((task->flags & RETRO_TASK_FLG_ALTERNATIVE_LOOK) > 0))
+            if (!msg_widget->alternative_look)
             {
                gfx_animation_ctx_entry_t entry;
 
@@ -457,6 +439,7 @@ static void gfx_widgets_msg_queue_move(dispgfx_widget_t *p_dispwidget)
 {
    int i;
    float y = 0;
+   bool size_small = false;
    /* there should always be one and only one unfolded message */
    disp_widget_msg_t *unfold        = NULL;
 
@@ -468,14 +451,16 @@ static void gfx_widgets_msg_queue_move(dispgfx_widget_t *p_dispwidget)
    {
       disp_widget_msg_t* msg = p_dispwidget->current_msgs[i];
 
+      size_small             = (msg->task_ptr || (msg->flags & DISPWIDG_FLAG_SMALL));
+
       if (!msg || (msg->flags & DISPWIDG_FLAG_DYING))
          continue;
 
       if (y == 0)
          y += (p_dispwidget->msg_queue_padding * 4.0f);
 
-      y +=    (p_dispwidget->msg_queue_height / 2.0f / (msg->task_ptr ? 2.0f : 1.0f))
-            + (p_dispwidget->msg_queue_spacing * (msg->task_ptr ? 1.0f : 2.0f))
+      y +=    (p_dispwidget->msg_queue_height / 2.0f / (size_small ? 2.0f : 1.0f))
+            + (p_dispwidget->msg_queue_spacing * (size_small ? 1.0f : 2.0f))
             + floor(p_dispwidget->divider_width_1px);
 
       if (!(msg->flags & DISPWIDG_FLAG_UNFOLDED))
@@ -868,6 +853,13 @@ static void gfx_widgets_layout(
 
    p_dispwidget->msg_queue_height                 = p_dispwidget->gfx_widget_fonts.msg_queue.line_height * 2.5f * (BASE_FONT_SIZE / MSG_QUEUE_FONT_SIZE);
    p_dispwidget->msg_queue_padding                = (unsigned)(((float)p_dispwidget->gfx_widget_fonts.msg_queue.line_height * (2.0f / 3.0f)) + 0.5f);
+   p_dispwidget->msg_queue_spacing                = p_dispwidget->msg_queue_height / 4.0f;
+   p_dispwidget->msg_queue_rect_start_x           = ceil((p_dispwidget->msg_queue_padding * 2.0f) - (p_dispwidget->simple_widget_padding * 0.15f));
+
+   if (p_dispwidget->flags & DISPGFX_WIDGET_FLAG_MSG_QUEUE_HAS_ICONS)
+      p_dispwidget->msg_queue_regular_padding_x   = p_dispwidget->simple_widget_padding / 2;
+   else
+      p_dispwidget->msg_queue_regular_padding_x   = p_dispwidget->simple_widget_padding;
 
    if (p_dispwidget->flags & DISPGFX_WIDGET_FLAG_MSG_QUEUE_HAS_ICONS)
    {
@@ -876,35 +868,21 @@ static void gfx_widgets_layout(
    }
    else
    {
-      p_dispwidget->msg_queue_icon_size_x         = p_dispwidget->simple_widget_padding * 1.4f;
-      p_dispwidget->msg_queue_icon_size_y         = 0;
+      p_dispwidget->msg_queue_icon_size_x         = p_dispwidget->msg_queue_height / 4.0f;
+      p_dispwidget->msg_queue_icon_size_y         = p_dispwidget->msg_queue_icon_size_x;
    }
 
-   p_dispwidget->msg_queue_spacing                = p_dispwidget->msg_queue_height / 4.0f;
-   p_dispwidget->msg_queue_rect_start_x           = ceil((p_dispwidget->msg_queue_padding * 2.0f) - (p_dispwidget->simple_widget_padding * 0.15f));
    p_dispwidget->msg_queue_internal_icon_size     = p_dispwidget->msg_queue_icon_size_y;
    p_dispwidget->msg_queue_internal_icon_offset   = (p_dispwidget->msg_queue_icon_size_y - p_dispwidget->msg_queue_internal_icon_size) / 2;
    p_dispwidget->msg_queue_icon_offset_y          = (p_dispwidget->msg_queue_icon_size_y - p_dispwidget->msg_queue_height) / 2;
    p_dispwidget->msg_queue_scissor_start_x        = p_dispwidget->msg_queue_spacing + p_dispwidget->msg_queue_icon_size_x - (p_dispwidget->msg_queue_icon_size_x * 0.28928571428f);
 
-   if (p_dispwidget->flags & DISPGFX_WIDGET_FLAG_MSG_QUEUE_HAS_ICONS)
-      p_dispwidget->msg_queue_regular_padding_x   = p_dispwidget->simple_widget_padding / 2;
-   else
-      p_dispwidget->msg_queue_regular_padding_x   = p_dispwidget->simple_widget_padding;
-
-   p_dispwidget->msg_queue_task_rect_start_x      = p_dispwidget->msg_queue_rect_start_x;
-
-   p_dispwidget->msg_queue_task_text_start_x      = p_dispwidget->msg_queue_task_rect_start_x + (p_dispwidget->msg_queue_height / 2.0f) + (p_dispwidget->simple_widget_padding / 2.0f);
+   p_dispwidget->msg_queue_regular_text_start     = p_dispwidget->msg_queue_rect_start_x + p_dispwidget->msg_queue_icon_size_x + (p_dispwidget->simple_widget_padding / 2.5f);
+   p_dispwidget->msg_queue_task_text_start_x      = p_dispwidget->msg_queue_rect_start_x + (p_dispwidget->msg_queue_height / 2.0f) + (p_dispwidget->simple_widget_padding / 2.0f);
 
    if (!p_dispwidget->gfx_widgets_icons_textures[MENU_WIDGETS_ICON_HOURGLASS])
       p_dispwidget->msg_queue_task_text_start_x  -= p_dispwidget->gfx_widget_fonts.msg_queue.glyph_width * 2.0f;
 
-   p_dispwidget->msg_queue_regular_text_start     = p_dispwidget->msg_queue_rect_start_x + p_dispwidget->msg_queue_icon_size_x + (p_dispwidget->simple_widget_padding / 2.5f);
-
-   p_dispwidget->msg_queue_task_hourglass_x       = p_dispwidget->msg_queue_task_rect_start_x + (p_dispwidget->simple_widget_padding / 2.5f);
-
-   p_dispwidget->generic_message_height           = p_dispwidget->gfx_widget_fonts.regular.line_height * 2.0f;
-
    p_dispwidget->msg_queue_default_rect_width_menu_alive
                                                   = p_dispwidget->gfx_widget_fonts.msg_queue.glyph_width * 40.0f;
    p_dispwidget->msg_queue_default_rect_width     = p_dispwidget->last_video_width
@@ -935,7 +913,7 @@ void gfx_widgets_iterate(
    dispgfx_widget_t *p_dispwidget   = &dispwidget_st;
    /* c.f. https://gcc.gnu.org/bugzilla/show_bug.cgi?id=323
     * On some platforms (e.g. 32-bit x86 without SSE),
-    * gcc can produce inconsistent floating point results
+    * GCC can produce inconsistent floating point results
     * depending upon optimisation level. This can break
     * floating point variable comparisons. A workaround is
     * to declare the affected variable as 'volatile', which
@@ -1123,12 +1101,13 @@ static int gfx_widgets_draw_indicator(
    }
    else
    {
+      char txt[NAME_MAX_LENGTH];
       unsigned height       = p_dispwidget->simple_widget_height;
-      const char *txt       = msg_hash_to_str(msg);
+      size_t _len = strlcpy(txt, msg_hash_to_str(msg), sizeof(txt));
 
       width = font_driver_get_message_width(
             p_dispwidget->gfx_widget_fonts.regular.font,
-            txt, strlen(txt), 1.0f)
+            txt, _len, 1.0f)
          + p_dispwidget->simple_widget_padding * 2;
 
       gfx_display_draw_quad(
@@ -1149,7 +1128,7 @@ static int gfx_widgets_draw_indicator(
             y + (height / 2.0f) +
             p_dispwidget->gfx_widget_fonts.regular.line_centre_offset,
             video_width, video_height,
-            0xFFFFFFFF, TEXT_ALIGN_LEFT,
+            TEXT_COLOR_INFO, TEXT_ALIGN_LEFT,
             false);
    }
 
@@ -1165,18 +1144,13 @@ static void gfx_widgets_draw_task_msg(
       unsigned video_width,
       unsigned video_height)
 {
-   /* Color of first progress bar in a task message */
-   static float msg_queue_task_progress_1[16] = COLOR_HEX_TO_FLOAT(0x1A1A1A, 1.0f);
-   /* Color of second progress bar in a task message
-    * (for multiple tasks with same message) */
-   static float msg_queue_task_progress_2[16] = COLOR_HEX_TO_FLOAT(0x1D5B1D, 1.0f);
-   /* Margin bar */
-   static float msg_queue_bar[16]             = COLOR_HEX_TO_FLOAT(0xCCCCCC, 1.0f);
-   /* Green icon */
-   static float msg_queue_task_positive[16]   = COLOR_HEX_TO_FLOAT(0x00C80A, 1.0f);
-   /* Red icon */
-   static float msg_queue_task_negative[16]   = COLOR_HEX_TO_FLOAT(0xC60000, 1.0f);
+   static float msg_queue_background[16]    = COLOR_HEX_TO_FLOAT(BG_COLOR_DEFAULT, 1.0f);
+   static float msg_queue_bar[16]           = COLOR_HEX_TO_FLOAT(BG_COLOR_MARGIN, 1.0f);
+   static float msg_queue_task_progress[16] = COLOR_HEX_TO_FLOAT(BG_COLOR_PROGRESS, 1.0f);
+   static float msg_queue_task_negative[16] = COLOR_HEX_TO_FLOAT(ICON_COLOR_RED, 1.0f);
+   static float msg_queue_task_positive[16] = COLOR_HEX_TO_FLOAT(ICON_COLOR_GREEN, 1.0f);
 
+   unsigned msg_queue_height                = p_dispwidget->msg_queue_height;
    unsigned text_color;
    unsigned bar_width;
 
@@ -1188,12 +1162,13 @@ static void gfx_widgets_draw_task_msg(
    float text_y_base;
 
    float *msg_queue_current_background;
-   float *msg_queue_current_bar;
+   float *msg_queue_current_progress;
 
    size_t _len                       = 0;
+   size_t task_percentage_offset     = 0;
    char task_percentage[256]         = "";
    bool draw_msg_new                 = false;
-   size_t task_percentage_offset     = 0;
+   bool msg_alternative              = msg->alternative_look;
 
    if (msg->msg_new)
       draw_msg_new                   = !string_is_equal(msg->msg_new, msg->msg);
@@ -1202,43 +1177,58 @@ static void gfx_widgets_draw_task_msg(
    {
       if (msg->flags & DISPWIDG_FLAG_TASK_ERROR)
          _len = strlcpy(task_percentage, msg_hash_to_str(MSG_ERROR), sizeof(task_percentage));
+
+      /* Not finished yet really */
+      if (msg->task_progress > 0 && msg->task_progress < 100)
+         msg->flags &= ~DISPWIDG_FLAG_TASK_FINISHED;
    }
    else if (msg->task_progress >= 0 && msg->task_progress <= 100)
       _len = snprintf(task_percentage, sizeof(task_percentage),
             "%i%%", msg->task_progress);
 
-   task_percentage_offset = p_dispwidget->gfx_widget_fonts.msg_queue.glyph_width * _len;
-   rect_width             = p_dispwidget->msg_queue_padding * 5.0f + msg->width  + task_percentage_offset;
+   task_percentage_offset = p_dispwidget->gfx_widget_fonts.msg_queue.glyph_width * (_len + 1);
+   rect_width             = (msg_alternative)
+         ? video_width
+         : (p_dispwidget->msg_queue_padding * 5.0f) + msg->width + task_percentage_offset;
    bar_width              = rect_width * msg->task_progress/100.0f;
-   text_color             = COLOR_TEXT_ALPHA(0xFFFFFF00, (unsigned)(msg->alpha*255.0f));
+   text_color             = COLOR_TEXT_ALPHA(TEXT_COLOR_INFO, (unsigned)(msg->alpha*255.0f));
 
    /* Rect */
-   msg_queue_current_background = msg_queue_task_progress_1;
+   if (     msg->flags & DISPWIDG_FLAG_TASK_FINISHED
+         && msg_alternative)
+      msg_queue_current_background = msg_queue_task_progress;
+   else
+      msg_queue_current_background = msg_queue_background;
 
-   if (msg->flags & DISPWIDG_FLAG_TASK_FINISHED)
-   {
-      if (msg->task_count == 1)
-         msg_queue_current_background = msg_queue_task_progress_1;
-      else
-         msg_queue_current_background = msg_queue_task_progress_2;
-   }
+   if (msg_alternative)
+      msg_queue_height *= 1.5f;
 
    rect_x      = p_dispwidget->msg_queue_rect_start_x;
    rect_y      = video_height - msg->offset_y;
-   rect_height = p_dispwidget->msg_queue_height / 2;
+   rect_height = msg_queue_height / 2;
    rect_margin = p_dispwidget->simple_widget_padding * 0.15f;
 
-   gfx_display_set_alpha(msg_queue_bar, msg->alpha);
-   gfx_display_draw_quad(
-         p_disp,
-         userdata,
-         video_width, video_height,
-         rect_x, rect_y,
-         rect_margin, rect_height,
-         video_width, video_height,
-         msg_queue_bar,
-         NULL
-         );
+   if (msg_alternative)
+   {
+      rect_x      = 0;
+      rect_y      = video_height - rect_height;
+      rect_margin = 0;
+   }
+
+   if (rect_margin)
+   {
+      gfx_display_set_alpha(msg_queue_bar, msg->alpha);
+      gfx_display_draw_quad(
+            p_disp,
+            userdata,
+            video_width, video_height,
+            rect_x, rect_y,
+            rect_margin, rect_height,
+            video_width, video_height,
+            msg_queue_bar,
+            NULL
+            );
+   }
 
    gfx_display_set_alpha(msg_queue_current_background, msg->alpha);
    gfx_display_draw_quad(
@@ -1257,27 +1247,22 @@ static void gfx_widgets_draw_task_msg(
          && (msg->task_progress >= 0)
          && (msg->task_progress <= 100))
    {
-      if (msg->task_count == 1)
-         msg_queue_current_bar = msg_queue_task_progress_1;
-      else
-         msg_queue_current_bar = msg_queue_task_progress_2;
+      msg_queue_current_progress = msg_queue_task_progress;
 
-      gfx_display_set_alpha(msg_queue_current_bar, 1.0f);
+      gfx_display_set_alpha(msg_queue_current_progress, msg->alpha);
       gfx_display_draw_quad(
             p_disp,
             userdata,
             video_width, video_height,
-            p_dispwidget->msg_queue_task_rect_start_x + rect_margin,
-            video_height - msg->offset_y,
+            rect_x + rect_margin, rect_y,
             bar_width, rect_height,
             video_width, video_height,
-            msg_queue_current_bar,
+            msg_queue_current_progress,
             NULL
             );
    }
 
    /* Icon */
-
    if (dispctx && dispctx->blend_begin)
       dispctx->blend_begin(userdata);
    {
@@ -1298,23 +1283,28 @@ static void gfx_widgets_draw_task_msg(
          texture    = MENU_WIDGETS_ICON_ADD;
          color      = msg_queue_task_positive;
       }
-      else if (msg->flags & DISPWIDG_FLAG_NEGATIVE)
+      else if (   msg->flags & DISPWIDG_FLAG_NEGATIVE
+               || msg->flags & DISPWIDG_FLAG_TASK_ERROR)
       {
          texture    = MENU_WIDGETS_ICON_EXIT;
          color      = msg_queue_task_negative;
       }
 
-      gfx_display_set_alpha(color, msg->alpha);
+      if (msg_alternative)
+         gfx_display_set_alpha(color, msg->alpha * 0.5f);
+      else
+         gfx_display_set_alpha(color, msg->alpha);
+
       gfx_widgets_draw_icon(
             userdata,
             p_disp,
             video_width,
             video_height,
-            p_dispwidget->msg_queue_height / 2.5f,
-            p_dispwidget->msg_queue_height / 2.5f,
+            msg_queue_height / 2.5f,
+            msg_queue_height / 2.5f,
             p_dispwidget->gfx_widgets_icons_textures[texture],
-            p_dispwidget->msg_queue_task_hourglass_x + (p_dispwidget->msg_queue_height / MSG_QUEUE_FONT_SIZE),
-            video_height - msg->offset_y + (p_dispwidget->msg_queue_height / MSG_QUEUE_FONT_SIZE),
+            rect_x + (msg_queue_height / 9.0f) + (msg_queue_height / MSG_QUEUE_FONT_SIZE),
+            rect_y + (msg_queue_height / MSG_QUEUE_FONT_SIZE),
             radians,
             cosine,
             sine,
@@ -1324,9 +1314,8 @@ static void gfx_widgets_draw_task_msg(
       dispctx->blend_end(userdata);
 
    /* Text */
-   text_y_base = video_height
-      - msg->offset_y
-      + p_dispwidget->msg_queue_height / 4.0f
+   text_y_base = rect_y
+      + (msg_queue_height / 4.0f)
       + p_dispwidget->gfx_widget_fonts.msg_queue.line_centre_offset;
 
    if (draw_msg_new)
@@ -1342,7 +1331,7 @@ static void gfx_widgets_draw_task_msg(
       gfx_widgets_draw_text(&p_dispwidget->gfx_widget_fonts.msg_queue,
             msg->msg_new,
             p_dispwidget->msg_queue_task_text_start_x,
-            text_y_base - p_dispwidget->msg_queue_height / 2.0f + msg->msg_transition_animation,
+            text_y_base - msg_queue_height / 2.0f + msg->msg_transition_animation,
             video_width, video_height,
             text_color,
             TEXT_ALIGN_LEFT,
@@ -1368,11 +1357,10 @@ static void gfx_widgets_draw_task_msg(
    }
 
    /* Progress text */
-   text_color = COLOR_TEXT_ALPHA(0xFFFFFF00, (unsigned)(msg->alpha/2*255.0f));
+   text_color = COLOR_TEXT_ALPHA(TEXT_COLOR_INFO, (unsigned)(msg->alpha/2*255.0f));
    gfx_widgets_draw_text(&p_dispwidget->gfx_widget_fonts.msg_queue,
       task_percentage,
-      p_dispwidget->msg_queue_rect_start_x
-            + rect_width - p_dispwidget->gfx_widget_fonts.msg_queue.glyph_width,
+      rect_x + rect_width - p_dispwidget->gfx_widget_fonts.msg_queue.glyph_width * 2,
       text_y_base,
       video_width, video_height,
       text_color,
@@ -1389,24 +1377,35 @@ static void gfx_widgets_draw_regular_msg(
       unsigned video_width,
       unsigned video_height)
 {
-   static float msg_queue_info[16] = COLOR_HEX_TO_FLOAT(0x0C99D6, 1.0f);
-   static float msg_queue_bar[16]  = COLOR_HEX_TO_FLOAT(0xCCCCCC, 1.0f);
+   static float msg_queue_info_blue[16]   = COLOR_HEX_TO_FLOAT(ICON_COLOR_BLUE, 1.0f);
+   static float msg_queue_info_yellow[16] = COLOR_HEX_TO_FLOAT(ICON_COLOR_YELLOW, 1.0f);
+   static float msg_queue_info_red[16]    = COLOR_HEX_TO_FLOAT(ICON_COLOR_RED, 1.0f);
+   static float msg_queue_info_green[16]  = COLOR_HEX_TO_FLOAT(ICON_COLOR_GREEN, 1.0f);
+   static float msg_queue_bar[16]         = COLOR_HEX_TO_FLOAT(BG_COLOR_MARGIN, 1.0f);
+   float* msg_queue_info;
+   float text_y_base;
    unsigned rect_width;
+   unsigned rect_height;
    unsigned rect_margin;
    unsigned text_color;
-   static float last_alpha = 0.0f;
 
    msg->flags             &= ~DISPWIDG_FLAG_UNFOLDING;
    msg->flags             |=  DISPWIDG_FLAG_UNFOLDED;
 
-   if (last_alpha != msg->alpha)
-   {
-      /* Icon */
-      gfx_display_set_alpha(msg_queue_info, msg->alpha);
-      gfx_display_set_alpha(p_dispwidget->pure_white, msg->alpha);
-      gfx_display_set_alpha(p_dispwidget->msg_queue_bg, msg->alpha);
-      last_alpha = msg->alpha;
-   }
+   /* Tint icon yellow for warnings, red for errors,
+    * green for success, and blue for info */
+   if (msg->flags & DISPWIDG_FLAG_CATEGORY_WARNING)
+      msg_queue_info = msg_queue_info_yellow;
+   else if (msg->flags & DISPWIDG_FLAG_CATEGORY_ERROR)
+      msg_queue_info = msg_queue_info_red;
+   else if (msg->flags & DISPWIDG_FLAG_CATEGORY_SUCCESS)
+      msg_queue_info = msg_queue_info_green;
+   else
+      msg_queue_info = msg_queue_info_blue;
+
+   gfx_display_set_alpha(msg_queue_info, msg->alpha);
+   gfx_display_set_alpha(p_dispwidget->pure_white, msg->alpha);
+   gfx_display_set_alpha(p_dispwidget->msg_queue_bg, msg->alpha);
 
    if (    !(msg->flags & DISPWIDG_FLAG_UNFOLDED)
          || (msg->flags & DISPWIDG_FLAG_UNFOLDING))
@@ -1429,9 +1428,16 @@ static void gfx_widgets_draw_regular_msg(
 
    /* Background */
    rect_width  = p_dispwidget->simple_widget_padding + msg->width + p_dispwidget->msg_queue_icon_size_x;
+   rect_height = p_dispwidget->msg_queue_height;
    rect_margin = p_dispwidget->simple_widget_padding * 0.15f;
    gfx_display_set_alpha(msg_queue_bar, msg->alpha);
 
+   if (msg->flags & DISPWIDG_FLAG_SMALL)
+   {
+      rect_width  = p_dispwidget->simple_widget_padding + msg->width + p_dispwidget->msg_queue_icon_size_x / 2;
+      rect_height = p_dispwidget->msg_queue_height / 2;
+   }
+
    gfx_display_draw_quad(
          p_disp,
          userdata,
@@ -1440,7 +1446,7 @@ static void gfx_widgets_draw_regular_msg(
          p_dispwidget->msg_queue_rect_start_x + rect_margin,
          video_height - msg->offset_y,
          rect_width - rect_margin,
-         p_dispwidget->msg_queue_height,
+         rect_height,
          video_width,
          video_height,
          p_dispwidget->msg_queue_bg,
@@ -1455,7 +1461,7 @@ static void gfx_widgets_draw_regular_msg(
          p_dispwidget->msg_queue_rect_start_x,
          video_height - msg->offset_y,
          rect_margin,
-         p_dispwidget->msg_queue_height,
+         rect_height,
          video_width,
          video_height,
          msg_queue_bar,
@@ -1463,14 +1469,25 @@ static void gfx_widgets_draw_regular_msg(
          );
 
    /* Text */
-   text_color = COLOR_TEXT_ALPHA(0xFFFFFF00, (unsigned)(msg->alpha*255.0f));
+   text_color = COLOR_TEXT_ALPHA(TEXT_COLOR_INFO, (unsigned)(msg->alpha*255.0f));
+
+   if (msg->flags & DISPWIDG_FLAG_SMALL)
+      text_y_base = video_height
+         - msg->offset_y
+         + p_dispwidget->msg_queue_height / 4.0f
+         + p_dispwidget->gfx_widget_fonts.msg_queue.line_centre_offset;
+   else
+      text_y_base = video_height
+         - msg->offset_y
+         + (rect_height - msg->text_height) / 2.0f
+         + p_dispwidget->gfx_widget_fonts.msg_queue.line_ascender;
 
    gfx_widgets_draw_text(&p_dispwidget->gfx_widget_fonts.msg_queue,
       msg->msg,
-      p_dispwidget->msg_queue_regular_text_start,
-      video_height - msg->offset_y
-            + (p_dispwidget->msg_queue_height - msg->text_height) / 2.0f
-            + p_dispwidget->gfx_widget_fonts.msg_queue.line_ascender,
+      (msg->flags & DISPWIDG_FLAG_SMALL)
+         ? p_dispwidget->msg_queue_task_text_start_x
+         : p_dispwidget->msg_queue_regular_text_start,
+      text_y_base,
       video_width, video_height,
       text_color,
       TEXT_ALIGN_LEFT,
@@ -1487,8 +1504,14 @@ static void gfx_widgets_draw_regular_msg(
          dispctx->scissor_end(userdata, video_width, video_height);
    }
 
+   /* Icon */
    if (p_dispwidget->flags & DISPGFX_WIDGET_FLAG_MSG_QUEUE_HAS_ICONS)
    {
+      float icon_size = p_dispwidget->msg_queue_icon_size_x / ((msg->flags & DISPWIDG_FLAG_SMALL) ? 2 : 1);
+      /* For warnings and errors, flip the 'i' upside down so it becomes '!' */
+      bool invert_y = (msg->flags & (  DISPWIDG_FLAG_CATEGORY_WARNING
+                                     | DISPWIDG_FLAG_CATEGORY_ERROR)) != 0;
+
       if (dispctx && dispctx->blend_begin)
          dispctx->blend_begin(userdata);
 
@@ -1497,14 +1520,14 @@ static void gfx_widgets_draw_regular_msg(
             p_disp,
             video_width,
             video_height,
-            p_dispwidget->msg_queue_icon_size_x,
-            p_dispwidget->msg_queue_icon_size_y,
+            icon_size,
+            icon_size,
             p_dispwidget->gfx_widgets_icons_textures[MENU_WIDGETS_ICON_INFO],
             p_dispwidget->msg_queue_rect_start_x
-                  + (p_dispwidget->simple_widget_padding / 4.0f),
+                  + (p_dispwidget->msg_queue_height / 9.0f),
             video_height - msg->offset_y - p_dispwidget->msg_queue_icon_offset_y,
             0.0f, /* rad                         */
-            1.0f, /* cos(rad)   = cos(0)  = 1.0f */
+            (invert_y ? -1.0f : 1.0f), /* cosine */
             0.0f, /* sine(rad)  = sine(0) = 0.0f */
             msg_queue_info);
 
@@ -1513,19 +1536,6 @@ static void gfx_widgets_draw_regular_msg(
    }
 }
 
-static void INLINE gfx_widgets_font_bind(gfx_widget_font_data_t *font_data)
-{
-   font_driver_bind_block(font_data->font, &font_data->raster_block);
-   font_data->raster_block.carr.coords.vertices = 0;
-   font_data->usage_count                       = 0;
-}
-
-static void INLINE gfx_widgets_font_unbind(gfx_widget_font_data_t *font_data)
-{
-   font_driver_bind_block(font_data->font, NULL);
-}
-
-
 void gfx_widgets_frame(void *data)
 {
    size_t i;
@@ -1567,9 +1577,19 @@ void gfx_widgets_frame(void *data)
             video_st->data, video_width, video_height, true, false);
 
    /* Font setup */
-   gfx_widgets_font_bind(&p_dispwidget->gfx_widget_fonts.regular);
-   gfx_widgets_font_bind(&p_dispwidget->gfx_widget_fonts.bold);
-   gfx_widgets_font_bind(&p_dispwidget->gfx_widget_fonts.msg_queue);
+   font_driver_bind_block(p_dispwidget->gfx_widget_fonts.regular.font,
+         &p_dispwidget->gfx_widget_fonts.regular.raster_block);
+   font_driver_bind_block(p_dispwidget->gfx_widget_fonts.bold.font,
+         &p_dispwidget->gfx_widget_fonts.bold.raster_block);
+   font_driver_bind_block(p_dispwidget->gfx_widget_fonts.msg_queue.font,
+         &p_dispwidget->gfx_widget_fonts.msg_queue.raster_block);
+
+   p_dispwidget->gfx_widget_fonts.regular.raster_block.carr.coords.vertices   = 0;
+   p_dispwidget->gfx_widget_fonts.regular.usage_count                         = 0;
+   p_dispwidget->gfx_widget_fonts.bold.raster_block.carr.coords.vertices      = 0;
+   p_dispwidget->gfx_widget_fonts.bold.usage_count                            = 0;
+   p_dispwidget->gfx_widget_fonts.msg_queue.raster_block.carr.coords.vertices = 0;
+   p_dispwidget->gfx_widget_fonts.msg_queue.usage_count                       = 0;
 
 #ifdef HAVE_TRANSLATE
    /* AI Service overlay */
@@ -1668,7 +1688,7 @@ void gfx_widgets_frame(void *data)
    }
 #endif
 
-   /* Status Text (fps, framecount, memory, core status message) */
+   /* Status Text (FPS, framecount, memory, core status message) */
    if (     fps_show
          || framecount_show
          || memory_show
@@ -1715,7 +1735,7 @@ void gfx_widgets_frame(void *data)
             p_dispwidget->simple_widget_height / 2.0f
             + p_dispwidget->gfx_widget_fonts.regular.line_centre_offset,
             video_width, video_height,
-            0xFFFFFFFF,
+            TEXT_COLOR_INFO,
             TEXT_ALIGN_LEFT,
             true);
    }
@@ -1834,9 +1854,9 @@ void gfx_widgets_frame(void *data)
          &p_dispwidget->gfx_widget_fonts.msg_queue);
 
    /* Unbind fonts */
-   gfx_widgets_font_unbind(&p_dispwidget->gfx_widget_fonts.regular);
-   gfx_widgets_font_unbind(&p_dispwidget->gfx_widget_fonts.bold);
-   gfx_widgets_font_unbind(&p_dispwidget->gfx_widget_fonts.msg_queue);
+   font_driver_bind_block(p_dispwidget->gfx_widget_fonts.regular.font, NULL);
+   font_driver_bind_block(p_dispwidget->gfx_widget_fonts.bold.font, NULL);
+   font_driver_bind_block(p_dispwidget->gfx_widget_fonts.msg_queue.font, NULL);
 
    if (video_st->current_video && video_st->current_video->set_viewport)
       video_st->current_video->set_viewport(
@@ -1937,6 +1957,23 @@ static void gfx_widgets_context_reset(
       unsigned width, unsigned height, bool fullscreen,
       const char *dir_assets, char *font_path)
 {
+   /* Icons */
+   static const char
+      *gfx_widgets_icons_names[MENU_WIDGETS_ICON_LAST]         = {
+         "menu_pause.png",
+         "menu_frameskip.png",
+         "menu_rewind.png",
+         "resume.png",
+
+         "menu_hourglass.png",
+         "menu_check.png",
+         "menu_add.png",
+         "menu_exit.png",
+
+         "menu_info.png",
+
+         "menu_achievements.png"
+      };
    size_t i;
 
    /* Load textures */
@@ -1998,7 +2035,6 @@ bool gfx_widgets_init(
       const char *dir_assets, char *font_path)
 {
    size_t i;
-   unsigned color                              = 0x1A1A1A;
    dispgfx_widget_t *p_dispwidget              = &dispwidget_st;
    gfx_display_t *p_disp                       = (gfx_display_t*)data_disp;
    gfx_animation_t *p_anim                     = (gfx_animation_t*)data_anim;
@@ -2012,21 +2048,21 @@ bool gfx_widgets_init(
    for (i = 0; i < 16; i++)
       p_dispwidget->pure_white[i] = 1.00f;
 
-   p_dispwidget->msg_queue_bg[0]  = HEX_R(color);
-   p_dispwidget->msg_queue_bg[1]  = HEX_G(color);
-   p_dispwidget->msg_queue_bg[2]  = HEX_B(color);
+   p_dispwidget->msg_queue_bg[0]  = HEX_R(BG_COLOR_DEFAULT);
+   p_dispwidget->msg_queue_bg[1]  = HEX_G(BG_COLOR_DEFAULT);
+   p_dispwidget->msg_queue_bg[2]  = HEX_B(BG_COLOR_DEFAULT);
    p_dispwidget->msg_queue_bg[3]  = 1.0f;
-   p_dispwidget->msg_queue_bg[4]  = HEX_R(color);
-   p_dispwidget->msg_queue_bg[5]  = HEX_G(color);
-   p_dispwidget->msg_queue_bg[6]  = HEX_B(color);
+   p_dispwidget->msg_queue_bg[4]  = HEX_R(BG_COLOR_DEFAULT);
+   p_dispwidget->msg_queue_bg[5]  = HEX_G(BG_COLOR_DEFAULT);
+   p_dispwidget->msg_queue_bg[6]  = HEX_B(BG_COLOR_DEFAULT);
    p_dispwidget->msg_queue_bg[7]  = 1.0f;
-   p_dispwidget->msg_queue_bg[8]  = HEX_R(color);
-   p_dispwidget->msg_queue_bg[9]  = HEX_G(color);
-   p_dispwidget->msg_queue_bg[10] = HEX_B(color);
+   p_dispwidget->msg_queue_bg[8]  = HEX_R(BG_COLOR_DEFAULT);
+   p_dispwidget->msg_queue_bg[9]  = HEX_G(BG_COLOR_DEFAULT);
+   p_dispwidget->msg_queue_bg[10] = HEX_B(BG_COLOR_DEFAULT);
    p_dispwidget->msg_queue_bg[11] = 1.0f;
-   p_dispwidget->msg_queue_bg[12] = HEX_R(color);
-   p_dispwidget->msg_queue_bg[13] = HEX_G(color);
-   p_dispwidget->msg_queue_bg[14] = HEX_B(color);
+   p_dispwidget->msg_queue_bg[12] = HEX_R(BG_COLOR_DEFAULT);
+   p_dispwidget->msg_queue_bg[13] = HEX_G(BG_COLOR_DEFAULT);
+   p_dispwidget->msg_queue_bg[14] = HEX_B(BG_COLOR_DEFAULT);
    p_dispwidget->msg_queue_bg[15] = 1.0f;
 
    if (!(p_dispwidget->flags & DISPGFX_WIDGET_FLAG_INITED))
@@ -2110,6 +2146,15 @@ error:
    return false;
 }
 
+static void gfx_widgets_font_free(gfx_widget_font_data_t *font_data)
+{
+   if (font_data->font)
+      font_driver_free(font_data->font);
+
+   font_data->font        = NULL;
+   font_data->usage_count = 0;
+}
+
 static void gfx_widgets_context_destroy(dispgfx_widget_t *p_dispwidget)
 {
    size_t i;
@@ -2134,7 +2179,6 @@ static void gfx_widgets_context_destroy(dispgfx_widget_t *p_dispwidget)
    gfx_widgets_font_free(&p_dispwidget->gfx_widget_fonts.msg_queue);
 }
 
-
 void gfx_widgets_deinit(bool widgets_persisting)
 {
    dispgfx_widget_t *p_dispwidget = &dispwidget_st;
