@@ -39,6 +39,9 @@ typedef struct video_display_config
    unsigned refreshrate;
    unsigned idx;
    bool current;
+   bool interlaced;
+   bool dblscan;
+   float refreshrate_float;
 } video_display_config_t;
 
 typedef struct video_display_server
@@ -101,6 +104,7 @@ extern const video_display_server_t dispserv_win32;
 extern const video_display_server_t dispserv_x11;
 extern const video_display_server_t dispserv_kms;
 extern const video_display_server_t dispserv_android;
+extern const video_display_server_t dispserv_apple;
 
 RETRO_END_DECLS
 
