@@ -23,6 +23,11 @@
 #include <features/features_cpu.h>
 #include <string/stdstring.h>
 
+#ifdef _3DS
+#include <3ds/types.h>
+#include <3ds/allocator/linear.h> /* linearMemAlign() */
+#endif
+
 #include "video_driver.h"
 #include "video_thread_wrapper.h"
 #include "font_driver.h"
@@ -1134,7 +1139,10 @@ static void thread_set_texture_frame(void *data, const void *frame,
       void *tmp_frame = realloc(thr->texture.frame, required);
 
       if (!tmp_frame)
-         goto end;
+      {
+         slock_unlock(thr->frame.lock);
+         return;
+      }
 
       thr->texture.frame     = tmp_frame;
       thr->texture.frame_cap = required;
@@ -1148,7 +1156,6 @@ static void thread_set_texture_frame(void *data, const void *frame,
    thr->texture.alpha         = alpha;
    thr->texture.frame_updated = true;
 
-end:
    slock_unlock(thr->frame.lock);
 }
 
