@@ -202,6 +202,10 @@ ACHIEVEMENTS
 #include "../cheevos/cheevos_client.c"
 #include "../cheevos/cheevos_menu.c"
 
+#if defined(HAVE_CHEEVOS_RVZ)
+#include "../cheevos/cheevos_rvz.c"
+#endif
+
 #include "../deps/rcheevos/src/rc_client.c"
 #include "../deps/rcheevos/src/rc_compat.c"
 #include "../deps/rcheevos/src/rc_libretro.c"
@@ -226,13 +230,19 @@ ACHIEVEMENTS
 #include "../deps/rcheevos/src/rhash/aes.c"
 #include "../deps/rcheevos/src/rhash/cdreader.c"
 #include "../deps/rcheevos/src/rhash/hash.c"
+#include "../deps/rcheevos/src/rhash/hash_rom.c"
+#include "../deps/rcheevos/src/rhash/hash_disc.c"
+#include "../deps/rcheevos/src/rhash/hash_zip.c"
+#include "../deps/rcheevos/src/rhash/hash_encrypted.c"
 
 #endif
 
 /*============================================================
 MD5
 ============================================================ */
+#ifndef __APPLE__
 #include "../libretro-common/utils/md5.c"
+#endif
 
 /*============================================================
 CHEATS
@@ -445,17 +455,14 @@ VIDEO DRIVER
 
 #if defined(HAVE_D3D11)
 #include "../gfx/drivers/d3d11.c"
-#include "../gfx/common/d3d11_common.c"
 #endif
 
 #if defined(HAVE_D3D12)
 #include "../gfx/drivers/d3d12.c"
-#include "../gfx/common/d3d12_common.c"
 #endif
 
 #if defined(HAVE_D3D10)
 #include "../gfx/drivers/d3d10.c"
-#include "../gfx/common/d3d10_common.c"
 #endif
 
 #if defined(HAVE_D3D10) || defined(HAVE_D3D11) || defined(HAVE_D3D12)
@@ -601,6 +608,10 @@ INPUT
 ============================================================ */
 
 #include "../input/input_driver.c"
+#ifdef HAVE_BSV_MOVIE
+#include "../input/bsv/bsvmovie.c"
+#include "../input/bsv/uint32s_index.c"
+#endif
 #include "../input/input_keymaps.c"
 #include "../tasks/task_autodetect.c"
 #include "../input/input_autodetect_builtin.c"
@@ -811,6 +822,13 @@ CAMERA
 #ifdef HAVE_V4L2
 #include "../camera/drivers/video4linux2.c"
 #endif
+#ifdef HAVE_PIPEWIRE
+#include "../camera/drivers/pipewire.c"
+#endif
+
+#ifdef HAVE_FFMPEG
+#include "../camera/drivers/ffmpeg.c"
+#endif
 
 #ifdef HAVE_VIDEOPROCESSOR
 #include "../cores/libretro-video-processor/video_processor_v4l2.c"
@@ -850,9 +868,6 @@ RSOUND
 AUDIO
 ============================================================ */
 #include "../audio/audio_driver.c"
-#ifdef HAVE_MICROPHONE
-#include "../audio/microphone_driver.c"
-#endif
 #if defined(__PS3__) || defined (__PSL1GHT__)
 #include "../audio/drivers/ps3_audio.c"
 #elif defined(XENON)
@@ -861,7 +876,7 @@ AUDIO
 #include "../audio/drivers/gx_audio.c"
 #elif defined(__wiiu__)
 #include "../audio/drivers/wiiu_audio.c"
-#elif defined(EMSCRIPTEN)
+#elif defined(HAVE_RWEBAUDIO)
 #include "../audio/drivers/rwebaudio.c"
 #elif defined(PSP) || defined(VITA) || defined(ORBIS)
 #include "../audio/drivers/psp_audio.c"
@@ -884,9 +899,6 @@ AUDIO
 #include "../input/drivers/sdl_input.c"
 #include "../input/drivers_joypad/sdl_joypad.c"
 #include "../gfx/drivers_context/sdl_gl_ctx.c"
-#ifdef HAVE_MICROPHONE
-#include "../audio/drivers_microphone/sdl_microphone.c"
-#endif
 #endif
 
 #ifdef HAVE_DSOUND
@@ -895,11 +907,6 @@ AUDIO
 
 #ifdef HAVE_WASAPI
 #include "../audio/drivers/wasapi.c"
-#include "../audio/common/wasapi.c"
-
-#ifdef HAVE_MICROPHONE
-#include "../audio/drivers_microphone/wasapi.c"
-#endif
 #endif
 
 #ifdef HAVE_SL
@@ -909,10 +916,6 @@ AUDIO
 #ifdef HAVE_PIPEWIRE
 #include "../audio/drivers/pipewire.c"
 #include "../audio/common/pipewire.c"
-
-#ifdef HAVE_MICROPHONE
-#include "../audio/drivers_microphone/pipewire.c"
-#endif
 #endif
 
 #ifdef HAVE_ALSA
@@ -922,12 +925,6 @@ AUDIO
 #include "../audio/drivers/alsa.c"
 #include "../audio/common/alsa.c"
 #include "../audio/drivers/alsathread.c"
-#include "../audio/common/alsathread.c"
-
-#ifdef HAVE_MICROPHONE
-#include "../audio/drivers_microphone/alsa.c"
-#include "../audio/drivers_microphone/alsathread.c"
-#endif
 #endif
 #endif
 
@@ -947,7 +944,7 @@ AUDIO
 #include "../audio/drivers/coreaudio.c"
 #endif
 
-#if defined(HAVE_WASAPI) || ((_WIN32_WINNT >= 0x0602) && !defined(__WINRT__))
+#if defined(HAVE_WASAPI) || ((_WIN32_WINNT >= 0x0600) && !defined(__WINRT__))
 #include "../audio/common/mmdevice_common.c"
 #endif
 
@@ -958,6 +955,10 @@ MIDI
 #include "../midi/drivers/winmm_midi.c"
 #endif
 
+#ifdef HAVE_COREMIDI
+#include "../midi/drivers/coremidi.c"
+#endif
+
 /*============================================================
 DRIVERS
 ============================================================ */
@@ -1081,6 +1082,10 @@ FILE
 #include "../libretro-common/media/media_detect_cd.c"
 #endif
 
+#ifdef ANDROID
+#include "../libretro-common/vfs/vfs_implementation_saf.c"
+#endif
+
 #include "../libretro-common/string/stdstring.c"
 #include "../libretro-common/file/nbio/nbio_stdio.c"
 #if defined(__linux__)
@@ -1448,6 +1453,7 @@ DEPENDENCIES
 #include "../libretro-common/formats/libchdr/libchdr_bitstream.c"
 #include "../libretro-common/formats/libchdr/libchdr_cdrom.c"
 #include "../libretro-common/formats/libchdr/libchdr_chd.c"
+#include "../libretro-common/formats/libchdr/libchdr_huffman.c"
 
 #ifdef HAVE_FLAC
 #include "../libretro-common/formats/libchdr/libchdr_flac.c"
@@ -1458,7 +1464,9 @@ DEPENDENCIES
 #include "../libretro-common/formats/libchdr/libchdr_lzma.c"
 #endif
 
-#include "../libretro-common/formats/libchdr/libchdr_huffman.c"
+#ifdef HAVE_ZSTD
+#include "../libretro-common/formats/libchdr/libchdr_zstd.c"
+#endif
 
 #include "../libretro-common/streams/chd_stream.c"
 #endif
@@ -1484,6 +1492,33 @@ DEPENDENCIES
 #include "../deps/7zip/7zStream.c"
 #endif
 
+#ifdef HAVE_ZSTD
+#if (DEBUGLEVEL>=2)
+#include "../deps/zstd/lib/common/debug.c"
+#endif
+#include "../deps/zstd/lib/common/entropy_common.c"
+#include "../deps/zstd/lib/common/error_private.c"
+#include "../deps/zstd/lib/common/fse_decompress.c"
+#include "../deps/zstd/lib/common/zstd_common.c"
+#include "../deps/zstd/lib/common/xxhash.c"
+#include "../deps/zstd/lib/compress/fse_compress.c"
+#include "../deps/zstd/lib/compress/hist.c"
+#include "../deps/zstd/lib/compress/huf_compress.c"
+#include "../deps/zstd/lib/compress/zstd_compress.c"
+#include "../deps/zstd/lib/compress/zstd_compress_literals.c"
+#include "../deps/zstd/lib/compress/zstd_compress_sequences.c"
+#include "../deps/zstd/lib/compress/zstd_compress_superblock.c"
+#include "../deps/zstd/lib/compress/zstd_double_fast.c"
+#include "../deps/zstd/lib/compress/zstd_fast.c"
+#include "../deps/zstd/lib/compress/zstd_lazy.c"
+#include "../deps/zstd/lib/compress/zstd_ldm.c"
+#include "../deps/zstd/lib/compress/zstd_opt.c"
+#include "../deps/zstd/lib/decompress/huf_decompress.c"
+#include "../deps/zstd/lib/decompress/zstd_ddict.c"
+#include "../deps/zstd/lib/decompress/zstd_decompress.c"
+#include "../deps/zstd/lib/decompress/zstd_decompress_block.c"
+#endif
+
 #ifdef WANT_LIBFAT
 #include "../deps/libfat/cache.c"
 #include "../deps/libfat/directory.c"
@@ -1614,11 +1649,11 @@ SSL
 #include "../deps/mbedtls/ssl_srv.c"
 #include "../deps/mbedtls/ssl_ticket.c"
 #include "../deps/mbedtls/ssl_tls.c"
+#endif
 
 #include "../libretro-common/net/net_socket_ssl_mbed.c"
 #endif
 #endif
-#endif
 
 /*============================================================
 PLAYLIST NAME SANITIZATION
@@ -1682,3 +1717,10 @@ CLOUD SYNC
 #include "../network/cloud_sync_driver.c"
 #include "../network/cloud_sync/webdav.c"
 #endif
+
+/*============================================================
+GAME AI
+============================================================ */
+#if defined(HAVE_GAME_AI)
+#include "../ai/game_ai.c"
+#endif
