@@ -185,22 +185,27 @@ static void linux_poll_illuminance_sensor(void *data)
         retro_sleep(1000 / poll_rate);
         if (errno == EINTR)
         {
-           RARCH_ERR("Illuminance sensor thread interrupted\n");
+           RARCH_ERR("Illuminance sensor thread interrupted.\n");
            break;
         }
    }
 
-   RARCH_DBG("Illuminance sensor thread for %s exiting\n", sensor->path);
+   RARCH_DBG("Illuminance sensor thread for %s exiting.\n", sensor->path);
 }
 
 linux_illuminance_sensor_t *linux_open_illuminance_sensor(unsigned rate)
 {
    RDIR *device = NULL;
-   linux_illuminance_sensor_t *sensor = malloc(sizeof(*sensor));
+   linux_illuminance_sensor_t *sensor = (linux_illuminance_sensor_t *)
+      malloc(sizeof(*sensor));
 
    if (!sensor)
       goto error;
 
+   device = retro_opendir(IIO_DEVICES_DIR);
+   if (!device)
+      goto error;
+
    sensor->millilux  = 0;
    sensor->poll_rate = rate ? rate : DEFAULT_POLL_RATE;
    sensor->thread    = NULL; /* We'll spawn a thread later, once we find a sensor */
@@ -213,7 +218,7 @@ linux_illuminance_sensor_t *linux_open_illuminance_sensor(unsigned rate)
 
       if (!name)
       {
-         RARCH_ERR("Error reading " IIO_DEVICES_DIR "\n");
+         RARCH_ERR("Error reading " IIO_DEVICES_DIR ".\n");
          goto error;
       }
 
@@ -232,27 +237,23 @@ linux_illuminance_sensor_t *linux_open_illuminance_sensor(unsigned rate)
 
          if (!sensor->thread)
          {
-            RARCH_ERR("Failed to spawn thread for illuminance sensor\n");
+            RARCH_ERR("Failed to spawn thread for illuminance sensor.\n");
             goto error;
          }
 
-         RARCH_LOG("Opened illuminance sensor at %s, polling at %u Hz\n", sensor->path, sensor->poll_rate);
-
-         goto done;
+         RARCH_LOG("Opened illuminance sensor at %s, polling at %u Hz.\n", sensor->path, sensor->poll_rate);
+         retro_closedir(device);
+         return sensor;
       }
    }
 
 error:
-   RARCH_ERR("Failed to find an illuminance sensor\n");
+   RARCH_ERR("Failed to find an illuminance sensor in " IIO_DEVICES_DIR ".\n");
    retro_closedir(device);
 
    free(sensor);
 
    return NULL;
-done:
-   retro_closedir(device);
-
-   return sensor;
 }
 
 void linux_close_illuminance_sensor(linux_illuminance_sensor_t *sensor)
@@ -262,7 +263,7 @@ void linux_close_illuminance_sensor(linux_illuminance_sensor_t *sensor)
 
    if (sensor->thread)
    {
-      pthread_t thread = sthread_get_thread_id(sensor->thread);
+      pthread_t thread = (pthread_t)sthread_get_thread_id(sensor->thread);
       sensor->done = true;
 
       if (pthread_cancel(thread) != 0)
@@ -270,7 +271,7 @@ void linux_close_illuminance_sensor(linux_illuminance_sensor_t *sensor)
          int err = errno;
          char errmesg[NAME_MAX_LENGTH];
          strerror_r(err, errmesg, sizeof(errmesg));
-         RARCH_ERR("Failed to cancel illuminance sensor thread: %s\n", errmesg);
+         RARCH_ERR("Failed to cancel illuminance sensor thread: %s.\n", errmesg);
          /* this doesn't happen often, it should probably be logged */
       }
 
@@ -310,6 +311,7 @@ static double linux_read_illuminance_sensor(const linux_illuminance_sensor_t *se
    char buffer[256];
    double illuminance = 0.0;
    RFILE *in_illuminance_input = NULL;
+   int err = 0;
 
    if (!sensor || sensor->path[0] == '\0')
       return -1.0;
@@ -317,29 +319,31 @@ static double linux_read_illuminance_sensor(const linux_illuminance_sensor_t *se
    in_illuminance_input = filestream_open(sensor->path, RETRO_VFS_FILE_ACCESS_READ, RETRO_VFS_FILE_ACCESS_HINT_NONE);
    if (!in_illuminance_input)
    {
-      RARCH_ERR("Failed to open %s\n", sensor->path);
-      goto done;
+      RARCH_ERR("Failed to open \"%s\".\n", sensor->path);
+      return 0.0;
    }
 
+   /* Read the illuminance value from the file. If that fails... */
    if (!filestream_gets(in_illuminance_input, buffer, sizeof(buffer)))
-   { /* Read the illuminance value from the file. If that fails... */
-      RARCH_ERR("Illuminance sensor read failed\n");
-      illuminance = -1.0;
-      goto done;
+   {
+      RARCH_ERR("Illuminance sensor read failed.\n");
+      filestream_close(in_illuminance_input);
+      return -1.0;
    }
 
+   filestream_close(in_illuminance_input);
+
+   /* Clear any existing error so we'll know if strtod fails */
+   errno = 0;
+
    /* TODO: This may be locale-sensitive */
    illuminance = strtod(buffer, NULL);
-   if (errno != 0)
+   err = errno;
+   if (err != 0)
    {
-      RARCH_ERR("Failed to parse input \"%s\" into a floating-point value\n", buffer);
-      illuminance = -1.0;
-      goto done;
+      RARCH_ERR("Failed to parse input \"%s\" into a floating-point value: %s.\n", buffer, strerror(err));
+      return -1.0;
    }
 
-done:
-   if (in_illuminance_input)
-      filestream_close(in_illuminance_input);
-
    return illuminance;
 }
