@@ -18,6 +18,8 @@
 #pragma comment(lib, "dinput8")
 #endif
 
+#define WIN32_LEAN_AND_MEAN
+
 #undef DIRECTINPUT_VERSION
 #define DIRECTINPUT_VERSION 0x0800
 
@@ -81,7 +83,8 @@ enum dinput_input_flags
    DINP_FLAG_MOUSE_WU_BTN      = (1 << 10),
    DINP_FLAG_MOUSE_WD_BTN      = (1 << 11),
    DINP_FLAG_MOUSE_HWU_BTN     = (1 << 12),
-   DINP_FLAG_MOUSE_HWD_BTN     = (1 << 13)
+   DINP_FLAG_MOUSE_HWD_BTN     = (1 << 13),
+   DINP_FLAG_MOUSE_IGNORE      = (1 << 14)
 };
 
 struct dinput_input
@@ -172,10 +175,10 @@ static void *dinput_init(const char *joypad_driver)
 
    if (di->keyboard)
    {
-      settings_t *settings = config_get_ptr();
-      DWORD flags          = DISCL_NONEXCLUSIVE | DISCL_FOREGROUND;
-      if (settings->bools.input_nowinkey_enable)
-         flags            |= DISCL_NOWINKEY;
+      bool input_nowinkey_enable = config_get_ptr()->bools.input_nowinkey_enable;
+      DWORD flags                = DISCL_NONEXCLUSIVE | DISCL_FOREGROUND;
+      if (input_nowinkey_enable)
+         flags                  |= DISCL_NOWINKEY;
 
       IDirectInputDevice8_SetDataFormat(di->keyboard, &c_dfDIKeyboard);
       IDirectInputDevice8_SetCooperativeLevel(di->keyboard,
@@ -388,14 +391,21 @@ static void dinput_poll(void *data)
       ScreenToClient((HWND)video_driver_window_get(), &point);
       di->mouse_x = point.x;
       di->mouse_y = point.y;
+
+      /* Ignore application focusing mouse clicks */
+      if (di->flags & DINP_FLAG_MOUSE_IGNORE)
+      {
+         if (mouse_state.rgbButtons[0] || mouse_state.rgbButtons[1])
+            di->flags &= ~(DINP_FLAG_MOUSE_L_BTN | DINP_FLAG_MOUSE_R_BTN);
+         else if (!mouse_state.rgbButtons[0] && !mouse_state.rgbButtons[1])
+            di->flags &= ~DINP_FLAG_MOUSE_IGNORE;
+      }
    }
 }
 
 static bool dinput_mouse_button_pressed(
       struct dinput_input *di, unsigned port, unsigned key)
 {
-   bool result = false;
-
    switch (key)
    {
       case RETRO_DEVICE_ID_MOUSE_LEFT:
@@ -409,24 +419,36 @@ static bool dinput_mouse_button_pressed(
       case RETRO_DEVICE_ID_MOUSE_BUTTON_5:
          return (di->flags & DINP_FLAG_MOUSE_B5_BTN) ? true : false;
       case RETRO_DEVICE_ID_MOUSE_WHEELUP:
-         result        = (di->flags & DINP_FLAG_MOUSE_WU_BTN)  ? true : false;
-         di->flags    &= ~DINP_FLAG_MOUSE_WU_BTN;
+         if (di->flags & DINP_FLAG_MOUSE_WU_BTN)
+         {
+            di->flags &= ~DINP_FLAG_MOUSE_WU_BTN;
+            return true;
+         }
          break;
       case RETRO_DEVICE_ID_MOUSE_WHEELDOWN:
-         result        = (di->flags & DINP_FLAG_MOUSE_WD_BTN)  ? true : false;
-         di->flags    &= ~DINP_FLAG_MOUSE_WD_BTN;
+         if (di->flags & DINP_FLAG_MOUSE_WD_BTN)
+         {
+            di->flags &= ~DINP_FLAG_MOUSE_WD_BTN;
+            return true;
+         }
          break;
       case RETRO_DEVICE_ID_MOUSE_HORIZ_WHEELUP:
-         result        = (di->flags & DINP_FLAG_MOUSE_HWU_BTN) ? true : false;
-         di->flags    &= ~DINP_FLAG_MOUSE_HWU_BTN;
+         if (di->flags & DINP_FLAG_MOUSE_HWU_BTN)
+         {
+            di->flags &= ~DINP_FLAG_MOUSE_HWU_BTN;
+            return true;
+         }
          break;
       case RETRO_DEVICE_ID_MOUSE_HORIZ_WHEELDOWN:
-         result        = (di->flags & DINP_FLAG_MOUSE_HWD_BTN) ? true : false;
-         di->flags    &= ~DINP_FLAG_MOUSE_HWD_BTN;
+         if (di->flags & DINP_FLAG_MOUSE_HWD_BTN)
+         {
+            di->flags &= ~DINP_FLAG_MOUSE_HWD_BTN;
+            return true;
+         }
          break;
    }
 
-   return result;
+   return false;
 }
 
 static int16_t dinput_lightgun_aiming_state(
@@ -891,6 +913,10 @@ bool dinput_handle_message(void *data,
 
    switch (message)
    {
+      case WM_SETFOCUS:
+      case WM_KILLFOCUS:
+         di->flags       |= DINP_FLAG_MOUSE_IGNORE;
+         break;
       case WM_NCLBUTTONDBLCLK:
          di->flags       |= DINP_FLAG_DBCLK_ON_TITLEBAR;
          break;
