@@ -23,14 +23,19 @@
 #include <encodings/crc32.h>
 #include <encodings/utf.h>
 
+#include <emscripten/emscripten.h>
 #include <emscripten/html5.h>
+#include "../../frontend/drivers/platform_emscripten.h"
 
+#include "../input_driver.h"
+#include "../input_types.h"
 #include "../input_keymaps.h"
 
 #include "../../tasks/tasks_internal.h"
 #include "../../configuration.h"
 #include "../../retroarch.h"
 #include "../../verbosity.h"
+#include "../../command.h"
 
 /* https://developer.mozilla.org/en-US/docs/Web/API/MouseEvent/button */
 #define RWEBINPUT_MOUSE_BTNL 0
@@ -39,6 +44,8 @@
 #define RWEBINPUT_MOUSE_BTN4 3
 #define RWEBINPUT_MOUSE_BTN5 4
 
+#define MAX_TOUCH 32
+
 typedef struct rwebinput_key_to_code_map_entry
 {
    const char *key;
@@ -58,26 +65,46 @@ typedef struct rwebinput_keyboard_event_queue
    size_t max_size;
 } rwebinput_keyboard_event_queue_t;
 
+typedef struct rwebinput_pointer_states
+{
+   int x;
+   int y;
+   int id;
+} rwebinput_pointer_state_t;
+
 typedef struct rwebinput_mouse_states
 {
    double pending_scroll_x;
    double pending_scroll_y;
    double scroll_x;
    double scroll_y;
-   signed x;
-   signed y;
-   signed pending_delta_x;
-   signed pending_delta_y;
-   signed delta_x;
-   signed delta_y;
+   int x;
+   int y;
+   int pending_delta_x;
+   int pending_delta_y;
+   int delta_x;
+   int delta_y;
    uint8_t buttons;
 } rwebinput_mouse_state_t;
 
+typedef struct rwebinput_motion_states
+{
+   float x;
+   float y;
+   float z;
+   bool enabled;
+} rwebinput_motion_state_t;
+
 typedef struct rwebinput_input
 {
-   rwebinput_mouse_state_t mouse;             /* double alignment */
-   rwebinput_keyboard_event_queue_t keyboard; /* ptr alignment */
+   rwebinput_mouse_state_t mouse;                /* double alignment */
+   rwebinput_keyboard_event_queue_t keyboard;    /* ptr alignment */
+   rwebinput_pointer_state_t pointer[MAX_TOUCH]; /* int alignment */
+   rwebinput_motion_state_t accelerometer;       /* float alignment */
+   rwebinput_motion_state_t gyroscope;           /* float alignment */
+   unsigned pointer_count;
    bool keys[RETROK_LAST];
+   bool pointerlock_active;
 } rwebinput_input_t;
 
 /* KeyboardEvent.keyCode has been deprecated for a while and doesn't have
@@ -255,11 +282,39 @@ static EM_BOOL rwebinput_mouse_cb(int event_type,
 
    uint8_t mask                      = 1 << mouse_event->button;
 
-   rwebinput->mouse.x                = mouse_event->targetX;
-   rwebinput->mouse.y                = mouse_event->targetY;
+   // note: movementX/movementY are pre-scaled in chromium (but not firefox)
+   // see https://github.com/w3c/pointerlock/issues/42
+
    rwebinput->mouse.pending_delta_x += mouse_event->movementX;
    rwebinput->mouse.pending_delta_y += mouse_event->movementY;
 
+   if (rwebinput->pointerlock_active)
+   {
+      unsigned video_width, video_height;
+      video_driver_get_size(&video_width, &video_height);
+
+      rwebinput->mouse.x += mouse_event->movementX;
+      rwebinput->mouse.y += mouse_event->movementY;
+
+      /* Clamp X */
+      if (rwebinput->mouse.x < 0)
+         rwebinput->mouse.x = 0;
+      if (rwebinput->mouse.x >= video_width)
+         rwebinput->mouse.x = (int)(video_width - 1);
+
+      /* Clamp Y */
+      if (rwebinput->mouse.y < 0)
+         rwebinput->mouse.y = 0;
+      if (rwebinput->mouse.y >= video_height)
+         rwebinput->mouse.y = (int)(video_height - 1);
+   }
+   else
+   {
+      double dpr = platform_emscripten_get_dpr();
+      rwebinput->mouse.x = (int)(mouse_event->targetX * dpr);
+      rwebinput->mouse.y = (int)(mouse_event->targetY * dpr);
+   }
+
    if (event_type ==  EMSCRIPTEN_EVENT_MOUSEDOWN)
       rwebinput->mouse.buttons |= mask;
    else if (event_type == EMSCRIPTEN_EVENT_MOUSEUP)
@@ -273,8 +328,110 @@ static EM_BOOL rwebinput_wheel_cb(int event_type,
 {
    rwebinput_input_t       *rwebinput = (rwebinput_input_t*)user_data;
 
-   rwebinput->mouse.pending_scroll_x += wheel_event->deltaX;
-   rwebinput->mouse.pending_scroll_y += wheel_event->deltaY;
+   double dpr = platform_emscripten_get_dpr();
+   rwebinput->mouse.pending_scroll_x += wheel_event->deltaX * dpr;
+   rwebinput->mouse.pending_scroll_y += wheel_event->deltaY * dpr;
+
+   return EM_TRUE;
+}
+
+static EM_BOOL rwebinput_touch_cb(int event_type,
+   const EmscriptenTouchEvent *touch_event, void *user_data)
+{
+   rwebinput_input_t *rwebinput = (rwebinput_input_t*)user_data;
+
+   unsigned touches_max      = MIN(touch_event->numTouches, MAX_TOUCH);
+   unsigned touches_released = 0;
+
+   switch (event_type)
+   {
+      case EMSCRIPTEN_EVENT_TOUCHSTART:
+      case EMSCRIPTEN_EVENT_TOUCHMOVE:
+         for (unsigned touch = 0; touch < touches_max; touch++)
+         {
+            if (!(touch_event->touches[touch].isChanged) && rwebinput->pointer[touch].id == touch_event->touches[touch].identifier)
+               continue;
+
+            double dpr = platform_emscripten_get_dpr();
+            rwebinput->pointer[touch].x  = (int)(touch_event->touches[touch].targetX * dpr);
+            rwebinput->pointer[touch].y  = (int)(touch_event->touches[touch].targetY * dpr);
+            rwebinput->pointer[touch].id = touch_event->touches[touch].identifier;
+         }
+         break;
+      case EMSCRIPTEN_EVENT_TOUCHEND:
+      case EMSCRIPTEN_EVENT_TOUCHCANCEL:
+         // note: touches_max/numTouches is out of date here - it uses the old value from before the release
+         // note 2: I'm unsure if multiple touches can trigger the same touchend anyway...
+         if (touches_max > 1)
+         {
+            for (unsigned touch_up = 0; touch_up < touches_max; touch_up++)
+            {
+               if (touch_event->touches[touch_up].isChanged)
+               {
+                  memmove(rwebinput->pointer + touch_up - touches_released,
+                          rwebinput->pointer + touch_up - touches_released + 1,
+                          (touches_max - touch_up - 1) * sizeof(rwebinput_pointer_state_t));
+                  touches_released++;
+               }
+            }
+         }
+         else
+            touches_released = 1;
+
+         if (touches_max > touches_released)
+            touches_max -= touches_released;
+         else
+            touches_max = 0;
+         break;
+   }
+
+   rwebinput->pointer_count = touches_max;
+
+   return EM_TRUE;
+}
+
+static EM_BOOL rwebinput_pointerlockchange_cb(int event_type,
+   const EmscriptenPointerlockChangeEvent *pointerlock_change_event, void *user_data)
+{
+   rwebinput_input_t *rwebinput = (rwebinput_input_t*)user_data;
+
+   rwebinput->pointerlock_active = pointerlock_change_event->isActive;
+
+   if (!pointerlock_change_event->isActive)
+   {
+      input_driver_state_t *input_st = input_state_get_ptr();
+
+      if (input_st->game_focus_state.enabled)
+      {
+         enum input_game_focus_cmd_type game_focus_cmd = GAME_FOCUS_CMD_OFF;
+         command_event(CMD_EVENT_GAME_FOCUS_TOGGLE, &game_focus_cmd);
+      }
+
+      if (input_st->flags & INP_FLAG_GRAB_MOUSE_STATE)
+      {
+         command_event(CMD_EVENT_GRAB_MOUSE_TOGGLE, NULL);
+      }
+   }
+
+   return EM_TRUE;
+}
+
+static EM_BOOL rwebinput_devicemotion_cb(int event_type,
+   const EmscriptenDeviceMotionEvent *device_motion_event, void *user_data)
+{
+   rwebinput_input_t *rwebinput = (rwebinput_input_t*)user_data;
+
+   /* TODO: what units does mGBA want? does something need to be changed on the core side? */
+   /* given in m/s^2 (inverted) */
+   rwebinput->accelerometer.x = device_motion_event->accelerationIncludingGravityX / -9.8;
+   rwebinput->accelerometer.y = device_motion_event->accelerationIncludingGravityY / -9.8;
+   rwebinput->accelerometer.z = device_motion_event->accelerationIncludingGravityZ / -9.8;
+   /* XYZ == BetaGammaAlpha according to W3C? in my testing it is AlphaBetaGamma... */
+   /* libretro wants radians/s but it is too fast in mGBA, see above comment */
+   /* given in degrees/s */
+   rwebinput->gyroscope.x = device_motion_event->rotationRateAlpha / 180;
+   rwebinput->gyroscope.y = device_motion_event->rotationRateBeta  / 180;
+   rwebinput->gyroscope.z = device_motion_event->rotationRateGamma / 180;
 
    return EM_TRUE;
 }
@@ -290,67 +447,104 @@ static void *rwebinput_input_init(const char *joypad_driver)
 
    rwebinput_generate_lut();
 
-   r = emscripten_set_keydown_callback(
-         "!canvas", rwebinput, false,
+   input_keymaps_init_keyboard_lut(rarch_key_map_rwebinput);
+
+   r = emscripten_set_keydown_callback("#canvas", rwebinput, false,
          rwebinput_keyboard_cb);
    if (r != EMSCRIPTEN_RESULT_SUCCESS)
    {
       RARCH_ERR(
-         "[EMSCRIPTEN/INPUT] failed to create keydown callback: %d\n", r);
+         "[EMSCRIPTEN/INPUT] Failed to create keydown callback: %d.\n", r);
    }
 
-   r = emscripten_set_keyup_callback(
-         "!canvas", rwebinput, false,
+   r = emscripten_set_keyup_callback("#canvas", rwebinput, false,
          rwebinput_keyboard_cb);
    if (r != EMSCRIPTEN_RESULT_SUCCESS)
    {
       RARCH_ERR(
-         "[EMSCRIPTEN/INPUT] failed to create keyup callback: %d\n", r);
+         "[EMSCRIPTEN/INPUT] Failed to create keyup callback: %d.\n", r);
    }
 
-   r = emscripten_set_keypress_callback(
-         "!canvas", rwebinput, false,
+   r = emscripten_set_keypress_callback("#canvas", rwebinput, false,
          rwebinput_keyboard_cb);
    if (r != EMSCRIPTEN_RESULT_SUCCESS)
    {
       RARCH_ERR(
-         "[EMSCRIPTEN/INPUT] failed to create keypress callback: %d\n", r);
+         "[EMSCRIPTEN/INPUT] Failed to create keypress callback: %d.\n", r);
    }
 
-   r = emscripten_set_mousedown_callback("!canvas", rwebinput, false,
+   r = emscripten_set_mousedown_callback("#canvas", rwebinput, false,
          rwebinput_mouse_cb);
    if (r != EMSCRIPTEN_RESULT_SUCCESS)
    {
       RARCH_ERR(
-         "[EMSCRIPTEN/INPUT] failed to create mousedown callback: %d\n", r);
+         "[EMSCRIPTEN/INPUT] Failed to create mousedown callback: %d.\n", r);
    }
 
-   r = emscripten_set_mouseup_callback("!canvas", rwebinput, false,
+   r = emscripten_set_mouseup_callback("#canvas", rwebinput, false,
          rwebinput_mouse_cb);
    if (r != EMSCRIPTEN_RESULT_SUCCESS)
    {
       RARCH_ERR(
-         "[EMSCRIPTEN/INPUT] failed to create mouseup callback: %d\n", r);
+         "[EMSCRIPTEN/INPUT] Failed to create mouseup callback: %d.\n", r);
    }
 
-   r = emscripten_set_mousemove_callback("!canvas", rwebinput, false,
+   r = emscripten_set_mousemove_callback("#canvas", rwebinput, false,
          rwebinput_mouse_cb);
    if (r != EMSCRIPTEN_RESULT_SUCCESS)
    {
       RARCH_ERR(
-         "[EMSCRIPTEN/INPUT] failed to create mousemove callback: %d\n", r);
+         "[EMSCRIPTEN/INPUT] Failed to create mousemove callback: %d.\n", r);
    }
 
-   r = emscripten_set_wheel_callback(
-         "!canvas", rwebinput, false,
+   r = emscripten_set_wheel_callback("#canvas", rwebinput, false,
          rwebinput_wheel_cb);
    if (r != EMSCRIPTEN_RESULT_SUCCESS)
    {
       RARCH_ERR(
-         "[EMSCRIPTEN/INPUT] failed to create wheel callback: %d\n", r);
+         "[EMSCRIPTEN/INPUT] Failed to create wheel callback: %d.\n", r);
    }
 
-   input_keymaps_init_keyboard_lut(rarch_key_map_rwebinput);
+   r = emscripten_set_touchstart_callback("#canvas", rwebinput, false,
+         rwebinput_touch_cb);
+   if (r != EMSCRIPTEN_RESULT_SUCCESS)
+   {
+      RARCH_ERR(
+         "[EMSCRIPTEN/INPUT] Failed to create touchstart callback: %d.\n", r);
+   }
+
+   r = emscripten_set_touchend_callback("#canvas", rwebinput, false,
+         rwebinput_touch_cb);
+   if (r != EMSCRIPTEN_RESULT_SUCCESS)
+   {
+      RARCH_ERR(
+         "[EMSCRIPTEN/INPUT] Failed to create touchend callback: %d.\n", r);
+   }
+
+   r = emscripten_set_touchmove_callback("#canvas", rwebinput, false,
+         rwebinput_touch_cb);
+   if (r != EMSCRIPTEN_RESULT_SUCCESS)
+   {
+      RARCH_ERR(
+         "[EMSCRIPTEN/INPUT] Failed to create touchmove callback: %d.\n", r);
+   }
+
+   r = emscripten_set_touchcancel_callback("#canvas", rwebinput, false,
+         rwebinput_touch_cb);
+   if (r != EMSCRIPTEN_RESULT_SUCCESS)
+   {
+      RARCH_ERR(
+         "[EMSCRIPTEN/INPUT] Failed to create touchcancel callback: %d.\n", r);
+   }
+
+   r = emscripten_set_pointerlockchange_callback(
+         EMSCRIPTEN_EVENT_TARGET_DOCUMENT, rwebinput, false,
+         rwebinput_pointerlockchange_cb);
+   if (r != EMSCRIPTEN_RESULT_SUCCESS)
+   {
+      RARCH_ERR(
+         "[EMSCRIPTEN/INPUT] Failed to create pointerlockchange callback: %d.\n", r);
+   }
 
    return rwebinput;
 }
@@ -505,24 +699,41 @@ static int16_t rwebinput_input_state(
          return rwebinput_mouse_state(&rwebinput->mouse, id, device == RARCH_DEVICE_MOUSE_SCREEN);
       case RETRO_DEVICE_POINTER:
       case RARCH_DEVICE_POINTER_SCREEN:
-         if (idx == 0)
          {
             struct video_viewport vp    = {0};
             rwebinput_mouse_state_t
                *mouse                   = &rwebinput->mouse;
-            bool screen                 = device ==
-               RARCH_DEVICE_POINTER_SCREEN;
+            bool pointer_down           = false;
+            unsigned pointer_count      = rwebinput->pointer_count;
+            int x                       = 0;
+            int y                       = 0;
             int16_t res_x               = 0;
             int16_t res_y               = 0;
             int16_t res_screen_x        = 0;
             int16_t res_screen_y        = 0;
 
+            if (pointer_count && idx < pointer_count)
+            {
+               x = rwebinput->pointer[idx].x;
+               y = rwebinput->pointer[idx].y;
+               pointer_down = true;
+            }
+            else if (idx == 0)
+            {
+               x = mouse->x;
+               y = mouse->y;
+               pointer_down = !!(mouse->buttons & (1 << RWEBINPUT_MOUSE_BTNL));
+               pointer_count = 1;
+            }
+            else
+               return 0;
+
             if (!(video_driver_translate_coord_viewport_confined_wrap(
-                        &vp, mouse->x, mouse->y,
+                        &vp, x, y,
                         &res_x, &res_y, &res_screen_x, &res_screen_y)))
                return 0;
 
-            if (screen)
+            if (device == RARCH_DEVICE_POINTER_SCREEN)
             {
                res_x = res_screen_x;
                res_y = res_screen_y;
@@ -535,7 +746,9 @@ static int16_t rwebinput_input_state(
                case RETRO_DEVICE_ID_POINTER_Y:
                   return res_y;
                case RETRO_DEVICE_ID_POINTER_PRESSED:
-                  return !!(mouse->buttons & (1 << RWEBINPUT_MOUSE_BTNL));
+                  return (pointer_down && !input_driver_pointer_is_offscreen(res_x, res_y));
+               case RETRO_DEVICE_ID_POINTER_COUNT:
+                  return pointer_count;
                case RETRO_DEVICE_ID_POINTER_IS_OFFSCREEN:
                   return input_driver_pointer_is_offscreen(res_x, res_y);
                default:
@@ -548,17 +761,99 @@ static int16_t rwebinput_input_state(
    return 0;
 }
 
+static void rwebinput_remove_event_listeners(void *data)
+{
+   /* *currently* not automatically proxied in the case of PROXY_TO_PTHREAD */
+   emscripten_html5_remove_all_event_listeners();
+}
+
 static void rwebinput_input_free(void *data)
 {
    rwebinput_input_t *rwebinput = (rwebinput_input_t*)data;
 
-   emscripten_html5_remove_all_event_listeners();
-
+   platform_emscripten_run_on_browser_thread_sync(rwebinput_remove_event_listeners, NULL);
    free(rwebinput->keyboard.events);
-
    free(data);
 }
 
+static bool rwebinput_set_sensor_state(void *data, unsigned port,
+      enum retro_sensor_action action, unsigned rate)
+{
+   rwebinput_input_t *rwebinput = (rwebinput_input_t*)data;
+   EMSCRIPTEN_RESULT r;
+   bool old_state = rwebinput->accelerometer.enabled || rwebinput->gyroscope.enabled;
+   bool new_state;
+
+   switch (action)
+   {
+      case RETRO_SENSOR_ACCELEROMETER_ENABLE:
+         rwebinput->accelerometer.enabled = true;
+         break;
+      case RETRO_SENSOR_ACCELEROMETER_DISABLE:
+         rwebinput->accelerometer.enabled = false;
+         break;
+      case RETRO_SENSOR_GYROSCOPE_ENABLE:
+         rwebinput->gyroscope.enabled = true;
+         break;
+      case RETRO_SENSOR_GYROSCOPE_DISABLE:
+         rwebinput->gyroscope.enabled = false;
+         break;
+      case RETRO_SENSOR_ILLUMINANCE_ENABLE:
+      case RETRO_SENSOR_ILLUMINANCE_DISABLE:
+         return false; /* not supported (browsers removed support for now) */
+      default:
+         return false;
+   }
+
+   new_state = rwebinput->accelerometer.enabled || rwebinput->gyroscope.enabled;
+
+   if (!old_state && new_state)
+   {
+      r = emscripten_set_devicemotion_callback(rwebinput, false, rwebinput_devicemotion_cb);
+      if (r != EMSCRIPTEN_RESULT_SUCCESS)
+      {
+         RARCH_ERR(
+            "[EMSCRIPTEN/INPUT] Failed to create devicemotion callback: %d.\n", r);
+         return false;
+      }
+   }
+   else if (old_state && !new_state)
+   {
+      r = emscripten_set_devicemotion_callback(rwebinput, false, NULL);
+      if (r != EMSCRIPTEN_RESULT_SUCCESS)
+      {
+         RARCH_ERR(
+            "[EMSCRIPTEN/INPUT] Failed to remove devicemotion callback: %d.\n", r);
+         return false;
+      }
+   }
+
+   return true;
+}
+
+static float rwebinput_get_sensor_input(void *data, unsigned port, unsigned id)
+{
+   rwebinput_input_t *rwebinput = (rwebinput_input_t*)data;
+
+   switch (id)
+   {
+      case RETRO_SENSOR_ACCELEROMETER_X:
+         return rwebinput->accelerometer.x;
+      case RETRO_SENSOR_ACCELEROMETER_Y:
+         return rwebinput->accelerometer.y;
+      case RETRO_SENSOR_ACCELEROMETER_Z:
+         return rwebinput->accelerometer.z;
+      case RETRO_SENSOR_GYROSCOPE_X:
+         return rwebinput->gyroscope.x;
+      case RETRO_SENSOR_GYROSCOPE_Y:
+         return rwebinput->gyroscope.y;
+      case RETRO_SENSOR_GYROSCOPE_Z:
+         return rwebinput->gyroscope.z;
+   }
+
+   return 0.0f;
+}
+
 static void rwebinput_process_keyboard_events(
       rwebinput_input_t *rwebinput,
       rwebinput_keyboard_event_t *event)
@@ -633,7 +928,7 @@ static void rwebinput_input_poll(void *data)
 static void rwebinput_grab_mouse(void *data, bool state)
 {
    if (state)
-      emscripten_request_pointerlock("!canvas", EM_TRUE);
+      emscripten_request_pointerlock("#canvas", EM_TRUE);
    else
       emscripten_exit_pointerlock();
 }
@@ -653,8 +948,8 @@ input_driver_t input_rwebinput = {
    rwebinput_input_poll,
    rwebinput_input_state,
    rwebinput_input_free,
-   NULL,
-   NULL,
+   rwebinput_set_sensor_state,
+   rwebinput_get_sensor_input,
    rwebinput_get_capabilities,
    "rwebinput",
    rwebinput_grab_mouse,
