@@ -72,13 +72,8 @@ typedef struct
 
 static input_test_step_t input_test_steps[MAX_TEST_STEPS];
 
-static unsigned current_frame         = 0;
-static unsigned next_teststep_frame   = 0;
 static unsigned current_test_step     = 0;
 static unsigned last_test_step        = MAX_TEST_STEPS + 1;
-static uint32_t input_state_validated = 0;
-static uint32_t combo_state_validated = 0;
-static bool     dump_state_blocked    = false;
 
 /************************************/
 /* JSON Helpers for test input file */
@@ -125,7 +120,7 @@ static bool KTifJSONObjectEndHandler(void* context)
    return true;
 }
 
-static bool KTifJSONObjectMemberHandler(void* context, const char *pValue, size_t length)
+static bool KTifJSONObjectMemberHandler(void* context, const char *pValue, size_t len)
 {
    KTifJSONContext *pCtx = (KTifJSONContext*)context;
 
@@ -133,7 +128,7 @@ static bool KTifJSONObjectMemberHandler(void* context, const char *pValue, size_
    if (pCtx->current_entry_str_val)
       return false;
 
-   if (length)
+   if (len)
    {
       if (string_is_equal(pValue, "frame"))
          pCtx->current_entry_uint_val = &pCtx->frame;
@@ -149,11 +144,11 @@ static bool KTifJSONObjectMemberHandler(void* context, const char *pValue, size_
    return true;
 }
 
-static bool KTifJSONNumberHandler(void* context, const char *pValue, size_t length)
+static bool KTifJSONNumberHandler(void* context, const char *pValue, size_t len)
 {
    KTifJSONContext *pCtx = (KTifJSONContext*)context;
 
-   if (pCtx->current_entry_uint_val && length && !string_is_empty(pValue))
+   if (pCtx->current_entry_uint_val && len && !string_is_empty(pValue))
       *pCtx->current_entry_uint_val = string_to_unsigned(pValue);
    /* ignore unknown members */
 
@@ -162,11 +157,11 @@ static bool KTifJSONNumberHandler(void* context, const char *pValue, size_t leng
    return true;
 }
 
-static bool KTifJSONStringHandler(void* context, const char *pValue, size_t length)
+static bool KTifJSONStringHandler(void* context, const char *pValue, size_t len)
 {
    KTifJSONContext *pCtx = (KTifJSONContext*)context;
 
-   if (pCtx->current_entry_str_val && length && !string_is_empty(pValue))
+   if (pCtx->current_entry_str_val && len && !string_is_empty(pValue))
    {
       if (*pCtx->current_entry_str_val)
          free(*pCtx->current_entry_str_val);
@@ -194,7 +189,7 @@ static bool input_test_file_read(const char* file_path)
        || !path_is_valid(file_path)
       )
    {
-      RARCH_DBG("[Test input driver]: No test input file supplied.\n");
+      RARCH_DBG("[Test input] No test input file supplied.\n");
       return false;
    }
 
@@ -206,7 +201,7 @@ static bool input_test_file_read(const char* file_path)
 
    if (!file)
    {
-      RARCH_ERR("[Test input driver]: Failed to open test input file: \"%s\".\n",
+      RARCH_ERR("[Test input] Failed to open test input file: \"%s\".\n",
             file_path);
       return false;
    }
@@ -214,7 +209,7 @@ static bool input_test_file_read(const char* file_path)
    /* Initialise JSON parser */
    if (!(parser = rjson_open_rfile(file)))
    {
-      RARCH_ERR("[Test input driver]: Failed to create JSON parser.\n");
+      RARCH_ERR("[Test input] Failed to create JSON parser.\n");
       goto end;
    }
 
@@ -233,16 +228,16 @@ static bool input_test_file_read(const char* file_path)
       if (rjson_get_source_context_len(parser))
       {
          RARCH_ERR(
-               "[Test input driver]: Error parsing chunk of test input file: %s\n---snip---\n%.*s\n---snip---\n",
+               "[Test input] Error parsing chunk of test input file: %s\n---snip---\n%.*s\n---snip---\n",
                file_path,
                rjson_get_source_context_len(parser),
                rjson_get_source_context_buf(parser));
       }
       RARCH_WARN(
-            "[Test input driver]: Error parsing test input file: %s\n",
+            "[Test input] Error parsing test input file: \"%s\".\n",
             file_path);
       RARCH_ERR(
-            "[Test input driver]: Error: Invalid JSON at line %d, column %d - %s.\n",
+            "[Test input] Error: Invalid JSON at line %d, column %d - %s.\n",
             (int)rjson_get_source_line(parser),
             (int)rjson_get_source_column(parser),
             (*rjson_get_error(parser) ? rjson_get_error(parser) : "format error"));
@@ -262,12 +257,12 @@ end:
 
    if (last_test_step >= MAX_TEST_STEPS)
    {
-      RARCH_WARN("[Test input driver]: too long test input json, maximum size: %d\n",MAX_TEST_STEPS);
+      RARCH_WARN("[Test input] Too long test input json, maximum size: %d.\n",MAX_TEST_STEPS);
    }
    for (current_test_step = 0; current_test_step < last_test_step; current_test_step++)
    {
       RARCH_DBG(
-         "[Test input driver]: test step %02d read from file: frame %d, action %x, num %x, str %s\n",
+         "[Test input] test step %02d read from file: frame %d, action %x, num %x, str %s\n",
          current_test_step,
          input_test_steps[current_test_step].frame,
          input_test_steps[current_test_step].action,
@@ -367,9 +362,8 @@ static void test_input_free_input(void *data)
 static void* test_input_init(const char *joypad_driver)
 {
    settings_t *settings = config_get_ptr();
-   unsigned i;
 
-   RARCH_DBG("[Test input driver]: start\n");
+   RARCH_DBG("[Test input] Start.\n");
 
    input_test_file_read(settings->paths.test_input_file_general);
    if (last_test_step > MAX_TEST_STEPS)
@@ -412,33 +406,33 @@ static void test_input_poll(void *data)
    {
       if (!input_test_steps[i].handled && curr_frame > input_test_steps[i].frame)
       {
-         if( input_test_steps[i].action == INPUT_TEST_COMMAND_PRESS_KEY)
+         if (input_test_steps[i].action == INPUT_TEST_COMMAND_PRESS_KEY)
          {
-            if(input_test_steps[i].param_num < RETROK_LAST)
+            if (input_test_steps[i].param_num < RETROK_LAST)
             {
                test_key_state[DEFAULT_MAX_PADS][input_test_steps[i].param_num] = 1;
                input_keyboard_event(true, input_test_steps[i].param_num, 0, 0, RETRO_DEVICE_KEYBOARD);
             }
             input_test_steps[i].handled = true;
             RARCH_DBG(
-               "[Test input driver]: Pressing keyboard button %d at frame %d\n",
+               "[Test input] Pressing keyboard button %d at frame %d.\n",
                input_test_steps[i].param_num, curr_frame);
          }
-         else if( input_test_steps[i].action == INPUT_TEST_COMMAND_RELEASE_KEY)
+         else if (input_test_steps[i].action == INPUT_TEST_COMMAND_RELEASE_KEY)
          {
-            if(input_test_steps[i].param_num < RETROK_LAST)
+            if (input_test_steps[i].param_num < RETROK_LAST)
             {
                test_key_state[DEFAULT_MAX_PADS][input_test_steps[i].param_num] = 0;
                input_keyboard_event(false, input_test_steps[i].param_num, 0, 0, RETRO_DEVICE_KEYBOARD);
             }
             input_test_steps[i].handled = true;
             RARCH_DBG(
-               "[Test input driver]: Releasing keyboard button %d at frame %d\n",
+               "[Test input] Releasing keyboard button %d at frame %d.\n",
                input_test_steps[i].param_num, curr_frame);
          }
-         else if(input_test_steps[i].action == INPUT_TEST_COMMAND_SET_SENSOR_ACC_X ||
-                 input_test_steps[i].action == INPUT_TEST_COMMAND_SET_SENSOR_ACC_Y ||
-                 input_test_steps[i].action == INPUT_TEST_COMMAND_SET_SENSOR_ACC_Z)
+         else if (  input_test_steps[i].action == INPUT_TEST_COMMAND_SET_SENSOR_ACC_X
+                 || input_test_steps[i].action == INPUT_TEST_COMMAND_SET_SENSOR_ACC_Y
+                 || input_test_steps[i].action == INPUT_TEST_COMMAND_SET_SENSOR_ACC_Z)
          {
             float setval = test_input_unsigned_to_float_acc(input_test_steps[i].param_num);
             switch (input_test_steps[i].action)
@@ -455,12 +449,12 @@ static void test_input_poll(void *data)
             }
             input_test_steps[i].handled = true;
             RARCH_DBG(
-               "[Test input driver]: Setting accelerometer axis %d to %f at frame %d\n",
+               "[Test input] Setting accelerometer axis %d to %f at frame %d.\n",
                input_test_steps[i].action - INPUT_TEST_COMMAND_SET_SENSOR_ACC_X, setval, curr_frame);
          }
-         else if(input_test_steps[i].action == INPUT_TEST_COMMAND_SET_SENSOR_GYR_X ||
-                 input_test_steps[i].action == INPUT_TEST_COMMAND_SET_SENSOR_GYR_Y ||
-                 input_test_steps[i].action == INPUT_TEST_COMMAND_SET_SENSOR_GYR_Z)
+         else if (  input_test_steps[i].action == INPUT_TEST_COMMAND_SET_SENSOR_GYR_X
+                 || input_test_steps[i].action == INPUT_TEST_COMMAND_SET_SENSOR_GYR_Y
+                 || input_test_steps[i].action == INPUT_TEST_COMMAND_SET_SENSOR_GYR_Z)
          {
             float setval = test_input_unsigned_to_float_gyro(input_test_steps[i].param_num);
             switch (input_test_steps[i].action)
@@ -477,23 +471,23 @@ static void test_input_poll(void *data)
             }
             input_test_steps[i].handled = true;
             RARCH_DBG(
-               "[Test input driver]: Setting gyroscope axis %d to %f at frame %d\n",
+               "[Test input] Setting gyroscope axis %d to %f at frame %d.\n",
                input_test_steps[i].action - INPUT_TEST_COMMAND_SET_SENSOR_GYR_X, setval, curr_frame);
          }
-         else if(input_test_steps[i].action == INPUT_TEST_COMMAND_SET_SENSOR_LUX)
+         else if (input_test_steps[i].action == INPUT_TEST_COMMAND_SET_SENSOR_LUX)
          {
             float setval = test_input_unsigned_to_float_lux(input_test_steps[i].param_num);
             test_input_values.lux_sensor_state = setval;
             input_test_steps[i].handled = true;
             RARCH_DBG(
-               "[Test input driver]: Setting lux sensor to %f at frame %d\n",
+               "[Test input] Setting lux sensor to %f at frame %d.\n",
                setval, curr_frame);
          }
          else
          {
             input_test_steps[i].handled = true;
             RARCH_WARN(
-               "[Test input driver]: Unrecognized action %d in step %d, skipping\n",
+               "[Test input] Unrecognized action %d in step %d, skipping...\n",
                input_test_steps[i].action,i);
          }
       }
@@ -503,30 +497,30 @@ static void test_input_poll(void *data)
 static bool test_input_set_sensor_state(void *data, unsigned port,
       enum retro_sensor_action action, unsigned event_rate)
 {
-   RARCH_DBG("[Test input driver]: Setting sensor action %d rate %d\n",action, event_rate);
+   RARCH_DBG("[Test input] Setting sensor action %d rate %d.\n", action, event_rate);
    return true;
 }
 
 static float test_input_get_sensor_input(void *data,
       unsigned port, unsigned id)
 {
-      switch (id)
-      {
-         case RETRO_SENSOR_ACCELEROMETER_X:
-            return test_input_values.accelerometer_state.x;
-         case RETRO_SENSOR_ACCELEROMETER_Y:
-            return test_input_values.accelerometer_state.y;
-         case RETRO_SENSOR_ACCELEROMETER_Z:
-            return test_input_values.accelerometer_state.z;
-         case RETRO_SENSOR_GYROSCOPE_X:
-            return test_input_values.gyroscope_state.x;
-         case RETRO_SENSOR_GYROSCOPE_Y:
-            return test_input_values.gyroscope_state.y;
-         case RETRO_SENSOR_GYROSCOPE_Z:
-            return test_input_values.gyroscope_state.z;
-         case RETRO_SENSOR_ILLUMINANCE:
-            return test_input_values.lux_sensor_state;
-      }
+   switch (id)
+   {
+      case RETRO_SENSOR_ACCELEROMETER_X:
+         return test_input_values.accelerometer_state.x;
+      case RETRO_SENSOR_ACCELEROMETER_Y:
+         return test_input_values.accelerometer_state.y;
+      case RETRO_SENSOR_ACCELEROMETER_Z:
+         return test_input_values.accelerometer_state.z;
+      case RETRO_SENSOR_GYROSCOPE_X:
+         return test_input_values.gyroscope_state.x;
+      case RETRO_SENSOR_GYROSCOPE_Y:
+         return test_input_values.gyroscope_state.y;
+      case RETRO_SENSOR_GYROSCOPE_Z:
+         return test_input_values.gyroscope_state.z;
+      case RETRO_SENSOR_ILLUMINANCE:
+         return test_input_values.lux_sensor_state;
+   }
 
    return 0.0f;
 }
