@@ -13,6 +13,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 
 #ifdef CXX_BUILD
@@ -128,14 +129,14 @@ static void winraw_log_mice_info(winraw_mouse_t *mice, unsigned mouse_cnt)
    char name[256];
    UINT name_size = sizeof(name);
 
-   name[0]        = '\0';
+   name[0] = '\0';
 
    for (i = 0; i < mouse_cnt; ++i)
    {
       UINT r = GetRawInputDeviceInfoA(mice[i].hnd, RIDI_DEVICENAME,
             name, &name_size);
       if (r == (UINT)-1 || r == 0)
-         name[0]   = '\0';
+         name[0] = '\0';
 
       if (name[0])
       {
@@ -146,7 +147,7 @@ static void winraw_log_mice_info(winraw_mouse_t *mice, unsigned mouse_cnt)
          if (hhid != INVALID_HANDLE_VALUE)
          {
             wchar_t prod_buf[128];
-            prod_buf[0]  = '\0';
+            prod_buf[0] = '\0';
             if (HidD_GetProductString(hhid, prod_buf, sizeof(prod_buf)))
                wcstombs(name, prod_buf, sizeof(name));
          }
@@ -158,7 +159,7 @@ static void winraw_log_mice_info(winraw_mouse_t *mice, unsigned mouse_cnt)
 
       input_config_set_mouse_display_name(i, name);
 
-      RARCH_LOG("[WinRaw]: Mouse #%u: \"%s\".\n", i, name);
+      RARCH_LOG("[WinRaw] Mouse #%u: \"%s\".\n", i + 1, name);
    }
 }
 
@@ -203,19 +204,23 @@ static bool winraw_init_devices(winraw_mouse_t **mice, unsigned *mouse_cnt)
       }
    }
 
+   *mouse_cnt = mouse_cnt_r;
+
    /* count is already checked, so this is safe */
    for (i = mouse_cnt_r = 0; i < dev_cnt; ++i)
    {
       if (devs[i].dwType == RIM_TYPEMOUSE)
-         mice_r[mouse_cnt_r++].hnd = devs[i].hDevice;
+      {
+         mouse_cnt_r++;
+         mice_r[*mouse_cnt - mouse_cnt_r].hnd = devs[i].hDevice;
+      }
    }
 
+   *mice      = mice_r;
+
    winraw_log_mice_info(mice_r, mouse_cnt_r);
    free(devs);
 
-   *mice      = mice_r;
-   *mouse_cnt = mouse_cnt_r;
-
    return true;
 
 error:
@@ -323,8 +328,6 @@ static void winraw_update_mouse_state(winraw_input_t *wr,
       }
       else
       {
-         int bottom      = wr->prev_rect.bottom;
-         int right       = wr->prev_rect.right;
          wr->active_rect = wr->prev_rect;
          winraw_init_mouse_xy_mapping(wr);
          wr->rect_delay  = 0;
@@ -370,9 +373,9 @@ static void winraw_update_mouse_state(winraw_input_t *wr,
          InterlockedExchangeAdd(&mouse->dlt_y, state->lLastY);
 
          if (!GetCursorPos(&crs_pos))
-            RARCH_DBG("[WinRaw]: GetCursorPos failed with error %lu.\n", GetLastError());
+            RARCH_DBG("[WinRaw] GetCursorPos failed with error %lu.\n", GetLastError());
          else if (!ScreenToClient((HWND)video_driver_window_get(), &crs_pos))
-            RARCH_DBG("[WinRaw]: ScreenToClient failed with error %lu.\n", GetLastError());
+            RARCH_DBG("[WinRaw] ScreenToClient failed with error %lu.\n", GetLastError());
       }
       else
       {
@@ -554,7 +557,7 @@ static LRESULT CALLBACK winraw_callback(
 static void *winraw_init(const char *joypad_driver)
 {
    RAWINPUTDEVICE rid;
-   settings_t *settings = config_get_ptr();
+   bool input_nowinkey_enable = config_get_ptr()->bools.input_nowinkey_enable;
    winraw_input_t *wr   = (winraw_input_t *)
       calloc(1, sizeof(winraw_input_t));
 
@@ -581,7 +584,7 @@ static void *winraw_init(const char *joypad_driver)
    rid.hwndTarget  = wr->window;
    rid.usUsagePage = 0x01; /* Generic desktop */
    rid.usUsage     = 0x06; /* Keyboard */
-   if (settings->bools.input_nowinkey_enable)
+   if (input_nowinkey_enable)
       rid.dwFlags |= RIDEV_NOHOTKEYS; /* Disable win keys while focused */
 
    if (!RegisterRawInputDevices(&rid, 1, sizeof(RAWINPUTDEVICE)))
@@ -613,7 +616,7 @@ error:
       rid.hwndTarget  = NULL;
       rid.usUsagePage = 0x01; /* Generic desktop */
       rid.usUsage     = 0x06; /* Keyboard */
-      if (settings->bools.input_nowinkey_enable)
+      if (input_nowinkey_enable)
          rid.dwFlags |= RIDEV_NOHOTKEYS; /* Disable win keys while focused */
 
       RegisterRawInputDevices(&rid, 1, sizeof(RAWINPUTDEVICE));
@@ -634,6 +637,10 @@ static void winraw_poll(void *data)
 
    for (i = 0; i < wr->mouse_cnt; ++i)
    {
+      /* Clear buttons when not focused */
+      if (!winraw_focus)
+         g_mice[i].flags = 0;
+
       wr->mice[i].x       = g_mice[i].x;
       wr->mice[i].y       = g_mice[i].y;
       wr->mice[i].dlt_x   = InterlockedExchange(&g_mice[i].dlt_x, 0);
@@ -988,8 +995,8 @@ bool winraw_handle_message(UINT msg,
 static void winraw_free(void *data)
 {
    RAWINPUTDEVICE rid;
-   settings_t *settings = config_get_ptr();
-   winraw_input_t *wr   = (winraw_input_t*)data;
+   winraw_input_t *wr         = (winraw_input_t*)data;
+   bool input_nowinkey_enable = config_get_ptr()->bools.input_nowinkey_enable;
 
    rid.dwFlags          = RIDEV_REMOVE;
    rid.hwndTarget       = NULL;
@@ -1002,7 +1009,7 @@ static void winraw_free(void *data)
    rid.hwndTarget       = NULL;
    rid.usUsagePage      = 0x01; /* Generic desktop */
    rid.usUsage          = 0x06; /* Keyboard */
-   if (settings->bools.input_nowinkey_enable)
+   if (input_nowinkey_enable)
       rid.dwFlags      |= RIDEV_NOHOTKEYS; /* Disable win keys while focused */
 
    RegisterRawInputDevices(&rid, 1, sizeof(RAWINPUTDEVICE));
