@@ -15,6 +15,8 @@
  */
 
 #include <stdlib.h>
+#include <unistd.h>
+#include <malloc.h>
 
 #include <gccore.h>
 #include <rthreads/rthreads.h>
@@ -120,21 +122,21 @@ static int32_t wiiusb_hid_read_cb(int32_t size, void *data)
 }
 
 static void wiiusb_hid_device_send_control(void *data,
-      uint8_t* data_buf, size_t size)
+      uint8_t *s, size_t len)
 {
    uint8_t control_type;
    struct wiiusb_adapter *adapter = (struct wiiusb_adapter*)data;
-   if (!adapter || !data_buf || !adapter->send_control_buffer)
+   if (!adapter || !s || !adapter->send_control_buffer)
       return;
 
    /* first byte contains the type of control to use
     * which can be NONE, INT_MSG, CTRL_MSG, CTRL_MSG2 */
-   control_type = data_buf[0];
+   control_type               = s[0];
    /* decrement size by one as we are getting rid of first byte */
-   adapter->send_control_size = size - 1;
+   adapter->send_control_size = len - 1;
    /* increase the buffer address so we access the actual data */
-   data_buf++;
-   memcpy(adapter->send_control_buffer, data_buf,  adapter->send_control_size);
+   s++;
+   memcpy(adapter->send_control_buffer, s, adapter->send_control_size);
    /* Activate it so it can be processed in the adapter thread */
    adapter->send_control_type = control_type;
 }
@@ -143,20 +145,15 @@ static void wiiusb_hid_device_add_autodetect(unsigned idx,
       const char *device_name, const char *driver_name,
       uint16_t dev_vid, uint16_t dev_pid)
 {
-   input_autoconfigure_connect(
-         device_name,
-         NULL,
-         "hid",
-         idx,
-         dev_vid,
-         dev_pid);
+   input_autoconfigure_connect(device_name, NULL, NULL, "hid",
+         idx, dev_vid, dev_pid);
 }
 
 static void wiiusb_get_description(usb_device_entry *device,
       struct wiiusb_adapter *adapter, usb_devdesc *devdesc)
 {
-   unsigned char c;
    unsigned i, k;
+   unsigned char c;
 
    for (c = 0; c < devdesc->bNumConfigurations; c++)
    {
@@ -284,13 +281,13 @@ static int wiiusb_hid_add_adapter(void *data, usb_device_entry *dev)
    if (!hid)
    {
       free(adapter);
-      RARCH_ERR("Allocation of adapter failed.\n");
+      RARCH_ERR("[wiiusb] Allocation of adapter failed.\n");
       return -1;
    }
 
    if (USB_OpenDevice(dev->device_id, dev->vid, dev->pid, &adapter->handle) < 0)
    {
-      RARCH_ERR("Error opening device 0x%p (VID/PID: %04x:%04x).\n",
+      RARCH_ERR("[wiiusb] Error opening device 0x%p (VID/PID: %04x:%04x).\n",
            dev->device_id, dev->vid, dev->pid);
       free(adapter);
       return -1;
@@ -304,7 +301,7 @@ static int wiiusb_hid_add_adapter(void *data, usb_device_entry *dev)
 
    if (adapter->endpoint_in == 0)
    {
-      RARCH_ERR("Could not find HID config for device.\n");
+      RARCH_ERR("[wiiusb] Could not find HID config for device.\n");
       goto error;
    }
 
@@ -314,7 +311,7 @@ static int wiiusb_hid_add_adapter(void *data, usb_device_entry *dev)
 
    if (!adapter->send_control_buffer)
    {
-      RARCH_ERR("Error creating send control buffer.\n");
+      RARCH_ERR("[wiiusb] Error creating send control buffer.\n");
       goto error;
    }
 
@@ -329,7 +326,7 @@ static int wiiusb_hid_add_adapter(void *data, usb_device_entry *dev)
 
    if (!pad_connection_has_interface(hid->connections, adapter->slot))
    {
-      RARCH_ERR(" Interface not found.\n");
+      RARCH_ERR("[wiiusb] Interface not found.\n");
       goto error;
    }
 
@@ -341,9 +338,9 @@ static int wiiusb_hid_add_adapter(void *data, usb_device_entry *dev)
    /*  Get the name from the interface */
    device_name = wiiusb_hid_joypad_name(hid, adapter->slot);
 
-   RARCH_LOG("Interface found: [%s].\n", device_name);
+   RARCH_LOG("[wiiusb] Interface found: \"%s\".\n", device_name);
 
-   RARCH_LOG("Device 0x%p attached (VID/PID: %04x:%04x).\n",
+   RARCH_LOG("[wiiusb] Device 0x%p attached (VID/PID: %04x:%04x).\n",
          adapter->device_id, desc.idVendor, desc.idProduct);
 
    wiiusb_hid_device_add_autodetect(adapter->slot,
@@ -629,7 +626,7 @@ static void *wiiusb_hid_init(void)
 
    if (!hid->poll_thread)
    {
-      RARCH_ERR("Error initializing poll thread.\n");
+      RARCH_ERR("[wiiusb] Error initializing poll thread.\n");
       goto error;
    }
 
