@@ -65,7 +65,7 @@ static int16_t hid_joypad_state(
       const struct retro_keybind *binds,
       unsigned port)
 {
-   unsigned i;
+   int i;
    int16_t ret                          = 0;
    uint16_t port_idx                    = joypad_info->joy_idx;
 
@@ -83,7 +83,7 @@ static int16_t hid_joypad_state(
                port_idx, (uint16_t)joykey))
          ret |= ( 1 << i);
       else if (joyaxis != AXIS_NONE &&
-            ((float)abs(hid_joypad_axis(port_idx, joyaxis)) 
+            ((float)abs(hid_joypad_axis(port_idx, joyaxis))
              / 0x8000) > joypad_info->axis_threshold)
          ret |= (1 << i);
    }
