@@ -27,6 +27,9 @@
 #include "../../tasks/tasks_internal.h"
 #include "../../verbosity.h"
 
+#define SDL_SUPPORTS_RUMBLE  SDL_VERSION_ATLEAST(2, 0, 9)
+#define SDL_SUPPORTS_SENSORS SDL_VERSION_ATLEAST(2, 0, 14)
+
 typedef struct _sdl_joypad
 {
    SDL_Joystick *joypad;
@@ -119,7 +122,7 @@ static void sdl_pad_connect(unsigned id)
 
    if (!success)
    {
-      RARCH_ERR("[SDL]: Couldn't open joystick #%u: %s.\n", id, SDL_GetError());
+      RARCH_ERR("[SDL] Couldn't open joystick #%u: %s.\n", id, SDL_GetError());
 
       if (pad->joypad)
          SDL_JoystickClose(pad->joypad);
@@ -142,7 +145,7 @@ static void sdl_pad_connect(unsigned id)
 #ifdef WEBOS
    if (vendor == 0x9999 && product == 0x9999)
    {
-      RARCH_WARN("[SDL_JOYPAD]: Ignoring pad #%d (vendor: %d; product: %d)\n", id, vendor, product);
+      RARCH_WARN("[SDL] Ignoring pad #%d (vendor: %d; product: %d).\n", id, vendor, product);
       if (pad->joypad)
          SDL_JoystickClose(pad->joypad);
 
@@ -154,7 +157,7 @@ static void sdl_pad_connect(unsigned id)
 
    input_autoconfigure_connect(
          sdl_joypad_name(id),
-         NULL,
+         NULL, NULL,
          sdl_joypad.ident,
          id,
          vendor,
@@ -190,13 +193,13 @@ static void sdl_pad_connect(unsigned id)
    }
 
    pad->haptic    = NULL;
-   
+
    if (g_has_haptic)
    {
       pad->haptic = SDL_HapticOpenFromJoystick(pad->joypad);
 
       if (!pad->haptic)
-         RARCH_WARN("[SDL]: Couldn't open haptic device of the joypad #%u: %s\n",
+         RARCH_WARN("[SDL] Couldn't open haptic device of the joypad #%u: %s.\n",
                id, SDL_GetError());
    }
 
@@ -213,13 +216,14 @@ static void sdl_pad_connect(unsigned id)
       if (SDL_HapticEffectSupported(pad->haptic, &efx) == SDL_FALSE)
       {
          pad->rumble_effect = -2;
-         RARCH_WARN("[SDL]: Device #%u does not support leftright haptic effect.\n", id);
+         RARCH_WARN("[SDL] Device #%u does not support leftright haptic effect.\n", id);
       }
    }
-#if SDL_VERSION_ATLEAST(2, 0, 9)
-   if (!pad->haptic || pad->rumble_effect == -2) {
+#if SDL_SUPPORTS_RUMBLE
+   if (!pad->haptic || pad->rumble_effect == -2)
+   {
       pad->rumble_effect = -3;
-      RARCH_LOG("[SDL]: Falling back to joystick rumble\n");
+      RARCH_LOG("[SDL] Falling back to joystick rumble.\n");
    }
 #endif
 #else
@@ -253,7 +257,7 @@ static void sdl_pad_disconnect(unsigned id)
 
 static void sdl_joypad_destroy(void)
 {
-   unsigned i;
+   int i;
    for (i = 0; i < MAX_USERS; i++)
       sdl_pad_disconnect(i);
 
@@ -262,7 +266,8 @@ static void sdl_joypad_destroy(void)
 
 static void *sdl_joypad_init(void *data)
 {
-   unsigned i, num_sticks;
+   size_t i;
+   unsigned num_sticks;
 #ifdef HAVE_SDL2
    uint32_t subsystem           = SDL_INIT_GAMECONTROLLER;
 #else
@@ -289,15 +294,15 @@ static void *sdl_joypad_init(void *data)
    if ((sdl_subsystem_flags & SDL_INIT_HAPTIC) == 0)
    {
       if (SDL_InitSubSystem(SDL_INIT_HAPTIC) < 0)
-         RARCH_WARN("[SDL]: Failed to initialize haptic device support: %s\n",
+         RARCH_WARN("[SDL] Failed to initialize haptic device support: %s.\n",
                SDL_GetError());
       else
          g_has_haptic = true;
    }
    else
       g_has_haptic = true;
-      
-#if SDL_VERSION_ATLEAST(2, 0, 9)
+
+#if SDL_SUPPORTS_RUMBLE
    /* enable extended hid reports to support ps4/ps5 rumble over bluetooth */
    SDL_SetHint(SDL_HINT_JOYSTICK_HIDAPI_PS4_RUMBLE, "1");
 #endif
@@ -389,7 +394,7 @@ static int16_t sdl_joypad_axis_state(
       if (val < 0)
       {
          /* Clamp - -0x8000 can cause trouble if we later abs() it. */
-         if (val < -0x7fff) 
+         if (val < -0x7fff)
             return -0x7fff;
          return val;
       }
@@ -417,7 +422,7 @@ static int16_t sdl_joypad_state(
       const struct retro_keybind *binds,
       unsigned port)
 {
-   unsigned i;
+   int i;
    int16_t ret                          = 0;
    uint16_t port_idx                    = joypad_info->joy_idx;
    sdl_joypad_t *pad                    = (sdl_joypad_t*)&sdl_pads[port_idx];
@@ -435,12 +440,12 @@ static int16_t sdl_joypad_state(
       const uint32_t joyaxis = (binds[i].joyaxis != AXIS_NONE)
          ? binds[i].joyaxis : joypad_info->auto_binds[i].joyaxis;
       if (
-               (uint16_t)joykey != NO_BTN 
+               (uint16_t)joykey != NO_BTN
             && sdl_joypad_button_state(pad, port_idx, (uint16_t)joykey)
          )
          ret |= ( 1 << i);
       else if (joyaxis != AXIS_NONE &&
-            ((float)abs(sdl_joypad_axis_state(pad, port_idx, joyaxis)) 
+            ((float)abs(sdl_joypad_axis_state(pad, port_idx, joyaxis))
              / 0x8000) > joypad_info->axis_threshold)
          ret |= (1 << i);
    }
@@ -502,12 +507,12 @@ static bool sdl_joypad_set_rumble(unsigned pad, enum retro_rumble_effect effect,
          return false;
    }
 
-#if SDL_VERSION_ATLEAST(2, 0, 9)
+#if SDL_SUPPORTS_RUMBLE
    if (joypad->rumble_effect == -3)
    {
       if (SDL_JoystickRumble(joypad->joypad, efx.leftright.large_magnitude, efx.leftright.small_magnitude, efx.leftright.length) == -1)
       {
-         RARCH_WARN("[SDL]: Failed to rumble joypad %u: %s\n",
+         RARCH_WARN("[SDL] Failed to rumble joypad %u: %s.\n",
                     pad, SDL_GetError());
          joypad->rumble_effect = -2;
          return false;
@@ -523,7 +528,7 @@ static bool sdl_joypad_set_rumble(unsigned pad, enum retro_rumble_effect effect,
       joypad->rumble_effect = SDL_HapticNewEffect(joypad->haptic, &efx);
       if (joypad->rumble_effect < 0)
       {
-         RARCH_WARN("[SDL]: Failed to create rumble effect for joypad %u: %s\n",
+         RARCH_WARN("[SDL] Failed to create rumble effect for joypad %u: %s.\n",
                     pad, SDL_GetError());
          joypad->rumble_effect = -2;
          return false;
@@ -537,7 +542,7 @@ static bool sdl_joypad_set_rumble(unsigned pad, enum retro_rumble_effect effect,
 
    if (SDL_HapticRunEffect(joypad->haptic, joypad->rumble_effect, 1) < 0)
    {
-      RARCH_WARN("[SDL]: Failed to set rumble effect on joypad %u: %s\n",
+      RARCH_WARN("[SDL] Failed to set rumble effect on joypad %u: %s.\n",
                           pad, SDL_GetError());
       return false;
    }
@@ -546,6 +551,85 @@ static bool sdl_joypad_set_rumble(unsigned pad, enum retro_rumble_effect effect,
 }
 #endif
 
+static bool sdl_joypad_set_sensor_state(unsigned pad, enum retro_sensor_action action, unsigned rate)
+{
+   sdl_joypad_t *joypad = (sdl_joypad_t*)&sdl_pads[pad];
+   (void)joypad; /* maybe unused */
+
+   switch (action)
+   {
+#if SDL_SUPPORTS_SENSORS
+      case RETRO_SENSOR_GYROSCOPE_DISABLE:
+      case RETRO_SENSOR_GYROSCOPE_ENABLE:
+         if (SDL_GameControllerHasSensor(joypad->controller, SDL_SENSOR_GYRO))
+            return !SDL_GameControllerSetSensorEnabled(joypad->controller, SDL_SENSOR_GYRO,
+                  (SDL_bool)(action == RETRO_SENSOR_GYROSCOPE_ENABLE));
+         else
+            return false;
+
+      case RETRO_SENSOR_ACCELEROMETER_DISABLE:
+      case RETRO_SENSOR_ACCELEROMETER_ENABLE:
+         if (SDL_GameControllerHasSensor(joypad->controller, SDL_SENSOR_ACCEL))
+            return !SDL_GameControllerSetSensorEnabled(joypad->controller, SDL_SENSOR_ACCEL,
+                  (SDL_bool)(action == RETRO_SENSOR_ACCELEROMETER_ENABLE));
+         else
+            return false;
+#endif
+
+      default:
+         return false;
+   }
+   return false;
+}
+
+static bool sdl_joypad_get_sensor_input(unsigned pad, unsigned id, float *value)
+{
+#if SDL_SUPPORTS_SENSORS
+   sdl_joypad_t *joypad = (sdl_joypad_t*)&sdl_pads[pad];
+   SDL_SensorType sensor_type;
+   float sensor_data[3];
+
+   if (!joypad->controller)
+      return false;
+
+   if ((id >= RETRO_SENSOR_ACCELEROMETER_X) && (id <= RETRO_SENSOR_ACCELEROMETER_Z))
+      sensor_type = SDL_SENSOR_ACCEL;
+   else if ((id >= RETRO_SENSOR_GYROSCOPE_X) && (id <= RETRO_SENSOR_GYROSCOPE_Z))
+      sensor_type = SDL_SENSOR_GYRO;
+   else
+      return false;
+
+   if (SDL_GameControllerGetSensorData(joypad->controller, sensor_type, sensor_data, 3) < 0)
+      return false;
+
+   switch (id)
+   {
+      case RETRO_SENSOR_ACCELEROMETER_X:
+         *value = sensor_data[0] / SDL_STANDARD_GRAVITY;
+         break;
+      case RETRO_SENSOR_ACCELEROMETER_Y:
+         *value = sensor_data[2] / SDL_STANDARD_GRAVITY;
+         break;
+      case RETRO_SENSOR_ACCELEROMETER_Z:
+         *value = sensor_data[1] / SDL_STANDARD_GRAVITY;
+         break;
+      case RETRO_SENSOR_GYROSCOPE_X:
+         *value = sensor_data[0];
+         break;
+      case RETRO_SENSOR_GYROSCOPE_Y:
+         *value = -sensor_data[2];
+         break;
+      case RETRO_SENSOR_GYROSCOPE_Z:
+         *value = sensor_data[1];
+         break;
+   }
+
+   return true;
+#else
+   return false;
+#endif
+}
+
 static bool sdl_joypad_query_pad(unsigned pad)
 {
    return pad < MAX_USERS && sdl_pads[pad].joypad;
@@ -563,9 +647,11 @@ input_device_driver_t sdl_joypad = {
 #ifdef HAVE_SDL2
    sdl_joypad_set_rumble,
 #else
-   NULL,
+   NULL, /* set_rumble */
 #endif
-   NULL,
+   NULL, /* set_rumble_gain */
+   sdl_joypad_set_sensor_state,
+   sdl_joypad_get_sensor_input,
    sdl_joypad_name,
 #ifdef HAVE_SDL2
    "sdl2",
