@@ -90,6 +90,10 @@ static XINPUT_FEEDBACK     g_xinput_rumble_states[4];
 static XINPUT_VIBRATION    g_xinput_rumble_states[4];
 #endif
 static xinput_joypad_state g_xinput_states[4];
+static bool xinput_active_port[4] = {0};
+
+static unsigned xinput_hotplug_index = 0;
+static unsigned xinput_poll_counter = 0;
 
 /* Buttons are provided by XInput as bits of a uint16.
  * Map from rarch button index (0..10) to a mask to
@@ -123,7 +127,8 @@ static bool guid_is_xinput_device(const GUID* product_guid)
       {MAKELONG(0x045E, 0x02A1),0x0000,0x0000,{0x00,0x00,0x50,0x49,0x44,0x56,0x49,0x44}}, /* Wired 360 pad */
       {MAKELONG(0x045E, 0x028E),0x0000,0x0000,{0x00,0x00,0x50,0x49,0x44,0x56,0x49,0x44}}  /* wireless 360 pad */
    };
-   unsigned i, num_raw_devs     = 0;
+   size_t i;
+   unsigned num_raw_devs        = 0;
    PRAWINPUTDEVICELIST raw_devs = NULL;
 
    /* Check for well known XInput device GUIDs,
@@ -135,8 +140,8 @@ static bool guid_is_xinput_device(const GUID* product_guid)
 
    for (i = 0; i < ARRAY_SIZE(common_xinput_guids); ++i)
    {
-      if (string_is_equal_fast(product_guid,
-               &common_xinput_guids[i], sizeof(GUID)))
+      if (memcmp(product_guid,
+               &common_xinput_guids[i], sizeof(GUID)) == 0)
          return true;
    }
 
@@ -309,6 +314,7 @@ static BOOL CALLBACK enum_joypad_cb_hybrid(
       input_autoconfigure_connect(
             g_pads[g_joypad_cnt].joy_name,
             g_pads[g_joypad_cnt].joy_friendly_name,
+            NULL,
             dinput_joypad.ident,
             g_joypad_cnt,
             g_pads[g_joypad_cnt].vid,
@@ -322,7 +328,7 @@ enum_iteration_done:
 
 static void dinput_joypad_init_hybrid(void *data)
 {
-   unsigned i;
+   int i;
 
    g_last_xinput_pad_idx = 0;
 
@@ -348,7 +354,7 @@ static const char *xinput_joypad_name(unsigned pad)
 
 static void *xinput_joypad_init(void *data)
 {
-   unsigned i, j;
+   int i, j;
    XINPUT_STATE dummy_state;
 
 #if defined(HAVE_DYLIB) && !defined(__WINRT__)
@@ -384,14 +390,14 @@ static void *xinput_joypad_init(void *data)
 
       if (!g_XInputGetStateEx)
       {
-         RARCH_ERR("[XInput]: Failed to init: DLL is invalid or corrupt.\n");
+         RARCH_ERR("[XInput] Failed to init: DLL is invalid or corrupt.\n");
 #if defined(HAVE_DYLIB) && !defined(__WINRT__)
          dylib_close(g_xinput_dll);
 #endif
          /* DLL was loaded but did not contain the correct function. */
          goto error;
       }
-      RARCH_WARN("[XInput]: No guide button support.\n");
+      RARCH_WARN("[XInput] No guide button support.\n");
    }
 
 #if defined(HAVE_DYLIB) && !defined(__WINRT__)
@@ -402,7 +408,7 @@ static void *xinput_joypad_init(void *data)
 #endif
    if (!g_XInputSetState)
    {
-      RARCH_ERR("[XInput]: Failed to init: DLL is invalid or corrupt.\n");
+      RARCH_ERR("[XInput] Failed to init: DLL is invalid or corrupt.\n");
 #if defined(HAVE_DYLIB) && !defined(__WINRT__)
       dylib_close(g_xinput_dll);
 #endif
@@ -424,6 +430,9 @@ static void *xinput_joypad_init(void *data)
          !(g_XInputGetStateEx(i, &dummy_state) == ERROR_DEVICE_NOT_CONNECTED);
    }
 
+   for (i = 0; i < 4; ++i)
+      xinput_active_port[i] = false;
+
    if (  (!g_xinput_states[0].connected) &&
          (!g_xinput_states[1].connected) &&
          (!g_xinput_states[2].connected) &&
@@ -457,11 +466,14 @@ static void *xinput_joypad_init(void *data)
          int32_t dinput_index = 0;
          bool success         = dinput_joypad_get_vidpid_from_xinput_index((int32_t)PAD_INDEX_TO_XUSER_INDEX(j), (int32_t*)&vid, (int32_t*)&pid,
 			 (int32_t*)&dinput_index);
+
          /* On success, found VID/PID from dinput index */
+         if (!success)
+            continue;
 
          input_autoconfigure_connect(
                name,
-               NULL,
+               NULL, NULL,
                xinput_joypad.ident,
                j,
                vid,
@@ -469,6 +481,13 @@ static void *xinput_joypad_init(void *data)
       }
    }
 
+   for (i = 0; i < MAX_USERS; ++i)
+   {
+      int xuser = PAD_INDEX_TO_XUSER_INDEX(i);
+      if (xuser >= 0 && xuser < 4)
+         xinput_active_port[xuser] = true;
+   }
+
 #ifdef __WINRT__
 succeeded:
 #endif
@@ -522,7 +541,7 @@ static int16_t xinput_joypad_state_func(
       const struct retro_keybind *binds,
       unsigned port)
 {
-   unsigned i;
+   int i;
    uint16_t btn_word;
    int16_t ret                = 0;
    uint16_t port_idx          = joypad_info->joy_idx;
@@ -558,14 +577,68 @@ static int16_t xinput_joypad_state_func(
 
 static void xinput_joypad_poll(void)
 {
-   unsigned i;
+   int i;
+#ifdef __WINRT__
+   bool has_active_ports = false;
+#endif
+   
+   /* Hotplugging detection: scanning one port at a time every few frames,
+    * to avoid polling overload and framerate drops. */
+   xinput_poll_counter++;
+   if (xinput_poll_counter >= 15)
+   {
+      xinput_poll_counter = 0;
+      if (!xinput_active_port[xinput_hotplug_index])
+      {
+         XINPUT_STATE tmp_state;
+         DWORD result = g_XInputGetStateEx(xinput_hotplug_index, &tmp_state);
+         if (result == ERROR_SUCCESS)
+         {
+            const char *name = xinput_joypad_name(xinput_hotplug_index);
+            int32_t vid = 0;
+            int32_t pid = 0;
+            input_autoconfigure_connect(
+               name,
+               NULL, NULL,
+               xinput_joypad.ident,
+               xinput_hotplug_index,
+               vid,
+               pid);
+
+            xinput_active_port[xinput_hotplug_index] = true;
+         }
+      }
+         xinput_hotplug_index = (xinput_hotplug_index + 1) % 4;
+   }
+
+#ifdef __WINRT__
+   for (i = 0; i < 4; ++i)
+   {
+      if (xinput_active_port[i])
+         has_active_ports = true;
+   }
+#endif
 
    for (i = 0; i < 4; ++i)
    {
-      xinput_joypad_state *state = &g_xinput_states[i];
-      DWORD status               = g_XInputGetStateEx(i, &state->xstate);
-      bool success               = (status == ERROR_SUCCESS);
-      bool new_connected         = (status != ERROR_DEVICE_NOT_CONNECTED);
+      DWORD status;
+      bool success, new_connected;
+      xinput_joypad_state *state;
+       /* On UWP, controllers may become available after initialization.
+       * If no ports are currently active, we need to poll all ports
+       * to catch any late arriving controllers. */
+#ifdef __WINRT__
+      if (!xinput_active_port[i] && has_active_ports)
+         continue;
+#else
+      if (!xinput_active_port[i])
+         continue;
+#endif
+
+      state         = &g_xinput_states[i];
+      status        = g_XInputGetStateEx(i, &state->xstate);
+      success       = (status == ERROR_SUCCESS);
+      new_connected = (status != ERROR_DEVICE_NOT_CONNECTED);
       if (new_connected != state->connected)
       {
          state->connected = new_connected;
@@ -641,27 +714,32 @@ static void xinput_joypad_poll(void)
 static bool xinput_joypad_rumble(unsigned pad,
       enum retro_rumble_effect effect, uint16_t strength)
 {
+   XINPUT_VIBRATION *state, prev;
    int xuser = PAD_INDEX_TO_XUSER_INDEX(pad);
 
    if (xuser == -1)
       return dinput_joypad_set_rumble(pad, effect, strength);
 
+   state = &g_xinput_rumble_states[xuser];
+   prev  = *state;
+
    /* Consider the low frequency (left) motor the "strong" one. */
    if (effect == RETRO_RUMBLE_STRONG)
-      g_xinput_rumble_states[xuser].wLeftMotorSpeed  = strength;
+      state->wLeftMotorSpeed  = strength;
    else if (effect == RETRO_RUMBLE_WEAK)
-      g_xinput_rumble_states[xuser].wRightMotorSpeed = strength;
+      state->wRightMotorSpeed = strength;
 
-   if (!g_XInputSetState)
-      return false;
+   /* Rumble state unchanged? */
+   if (   (state->wLeftMotorSpeed  == prev.wLeftMotorSpeed)
+       && (state->wRightMotorSpeed == prev.wRightMotorSpeed))
+      return true;
 
-   return (g_XInputSetState(xuser, &g_xinput_rumble_states[xuser])
-      == 0);
+   return g_XInputSetState && (g_XInputSetState(xuser, state) == ERROR_SUCCESS);
 }
 
 static void xinput_joypad_destroy(void)
 {
-   unsigned i;
+   int i;
 
    for (i = 0; i < 4; ++i)
    {
