@@ -71,6 +71,10 @@ static XINPUT_FEEDBACK     g_xinput_rumble_states[4];
 static XINPUT_VIBRATION    g_xinput_rumble_states[4];
 #endif
 static xinput_joypad_state g_xinput_states[4];
+static bool xinput_active_port[4] = {0};
+
+static unsigned xinput_hotplug_index = 0;
+static unsigned xinput_poll_counter  = 0;
 
 /* Buttons are provided by XInput as bits of a uint16.
  * Map from rarch button index (0..10) to a mask to
@@ -118,7 +122,7 @@ static const char *xinput_joypad_name(unsigned pad)
 
 static void *xinput_joypad_init(void *data)
 {
-   unsigned i, j;
+   int i, j;
    XINPUT_STATE dummy_state;
 
 #if defined(HAVE_DYLIB) && !defined(__WINRT__)
@@ -141,7 +145,7 @@ static void *xinput_joypad_init(void *data)
 
    if (!g_XInputGetStateEx)
    {
-      /* no ordinal 100. (Presumably a wrapper.) Load the ordinary
+      /* No ordinal 100. (Presumably a wrapper.) Load the ordinary
        * XInputGetState, at the cost of losing guide button support.
        */
       g_xinput_guide_button_supported = false;
@@ -154,14 +158,14 @@ static void *xinput_joypad_init(void *data)
 
       if (!g_XInputGetStateEx)
       {
-         RARCH_ERR("[XInput]: Failed to init: DLL is invalid or corrupt.\n");
+         RARCH_ERR("[XInput] Failed to init: DLL is invalid or corrupt.\n");
 #if defined(HAVE_DYLIB) && !defined(__WINRT__)
          dylib_close(g_xinput_dll);
 #endif
          /* DLL was loaded but did not contain the correct function. */
          goto error;
       }
-      RARCH_WARN("[XInput]: No guide button support.\n");
+      RARCH_WARN("[XInput] No guide button support.\n");
    }
 
 #if defined(HAVE_DYLIB) && !defined(__WINRT__)
@@ -172,7 +176,7 @@ static void *xinput_joypad_init(void *data)
 #endif
    if (!g_XInputSetState)
    {
-      RARCH_ERR("[XInput]: Failed to init: DLL is invalid or corrupt.\n");
+      RARCH_ERR("[XInput] Failed to init: DLL is invalid or corrupt.\n");
 #if defined(HAVE_DYLIB) && !defined(__WINRT__)
       dylib_close(g_xinput_dll);
 #endif
@@ -194,16 +198,19 @@ static void *xinput_joypad_init(void *data)
          !(g_XInputGetStateEx(i, &dummy_state) == ERROR_DEVICE_NOT_CONNECTED);
    }
 
-   if (  (!g_xinput_states[0].connected) &&
-         (!g_xinput_states[1].connected) &&
-         (!g_xinput_states[2].connected) &&
-         (!g_xinput_states[3].connected))
+   if (     (!g_xinput_states[0].connected)
+         && (!g_xinput_states[1].connected)
+         && (!g_xinput_states[2].connected)
+         && (!g_xinput_states[3].connected))
 #ifdef __WINRT__
       goto succeeded;
 #else
       goto error;
 #endif
 
+   for (i = 0; i < 4; ++i)
+      xinput_active_port[i] = false;
+
    for (j = 0; j < MAX_USERS; j++)
    {
       const char *name = xinput_joypad_name(j);
@@ -215,7 +222,7 @@ static void *xinput_joypad_init(void *data)
          int32_t pid          = 0;
          input_autoconfigure_connect(
                name,
-               NULL,
+               NULL, NULL,
                xinput_joypad.ident,
                j,
                vid,
@@ -223,6 +230,13 @@ static void *xinput_joypad_init(void *data)
       }
    }
 
+   for (i = 0; i < MAX_USERS; ++i)
+   {
+      int xuser = pad_index_to_xuser_index(i);
+      if (xuser >= 0 && xuser < 4)
+         xinput_active_port[xuser] = true;
+   }
+
 #ifdef __WINRT__
 succeeded:
 #endif
@@ -248,7 +262,7 @@ static bool xinput_joypad_query_pad(unsigned pad)
 
 static void xinput_joypad_destroy(void)
 {
-   unsigned i;
+   int i;
 
    for (i = 0; i < 4; ++i)
    {
@@ -298,7 +312,7 @@ static int16_t xinput_joypad_state_func(
       const struct retro_keybind *binds,
       unsigned port)
 {
-   unsigned i;
+   int i;
    uint16_t btn_word;
    int16_t ret                = 0;
    uint16_t port_idx          = joypad_info->joy_idx;
@@ -332,15 +346,69 @@ static int16_t xinput_joypad_state_func(
 
 static void xinput_joypad_poll(void)
 {
-   unsigned i;
+   int i;
+#ifdef __WINRT__
+   bool has_active_ports = false;
+#endif
+
+   /* Hotplugging detection: scanning one port at a time every few frames,
+    * to avoid polling overload and framerate drops. */
+   xinput_poll_counter++;
+   if (xinput_poll_counter >= 15)
+   {
+      xinput_poll_counter = 0;
+      if (!xinput_active_port[xinput_hotplug_index])
+      {
+         XINPUT_STATE tmp_state;
+         DWORD result = g_XInputGetStateEx(xinput_hotplug_index, &tmp_state);
+         if (result == ERROR_SUCCESS)
+         {
+            const char *name = xinput_joypad_name(xinput_hotplug_index);
+            int32_t vid = 0;
+            int32_t pid = 0;
+            input_autoconfigure_connect(
+                  name,
+                  NULL, NULL,
+                  xinput_joypad.ident,
+                  xinput_hotplug_index,
+                  vid,
+                  pid);
+
+            xinput_active_port[xinput_hotplug_index] = true;
+         }
+      }
+      xinput_hotplug_index = (xinput_hotplug_index + 1) % 4;
+   }
+
+#ifdef __WINRT__
+   for (i = 0; i < 4; ++i)
+   {
+      if (xinput_active_port[i])
+         has_active_ports = true;
+   }
+#endif
 
    for (i = 0; i < 4; ++i)
    {
-      xinput_joypad_state
-         *state          = &g_xinput_states[i];
-      DWORD status       = g_XInputGetStateEx(i, &state->xstate);
-      bool success       = status == ERROR_SUCCESS;
-      bool new_connected = status != ERROR_DEVICE_NOT_CONNECTED;
+      DWORD status;
+      bool success, new_connected;
+      xinput_joypad_state *state;
+      /* On UWP, controllers may become available after initialization.
+       * If no ports are currently active, we need to poll all ports
+       * to catch any late arriving controllers. */
+#ifdef __WINRT__
+      if (!xinput_active_port[i] && has_active_ports)
+         continue;
+#else
+      if (!xinput_active_port[i])
+         continue;
+#endif
+
+      state          = &g_xinput_states[i];
+      status         = g_XInputGetStateEx(i, &state->xstate);
+      success        = status == ERROR_SUCCESS;
+      new_connected  = status != ERROR_DEVICE_NOT_CONNECTED;
+
       if (new_connected != state->connected)
       {
          /* Normally, dinput handles device insertion/removal for us, but
@@ -366,22 +434,27 @@ static void xinput_joypad_poll(void)
 static bool xinput_joypad_rumble(unsigned pad,
       enum retro_rumble_effect effect, uint16_t strength)
 {
+   XINPUT_VIBRATION *state, prev;
    int xuser = pad_index_to_xuser_index(pad);
 
    if (xuser == -1)
       return false;
 
+   state = &g_xinput_rumble_states[xuser];
+   prev  = *state;
+
    /* Consider the low frequency (left) motor the "strong" one. */
    if (effect == RETRO_RUMBLE_STRONG)
-      g_xinput_rumble_states[xuser].wLeftMotorSpeed = strength;
+      state->wLeftMotorSpeed  = strength;
    else if (effect == RETRO_RUMBLE_WEAK)
-      g_xinput_rumble_states[xuser].wRightMotorSpeed = strength;
+      state->wRightMotorSpeed = strength;
 
-   if (!g_XInputSetState)
-      return false;
+   /* Rumble state unchanged? */
+   if (   (state->wLeftMotorSpeed  == prev.wLeftMotorSpeed)
+       && (state->wRightMotorSpeed == prev.wRightMotorSpeed))
+      return true;
 
-   return (g_XInputSetState(xuser, &g_xinput_rumble_states[xuser])
-      == 0);
+   return g_XInputSetState && (g_XInputSetState(xuser, state) == ERROR_SUCCESS);
 }
 
 input_device_driver_t xinput_joypad = {
