@@ -34,6 +34,7 @@
 #define RARCH_FIRST_META_KEY           RARCH_CUSTOM_BIND_LIST_END
 
 #define RARCH_UNMAPPED                 1024
+#define RARCH_NO_BIND                  "---"
 
 /* Specialized _MOUSE that targets the full screen regardless of viewport.
  */
@@ -147,6 +148,9 @@ enum
    RARCH_PLAY_REPLAY_KEY,
    RARCH_RECORD_REPLAY_KEY,
    RARCH_HALT_REPLAY_KEY,
+   RARCH_SAVE_REPLAY_CHECKPOINT_KEY,
+   RARCH_PREV_REPLAY_CHECKPOINT_KEY,
+   RARCH_NEXT_REPLAY_CHECKPOINT_KEY,
    RARCH_REPLAY_SLOT_PLUS,
    RARCH_REPLAY_SLOT_MINUS,
 
@@ -155,6 +159,7 @@ enum
    RARCH_DISK_PREV,
 
    RARCH_SHADER_TOGGLE,
+   RARCH_SHADER_HOLD,
    RARCH_SHADER_NEXT,
    RARCH_SHADER_PREV,
 
@@ -166,6 +171,7 @@ enum
    RARCH_RECORDING_TOGGLE,
    RARCH_STREAMING_TOGGLE,
 
+   RARCH_TURBO_FIRE_TOGGLE,
    RARCH_GRAB_MOUSE_TOGGLE,
    RARCH_GAME_FOCUS_TOGGLE,
    RARCH_FULLSCREEN_TOGGLE_KEY,
@@ -189,9 +195,6 @@ enum
 
    RARCH_BIND_LIST_END,
 
-   /* Deprecated */
-   RARCH_SEND_DEBUG_INFO,
-
    RARCH_BIND_LIST_END_NULL
 };
 
@@ -230,21 +233,6 @@ enum input_turbo_mode
    INPUT_TURBO_MODE_LAST
 };
 
-enum input_turbo_default_button
-{
-   INPUT_TURBO_DEFAULT_BUTTON_B = 0,
-   INPUT_TURBO_DEFAULT_BUTTON_Y,
-   INPUT_TURBO_DEFAULT_BUTTON_A,
-   INPUT_TURBO_DEFAULT_BUTTON_X,
-   INPUT_TURBO_DEFAULT_BUTTON_L,
-   INPUT_TURBO_DEFAULT_BUTTON_R,
-   INPUT_TURBO_DEFAULT_BUTTON_L2,
-   INPUT_TURBO_DEFAULT_BUTTON_R2,
-   INPUT_TURBO_DEFAULT_BUTTON_L3,
-   INPUT_TURBO_DEFAULT_BUTTON_R3,
-   INPUT_TURBO_DEFAULT_BUTTON_LAST
-};
-
 enum input_device_reservation_type
 {
   INPUT_DEVICE_RESERVATION_NONE = 0,
