@@ -32,6 +32,10 @@
 #include "../config.h"
 #endif /* HAVE_CONFIG_H */
 
+#if defined(_WIN32) && !defined(SOCKET)
+#include <winsock2.h>
+#endif
+
 #include "input_defines.h"
 #include "input_types.h"
 #ifdef HAVE_OVERLAY
@@ -52,6 +56,10 @@
 #include "../command.h"
 #endif
 
+#ifdef HAVE_BSV_MOVIE
+#include "bsv/uint32s_index.h"
+#endif
+
 #if defined(ANDROID)
 #define DEFAULT_MAX_PADS 8
 #define ANDROID_KEYBOARD_PORT DEFAULT_MAX_PADS
@@ -92,6 +100,8 @@
 #define DEFAULT_MAX_PADS 4
 #elif defined(DINGUX)
 #define DEFAULT_MAX_PADS 2
+#elif defined(EMSCRIPTEN)
+#define DEFAULT_MAX_PADS 4
 #else
 #define DEFAULT_MAX_PADS 16
 #endif /* defined(ANDROID) */
@@ -100,11 +110,35 @@
 #define MAPPER_SET_KEY(state, key) (state)->keys[(key) / 32] |= 1 << ((key) % 32)
 #define MAPPER_UNSET_KEY(state, key) (state)->keys[(key) / 32] &= ~(1 << ((key) % 32))
 
-#define INHERIT_JOYAXIS(binds) (((binds)[x_plus].joyaxis == (binds)[x_minus].joyaxis) || (  (binds)[y_plus].joyaxis == (binds)[y_minus].joyaxis))
-
+/*
+  INVALID: should never arise.
+  REGULAR: just key and button inputs, nothing else
+  CHECKPOINT: an 8-byte size and serialized raw state follow the actions.
+  CHECKPOINT2: a state follows the actions, but it is encoded and/or
+               compressed in some way. The next two bytes are the compression
+               type and the encoding type, followed by the 4-byte uncompressed,
+               unencoded size; the 4-byte uncompressed, encoded size; the 4-byte
+               compressed, encoeded, size; and the compressed, encoded data.
+               If either the encoding or the compression codec are not supported,
+               the checkpoint will be skipped.
+ */
 #define REPLAY_TOKEN_INVALID          '\0'
-#define REPLAY_TOKEN_REGULAR_FRAME    'f'
-#define REPLAY_TOKEN_CHECKPOINT_FRAME 'c'
+#define REPLAY_TOKEN_REGULAR_FRAME     'f'
+#define REPLAY_TOKEN_CHECKPOINT_FRAME  'c'
+#define REPLAY_TOKEN_CHECKPOINT2_FRAME 'C'
+
+/* Which compression codec to use. */
+#define REPLAY_CHECKPOINT2_COMPRESSION_NONE 0
+#define REPLAY_CHECKPOINT2_COMPRESSION_ZLIB 1
+#define REPLAY_CHECKPOINT2_COMPRESSION_ZSTD 2
+
+/* Which encoding to use.
+   RAW: Just raw checkpoint data, possibly compressed.
+   STATESTREAM: Incremental, block-deduplicated encoding per
+             https://github.com/sumitshetye2/v86_savestreams
+*/
+#define REPLAY_CHECKPOINT2_ENCODING_RAW 0
+#define REPLAY_CHECKPOINT2_ENCODING_STATESTREAM 1
 
 /**
  * Takes as input analog key identifiers and converts them to corresponding
@@ -153,11 +187,11 @@ enum input_driver_state_flags
    INP_FLAG_BLOCK_LIBRETRO_INPUT     = (1 << 4),
    INP_FLAG_BLOCK_POINTER_INPUT      = (1 << 5),
    INP_FLAG_GRAB_MOUSE_STATE         = (1 << 6),
-   INP_FLAG_OLD_ANALOG_DPAD_MODE_SET = (1 << 7),
-   INP_FLAG_OLD_LIBRETRO_DEVICE_SET  = (1 << 8),
-   INP_FLAG_REMAPPING_CACHE_ACTIVE   = (1 << 9),
-   INP_FLAG_DEFERRED_WAIT_KEYS       = (1 << 10),
-   INP_FLAG_WAIT_INPUT_RELEASE       = (1 << 11)
+   INP_FLAG_REMAPPING_CACHE_ACTIVE   = (1 << 7),
+   INP_FLAG_DEFERRED_WAIT_KEYS       = (1 << 8),
+   INP_FLAG_WAIT_INPUT_RELEASE       = (1 << 9),
+   INP_FLAG_MENU_PRESS_PENDING       = (1 << 10),
+   INP_FLAG_MENU_PRESS_CANCEL        = (1 << 11)
 };
 
 #ifdef HAVE_BSV_MOVIE
@@ -168,49 +202,54 @@ enum bsv_flags
    BSV_FLAG_MOVIE_PLAYBACK           = (1 << 2),
    BSV_FLAG_MOVIE_RECORDING          = (1 << 3),
    BSV_FLAG_MOVIE_END                = (1 << 4),
-   BSV_FLAG_MOVIE_EOF_EXIT           = (1 << 5)
+   BSV_FLAG_MOVIE_EOF_EXIT           = (1 << 5),
+   BSV_FLAG_MOVIE_FORCE_CHECKPOINT   = (1 << 6),
+   BSV_FLAG_MOVIE_PREV_CHECKPOINT    = (1 << 7),
+   BSV_FLAG_MOVIE_NEXT_CHECKPOINT    = (1 << 8),
+   BSV_FLAG_MOVIE_SEEK_TO_FRAME      = (1 << 9),
+   BSV_FLAG_MOVIE_SEEKING            = (1 << 10)
 };
 
 struct bsv_state
 {
-   uint8_t flags;
+   uint16_t flags;
    /* Movie playback/recording support. */
    char movie_auto_path[PATH_MAX_LENGTH];
    /* Immediate playback/recording. */
    char movie_start_path[PATH_MAX_LENGTH];
+   /* Target frame/position to seek to next iteration. */
+   int64_t seek_target_frame, seek_target_pos;
 };
 
 /* These data are always little-endian. */
 struct bsv_key_data
 {
-  uint8_t down;
-  uint8_t _padding;
-  uint16_t mod;
-  uint32_t code;
-  uint32_t character;
+   uint8_t down;
+   uint8_t _padding;
+   uint16_t mod;
+   uint32_t code;
+   uint32_t character;
 };
 typedef struct bsv_key_data bsv_key_data_t;
 
 struct bsv_input_data
 {
-  uint8_t port;
-  uint8_t device;
-  uint8_t idx;
-  uint8_t _padding;
-  /* little-endian numbers */
-  uint16_t id;
-  int16_t value;
+   uint8_t port;
+   uint8_t device;
+   uint8_t idx;
+   uint8_t _padding;
+   /* little-endian numbers */
+   uint16_t id;
+   int16_t value;
 };
 typedef struct bsv_input_data bsv_input_data_t;
 
 struct bsv_movie
 {
    intfstream_t *file;
-   uint8_t *state;
    int64_t identifier;
    uint32_t version;
    size_t min_file_pos;
-   size_t state_size;
 
    /* A ring buffer keeping track of positions
     * in the file for each frame. */
@@ -228,9 +267,34 @@ struct bsv_movie
    bool playback;
    bool first_rewind;
    bool did_rewind;
+   bool checkpoint_ready;
+
+#ifdef HAVE_STATESTREAM
+   /* Block index and superblock index for incremental checkpoints */
+   uint32s_index_t *superblocks;
+   uint32s_index_t *blocks;
+   uint32_t *superblock_seq;
+   uint8_t commit_interval, commit_threshold;
+#endif
+
+   uint8_t checkpoint_compression, checkpoint_encoding;
+
+   uint8_t *last_save, *cur_save;
+   size_t last_save_size, cur_save_size;
+
+   bool cur_save_valid;
 };
 
 typedef struct bsv_movie bsv_movie_t;
+
+enum replay_checkpoint_behavior_ {
+   REPLAY_CPBEHAVIOR_SKIP,
+   REPLAY_CPBEHAVIOR_UPDATE,
+   REPLAY_CPBEHAVIOR_DESERIALIZE
+};
+
+typedef enum replay_checkpoint_behavior_ replay_checkpoint_behavior;
+
 #endif
 
 /**
@@ -272,6 +336,7 @@ typedef struct
    char joypad_driver[32];
    char name[128];
    char display_name[128];
+   char phys[NAME_MAX_LENGTH];
    char config_name[NAME_MAX_LENGTH]; /* Base name of the RetroArch config file */
    bool autoconfigured;
 } input_device_info_t;
@@ -288,7 +353,11 @@ struct remote_message
 struct input_remote
 {
 #if defined(HAVE_NETWORKING) && defined(HAVE_NETWORKGAMEPAD)
+#ifdef _WIN32
+   SOCKET net_fd[MAX_USERS];
+#else
    int net_fd[MAX_USERS];
+#endif
 #endif
    bool state[RARCH_BIND_LIST_END];
 };
@@ -480,9 +549,10 @@ struct rarch_joypad_driver
    void (*poll)(void);
    bool (*set_rumble)(unsigned, enum retro_rumble_effect, uint16_t);
    bool (*set_rumble_gain)(unsigned, unsigned);
-   bool (*set_sensor_state)(void *data, unsigned port,
+   bool (*set_sensor_state)(unsigned port,
          enum retro_sensor_action action, unsigned rate);
-   float (*get_sensor_input)(void *data, unsigned port, unsigned id);
+   /* return true if handled; false to fall back to input driver */
+   bool (*get_sensor_input)(unsigned port, unsigned id, float *value);
    const char *(*name)(unsigned);
 
    const char *ident;
@@ -556,10 +626,9 @@ typedef struct
    turbo_buttons_t turbo_btns; /* int32_t alignment */
 
    input_mapper_t mapper;          /* uint32_t alignment */
+   input_remap_cache_t remapping_cache;
    input_device_info_t input_device_info[MAX_INPUT_DEVICES]; /* unsigned alignment */
    input_mouse_info_t input_mouse_info[MAX_INPUT_DEVICES];
-   unsigned old_analog_dpad_mode[MAX_USERS];
-   unsigned old_libretro_device[MAX_USERS];
    unsigned osk_last_codepoint;
    unsigned osk_last_codepoint_len;
    unsigned input_hotkey_block_counter;
@@ -1037,12 +1106,19 @@ void input_overlay_check_mouse_cursor(void);
 #ifdef HAVE_BSV_MOVIE
 void bsv_movie_frame_rewind(void);
 void bsv_movie_next_frame(input_driver_state_t *input_st);
-void bsv_movie_read_next_events(bsv_movie_t*handle);
+bool bsv_movie_read_next_events(bsv_movie_t *handle, replay_checkpoint_behavior checkpoint_behavior, bool end_movie_on_eof);
+bool bsv_movie_reset_playback(bsv_movie_t *handle);
+bool bsv_movie_reset_recording(bsv_movie_t *handle);
 void bsv_movie_finish_rewind(input_driver_state_t *input_st);
 void bsv_movie_deinit(input_driver_state_t *input_st);
 void bsv_movie_deinit_full(input_driver_state_t *input_st);
 void bsv_movie_enqueue(input_driver_state_t *input_st, bsv_movie_t *state, enum bsv_flags flags);
+void bsv_movie_dequeue_next(input_driver_state_t *input_st);
 
+bool movie_commit_checkpoint(input_driver_state_t *input_st);
+bool movie_skip_to_prev_checkpoint(input_driver_state_t *input_st);
+bool movie_skip_to_next_checkpoint(input_driver_state_t *input_st);
+bool movie_seek_to_frame(input_driver_state_t *input_st, int64_t frame);
 bool movie_start_playback(input_driver_state_t *input_st, char *path);
 bool movie_start_record(input_driver_state_t *input_st, char *path);
 bool movie_stop_playback(input_driver_state_t *input_st);
