@@ -68,6 +68,7 @@
 #endif
 
 #ifdef HAVE_DINPUT
+#define WIN32_LEAN_AND_MEAN
 #undef DIRECTINPUT_VERSION
 #define DIRECTINPUT_VERSION 0x0800
 
@@ -221,7 +222,7 @@ const struct input_key_map input_config_key_map[] = {
    { "media", RETROK_LAUNCH_MEDIA },
    { "app1", RETROK_LAUNCH_APP1 },
    { "app2", RETROK_LAUNCH_APP2 },
-   
+
    { "nul", RETROK_UNKNOWN },
    { NULL, RETROK_UNKNOWN },
 };
@@ -1189,7 +1190,7 @@ const struct rarch_key_map rarch_key_map_x11[] = {
    { XFVK_KP0, RETROK_KP0 },
    { XFVK_KPDL, RETROK_KP_PERIOD },
    { XFVK_KPEQ, RETROK_KP_EQUALS },
-   
+
    { XFVK_MUTE, RETROK_VOLUME_MUTE },
    { XFVK_VOUP, RETROK_VOLUME_UP },
    { XFVK_VODN, RETROK_VOLUME_DOWN },
@@ -1394,6 +1395,7 @@ const struct rarch_key_map rarch_key_map_android[] = {
    { AKEYCODE_TAB, RETROK_TAB },
    { AKEYCODE_CLEAR, RETROK_CLEAR },
    { AKEYCODE_ENTER, RETROK_RETURN },
+/*   { AKEYCODE_DPAD_CENTER, RETROK_RETURN }, */ /* Duplicate - skip */
    { AKEYCODE_BREAK, RETROK_PAUSE },
    { AKEYCODE_ESCAPE, RETROK_ESCAPE },
    { AKEYCODE_SPACE, RETROK_SPACE },
@@ -1420,6 +1422,7 @@ const struct rarch_key_map rarch_key_map_android[] = {
    { AKEYCODE_EQUALS, RETROK_EQUALS },
    { AKEYCODE_LEFT_BRACKET, RETROK_LEFTBRACKET },
    { AKEYCODE_BACKSLASH, RETROK_BACKSLASH },
+   /* 102. key can not be mapped, it behaves the same as backslash */
    { AKEYCODE_RIGHT_BRACKET, RETROK_RIGHTBRACKET },
    { AKEYCODE_GRAVE, RETROK_BACKQUOTE },
    { AKEYCODE_A, RETROK_a },
@@ -1490,8 +1493,8 @@ const struct rarch_key_map rarch_key_map_android[] = {
    { AKEYCODE_NUM_LOCK, RETROK_NUMLOCK },
    { AKEYCODE_CAPS_LOCK, RETROK_CAPSLOCK },
    { AKEYCODE_SCROLL_LOCK, RETROK_SCROLLOCK },
-   { AKEYCODE_SHIFT_LEFT, RETROK_RSHIFT },
-   { AKEYCODE_SHIFT_RIGHT, RETROK_LSHIFT },
+   { AKEYCODE_SHIFT_LEFT, RETROK_LSHIFT },
+   { AKEYCODE_SHIFT_RIGHT, RETROK_RSHIFT },
    { AKEYCODE_CTRL_RIGHT, RETROK_RCTRL },
    { AKEYCODE_CTRL_LEFT, RETROK_LCTRL },
    { AKEYCODE_ALT_RIGHT, RETROK_RALT },
@@ -1914,7 +1917,7 @@ const struct rarch_key_map rarch_key_map_ps3[] = {
    { KB_RAWKEY_SCROLL_LOCK, RETROK_SCROLLOCK },
    { KB_RAWKEY_PAUSE, RETROK_BREAK },
 
-   /* 
+   /*
    { KB_RAWKEY_HASHTILDE, RETROK_HASH },
    { KB_RAWKEY_KPLEFTPAREN, RETROK_LEFTPAREN },
    { KB_RAWKEY_KPRIGHTPAREN, RETROK_RIGHTPAREN },
@@ -2091,12 +2094,6 @@ enum retro_key rarch_keysym_lut[RETROK_LAST];
 static unsigned *rarch_keysym_rlut           = NULL;
 static unsigned rarch_keysym_rlut_size       = 0;
 
-/**
- * input_keymaps_init_keyboard_lut:
- * @map                   : Keyboard map.
- *
- * Initializes and sets the keyboard layout to a keyboard map (@map).
- **/
 void input_keymaps_init_keyboard_lut(const struct rarch_key_map *map)
 {
    const struct rarch_key_map *map_start = map;
@@ -2124,15 +2121,6 @@ void input_keymaps_init_keyboard_lut(const struct rarch_key_map *map)
       rarch_keysym_rlut_size = 0;
 }
 
-/**
- * input_keymaps_translate_keysym_to_rk:
- * @sym                   : Key symbol.
- *
- * Translates a key symbol from the keyboard layout table
- * to an associated retro key identifier.
- *
- * Returns: Retro key identifier.
- **/
 enum retro_key input_keymaps_translate_keysym_to_rk(unsigned sym)
 {
    unsigned i;
@@ -2153,25 +2141,16 @@ enum retro_key input_keymaps_translate_keysym_to_rk(unsigned sym)
    return RETROK_UNKNOWN;
 }
 
-/**
- * input_keymaps_translate_rk_to_str:
- * @key                   : Retro key identifier.
- * @buf                   : Buffer.
- * @size                  : Size of @buf.
- *
- * Translates a retro key identifier to a human-readable
- * identifier string.
- **/
-void input_keymaps_translate_rk_to_str(enum retro_key key, char *buf, size_t size)
+void input_keymaps_translate_rk_to_str(enum retro_key key, char *s, size_t len)
 {
    unsigned i;
 
-   *buf = '\0';
+   *s = '\0';
 
    if (key >= RETROK_a && key <= RETROK_z)
    {
-      buf[0] = (key - RETROK_a) + 'a';
-      buf[1] = '\0';
+      s[0] = (key - RETROK_a) + 'a';
+      s[1] = '\0';
       return;
    }
 
@@ -2180,7 +2159,7 @@ void input_keymaps_translate_rk_to_str(enum retro_key key, char *buf, size_t siz
       if (input_config_key_map[i].key != key)
          continue;
 
-      strlcpy(buf, input_config_key_map[i].str, size);
+      strlcpy(s, input_config_key_map[i].str, len);
       break;
    }
 }
