@@ -8,7 +8,9 @@ with open("crowdin.yaml", 'r') as config_file:
    config = yaml.safe_load(config_file)
    headers = { 'Authorization': 'Bearer ' + config['api_token']}
 
-   url1 = 'https://api.crowdin.com/api/v2/projects/' + config['project_id'] + '/languages/progress?limit=100'
+   url1 = ('https://api.crowdin.com/api/v2/projects/' + config['project_id'] +
+           '/files/' + config['main_file_id'] + '/languages/progress?limit=100')
+
    res1 = requests.get(url1, headers=headers)
    output = ''
    for lang in res1.json()['data']:
@@ -18,7 +20,8 @@ with open("crowdin.yaml", 'r') as config_file:
       lang_name = res2.json()['data']['name']
    
       output += '/* ' + lang_name + ' */\n'
-      escaped_name = lang_name.replace(', ', '_').replace(' ', '_').upper()
+      replacements = lang_name.maketrans(' ', '_', ',()')
+      escaped_name = lang_name.translate(replacements).upper()
       output += '#define LANGUAGE_PROGRESS_' + escaped_name + '_TRANSLATED ' + str(lang['data']['translationProgress']) + '\n'
       output += '#define LANGUAGE_PROGRESS_' + escaped_name + '_APPROVED   ' + str(lang['data']['approvalProgress']) + '\n\n'
    with open("progress.h", 'w') as output_file:
