@@ -133,10 +133,6 @@ MSG_HASH(
    MENU_ENUM_SUBLABEL_SHOW_WIMP,
    "Отворете традиционното меню на работния плот."
    )
-MSG_HASH(
-   MENU_ENUM_LABEL_VALUE_MENU_DISABLE_KIOSK_MODE,
-   "Изключване на режим Киоск (Необходимо е рестартиране)"
-   )
 MSG_HASH(
    MENU_ENUM_SUBLABEL_MENU_DISABLE_KIOSK_MODE,
    "Показване на всички настройки свързани с конфигурацията."
@@ -282,6 +278,10 @@ MSG_HASH(
    MENU_ENUM_LABEL_VALUE_GOTO_VIDEO,
    "Видеа"
    )
+MSG_HASH(
+   MENU_ENUM_SUBLABEL_GOTO_VIDEO,
+   "Предишно пуснати видеота, ще се покажат тук."
+   )
 MSG_HASH(
    MENU_ENUM_LABEL_VALUE_GOTO_EXPLORE,
    "Разгледайте"
@@ -998,6 +998,7 @@ MSG_HASH(
    "Задръж"
    )
 
+
 /* Settings > Input > Haptic Feedback/Vibration */
 
 
@@ -1036,7 +1037,6 @@ MSG_HASH(
 
 
 
-
 /* Settings > Input > Port # Controls */
 
 MSG_HASH(
@@ -1236,7 +1236,7 @@ MSG_HASH(
    )
 MSG_HASH( /* FIXME Not RGUI specific */
    MENU_ENUM_LABEL_VALUE_RGUI_BROWSER_DIRECTORY,
-   "Разглеждане на файловете"
+   "Начална Директория"
    )
 MSG_HASH(
    MENU_ENUM_LABEL_VALUE_PLAYLIST_DIRECTORY,
@@ -1346,13 +1346,6 @@ MSG_HASH(
 /* Quick Menu > Shaders */
 
 
-/* Quick Menu > Shaders > Save */
-
-
-
-
-/* Quick Menu > Shaders > Remove */
-
 
 /* Quick Menu > Shaders > Shader Parameters */
 
@@ -1418,6 +1411,12 @@ MSG_HASH(
 
 /* Ozone: Settings > User Interface > Appearance */
 
+MSG_HASH(
+   MENU_ENUM_LABEL_VALUE_OZONE_FONT,
+   "Шрифт"
+   )
+
+
 
 /* MaterialUI: Settings > User Interface > Appearance */
 
@@ -1551,4 +1550,11 @@ MSG_HASH(
 #ifdef _3DS
 #endif
 #ifdef HAVE_QT
+#endif
+#ifdef HAVE_GAME_AI
+
+
+
+
+
 #endif
