@@ -1062,6 +1062,7 @@ MSG_HASH(
    "ISKLJUČENO"
    )
 
+
 /* Settings > Input > Haptic Feedback/Vibration */
 
 
@@ -1084,7 +1085,6 @@ MSG_HASH(
 
 
 
-
 /* Settings > Input > Port # Controls */
 
 
@@ -1156,6 +1156,8 @@ MSG_HASH(
 
 /* Settings > User Interface */
 
+#ifdef _3DS
+#endif
 MSG_HASH(
    MENU_ENUM_LABEL_VALUE_APPICON_SETTINGS,
    "Ikona aplikacije"
@@ -1164,8 +1166,6 @@ MSG_HASH(
    MENU_ENUM_SUBLABEL_APPICON_SETTINGS,
    "Promijenite ikonu aplikacije."
    )
-#ifdef _3DS
-#endif
 
 /* Settings > User Interface > Menu Item Visibility */
 
@@ -1268,7 +1268,7 @@ MSG_HASH(
    )
 MSG_HASH( /* FIXME Not RGUI specific */
    MENU_ENUM_LABEL_VALUE_RGUI_BROWSER_DIRECTORY,
-   "Preglednik datoteka"
+   "Početna mapa"
    )
 MSG_HASH(
    MENU_ENUM_LABEL_VALUE_PLAYLIST_DIRECTORY,
@@ -1402,13 +1402,6 @@ MSG_HASH(
 /* Quick Menu > Shaders */
 
 
-/* Quick Menu > Shaders > Save */
-
-
-
-
-/* Quick Menu > Shaders > Remove */
-
 
 /* Quick Menu > Shaders > Shader Parameters */
 
@@ -1490,6 +1483,12 @@ MSG_HASH(
 
 /* Ozone: Settings > User Interface > Appearance */
 
+MSG_HASH(
+   MENU_ENUM_LABEL_VALUE_OZONE_HEADER_SEPARATOR_NONE,
+   "Ništa"
+   )
+
+
 
 /* MaterialUI: Settings > User Interface > Appearance */
 
@@ -1635,4 +1634,11 @@ MSG_HASH(
 #ifdef _3DS
 #endif
 #ifdef HAVE_QT
+#endif
+#ifdef HAVE_GAME_AI
+
+
+
+
+
 #endif
