@@ -1,11 +1,10 @@
-#include <stdio.h>
+#include <stdint.h>
 #include "../led_driver.h"
 #include "../led_defines.h"
 
 #include "../../input/input_overlay.h"
 
 #include "../../configuration.h"
-#include "../../retroarch.h"
 
 typedef struct
 {
