@@ -61,15 +61,13 @@ typedef struct
    uint8_t *decompressed_data;
 } zip_context_t;
 
-static INLINE uint32_t read_le(const uint8_t *data, unsigned size)
+static INLINE uint32_t read_le(const uint8_t *data, size_t len)
 {
    unsigned i;
    uint32_t val = 0;
-
-   size *= 8;
-   for (i = 0; i < size; i += 8)
+   len *= 8;
+   for (i = 0; i < len; i += 8)
       val |= (uint32_t)*data++ << i;
-
    return val;
 }
 
@@ -101,12 +99,12 @@ static bool zlib_stream_decompress_data_to_file_init(
       void *context, file_archive_file_handle_t *handle,
       const uint8_t *cdata, unsigned cmode, uint32_t csize, uint32_t size)
 {
-   zip_context_t *zip_context = (zip_context_t *)context;
-   struct file_archive_transfer *state = zip_context->state;
-   uint8_t local_header_buf[4];
+   int64_t offsetData;
    uint8_t *local_header;
    uint32_t offsetNL, offsetEL;
-   int64_t offsetData;
+   uint8_t local_header_buf[4];
+   zip_context_t *zip_context = (zip_context_t *)context;
+   struct file_archive_transfer *state = zip_context->state;
 
    /* free previous data and stream if left unfinished */
    zip_context_free_stream(zip_context, false);
@@ -114,15 +112,16 @@ static bool zlib_stream_decompress_data_to_file_init(
    /* seek past most of the local directory header */
 #ifdef HAVE_MMAP
    if (state->archive_mmap_data)
-   {
       local_header = state->archive_mmap_data + (size_t)cdata + 26;
-   }
    else
 #endif
    {
       filestream_seek(state->archive_file, (int64_t)(size_t)cdata + 26, RETRO_VFS_SEEK_POSITION_START);
       if (filestream_read(state->archive_file, local_header_buf, 4) != 4)
-         goto error;
+      {
+         zip_context_free_stream(zip_context, false);
+         return false;
+      }
       local_header = local_header_buf;
    }
 
@@ -160,36 +159,31 @@ static bool zlib_stream_decompress_data_to_file_init(
       {
          free(zip_context->zstream);
          zip_context->zstream = NULL;
-         goto error;
+         zip_context_free_stream(zip_context, false);
+         return false;
       }
    }
 
    return true;
-
-error:
-   zip_context_free_stream(zip_context, false);
-   return false;
 }
 
 static int zlib_stream_decompress_data_to_file_iterate(
       void *context, file_archive_file_handle_t *handle)
 {
+   int64_t rd;
    zip_context_t *zip_context = (zip_context_t *)context;
    struct file_archive_transfer *state = zip_context->state;
-   int64_t rd;
 
    if (zip_context->cmode == ZIP_MODE_STORED)
    {
-      #ifdef HAVE_MMAP
+#ifdef HAVE_MMAP
+      /* Simply copy the data to the output buffer */
       if (zip_context->state->archive_mmap_data)
-      {
-         /* Simply copy the data to the output buffer */
          memcpy(zip_context->decompressed_data,
-                zip_context->state->archive_mmap_data + (size_t)zip_context->fdoffset,
-                zip_context->usize);
-      }
+               zip_context->state->archive_mmap_data + (size_t)zip_context->fdoffset,
+               zip_context->usize);
       else
-      #endif
+#endif
       {
          /* Read the entire file to memory */
          filestream_seek(state->archive_file, zip_context->fdoffset, RETRO_VFS_SEEK_POSITION_START);
@@ -204,27 +198,26 @@ static int zlib_stream_decompress_data_to_file_iterate(
    }
    else if (zip_context->cmode == ZIP_MODE_DEFLATED)
    {
-      int to_read = MIN(zip_context->csize - zip_context->boffset, _READ_CHUNK_SIZE);
       uint8_t *dptr;
+      int to_read = MIN(zip_context->csize - zip_context->boffset, _READ_CHUNK_SIZE);
+      /* File was uncompressed or decompression finished before */
       if (!zip_context->zstream)
-      {
-         /* file was uncompressed or decompression finished before */
          return 1;
-      }
 
-      #ifdef HAVE_MMAP
+#ifdef HAVE_MMAP
       if (state->archive_mmap_data)
       {
          /* Decompress from the mapped file */
          dptr = state->archive_mmap_data + (size_t)zip_context->fdoffset + zip_context->boffset;
-         rd = to_read;
+         rd   = to_read;
       }
       else
-      #endif
+#endif
       {
          /* Read some compressed data from file to the temp buffer */
-         filestream_seek(state->archive_file, zip_context->fdoffset + zip_context->boffset,
-                         RETRO_VFS_SEEK_POSITION_START);
+         filestream_seek(state->archive_file,
+               zip_context->fdoffset + zip_context->boffset,
+               RETRO_VFS_SEEK_POSITION_START);
          rd = filestream_read(state->archive_file, zip_context->tmpbuf, to_read);
          if (rd < 0)
             return -1;
@@ -256,9 +249,9 @@ static int zlib_stream_decompress_data_to_file_iterate(
 }
 
 static uint32_t zlib_stream_crc32_calculate(uint32_t crc,
-      const uint8_t *data, size_t length)
+      const uint8_t *data, size_t len)
 {
-   return encoding_crc32(crc, data, length);
+   return encoding_crc32(crc, data, len);
 }
 
 static bool zip_file_decompressed_handle(
@@ -365,7 +358,6 @@ static int64_t zip_file_read(
    file_archive_transfer_t state            = {0};
    decomp_state_t decomp                    = {0};
    struct archive_extract_userdata userdata = {0};
-   bool returnerr                           = true;
    int ret                                  = 0;
 
    if (needle)
@@ -380,6 +372,7 @@ static int64_t zip_file_read(
 
    do
    {
+      bool returnerr = true;
       ret = file_archive_parse_file_iterate(&state, &returnerr, path,
             "", zip_file_decompressed, &userdata);
       if (!returnerr)
@@ -522,19 +515,20 @@ static int zip_parse_file_iterate_step(void *context,
       file_archive_file_cb file_cb)
 {
    zip_context_t *zip_context = (zip_context_t *)context;
-   const uint8_t *cdata           = NULL;
-   uint32_t checksum              = 0;
-   uint32_t size                  = 0;
-   uint32_t csize                 = 0;
-   unsigned cmode                 = 0;
-   unsigned payload               = 0;
-   int ret                        = zip_parse_file_iterate_step_internal(zip_context,
+   const uint8_t *cdata       = NULL;
+   uint32_t checksum          = 0;
+   uint32_t size              = 0;
+   uint32_t csize             = 0;
+   unsigned cmode             = 0;
+   unsigned payload           = 0;
+   int ret                    = zip_parse_file_iterate_step_internal(zip_context,
          userdata->current_file_path, &cdata, &cmode, &size, &csize, &checksum, &payload);
 
    if (ret != 1)
       return ret;
 
-   userdata->crc = checksum;
+   userdata->crc  = checksum;
+   userdata->size = size;
 
    if (file_cb && !file_cb(userdata->current_file_path, valid_exts, cdata, cmode,
             csize, size, checksum, userdata))
