@@ -634,20 +634,21 @@ static bool config_file_parse_line(config_file_t *conf,
    if (*line != '=')
    {
       list->value = NULL;
-      goto error;
+      list->key   = NULL;
+      free(key);
+      return false;
    }
 
    line++;
 
    if (!(list->value   = config_file_extract_value(line)))
-      goto error;
+   {
+      list->key   = NULL;
+      free(key);
+      return false;
+   }
 
    return true;
-
-error:
-   list->key   = NULL;
-   free(key);
-   return false;
 }
 
 static int config_file_from_string_internal(
@@ -840,7 +841,7 @@ config_file_t *config_file_new_from_path_to_string(const char *path)
 {
    if (path_is_valid(path))
    {
-	   uint8_t *ret_buf                 = NULL;
+      uint8_t *ret_buf                 = NULL;
       int64_t length                   = 0;
       if (filestream_read_file(path, (void**)&ret_buf, &length))
       {
@@ -1168,24 +1169,24 @@ size_t config_get_config_path(config_file_t *conf, char *s, size_t len)
 }
 
 bool config_get_array(config_file_t *conf, const char *key,
-      char *buf, size_t size)
+      char *s, size_t len)
 {
    const struct config_entry_list *entry = config_get_entry(conf, key);
    if (entry)
-      return strlcpy(buf, entry->value, size) < size;
+      return strlcpy(s, entry->value, len) < len;
    return false;
 }
 
 bool config_get_path(config_file_t *conf, const char *key,
-      char *buf, size_t size)
+      char *s, size_t len)
 {
 #if defined(RARCH_CONSOLE) || !defined(RARCH_INTERNAL)
-   return config_get_array(conf, key, buf, size);
+   return config_get_array(conf, key, s, len);
 #else
    const struct config_entry_list *entry = config_get_entry(conf, key);
    if (entry)
    {
-      fill_pathname_expand_special(buf, entry->value, size);
+      fill_pathname_expand_special(s, entry->value, len);
       return true;
    }
    return false;
