@@ -146,7 +146,7 @@ void path_linked_list_add_path(struct path_linked_list *in_path_llist,
       in_path_llist->path = strdup(path);
    else
    {
-      struct path_linked_list *node = (struct path_linked_list*) malloc(sizeof(*node));
+      struct path_linked_list *node = (struct path_linked_list*)malloc(sizeof(*node));
 
       if (node)
       {
@@ -255,7 +255,8 @@ const char *path_get_extension(const char *path)
 char *path_get_extension_mutable(const char *path)
 {
    char *ext = NULL;
-   if (!string_is_empty(path) && ((ext = (char*)strrchr(path_basename(path), '.'))))
+   if (    !string_is_empty(path)
+       && ((ext = (char*)strrchr(path_basename(path), '.'))))
       return ext;
    return NULL;
 }
@@ -276,8 +277,7 @@ char *path_get_extension_mutable(const char *path)
  **/
 char *path_remove_extension(char *s)
 {
-   char *last = !string_is_empty(s)
-      ? (char*)strrchr(path_basename(s), '.') : NULL;
+   char *last = path_get_extension_mutable(s);
    if (!last)
       return NULL;
    if (*last)
@@ -353,10 +353,25 @@ size_t fill_pathname(char *s, const char *in_path,
  **/
 char *find_last_slash(const char *str)
 {
-   const char *slash     = strrchr(str, '/');
-   const char *backslash = strrchr(str, '\\');
-   char       *last_slash = (!slash || (backslash > slash)) ? (char*)backslash : (char*)slash;
-   return last_slash;
+   const char *p;
+   const char *last_slash     = NULL;
+   const char *last_backslash = NULL;
+
+   /* Traverse the string once */
+   for (p = str; *p != '\0'; ++p)
+   {
+      if (*p == '/')
+         last_slash = p; /*   Update last forward slash */
+      else if (*p == '\\')
+         last_backslash = p; /* Update last backslash */
+   }
+
+   /* Determine which one is last */
+   if (!last_slash) /* Backslash */
+      return (char*)last_backslash;
+   if (!last_backslash) /* Forward slash */
+      return (char*)last_slash;
+   return (last_backslash > last_slash) ? (char*)last_backslash : (char*)last_slash;
 }
 
 /**
@@ -369,17 +384,18 @@ char *find_last_slash(const char *str)
  **/
 size_t fill_pathname_slash(char *s, size_t len)
 {
-   const char *slash      = strrchr(s, '/');
-   const char *backslash  = strrchr(s, '\\');
-   char       *last_slash = (!slash || (backslash > slash)) ? (char*)backslash : (char*)slash;
+   char *last_slash = find_last_slash(s);
+   len              = strlen(s);
    if (!last_slash)
-      return strlcat(s, PATH_DEFAULT_SLASH(), len);
-   len         = strlen(s);
-   /* Try to preserve slash type. */
-   if (last_slash != (s + len - 1))
    {
-      s[  len] = last_slash[0];
-      s[++len] = '\0';
+      s[  len]      = PATH_DEFAULT_SLASH_C();
+      s[++len]      = '\0';
+   }
+   else if (last_slash != (s + len - 1))
+   {
+      /* Try to preserve slash type. */
+      s[  len]       = last_slash[0];
+      s[++len]       = '\0';
    }
    return len;
 }
@@ -460,33 +476,26 @@ size_t fill_pathname_basedir(char *s, const char *in_path, size_t len)
  **/
 size_t fill_pathname_parent_dir_name(char *s, const char *in_dir, size_t len)
 {
-   size_t _len           = 0;
-   char *tmp             = strdup(in_dir);
-   const char *slash     = strrchr(tmp, '/');
-   const char *backslash = strrchr(tmp, '\\');
-   char *last_slash      = (!slash || (backslash > slash)) ? (char*)backslash : (char*)slash;
+   size_t _len        = 0;
+   char *tmp          = strdup(in_dir);
+   char *last_slash   = find_last_slash(tmp);
 
    if (last_slash && last_slash[1] == 0)
    {
-      *last_slash        = '\0';
-      slash              = strrchr(tmp, '/');
-      backslash          = strrchr(tmp, '\\');
-      last_slash         = (!slash || (backslash > slash)) ? (char*)backslash : (char*)slash;
+      *last_slash     = '\0';
+      last_slash      = find_last_slash(tmp);
    }
 
    /* Cut the last part of the string (the filename) after the slash,
       leaving the directory name (or nested directory names) only. */
    if (last_slash)
-      *last_slash        = '\0';
+      *last_slash     = '\0';
 
    /* Point in_dir to the address of the last slash.
     * If in_dir is NULL, it means there was no slash in tmp,
     * so use tmp as-is. */
-   slash                 = strrchr(tmp, '/');
-   backslash             = strrchr(tmp, '\\');
-   in_dir                = (!slash || (backslash > slash)) ? (char*)backslash : (char*)slash;
-   if (!in_dir)
-       in_dir            = tmp;
+   if (!(in_dir = find_last_slash(tmp)))
+       in_dir         = tmp;
 
    if (in_dir && in_dir[1])
    {
@@ -512,7 +521,7 @@ size_t fill_pathname_parent_dir_name(char *s, const char *in_dir, size_t len)
  * If the path was already at the root directory,
  * @s will be an empty string.
  **/
-void fill_pathname_parent_dir(char *s,
+size_t fill_pathname_parent_dir(char *s,
       const char *in_dir, size_t len)
 {
    size_t _len = 0;
@@ -520,7 +529,7 @@ void fill_pathname_parent_dir(char *s,
       _len = strlen(s);
    else
       _len = strlcpy(s, in_dir, len);
-   path_parent_dir(s, _len);
+   return path_parent_dir(s, _len);
 }
 
 /**
@@ -592,26 +601,19 @@ size_t fill_str_dated_filename(char *s,
  **/
 size_t path_basedir(char *s)
 {
-   const char *slash;
-   const char *backslash;
    char *last_slash = NULL;
    if (!s || s[0] == '\0' || s[1] == '\0')
       return (s && s[0] != '\0') ? 1 : 0;
-   slash             = strrchr(s, '/');
-   backslash         = strrchr(s, '\\');
-   last_slash        = (!slash || (backslash > slash)) ? (char*)backslash : (char*)slash;
+   last_slash       = find_last_slash(s);
    if (last_slash)
    {
-      last_slash[1]  = '\0';
+      last_slash[1] = '\0';
       return last_slash + 1 - s;
    }
-   else
-   {
-      s[0]           = '.';
-      s[1]           = PATH_DEFAULT_SLASH_C();
-      s[2]           = '\0';
-      return 2;
-   }
+   s[0]             = '.';
+   s[1]             = PATH_DEFAULT_SLASH_C();
+   s[2]             = '\0';
+   return 2;
 }
 
 /**
@@ -633,15 +635,10 @@ size_t path_parent_dir(char *s, size_t len)
    if (len && PATH_CHAR_IS_SLASH(s[len - 1]))
    {
       char *last_slash;
-      const char *slash;
-      const char *backslash;
       bool was_absolute = path_is_absolute(s);
 
       s[len - 1]        = '\0';
-
-      slash             = strrchr(s, '/');
-      backslash         = strrchr(s, '\\');
-      last_slash        = (!slash || (backslash > slash)) ? (char*)backslash : (char*)slash;
+      last_slash        = find_last_slash(s);
 
       if (was_absolute && !last_slash)
       {
@@ -670,9 +667,7 @@ const char *path_basename(const char *path)
    /* We cut either at the first compression-related hash,
     * or we cut at the last slash */
    const char *ptr       = NULL;
-   const char *slash     = strrchr(path, '/');
-   const char *backslash = strrchr(path, '\\');
-   char *last_slash      = (!slash || (backslash > slash)) ? (char*)backslash : (char*)slash;
+   char *last_slash      = find_last_slash(path);
    return ((ptr = path_get_archive_delim(path)) || (ptr = last_slash))
       ? (ptr + 1) : path;
 }
@@ -690,9 +685,7 @@ const char *path_basename(const char *path)
 const char *path_basename_nocompression(const char *path)
 {
    /* We cut at the last slash */
-   const char *slash     = strrchr(path, '/');
-   const char *backslash = strrchr(path, '\\');
-   char *last_slash      = (!slash || (backslash > slash)) ? (char*)backslash : (char*)slash;
+   char *last_slash = find_last_slash(path);
    return (last_slash) ? (last_slash + 1) : path;
 }
 
@@ -812,7 +805,11 @@ char *path_resolve_realpath(char *s, size_t len, bool resolve_symlinks)
          tmp[t++] = '/';
 
       if (string_is_empty(s))
-         goto end;
+      {
+         tmp[t] = '\0';
+         strlcpy(s, tmp, len);
+         return s;
+      }
 
       p = s;
    }
@@ -858,10 +855,8 @@ char *path_resolve_realpath(char *s, size_t len, bool resolve_symlinks)
          while (p <= next)
             tmp[t++] = *p++;
       }
-   }while(next < buf_end);
+   } while(next < buf_end);
 
-
-end:
    tmp[t] = '\0';
    strlcpy(s, tmp, len);
    return s;
@@ -1002,22 +997,17 @@ size_t fill_pathname_join_special(char *s,
 
    if (*s)
    {
-      const char *slash      = strrchr(s, '/');
-      const char *backslash  = strrchr(s, '\\');
-      char *last_slash       = (!slash || (backslash > slash)) ? (char*)backslash : (char*)slash;
-      if (last_slash)
+      char *last_slash = find_last_slash(s);
+      if (!last_slash)
+      {
+         s[  _len]     = PATH_DEFAULT_SLASH_C();
+         s[++_len]     = '\0';
+      }
+      else if (last_slash != (s + _len - 1))
       {
          /* Try to preserve slash type. */
-         if (last_slash != (s + _len - 1))
-         {
-            s[  _len] = last_slash[0];
-            s[++_len] = '\0';
-         }
-      }
-      else
-      {
-         s[  _len]    = PATH_DEFAULT_SLASH_C();
-         s[++_len]    = '\0';
+         s[  _len]     = last_slash[0];
+         s[++_len]     = '\0';
       }
    }
 
@@ -1058,6 +1048,8 @@ size_t fill_pathname_join_delim(char *s, const char *dir,
       _len     = strlen(dir);
    else
       _len     = strlcpy(s, dir, len);
+   if (len - _len < 2)
+      return _len;
    s[_len++]   = delim;
    s[_len  ]   = '\0';
    if (path)
@@ -1150,7 +1142,7 @@ size_t fill_pathname_abbreviate_special(char *s,
 
          if (!PATH_CHAR_IS_SLASH(*in_path))
          {
-            strcpy_literal(s, PATH_DEFAULT_SLASH());
+            strcpy(s, PATH_DEFAULT_SLASH());
             s++;
             len--;
          }
@@ -1173,7 +1165,7 @@ size_t fill_pathname_abbreviate_special(char *s,
  *
  * @returns new string that has been sanitized
  **/
-const char *sanitize_path_part(const char *path_part, size_t size)
+const char *sanitize_path_part(const char *path_part, size_t len)
 {
    int i;
    int j = 0;
@@ -1183,7 +1175,7 @@ const char *sanitize_path_part(const char *path_part, size_t size)
    if (string_is_empty(path_part))
       return NULL;
 
-   tmp = (char *)malloc((size + 1) * sizeof(char));
+   tmp = (char *)malloc((len + 1) * sizeof(char));
 
    for (i = 0; path_part[i] != '\0'; i++)
    {
@@ -1328,8 +1320,6 @@ size_t fill_pathname_abbreviated_or_relative(char *s,
  **/
 void path_basedir_wrapper(char *s)
 {
-   const char *slash;
-   const char *backslash;
    char *last_slash = NULL;
    if (!s || s[0] == '\0' || s[1] == '\0')
       return;
@@ -1338,17 +1328,15 @@ void path_basedir_wrapper(char *s)
    if ((last_slash  = (char*)path_get_archive_delim(s)))
       *last_slash   = '\0';
 #endif
-   slash            = strrchr(s, '/');
-   backslash        = strrchr(s, '\\');
-   last_slash       = (!slash || (backslash > slash)) ? (char*)backslash : (char*)slash;
-   if (last_slash)
-      last_slash[1] = '\0';
-   else
+   last_slash       = find_last_slash(s);
+   if (!last_slash)
    {
       s[0]          = '.';
       s[1]          = PATH_DEFAULT_SLASH_C();
       s[2]          = '\0';
    }
+   else
+      last_slash[1] = '\0';
 }
 
 #if !defined(RARCH_CONSOLE) && defined(RARCH_INTERNAL)
@@ -1413,12 +1401,12 @@ size_t fill_pathname_application_path(char *s, size_t len)
             return strlcpy(s, info.name, len);
       }
 #elif defined(__QNX__)
-      char *buff = malloc(len);
-      size_t rv = 0;
+      char *buff  = (char*)malloc(len);
+      size_t _len = 0;
       if (_cmdname(buff))
-         rv = strlcpy(s, buff, len);
+         _len = strlcpy(s, buff, len);
       free(buff);
-      return rv;
+      return _len;
 #else
       size_t i;
       static const char *exts[] = { "exe", "file", "path/a.out" };
@@ -1446,13 +1434,13 @@ size_t fill_pathname_application_path(char *s, size_t len)
    return 0;
 }
 
-void fill_pathname_application_dir(char *s, size_t len)
+size_t fill_pathname_application_dir(char *s, size_t len)
 {
 #ifdef __WINRT__
-   strlcpy(s, uwp_dir_install, len);
+   return strlcpy(s, uwp_dir_install, len);
 #else
    fill_pathname_application_path(s, len);
-   path_basedir(s);
+   return path_basedir(s);
 #endif
 }
 
