@@ -163,14 +163,15 @@ static INLINE bool _rjson_pushchar(rjson_t *json, _rjson_char_t c)
 static INLINE bool _rjson_pushchars(rjson_t *json,
       const unsigned char *from, const unsigned char *to)
 {
-   size_t len = json->string_len, new_len = len + (to - from);
    unsigned char* string;
+   size_t _len    = json->string_len;
+   size_t new_len = _len + (to - from);
    while (new_len >= json->string_cap)
       if (!_rjson_grow_string(json))
          return false;
    string = (unsigned char *)json->string;
-   while (len != new_len)
-      string[len++] = *(from++);
+   while (_len != new_len)
+      string[_len++] = *(from++);
    json->string_len = new_len;
    return true;
 }
@@ -929,14 +930,14 @@ static int _rjson_buffer_io(void* buf, int len, void *user)
    return len;
 }
 
-rjson_t *rjson_open_buffer(const void *buffer, size_t size)
+rjson_t *rjson_open_buffer(const void *buffer, size_t len)
 {
    rjson_t *json   = (rjson_t *)malloc(sizeof(rjson_t) + sizeof(const char *)*2);
    const char **ud = (const char **)(json + 1);
    if (!json)
       return NULL;
    ud[0] = (const char *)buffer;
-   ud[1] = ud[0] + size;
+   ud[1] = ud[0] + len;
    _rjson_setup(json, _rjson_buffer_io, (void*)ud, sizeof(json->input_buf));
    return json;
 }
@@ -986,12 +987,12 @@ void rjson_set_max_depth(rjson_t *json, unsigned int max_depth)
    json->stack_max = max_depth;
 }
 
-const char *rjson_get_string(rjson_t *json, size_t *length)
+const char *rjson_get_string(rjson_t *json, size_t *len)
 {
    char* str             = (json->string_pass_through
          ? json->string_pass_through : json->string);
-   if (length)
-      *length            = json->string_len;
+   if (len)
+      *len               = json->string_len;
    str[json->string_len] = '\0';
    return str;
 }
@@ -1010,7 +1011,7 @@ double rjson_get_double(rjson_t *json)
          snprintf(test, sizeof(test), "%.1f", 0.0f);
          json->decimal_sep = test[1];
       }
-      if (json->decimal_sep != '.' && (p = strchr(str, '.')) != NULL)
+      if (json->decimal_sep != '.' && (p = (char*)memchr(str, '.', strlen(str) + 1)) != NULL)
       {
          double res;
          *p  = json->decimal_sep;
@@ -1111,7 +1112,7 @@ void rjson_free(rjson_t *json)
 }
 
 static bool _rjson_nop_default(void *context) { return true; }
-static bool _rjson_nop_string(void *context, const char *value, size_t length) { return true; }
+static bool _rjson_nop_string(void *context, const char *value, size_t len) { return true; }
 static bool _rjson_nop_bool(void *context, bool value) { return true; }
 
 enum rjson_type rjson_parse(rjson_t *json, void* context,
@@ -1126,7 +1127,7 @@ enum rjson_type rjson_parse(rjson_t *json, void* context,
       bool (*null_handler         )(void *context))
 {
    bool in_object = false;
-   size_t len;
+   size_t _len;
    const char* string;
    if (!object_member_handler) object_member_handler = _rjson_nop_string;
    if (!string_handler       ) string_handler        = _rjson_nop_string;
@@ -1142,16 +1143,16 @@ enum rjson_type rjson_parse(rjson_t *json, void* context,
       switch (rjson_next(json))
       {
          case RJSON_STRING:
-            string = rjson_get_string(json, &len);
+            string = rjson_get_string(json, &_len);
             if (_rJSON_LIKELY(
                   (in_object && (json->stack_top->count & 1) ?
                      object_member_handler : string_handler)
-                     (context, string, len)))
+                     (context, string, _len)))
                continue;
             return RJSON_STRING;
          case RJSON_NUMBER:
-            string = rjson_get_string(json, &len);
-            if (_rJSON_LIKELY(number_handler(context, string, len)))
+            string = rjson_get_string(json, &_len);
+            if (_rJSON_LIKELY(number_handler(context, string, _len)))
                continue;
             return RJSON_NUMBER;
          case RJSON_OBJECT:
