@@ -55,16 +55,7 @@ static bool string_list_deinitialize_internal(struct string_list *list)
    return true;
 }
 
-/**
- * string_list_capacity:
- * @list             : pointer to string list
- * @cap              : new capacity for string list.
- *
- * Change maximum capacity of string list's size.
- *
- * @return true if successful, otherwise false.
- **/
-static bool string_list_capacity(struct string_list *list, size_t cap)
+bool string_list_capacity(struct string_list *list, size_t cap)
 {
    struct string_list_elem *new_data = (struct string_list_elem*)
       realloc(list->elems, cap * sizeof(*new_data));
@@ -80,12 +71,6 @@ static bool string_list_capacity(struct string_list *list, size_t cap)
    return true;
 }
 
-/**
- * string_list_free
- * @list             : pointer to string list object
- *
- * Frees a string list.
- **/
 void string_list_free(struct string_list *list)
 {
    if (!list)
@@ -108,13 +93,6 @@ bool string_list_deinitialize(struct string_list *list)
    return true;
 }
 
-/**
- * string_list_new:
- *
- * Creates a new string list. Has to be freed manually.
- *
- * @return New string list if successful, otherwise NULL.
- **/
 struct string_list *string_list_new(void)
 {
    struct string_list_elem *
@@ -124,6 +102,10 @@ struct string_list *string_list_new(void)
    if (!list)
       return NULL;
 
+   list->cap                = 0;
+   list->size               = 0;
+   list->elems              = NULL;
+
    if (!(elems = (struct string_list_elem*)
       calloc(32, sizeof(*elems))))
    {
@@ -132,7 +114,6 @@ struct string_list *string_list_new(void)
    }
 
    list->elems              = elems;
-   list->size               = 0;
    list->cap                = 32;
 
    return list;
@@ -156,16 +137,6 @@ bool string_list_initialize(struct string_list *list)
    return true;
 }
 
-/**
- * string_list_append:
- * @list             : pointer to string list
- * @elem             : element to add to the string list
- * @attr             : attributes of new element.
- *
- * Appends a new element to the string list.
- *
- * @return true if successful, otherwise false.
- **/
 bool string_list_append(struct string_list *list, const char *elem,
       union string_list_elem_attr attr)
 {
@@ -177,8 +148,8 @@ bool string_list_append(struct string_list *list, const char *elem,
     * it) capacity will be zero. This will cause
     * a segfault. Handle this case by forcing the new
     * capacity to a fixed size of 32 */
-   if (list->size >= list->cap &&
-         !string_list_capacity(list,
+   if (      list->size >= list->cap
+         && !string_list_capacity(list,
                (list->cap > 0) ? (list->cap * 2) : 32))
       return false;
 
@@ -192,99 +163,43 @@ bool string_list_append(struct string_list *list, const char *elem,
    return true;
 }
 
-/**
- * string_list_append_n:
- * @list             : pointer to string list
- * @elem             : element to add to the string list
- * @length           : read at most this many bytes from elem
- * @attr             : attributes of new element.
- *
- * Appends a new element to the string list.
- *
- * @return true if successful, otherwise false.
- **/
-bool string_list_append_n(struct string_list *list, const char *elem,
-      unsigned length, union string_list_elem_attr attr)
-{
-   char *data_dup = NULL;
-
-   if (list->size >= list->cap &&
-         !string_list_capacity(list, list->cap * 2))
-      return false;
-
-   if (!(data_dup = (char*)malloc(length + 1)))
-      return false;
-
-   strlcpy(data_dup, elem, length + 1);
-
-   list->elems[list->size].data = data_dup;
-   list->elems[list->size].attr = attr;
-
-   list->size++;
-   return true;
-}
-
-/**
- * string_list_set:
- * @list             : pointer to string list
- * @idx              : index of element in string list
- * @str              : value for the element.
- *
- * Set value of element inside string list.
- **/
-void string_list_set(struct string_list *list,
-      unsigned idx, const char *str)
-{
-   free(list->elems[idx].data);
-   list->elems[idx].data = strdup(str);
-}
-
-/**
- * string_list_join_concat:
- * @buffer           : buffer that @list will be joined to.
- * @size             : length of @buffer.
- * @list             : pointer to string list.
- * @delim            : delimiter character for @list.
- *
- * A string list will be joined/concatenated as a
- * string to @buffer, delimited by @delim.
- **/
-void string_list_join_concat(char *buffer, size_t size,
+void string_list_join_concat(char *s, size_t len,
       const struct string_list *list, const char *delim)
 {
-   size_t i;
-   size_t len = strlen_size(buffer, size);
+   size_t _len = strlen(s);
 
-   /* If buffer is already 'full', nothing
+   /* If @s is already 'full', nothing
     * further can be added
     * > This condition will also be triggered
-    *   if buffer is not NULL-terminated,
+    *   if @s is not NULL-terminated,
     *   in which case any attempt to increment
-    *   buffer or decrement size would lead to
+    *   @s or decrement @len would lead to
     *   undefined behaviour */
-   if (len >= size)
-      return;
-
-   buffer += len;
-   size   -= len;
-
-   for (i = 0; i < list->size; i++)
+   if (_len < len)
    {
-      strlcat(buffer, list->elems[i].data, size);
+      size_t i;
+      for (i = 0; i < list->size; i++)
+      {
+         _len += strlcpy(s + _len, list->elems[i].data, len - _len);
+         if ((i + 1) < list->size)
+            _len += strlcpy(s + _len, delim, len - _len);
+      }
+   }
+}
+
+void string_list_join_concat_special(char *s, size_t len,
+      const struct string_list *list, const char *delim)
+{
+   size_t i;
+   size_t _len = strlen(s);
+   for (i = 0; i < list->size; i++)
+   {
+      _len += strlcpy(s + _len, list->elems[i].data, len - _len);
       if ((i + 1) < list->size)
-         strlcat(buffer, delim, size);
+         _len += strlcpy(s + _len, delim, len - _len);
    }
 }
 
-/**
- * string_split:
- * @str              : string to turn into a string list
- * @delim            : delimiter character to use for splitting the string.
- *
- * Creates a new string list based on string @str, delimited by @delim.
- *
- * Returns: new string list if successful, otherwise NULL.
- */
 struct string_list *string_split(const char *str, const char *delim)
 {
    char *save      = NULL;
@@ -353,97 +268,6 @@ bool string_split_noalloc(struct string_list *list,
    return true;
 }
 
-/**
- * string_separate:
- * @str              : string to turn into a string list
- * @delim            : delimiter character to use for separating the string.
- *
- * Creates a new string list based on string @str, delimited by @delim.
- * Includes empty strings - i.e. two adjacent delimiters will resolve
- * to a string list element of "".
- *
- * @return New string list if successful, otherwise NULL.
- **/
-struct string_list *string_separate(char *str, const char *delim)
-{
-   char *token              = NULL;
-   char **str_ptr           = NULL;
-   struct string_list *list = NULL;
-
-   /* Sanity check */
-   if (!str || string_is_empty(delim))
-      return NULL;
-   if (!(list = string_list_new()))
-	   return NULL;
-
-   str_ptr = &str;
-   token   = string_tokenize(str_ptr, delim);
-
-   while (token)
-   {
-      union string_list_elem_attr attr;
-
-      attr.i = 0;
-
-      if (!string_list_append(list, token, attr))
-      {
-         free(token);
-         string_list_free(list);
-         return NULL;
-      }
-
-      free(token);
-      token = string_tokenize(str_ptr, delim);
-   }
-
-   return list;
-}
-
-bool string_separate_noalloc(
-      struct string_list *list,
-      char *str, const char *delim)
-{
-   char *token              = NULL;
-   char **str_ptr           = NULL;
-
-   /* Sanity check */
-   if (!str || string_is_empty(delim) || !list)
-      return false;
-
-   str_ptr = &str;
-   token   = string_tokenize(str_ptr, delim);
-
-   while (token)
-   {
-      union string_list_elem_attr attr;
-
-      attr.i = 0;
-
-      if (!string_list_append(list, token, attr))
-      {
-         free(token);
-         return false;
-      }
-
-      free(token);
-      token = string_tokenize(str_ptr, delim);
-   }
-
-   return true;
-}
-
-/**
- * string_list_find_elem:
- *
- * @param list
- * Pointer to string list
- * @param elem
- * Element to find inside the string list.
- *
- * Searches for an element (@elem) inside the string list.
- *
- * @return Number of elements found, otherwise 0.
- */
 int string_list_find_elem(const struct string_list *list, const char *elem)
 {
    if (list)
@@ -458,21 +282,6 @@ int string_list_find_elem(const struct string_list *list, const char *elem)
    return 0;
 }
 
-/**
- * string_list_find_elem_prefix:
- *
- * @param list
- * Pointer to string list
- * @param prefix
- * Prefix to append to @elem
- * @param elem
- * Element to find inside the string list.
- *
- * Searches for an element (@elem) inside the string list. Will
- * also search for the same element prefixed by @prefix.
- *
- * @return true if element could be found, otherwise false.
- */
 bool string_list_find_elem_prefix(const struct string_list *list,
       const char *prefix, const char *elem)
 {
@@ -520,19 +329,19 @@ struct string_list *string_list_clone(const struct string_list *src)
 
    for (i = 0; i < src->size; i++)
    {
-      const char *_src       = src->elems[i].data;
-      size_t      len        = _src ? strlen(_src) : 0;
+      const char *_src    = src->elems[i].data;
+      size_t      len     = _src ? strlen(_src) : 0;
 
-      dest->elems[i].data    = NULL;
-      dest->elems[i].attr    = src->elems[i].attr;
+      dest->elems[i].data = NULL;
+      dest->elems[i].attr = src->elems[i].attr;
 
       if (len != 0)
       {
-         char *result        = (char*)malloc(len + 1);
-         if (result)
+         char *ret        = (char*)malloc(len + 1);
+         if (ret)
          {
-            strcpy(result, _src);
-            dest->elems[i].data = result;
+            strcpy(ret, _src);
+            dest->elems[i].data = ret;
          }
       }
    }
