@@ -91,28 +91,25 @@ int socket_next(void **address)
    return -1;
 }
 
-ssize_t socket_receive_all_nonblocking(int fd, bool *error,
-      void *data_, size_t size)
+ssize_t socket_receive_all_nonblocking(int fd, bool *err,
+      void *data_, size_t len)
 {
-   ssize_t ret = recv(fd, (char*)data_, size, 0);
-
+   ssize_t ret = recv(fd, (char*)data_, len, 0);
    if (ret > 0)
       return ret;
-
    if (ret < 0 && isagain((int)ret))
       return 0;
-
-   *error = true;
+   *err = true;
    return -1;
 }
 
-bool socket_receive_all_blocking(int fd, void *data_, size_t size)
+bool socket_receive_all_blocking(int fd, void *data_, size_t len)
 {
    const uint8_t *data = (const uint8_t*)data_;
 
-   while (size)
+   while (len)
    {
-      ssize_t ret = recv(fd, (char*)data, size, 0);
+      ssize_t ret = recv(fd, (char*)data, len, 0);
 
       if (!ret)
          return false;
@@ -125,7 +122,7 @@ bool socket_receive_all_blocking(int fd, void *data_, size_t size)
       else
       {
          data += ret;
-         size -= ret;
+         len  -= ret;
       }
    }
 
@@ -133,8 +130,7 @@ bool socket_receive_all_blocking(int fd, void *data_, size_t size)
 }
 
 bool socket_receive_all_blocking_with_timeout(int fd,
-      void *data_, size_t size,
-      int timeout)
+      void *data_, size_t len, int timeout)
 {
    const uint8_t *data    = (const uint8_t*)data_;
    retro_time_t  deadline = cpu_features_get_time_usec();
@@ -144,9 +140,9 @@ bool socket_receive_all_blocking_with_timeout(int fd,
    else
       deadline += 5000000;
 
-   while (size)
+   while (len)
    {
-      ssize_t ret = recv(fd, (char*)data, size, 0);
+      ssize_t ret = recv(fd, (char*)data, len, 0);
 
       if (!ret)
          return false;
@@ -169,7 +165,7 @@ bool socket_receive_all_blocking_with_timeout(int fd,
       else
       {
          data += ret;
-         size -= ret;
+         len  -= ret;
       }
    }
 
@@ -182,7 +178,7 @@ bool socket_set_block(int fd, bool block)
    u_long i = !block;
 
    return !ioctlsocket(fd, FIONBIO, &i);
-#elif !defined(__PSL1GHT__) && defined(__PS3__) || defined(VITA) || defined(WIIU)
+#elif defined(__PS3__) || defined(VITA) || defined(WIIU)
    int i = !block;
 
    return !setsockopt(fd, SOL_SOCKET, SO_NBIO, &i, sizeof(i));
@@ -212,7 +208,7 @@ int socket_close(int fd)
 #if defined(_WIN32) && !defined(_XBOX360)
    /* WinSock has headers from the stone age. */
    return closesocket(fd);
-#elif !defined(__PSL1GHT__) && defined(__PS3__) || defined(WIIU)
+#elif defined(__PS3__) || defined(WIIU)
    return socketclose(fd);
 #elif defined(VITA)
    return sceNetSocketClose(fd);
@@ -222,10 +218,10 @@ int socket_close(int fd)
 }
 
 int socket_select(int nfds, fd_set *readfds, fd_set *writefds,
-      fd_set *errorfds, struct timeval *timeout)
+      fd_set *err_fds, struct timeval *timeout)
 {
-#if !defined(__PSL1GHT__) && defined(__PS3__)
-   return socketselect(nfds, readfds, writefds, errorfds, timeout);
+#if defined(__PS3__)
+   return socketselect(nfds, readfds, writefds, err_fds, timeout);
 #elif defined(VITA)
    int i, j;
    fd_set rfds, wfds, efds;
@@ -254,7 +250,7 @@ int socket_select(int nfds, fd_set *readfds, fd_set *writefds,
          event_count++;
       else if (writefds && FD_ISSET(i, writefds))
          event_count++;
-      else if (errorfds && FD_ISSET(i, errorfds))
+      else if (err_fds && FD_ISSET(i, err_fds))
          event_count++;
    }
 
@@ -279,7 +275,7 @@ int socket_select(int nfds, fd_set *readfds, fd_set *writefds,
          if (writefds && FD_ISSET(i, writefds))
             event->events |= SCE_NET_EPOLLOUT;
 
-         if (event->events || (errorfds && FD_ISSET(i, errorfds)))
+         if (event->events || (err_fds && FD_ISSET(i, err_fds)))
          {
             event->data.fd = i;
 
@@ -310,8 +306,8 @@ int socket_select(int nfds, fd_set *readfds, fd_set *writefds,
          memcpy(&rfds, readfds, sizeof(rfds));
       if (writefds)
          memcpy(&wfds, writefds, sizeof(wfds));
-      if (errorfds)
-         memcpy(&efds, errorfds, sizeof(efds));
+      if (err_fds)
+         memcpy(&efds, err_fds, sizeof(efds));
    }
    else
    {
@@ -326,8 +322,8 @@ int socket_select(int nfds, fd_set *readfds, fd_set *writefds,
       FD_ZERO(readfds);
    if (writefds)
       FD_ZERO(writefds);
-   if (errorfds)
-      FD_ZERO(errorfds);
+   if (err_fds)
+      FD_ZERO(err_fds);
 
    /* Vita's epoll takes a microsecond timeout parameter. */
    if (timeout)
@@ -354,7 +350,7 @@ int socket_select(int nfds, fd_set *readfds, fd_set *writefds,
 
       EPOLL_FD_SET(SCE_NET_EPOLLIN,  &rfds, readfds)
       EPOLL_FD_SET(SCE_NET_EPOLLOUT, &wfds, writefds)
-      EPOLL_FD_SET(SCE_NET_EPOLLERR, &efds, errorfds)
+      EPOLL_FD_SET(SCE_NET_EPOLLERR, &efds, err_fds)
    }
 
    ret = j;
@@ -367,7 +363,7 @@ done:
 
    return ret;
 #else
-   return select(nfds, readfds, writefds, errorfds, timeout);
+   return select(nfds, readfds, writefds, err_fds, timeout);
 #endif
 }
 
@@ -483,7 +479,6 @@ done:
    for (i = 0; i < timeout_quotient; i++)
    {
       ret = poll(fds, nfds, TIMEOUT_DIVISOR);
-
       /* Success or error. */
       if (ret)
          return ret;
@@ -570,15 +565,15 @@ bool socket_wait(int fd, bool *rd, bool *wr, int timeout)
 #endif
 }
 
-bool socket_send_all_blocking(int fd, const void *data_, size_t size,
+bool socket_send_all_blocking(int fd, const void *data_, size_t len,
       bool no_signal)
 {
    const uint8_t *data = (const uint8_t*)data_;
    int           flags = no_signal ? MSG_NOSIGNAL : 0;
 
-   while (size)
+   while (len)
    {
-      ssize_t ret = send(fd, (const char*)data, size, flags);
+      ssize_t ret = send(fd, (const char*)data, len, flags);
 
       if (!ret)
          continue;
@@ -591,7 +586,7 @@ bool socket_send_all_blocking(int fd, const void *data_, size_t size,
       else
       {
          data += ret;
-         size -= ret;
+         len  -= ret;
       }
    }
 
@@ -599,7 +594,7 @@ bool socket_send_all_blocking(int fd, const void *data_, size_t size,
 }
 
 bool socket_send_all_blocking_with_timeout(int fd,
-      const void *data_, size_t size,
+      const void *data_, size_t len,
       int timeout, bool no_signal)
 {
    const uint8_t *data    = (const uint8_t*)data_;
@@ -611,9 +606,9 @@ bool socket_send_all_blocking_with_timeout(int fd,
    else
       deadline += 5000000;
 
-   while (size)
+   while (len)
    {
-      ssize_t ret = send(fd, (const char*)data, size, flags);
+      ssize_t ret = send(fd, (const char*)data, len, flags);
 
       if (!ret)
          continue;
@@ -636,22 +631,22 @@ bool socket_send_all_blocking_with_timeout(int fd,
       else
       {
          data += ret;
-         size -= ret;
+         len  -= ret;
       }
    }
 
    return true;
 }
 
-ssize_t socket_send_all_nonblocking(int fd, const void *data_, size_t size,
+ssize_t socket_send_all_nonblocking(int fd, const void *data_, size_t len,
       bool no_signal)
 {
    const uint8_t *data = (const uint8_t*)data_;
    int           flags = no_signal ? MSG_NOSIGNAL : 0;
 
-   while (size)
+   while (len)
    {
-      ssize_t ret = send(fd, (const char*)data, size, flags);
+      ssize_t ret = send(fd, (const char*)data, len, flags);
 
       if (!ret)
          break;
@@ -666,7 +661,7 @@ ssize_t socket_send_all_nonblocking(int fd, const void *data_, size_t size,
       else
       {
          data += ret;
-         size -= ret;
+         len  -= ret;
       }
    }
 
@@ -772,11 +767,11 @@ bool socket_connect_with_timeout(int fd, void *data, int timeout)
       return false;
 #else
    {
-      int       error = -1;
-      socklen_t errsz = sizeof(error);
+      int       err = -1;
+      socklen_t errsz = sizeof(err);
 
-      getsockopt(fd, SOL_SOCKET, SO_ERROR, (char*)&error, &errsz);
-      if (error)
+      getsockopt(fd, SOL_SOCKET, SO_ERROR, (char*)&err, &errsz);
+      if (err)
          return false;
    }
 #endif
