@@ -59,9 +59,7 @@ struct argument;
 
 typedef struct rmsgpack_dom_value (*rarch_query_func)(
       struct rmsgpack_dom_value input,
-      unsigned argc,
-      const struct argument *argv
-      );
+      unsigned argc, const struct argument *argv);
 
 struct invocation
 {
@@ -92,13 +90,13 @@ struct registered_func
    rarch_query_func func;
 };
 
+struct rmsgpack_dom_value intermediate_res;
+
 /* Forward declarations */
 static struct buffer query_parse_method_call(char *s, size_t len,
-      struct buffer buff,
-      struct invocation *invocation, const char **error);
-static struct buffer query_parse_table(char *s,
-      size_t len, struct buffer buff,
-      struct invocation *invocation, const char **error);
+      struct buffer buff, struct invocation *invocation, const char **err);
+static struct buffer query_parse_table(char *s, size_t len, struct buffer buff,
+      struct invocation *invocation, const char **err);
 
 /* Errors */
 static struct rmsgpack_dom_value query_func_is_true(
@@ -258,30 +256,101 @@ static struct rmsgpack_dom_value query_func_glob(
    return res;
 }
 
+/* Min and max functions will return all entries smaller/larger than previous *
+ * - in practice, last entry will contain the actual min/max value.           *
+ * Empty result means there is no such field. */
+static struct rmsgpack_dom_value query_func_min(
+      struct rmsgpack_dom_value input,
+      unsigned argc, const struct argument * argv)
+{
+   struct rmsgpack_dom_value res;
+
+   res.type                       = RDT_BOOL;
+   res.val.bool_                  = 0;
+
+   switch (input.type)
+   {
+      case RDT_INT:
+         res.val.bool_ = (
+               (input.val.int_ == 0)
+               || (input.val.int_ < intermediate_res.val.int_)
+               || (intermediate_res.val.int_ == 0));
+         if (res.val.bool_ || intermediate_res.val.int_ == 0)
+            memcpy(&intermediate_res, &input, sizeof(intermediate_res));
+         break;
+      case RDT_UINT:
+         res.val.bool_ = (
+               (input.val.uint_ == 0)
+               || (input.val.uint_ < intermediate_res.val.uint_)
+               || (intermediate_res.val.uint_ == 0));
+         if (res.val.bool_ || intermediate_res.val.uint_ == 0)
+            memcpy(&intermediate_res, &input, sizeof(intermediate_res));
+         break;
+      default:
+         break;
+   }
+
+   return res;
+}
+
+static struct rmsgpack_dom_value query_func_max(
+      struct rmsgpack_dom_value input,
+      unsigned argc, const struct argument * argv)
+{
+   struct rmsgpack_dom_value res;
+
+   res.type                       = RDT_BOOL;
+   res.val.bool_                  = 0;
+
+   switch (input.type)
+   {
+      case RDT_INT:
+         res.val.bool_ = (
+               (input.val.int_ == 0)
+               || (input.val.int_ > intermediate_res.val.int_)
+               || (intermediate_res.val.int_ == 0));
+         if (res.val.bool_ || intermediate_res.val.int_ == 0)
+            memcpy(&intermediate_res, &input, sizeof(intermediate_res));
+         break;
+      case RDT_UINT:
+         res.val.bool_ = (
+               (input.val.uint_ == 0)
+               || (input.val.uint_ > intermediate_res.val.uint_)
+               || (intermediate_res.val.uint_ == 0));
+         if (res.val.bool_ || intermediate_res.val.uint_ == 0)
+            memcpy(&intermediate_res, &input, sizeof(intermediate_res));
+         break;
+      default:
+         break;
+   }
+
+   return res;
+}
+
 struct registered_func registered_functions[100] = {
    {"is_true", query_func_is_true},
    {"or",      query_func_operator_or},
    {"and",     query_func_operator_and},
    {"between", query_func_between},
    {"glob",    query_func_glob},
+   {"min",     query_func_min},
+   {"max",     query_func_max},
    {NULL, NULL}
 };
 
 static void query_raise_unknown_function(
       char *s, size_t _len,
       ssize_t where, const char *name,
-      ssize_t len, const char **error)
+      ssize_t len, const char **err)
 {
-   int n = snprintf(s, _len,
+   int __len = snprintf(s, _len,
          "%" PRIu64 "::Unknown function '",
          (uint64_t)where
          );
-
-   if (len < ((ssize_t)_len - n - 3))
-      strncpy(s + n, name, len);
-
-   strcpy_literal(s + n + len, "'");
-   *error = s;
+   if (len < ((ssize_t)_len - __len - 3))
+      strncpy(s + __len, name, len);
+   strcpy(s + __len + len, "'");
+   *err = s;
 }
 
 static void query_argument_free(struct argument *arg)
@@ -304,7 +373,7 @@ static struct buffer query_parse_integer(
       char *s, size_t len,
       struct buffer buff,
       struct rmsgpack_dom_value *value,
-      const char **error)
+      const char **err)
 {
    value->type = RDT_INT;
    if (sscanf(buff.data + buff.offset,
@@ -314,7 +383,7 @@ static struct buffer query_parse_integer(
       snprintf(s, len,
             "%" PRIu64 "::Expected number",
             (uint64_t)buff.offset);
-      *error = s;
+      *err = s;
    }
    else
    {
@@ -333,7 +402,7 @@ static struct buffer query_chomp(struct buffer buff)
 }
 
 static struct buffer query_expect_eof(char *s, size_t len,
-      struct buffer buff, const char ** error)
+      struct buffer buff, const char ** err)
 {
    buff = query_chomp(buff);
    if ((unsigned)buff.offset < buff.len)
@@ -343,25 +412,24 @@ static struct buffer query_expect_eof(char *s, size_t len,
             (uint64_t)buff.offset,
             buff.data[buff.offset]
             );
-      *error = s;
+      *err = s;
    }
    return buff;
 }
 
 static int query_peek(struct buffer buff, const char * data,
-      size_t size_data)
+      size_t len)
 {
-   size_t remain    = buff.len - buff.offset;
-   if (remain < size_data)
+   size_t remain = buff.len - buff.offset;
+   if (remain < len)
       return 0;
-   return (strncmp(buff.data + buff.offset,
-            data, size_data) == 0);
+   return (strncmp(buff.data + buff.offset, data, len) == 0);
 }
 
 static struct buffer query_get_char(
       char *s, size_t len,
       struct buffer buff, char * c,
-      const char ** error)
+      const char ** err)
 {
    if ((unsigned)buff.offset >= buff.len)
    {
@@ -369,7 +437,7 @@ static struct buffer query_get_char(
             "%" PRIu64 "::Unexpected EOF",
             (uint64_t)buff.offset
             );
-      *error = s;
+      *err = s;
       return buff;
    }
 
@@ -381,21 +449,21 @@ static struct buffer query_get_char(
 static struct buffer query_parse_string(
       char *s, size_t len,
       struct buffer buff,
-      struct rmsgpack_dom_value *value, const char **error)
+      struct rmsgpack_dom_value *value, const char **err)
 {
    const char * str_start = NULL;
    char terminator        = '\0';
    char c                 = '\0';
    int  is_binstr         = 0;
-   buff                   = query_get_char(s, len,buff, &terminator, error);
+   buff                   = query_get_char(s, len,buff, &terminator, err);
 
-   if (*error)
+   if (*err)
       return buff;
 
    if (terminator == 'b')
    {
       is_binstr           = 1;
-      buff                = query_get_char(s, len, buff, &terminator, error);
+      buff                = query_get_char(s, len, buff, &terminator, err);
    }
 
    if (terminator != '"' && terminator != '\'')
@@ -404,20 +472,20 @@ static struct buffer query_parse_string(
       snprintf(s, len,
             "%" PRIu64 "::Expected string",
             (uint64_t)buff.offset);
-      *error = s;
+      *err = s;
    }
 
    str_start = buff.data + buff.offset;
-   buff      = query_get_char(s, len, buff, &c, error);
+   buff      = query_get_char(s, len, buff, &c, err);
 
-   while (!*error)
+   while (!*err)
    {
       if (c == terminator)
          break;
-      buff = query_get_char(s, len, buff, &c, error);
+      buff = query_get_char(s, len, buff, &c, err);
    }
 
-   if (!*error)
+   if (!*err)
    {
       size_t count;
       value->type            = is_binstr ? RDT_BINARY : RDT_STRING;
@@ -430,11 +498,11 @@ static struct buffer query_parse_string(
 
       if (!value->val.string.buff)
       {
-         s[0]   = 'O';
-         s[1]   = 'O';
-         s[2]   = 'M';
-         s[3]   = '\0';
-         *error = s;
+         s[0] = 'O';
+         s[1] = 'O';
+         s[2] = 'M';
+         s[3] = '\0';
+         *err = s;
       }
       else if (is_binstr)
       {
@@ -469,10 +537,9 @@ static struct buffer query_parse_string(
    return buff;
 }
 
-static struct buffer query_parse_value(
-      char *s, size_t len,
-      struct buffer buff,
-      struct rmsgpack_dom_value *value, const char **error)
+static struct buffer query_parse_value(char *s, size_t len,
+      struct buffer buff, struct rmsgpack_dom_value *value,
+      const char **err)
 {
    buff                 = query_chomp(buff);
 
@@ -497,16 +564,14 @@ static struct buffer query_parse_value(
             query_peek(buff, "b",  STRLEN_CONST("b"))
          || query_peek(buff, "\"", STRLEN_CONST("\""))
          || query_peek(buff, "'",  STRLEN_CONST("'")))
-      buff = query_parse_string(s, len,
-             buff, value, error);
+      buff = query_parse_string(s, len, buff, value, err);
    else if (ISDIGIT((int)buff.data[buff.offset]))
-      buff = query_parse_integer(s, len, buff, value, error);
+      buff = query_parse_integer(s, len, buff, value, err);
    return buff;
 }
 
 static void query_peek_char(char *s, size_t len,
-      struct buffer buff, char *c,
-      const char **error)
+      struct buffer buff, char *c, const char **err)
 {
    if ((unsigned)buff.offset >= buff.len)
    {
@@ -514,18 +579,16 @@ static void query_peek_char(char *s, size_t len,
             "%" PRIu64 "::Unexpected EOF",
             (uint64_t)buff.offset
             );
-      *error = s;
+      *err = s;
       return;
    }
 
    *c = buff.data[buff.offset];
 }
 
-static struct buffer query_get_ident(
-      char *s, size_t _len,
-      struct buffer buff,
-      const char **ident,
-      size_t *len, const char **error)
+static struct buffer query_get_ident(char *s, size_t _len,
+      struct buffer buff, const char **ident,
+      size_t *len, const char **err)
 {
    char c = '\0';
 
@@ -535,28 +598,28 @@ static struct buffer query_get_ident(
             "%" PRIu64 "::Unexpected EOF",
             (uint64_t)buff.offset
             );
-      *error = s;
+      *err = s;
       return buff;
    }
 
    *ident = buff.data + buff.offset;
    *len   = 0;
-   query_peek_char(s, _len, buff, &c, error);
+   query_peek_char(s, _len, buff, &c, err);
 
-   if (*error || !ISALPHA((int)c))
+   if (*err || !ISALPHA((int)c))
       return buff;
 
    buff.offset++;
    *len = *len + 1;
-   query_peek_char(s, _len, buff, &c, error);
+   query_peek_char(s, _len, buff, &c, err);
 
-   while (!*error)
+   while (!*err)
    {
       if (!(ISALNUM((int)c) || c == '_'))
          break;
       buff.offset++;
       *len = *len + 1;
-      query_peek_char(s, _len, buff, &c, error);
+      query_peek_char(s, _len, buff, &c, err);
    }
 
    return buff;
@@ -565,7 +628,7 @@ static struct buffer query_get_ident(
 static struct buffer query_expect_char(
       char *s, size_t len,
       struct buffer buff,
-      char c, const char ** error)
+      char c, const char ** err)
 {
    if ((unsigned)buff.offset >= buff.len)
    {
@@ -573,14 +636,14 @@ static struct buffer query_expect_char(
             "%" PRIu64 "::Unexpected EOF",
             (uint64_t)buff.offset
             );
-      *error = s;
+      *err = s;
    }
    else if (buff.data[buff.offset] != c)
    {
       snprintf(s, len,
             "%" PRIu64 "::Expected '%c' found '%c'",
             (uint64_t)buff.offset, c, buff.data[buff.offset]);
-      *error = s;
+      *err = s;
    }
    else
       buff.offset++;
@@ -590,7 +653,7 @@ static struct buffer query_expect_char(
 static struct buffer query_parse_argument(
       char *s, size_t len,
       struct buffer buff,
-      struct argument *arg, const char **error)
+      struct argument *arg, const char **err)
 {
    buff = query_chomp(buff);
 
@@ -608,120 +671,23 @@ static struct buffer query_parse_argument(
    {
       arg->type = AT_FUNCTION;
       buff      = query_parse_method_call(s, len, buff,
-            &arg->a.invocation, error);
+            &arg->a.invocation, err);
    }
    else if (query_peek(buff, "{", STRLEN_CONST("{")))
    {
       arg->type = AT_FUNCTION;
       buff      = query_parse_table(s, len,
-                  buff, &arg->a.invocation, error);
+                  buff, &arg->a.invocation, err);
    }
    else
    {
       arg->type = AT_VALUE;
       buff      = query_parse_value(s,
-                  len, buff, &arg->a.value, error);
+                  len, buff, &arg->a.value, err);
    }
    return buff;
 }
 
-static struct buffer query_parse_method_call(
-      char *s, size_t len, struct buffer buff,
-      struct invocation *invocation, const char **error)
-{
-   size_t func_name_len;
-   unsigned i;
-   struct argument args[QUERY_MAX_ARGS];
-   unsigned argi              = 0;
-   const char *func_name      = NULL;
-   struct registered_func *rf = registered_functions;
-
-   invocation->func           = NULL;
-
-   buff                       = query_get_ident(s, len,
-         buff, &func_name, &func_name_len, error);
-   if (*error)
-      goto clean;
-
-   buff                       = query_chomp(buff);
-   buff                       = query_expect_char(s, len, buff, '(', error);
-   if (*error)
-      goto clean;
-
-   while (rf->name)
-   {
-      if (strncmp(rf->name, func_name, func_name_len) == 0)
-      {
-         invocation->func = rf->func;
-         break;
-      }
-      rf++;
-   }
-
-   if (!invocation->func)
-   {
-      query_raise_unknown_function(s, len,
-            buff.offset, func_name,
-            func_name_len, error);
-      goto clean;
-   }
-
-   buff = query_chomp(buff);
-   while (!query_peek(buff, ")", STRLEN_CONST(")")))
-   {
-      if (argi >= QUERY_MAX_ARGS)
-      {
-         strcpy_literal(s,
-               "Too many arguments in function call.");
-         *error = s;
-         goto clean;
-      }
-
-      buff = query_parse_argument(s, len, buff, &args[argi], error);
-
-      if (*error)
-         goto clean;
-
-      argi++;
-      buff = query_chomp(buff);
-      buff = query_expect_char(s, len, buff, ',', error);
-
-      if (*error)
-      {
-         *error = NULL;
-         break;
-      }
-      buff = query_chomp(buff);
-   }
-   buff = query_expect_char(s, len, buff, ')', error);
-
-   if (*error)
-      goto clean;
-
-   invocation->argc = argi;
-   invocation->argv = (argi > 0) ? (struct argument*)
-      malloc(sizeof(struct argument) * argi) : NULL;
-
-   if (!invocation->argv)
-   {
-      s[0]   = 'O';
-      s[1]   = 'O';
-      s[2]   = 'M';
-      s[3]   = '\0';
-      *error = s;
-      goto clean;
-   }
-   memcpy(invocation->argv, args,
-         sizeof(struct argument) * argi);
-
-   return buff;
-
-clean:
-   for (i = 0; i < argi; i++)
-      query_argument_free(&args[i]);
-   return buff;
-}
-
 static struct rmsgpack_dom_value query_func_all_map(
       struct rmsgpack_dom_value input,
       unsigned argc, const struct argument *argv)
@@ -777,19 +743,19 @@ static struct rmsgpack_dom_value query_func_all_map(
 static struct buffer query_parse_table(
       char *s, size_t len,
       struct buffer buff,
-      struct invocation *invocation, const char **error)
+      struct invocation *invocation, const char **err)
 {
    unsigned i;
-   size_t ident_len;
+   size_t _len;
+   unsigned argi = 0;
    struct argument args[QUERY_MAX_ARGS];
    const char *ident_name = NULL;
-   unsigned argi = 0;
 
    buff = query_chomp(buff);
-   buff = query_expect_char(s, len, buff, '{', error);
+   buff = query_expect_char(s, len, buff, '{', err);
 
-   if (*error)
-      goto clean;
+   if (*err)
+      return buff;
 
    buff = query_chomp(buff);
 
@@ -797,80 +763,74 @@ static struct buffer query_parse_table(
    {
       if (argi >= QUERY_MAX_ARGS)
       {
-         strcpy_literal(s,
-               "Too many arguments in function call.");
-         *error = s;
+         strlcpy(s, "Too many arguments in function call.", len);
+         *err = s;
          goto clean;
       }
 
       if (ISALPHA((int)buff.data[buff.offset]))
       {
          buff = query_get_ident(s, len,
-               buff, &ident_name, &ident_len, error);
+               buff, &ident_name, &_len, err);
 
-         if (!*error)
+         if (!*err)
          {
             args[argi].a.value.type            = RDT_STRING;
-            args[argi].a.value.val.string.len  = (uint32_t)ident_len;
+            args[argi].a.value.val.string.len  = (uint32_t)_len;
             args[argi].a.value.val.string.buff = (char*)calloc(
-                  ident_len + 1,
-                  sizeof(char)
-                  );
+                  _len + 1, sizeof(char));
 
             if (!args[argi].a.value.val.string.buff)
                goto clean;
 
             strncpy(
                   args[argi].a.value.val.string.buff,
-                  ident_name,
-                  ident_len
-                  );
+                  ident_name, _len);
          }
       }
       else
          buff = query_parse_string(s, len,
-               buff, &args[argi].a.value, error);
+               buff, &args[argi].a.value, err);
 
-      if (*error)
+      if (*err)
          goto clean;
 
       args[argi].type = AT_VALUE;
       buff            = query_chomp(buff);
       argi++;
-      buff            = query_expect_char(s, len, buff, ':', error);
+      buff            = query_expect_char(s, len, buff, ':', err);
 
-      if (*error)
+      if (*err)
          goto clean;
 
       buff = query_chomp(buff);
 
       if (argi >= QUERY_MAX_ARGS)
       {
-         strcpy_literal(s,
-               "Too many arguments in function call.");
-         *error = s;
+         strlcpy(s, "Too many arguments in function call.", len);
+         *err = s;
          goto clean;
       }
 
-      buff = query_parse_argument(s, len, buff, &args[argi], error);
+      buff = query_parse_argument(s, len, buff, &args[argi], err);
 
-      if (*error)
+      if (*err)
          goto clean;
       argi++;
       buff = query_chomp(buff);
-      buff = query_expect_char(s, len, buff, ',', error);
+      buff = query_expect_char(s, len, buff, ',', err);
 
-      if (*error)
+      if (*err)
       {
-         *error = NULL;
+         *err = NULL;
          break;
       }
       buff = query_chomp(buff);
    }
 
-   buff = query_expect_char(s, len, buff, '}', error);
+   buff = query_expect_char(s, len, buff, '}', err);
 
-   if (*error)
+   if (*err)
       goto clean;
 
    invocation->func = query_func_all_map;
@@ -880,11 +840,106 @@ static struct buffer query_parse_table(
 
    if (!invocation->argv)
    {
-      s[0]   = 'O';
-      s[1]   = 'O';
-      s[2]   = 'M';
-      s[3]   = '\0';
-      *error = s;
+      s[0] = 'O';
+      s[1] = 'O';
+      s[2] = 'M';
+      s[3] = '\0';
+      *err = s;
+      goto clean;
+   }
+
+   memcpy(invocation->argv, args,
+         sizeof(struct argument) * argi);
+
+   return buff;
+
+clean:
+   for (i = 0; i < argi; i++)
+      query_argument_free(&args[i]);
+   return buff;
+}
+
+static struct buffer query_parse_method_call(
+      char *s, size_t len, struct buffer buff,
+      struct invocation *invocation, const char **err)
+{
+   unsigned i;
+   size_t _len;
+   struct argument args[QUERY_MAX_ARGS];
+   unsigned argi              = 0;
+   const char *func_name      = NULL;
+   struct registered_func *rf = registered_functions;
+
+   invocation->func           = NULL;
+
+   buff = query_get_ident(s, len, buff, &func_name, &_len, err);
+   if (*err)
+      return buff;
+
+   buff = query_chomp(buff);
+   buff = query_expect_char(s, len, buff, '(', err);
+   if (*err)
+      goto clean;
+
+   while (rf->name)
+   {
+      if (strncmp(rf->name, func_name, _len) == 0)
+      {
+         invocation->func = rf->func;
+         break;
+      }
+      rf++;
+   }
+
+   if (!invocation->func)
+   {
+      query_raise_unknown_function(s, len,
+            buff.offset, func_name, _len, err);
+      goto clean;
+   }
+
+   buff = query_chomp(buff);
+   while (!query_peek(buff, ")", STRLEN_CONST(")")))
+   {
+      if (argi >= QUERY_MAX_ARGS)
+      {
+         strlcpy(s, "Too many arguments in function call.", len);
+         *err = s;
+         goto clean;
+      }
+
+      buff = query_parse_argument(s, len, buff, &args[argi], err);
+
+      if (*err)
+         goto clean;
+
+      argi++;
+      buff = query_chomp(buff);
+      buff = query_expect_char(s, len, buff, ',', err);
+
+      if (*err)
+      {
+         *err = NULL;
+         break;
+      }
+      buff = query_chomp(buff);
+   }
+   buff = query_expect_char(s, len, buff, ')', err);
+
+   if (*err)
+      goto clean;
+
+   invocation->argc = argi;
+   invocation->argv = (argi > 0) ? (struct argument*)
+      malloc(sizeof(struct argument) * argi) : NULL;
+
+   if (!invocation->argv)
+   {
+      s[0] = 'O';
+      s[1] = 'O';
+      s[2] = 'M';
+      s[3] = '\0';
+      *err = s;
       goto clean;
    }
    memcpy(invocation->argv, args,
@@ -917,55 +972,58 @@ void libretrodb_query_free(void *q)
 }
 
 void *libretrodb_query_compile(libretrodb_t *db,
-      const char *query, size_t buff_len, const char **error_string)
+      const char *query, size_t len, const char **err_string)
 {
    struct buffer buff;
    /* TODO/FIXME - static local variable */
-   static char tmp_error_buff [MAX_ERROR_LEN] = {0};
-   struct query *q       = (struct query*)malloc(sizeof(*q));
-   size_t error_buff_len = sizeof(tmp_error_buff);
+   static char tmp_err_buff [MAX_ERROR_LEN] = {0};
+   struct query *q     = (struct query*)malloc(sizeof(*q));
+   size_t err_buff_len = sizeof(tmp_err_buff);
+
+   intermediate_res.val.int_  = 0;
+   intermediate_res.val.uint_ = 0;
 
    if (!q)
       return NULL;
 
-   q->ref_count          = 1;
-   q->root.argc          = 0;
-   q->root.func          = NULL;
-   q->root.argv          = NULL;
+   q->ref_count        = 1;
+   q->root.argc        = 0;
+   q->root.func        = NULL;
+   q->root.argv        = NULL;
 
-   buff.data             = query;
-   buff.len              = buff_len;
-   buff.offset           = 0;
-   *error_string         = NULL;
+   buff.data           = query;
+   buff.len            = len;
+   buff.offset         = 0;
+   *err_string         = NULL;
 
    buff                  = query_chomp(buff);
 
    if (query_peek(buff, "{", STRLEN_CONST("{")))
    {
-      buff = query_parse_table(tmp_error_buff,
-            error_buff_len, buff, &q->root, error_string);
-      if (*error_string)
+      buff = query_parse_table(tmp_err_buff,
+            err_buff_len, buff, &q->root, err_string);
+      if (*err_string)
          goto error;
    }
    else if (ISALPHA((int)buff.data[buff.offset]))
-      buff = query_parse_method_call(tmp_error_buff,
-            error_buff_len,
-            buff, &q->root, error_string);
+      buff = query_parse_method_call(tmp_err_buff,
+            err_buff_len,
+            buff, &q->root, err_string);
 
-   buff = query_expect_eof(tmp_error_buff,
-            error_buff_len,
-            buff, error_string);
+   buff = query_expect_eof(tmp_err_buff,
+            err_buff_len,
+            buff, err_string);
 
-   if (*error_string)
+   if (*err_string)
       goto error;
 
    if (!q->root.func)
    {
-      snprintf(tmp_error_buff, error_buff_len,
+      snprintf(tmp_err_buff, err_buff_len,
             "%" PRIu64 "::Unexpected EOF",
             (uint64_t)buff.offset
             );
-      *error_string = tmp_error_buff;
+      *err_string = tmp_err_buff;
       goto error;
    }
 
