@@ -112,8 +112,8 @@ int generic_action_cheat_toggle(size_t idx, unsigned type, const char *label,
    settings_t           *settings = config_get_ptr();
    bool apply_cheats_after_toggle = settings->bools.apply_cheats_after_toggle;
 
-   cheat_manager_toggle_index(
-         apply_cheats_after_toggle,
+   cheat_manager_toggle_index(apply_cheats_after_toggle,
+         settings->bools.notification_show_cheats_applied,
          (unsigned)idx);
 
    return 0;
@@ -139,6 +139,57 @@ static int action_right_cheat_num_passes(unsigned type, const char *label,
 }
 #endif
 
+static int action_right_input_desc(unsigned type, const char *label,
+      bool wraparound)
+{
+   settings_t *settings          = config_get_ptr();
+   rarch_system_info_t *sys_info = &runloop_state_get_ptr()->system;
+
+   if (settings && sys_info)
+   {
+      unsigned bind_idx;
+      unsigned user_idx    = (type - MENU_SETTINGS_INPUT_DESC_BEGIN) / (RARCH_FIRST_CUSTOM_BIND + 8);
+      unsigned btn_idx     = (type - MENU_SETTINGS_INPUT_DESC_BEGIN) - (RARCH_FIRST_CUSTOM_BIND + 8) * user_idx;
+      unsigned mapped_port = settings->uints.input_remap_ports[user_idx];
+      unsigned remap_idx   = settings->uints.input_remap_ids[user_idx][btn_idx];
+
+      for (bind_idx = 0; bind_idx < RARCH_ANALOG_BIND_LIST_END; bind_idx++)
+      {
+         if (input_config_bind_order[bind_idx] == remap_idx)
+            break;
+      }
+
+      /* If pressed from unmapped bind, start from the top */
+      if (label)
+      {
+         struct menu_state *menu_st = menu_state_get_ptr();
+         menu_entry_t entry;
+         MENU_ENTRY_INITIALIZE(entry);
+         entry.flags |= MENU_ENTRY_FLAG_VALUE_ENABLED;
+         menu_entry_get(&entry, 0, menu_st->selection_ptr, NULL, true);
+         if (string_is_equal(entry.value, RARCH_NO_BIND))
+            bind_idx = RARCH_UNMAPPED;
+      }
+
+      if (bind_idx < RARCH_ANALOG_BIND_LIST_END - 1)
+      {
+         bind_idx++;
+         bind_idx = input_config_bind_order[bind_idx];
+         settings->uints.input_remap_ids[user_idx][btn_idx] = bind_idx;
+
+         /* Skip empty descs */
+         if (string_is_empty(sys_info->input_desc_btn[mapped_port][bind_idx]))
+            return action_right_input_desc(type, NULL, wraparound);
+      }
+      else if (bind_idx == RARCH_ANALOG_BIND_LIST_END - 1)
+         settings->uints.input_remap_ids[user_idx][btn_idx] = RARCH_UNMAPPED;
+      else
+         settings->uints.input_remap_ids[user_idx][btn_idx] = input_config_bind_order[0];
+   }
+
+   return 0;
+}
+
 static int action_right_input_desc_kbd(unsigned type, const char *label,
       bool wraparound)
 {
@@ -152,8 +203,7 @@ static int action_right_input_desc_kbd(unsigned type, const char *label,
    user_idx = (type - MENU_SETTINGS_INPUT_DESC_KBD_BEGIN) / RARCH_ANALOG_BIND_LIST_END;
    btn_idx  = (type - MENU_SETTINGS_INPUT_DESC_KBD_BEGIN) - RARCH_ANALOG_BIND_LIST_END * user_idx;
 
-   remap_id =
-      settings->uints.input_keymapper_ids[user_idx][btn_idx];
+   remap_id = settings->uints.input_keymapper_ids[user_idx][btn_idx];
 
    for (key_id = 0; key_id < RARCH_MAX_KEYS; key_id++)
    {
@@ -171,62 +221,6 @@ static int action_right_input_desc_kbd(unsigned type, const char *label,
    return 0;
 }
 
-/* TODO/FIXME: incomplete, lacks error checking */
-static int action_right_input_desc(unsigned type, const char *label,
-   bool wraparound)
-{
-   settings_t *settings                  = config_get_ptr();
-   rarch_system_info_t *sys_info         = &runloop_state_get_ptr()->system;
-   if (settings && sys_info)
-   {
-      unsigned bind_idx;
-      unsigned user_idx    = (type - MENU_SETTINGS_INPUT_DESC_BEGIN) / (RARCH_FIRST_CUSTOM_BIND + 8);
-      unsigned btn_idx     = (type - MENU_SETTINGS_INPUT_DESC_BEGIN) - (RARCH_FIRST_CUSTOM_BIND + 8) * user_idx;
-      unsigned mapped_port = settings->uints.input_remap_ports[user_idx];
-      unsigned remap_idx   = settings->uints.input_remap_ids[user_idx][btn_idx];
-      for (bind_idx = 0; bind_idx < RARCH_ANALOG_BIND_LIST_END; bind_idx++)
-      {
-         if (input_config_bind_order[bind_idx] == remap_idx)
-            break;
-      }
-
-      if (bind_idx < RARCH_CUSTOM_BIND_LIST_END - 1)
-      {
-         if (bind_idx > RARCH_ANALOG_BIND_LIST_END)
-            settings->uints.input_remap_ids[user_idx][btn_idx]++;
-         else
-         {
-            if (bind_idx < RARCH_ANALOG_BIND_LIST_END - 1)
-            {
-               bind_idx++;
-               bind_idx = input_config_bind_order[bind_idx];
-            }
-            else if (bind_idx == RARCH_ANALOG_BIND_LIST_END - 1)
-               bind_idx = RARCH_UNMAPPED;
-            else
-               bind_idx = input_config_bind_order[0];
-            settings->uints.input_remap_ids[user_idx][btn_idx] = bind_idx;
-         }
-      }
-      else if (bind_idx == RARCH_CUSTOM_BIND_LIST_END - 1)
-         settings->uints.input_remap_ids[user_idx][btn_idx] = RARCH_UNMAPPED;
-      else
-         settings->uints.input_remap_ids[user_idx][btn_idx] = input_config_bind_order[0];
-
-      remap_idx = settings->uints.input_remap_ids[user_idx][btn_idx];
-
-      /* skip the not used buttons (unless they are at the end by calling the right desc function recursively
-         also skip all the axes until analog remapping is implemented */
-      if (remap_idx != RARCH_UNMAPPED)
-      {
-         if ((string_is_empty(sys_info->input_desc_btn[mapped_port][remap_idx]) && remap_idx < RARCH_CUSTOM_BIND_LIST_END))
-            action_right_input_desc(type, label, wraparound);
-      }
-   }
-
-   return 0;
-}
-
 static int action_right_scroll(unsigned type, const char *label,
       bool wraparound)
 {
@@ -290,12 +284,12 @@ static int action_right_mainmenu(unsigned type, const char *label,
    const char *menu_ident              = (driver_ctx && driver_ctx->ident)
       ? driver_ctx->ident
       : NULL;
-   size_t size                         = (driver_ctx && driver_ctx->list_get_size)
+   size_t _len                         = (driver_ctx && driver_ctx->list_get_size)
       ? driver_ctx->list_get_size(menu_st->userdata, MENU_LIST_PLAIN)
       : 0;
    /* Tab switching functionality only applies
     * to XMB */
-   if (  (size == 1)
+   if (  (_len == 1)
        && string_is_equal(menu_ident, "xmb"))
    {
       size_t horiz_size = 0, tabs_size = 0, selection = 0;
@@ -951,8 +945,8 @@ static int disk_options_disk_idx_right(unsigned type, const char *label,
 static int action_right_state_slot(unsigned type, const char *label,
       bool wraparound)
 {
-   settings_t       *settings = config_get_ptr();
    struct menu_state *menu_st = menu_state_get_ptr();
+   settings_t       *settings = config_get_ptr();
 
    settings->ints.state_slot++;
    if (settings->ints.state_slot > 999)
@@ -960,10 +954,9 @@ static int action_right_state_slot(unsigned type, const char *label,
 
    if (menu_st->driver_ctx)
    {
-      size_t selection = menu_st->selection_ptr;
       if (menu_st->driver_ctx->update_savestate_thumbnail_path)
          menu_st->driver_ctx->update_savestate_thumbnail_path(
-               menu_st->userdata, (unsigned)selection);
+               menu_st->userdata, (unsigned)menu_st->selection_ptr);
       if (menu_st->driver_ctx->update_savestate_thumbnail_image)
          menu_st->driver_ctx->update_savestate_thumbnail_image(menu_st->userdata);
    }
@@ -974,23 +967,12 @@ static int action_right_state_slot(unsigned type, const char *label,
 static int action_right_replay_slot(unsigned type, const char *label,
       bool wraparound)
 {
-   struct menu_state *menu_st     = menu_state_get_ptr();
-   size_t selection               = menu_st->selection_ptr;
    settings_t           *settings = config_get_ptr();
 
    settings->ints.replay_slot++;
    if (settings->ints.replay_slot > 999)
       settings->ints.replay_slot = -1;
 
-   if (menu_st->driver_ctx)
-   {
-      if (menu_st->driver_ctx->update_savestate_thumbnail_path)
-         menu_st->driver_ctx->update_savestate_thumbnail_path(
-               menu_st->userdata, (unsigned)selection);
-      if (menu_st->driver_ctx->update_savestate_thumbnail_image)
-         menu_st->driver_ctx->update_savestate_thumbnail_image(menu_st->userdata);
-   }
-
    return 0;
 }
 
@@ -1053,6 +1035,7 @@ static int menu_cbs_init_bind_right_compare_type(menu_file_list_cbs_t *cbs,
             break;
          case FILE_TYPE_PLAIN:
          case FILE_TYPE_DIRECTORY:
+         case FILE_TYPE_PATH:
          case FILE_TYPE_PARENT_DIRECTORY:
          case FILE_TYPE_CARCHIVE:
          case FILE_TYPE_IN_CARCHIVE:
@@ -1242,6 +1225,9 @@ static int menu_cbs_init_bind_right_compare_label(menu_file_list_cbs_t *cbs,
             case MENU_ENUM_LABEL_MANUAL_CONTENT_SCAN_CORE_NAME:
                BIND_ACTION_RIGHT(cbs, manual_content_scan_core_name_right);
                break;
+            case MENU_ENUM_LABEL_STATE_SLOT:
+               BIND_ACTION_RIGHT(cbs, action_right_state_slot);
+               break;
             #ifdef HAVE_LAKKA
             case MENU_ENUM_LABEL_CPU_PERF_MODE:
                BIND_ACTION_RIGHT(cbs, cpu_policy_mode_change);
