@@ -39,6 +39,7 @@
 #endif
 #include "../../retroarch.h"
 #include "../../verbosity.h"
+#include "../../paths.h"
 #include "../../performance_counters.h"
 #include "../../playlist.h"
 #include "../../manual_content_scan.h"
@@ -82,9 +83,7 @@ static int action_start_remap_file_info(
       unsigned type, size_t idx, size_t entry_idx)
 {
    struct menu_state *menu_st            = menu_state_get_ptr();
-   settings_t *settings                  = config_get_ptr();
-   const char *directory_input_remapping = settings ?
-         settings->paths.directory_input_remapping : NULL;
+   const char *directory_input_remapping = config_get_ptr()->paths.directory_input_remapping;
    rarch_system_info_t *sys_info         = &runloop_state_get_ptr()->system;
 
    input_remapping_deinit(false);
@@ -105,53 +104,35 @@ static int action_start_override_file_info(
    struct menu_state *menu_st      = menu_state_get_ptr();
    rarch_system_info_t *sys_info   = &runloop_state_get_ptr()->system;
    config_load_override(sys_info);
+
    /* Refresh menu */
    menu_st->flags                 |=  MENU_ST_FLAG_ENTRIES_NEED_REFRESH
                                    |  MENU_ST_FLAG_PREVENT_POPULATE;
    return 0;
 }
 
-static int action_start_shader_preset(
+static int action_start_shader_preset_file_info(
       const char *path, const char *label,
       unsigned type, size_t idx, size_t entry_idx)
 {
 #if defined(HAVE_CG) || defined(HAVE_GLSL) || defined(HAVE_SLANG) || defined(HAVE_HLSL)
-   struct menu_state *menu_st      = menu_state_get_ptr();
-   struct video_shader *shader     = menu_shader_get();
-   shader->passes                  = 0;
-   menu_st->flags                 |=  MENU_ST_FLAG_ENTRIES_NEED_REFRESH
-                                   |  MENU_ST_FLAG_PREVENT_POPULATE;
-   command_event(CMD_EVENT_SHADERS_APPLY_CHANGES, NULL);
+   const char *current = video_shader_get_current_shader_preset();
+   command_set_shader(NULL, current);
 #endif
    return 0;
 }
 
-static int action_start_shader_preset_prepend(
-   const char* path, const char* label,
-   unsigned type, size_t idx, size_t entry_idx)
+static int action_start_shader_parameters(
+      const char *path, const char *label,
+      unsigned type, size_t idx, size_t entry_idx)
 {
 #if defined(HAVE_CG) || defined(HAVE_GLSL) || defined(HAVE_SLANG) || defined(HAVE_HLSL)
-   struct menu_state *menu_st      = menu_state_get_ptr();
-   struct video_shader* shader     = menu_shader_get();
-   shader->passes                  = 0;
-   menu_st->flags                 |=  MENU_ST_FLAG_ENTRIES_NEED_REFRESH
-                                   |  MENU_ST_FLAG_PREVENT_POPULATE;
-   command_event(CMD_EVENT_SHADERS_APPLY_CHANGES, NULL);
-#endif
-   return 0;
-}
-
-static int action_start_shader_preset_append(
-   const char* path, const char* label,
-   unsigned type, size_t idx, size_t entry_idx)
-{
-#if defined(HAVE_CG) || defined(HAVE_GLSL) || defined(HAVE_SLANG) || defined(HAVE_HLSL)
-   struct menu_state *menu_st      = menu_state_get_ptr();
-   struct video_shader* shader     = menu_shader_get();
-   shader->passes                  = 0;
-   menu_st->flags                 |=  MENU_ST_FLAG_ENTRIES_NEED_REFRESH
-                                   |  MENU_ST_FLAG_PREVENT_POPULATE;
-   command_event(CMD_EVENT_SHADERS_APPLY_CHANGES, NULL);
+   generic_action_ok_displaylist_push(
+         msg_hash_to_str(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PARAMETERS),
+         NULL,
+         msg_hash_to_str(MENU_ENUM_LABEL_VIDEO_SHADER_PARAMETERS),
+         MENU_SETTING_ACTION,
+         idx, 0, ACTION_OK_DL_GENERIC);
 #endif
    return 0;
 }
@@ -487,7 +468,6 @@ static int action_start_state_slot(
       unsigned type, size_t idx, size_t entry_idx)
 {
    struct menu_state *menu_st = menu_state_get_ptr();
-   size_t selection           = menu_st->selection_ptr;
    settings_t *settings       = config_get_ptr();
 
    settings->ints.state_slot  = 0;
@@ -496,7 +476,7 @@ static int action_start_state_slot(
    {
       if (menu_st->driver_ctx->update_savestate_thumbnail_path)
          menu_st->driver_ctx->update_savestate_thumbnail_path(
-               menu_st->userdata, (unsigned)selection);
+               menu_st->userdata, (unsigned)menu_st->selection_ptr);
       if (menu_st->driver_ctx->update_savestate_thumbnail_image)
          menu_st->driver_ctx->update_savestate_thumbnail_image(menu_st->userdata);
    }
@@ -637,8 +617,8 @@ static int action_start_load_core(
       unsigned type, size_t idx, size_t entry_idx)
 {
    struct menu_state *menu_st  = menu_state_get_ptr();
-   int ret                     = generic_action_ok_command(
-         CMD_EVENT_UNLOAD_CORE);
+   int ret                     = generic_action_ok_command(CMD_EVENT_UNLOAD_CORE);
+   path_clear(RARCH_PATH_CORE_LAST);
    menu_st->flags             |=  MENU_ST_FLAG_ENTRIES_NEED_REFRESH
                                |  MENU_ST_FLAG_PREVENT_POPULATE;
    return ret;
@@ -717,7 +697,7 @@ static int action_start_core_lock(
          _len += strlcpy(msg + _len, core_name, sizeof(msg) - _len);
 
       /* Generate log + notification */
-      RARCH_ERR("%s\n", msg);
+      RARCH_ERR("[Core] %s\n", msg);
 
       runloop_msg_queue_push(msg, _len, 1, 100, true, NULL,
             MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
@@ -775,7 +755,7 @@ static int action_start_core_set_standalone_exempt(
             _len += strlcpy(msg + _len, core_name, sizeof(msg) - _len);
 
          /* Generate log + notification */
-         RARCH_ERR("%s\n", msg);
+         RARCH_ERR("[Core] %s\n", msg);
 
          runloop_msg_queue_push(msg, _len, 1, 100, true, NULL,
                MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
@@ -801,16 +781,19 @@ static int menu_cbs_init_bind_start_compare_label(menu_file_list_cbs_t *cbs)
       switch (cbs->enum_idx)
       {
          case MENU_ENUM_LABEL_CORE_LIST:
+         case MENU_ENUM_LABEL_CORE_LIST_UNLOAD:
             BIND_ACTION_START(cbs, action_start_load_core);
             break;
+         case MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_MANAGER:
          case MENU_ENUM_LABEL_VIDEO_SHADER_PRESET:
-            BIND_ACTION_START(cbs, action_start_shader_preset);
-            break;
-         case MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_APPEND:
-            BIND_ACTION_START(cbs, action_start_shader_preset_append);
-            break;
          case MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_PREPEND:
-            BIND_ACTION_START(cbs, action_start_shader_preset_prepend);
+         case MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_APPEND:
+         case MENU_ENUM_LABEL_VIDEO_SHADER_PARAMETERS:
+         case MENU_ENUM_LABEL_SHADER_APPLY_CHANGES:
+            BIND_ACTION_START(cbs, action_start_shader_parameters);
+            break;
+         case MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_FILE_INFO:
+            BIND_ACTION_START(cbs, action_start_shader_preset_file_info);
             break;
          case MENU_ENUM_LABEL_REMAP_FILE_INFO:
             BIND_ACTION_START(cbs, action_start_remap_file_info);
@@ -898,6 +881,13 @@ static int menu_cbs_init_bind_start_compare_label(menu_file_list_cbs_t *cbs)
          case MENU_ENUM_LABEL_MENU_WALLPAPER:
             BIND_ACTION_START(cbs, action_start_menu_wallpaper);
             break;
+         case MENU_ENUM_LABEL_LOAD_CONTENT_HISTORY:
+         case MENU_ENUM_LABEL_GOTO_FAVORITES:
+         case MENU_ENUM_LABEL_GOTO_IMAGES:
+         case MENU_ENUM_LABEL_GOTO_MUSIC:
+         case MENU_ENUM_LABEL_GOTO_VIDEO:
+            BIND_ACTION_START(cbs, action_ok_push_playlist_manager_settings);
+            break;
          default:
             return -1;
       }
