@@ -298,9 +298,9 @@ static INLINE void menu_screensaver_set_dimensions(
 
 static bool menu_screensaver_init_effect(menu_screensaver_t *screensaver)
 {
+   size_t i;
    unsigned width;
    unsigned height;
-   size_t i;
 
    /* Create particle array, if required */
    if (!screensaver->particles)
@@ -311,7 +311,7 @@ static bool menu_screensaver_init_effect(menu_screensaver_t *screensaver)
       if (!screensaver->particles)
          return false;
    }
-   
+
    width  = screensaver->last_width;
    height = screensaver->last_height;
 
@@ -420,8 +420,8 @@ static bool menu_screensaver_update_state(
 #endif
 
    /* Check if dimensions have changed */
-   if ((screensaver->last_width  != width) ||
-       (screensaver->last_height != height))
+   if (   (screensaver->last_width  != width)
+       || (screensaver->last_height != height))
    {
       menu_screensaver_set_dimensions(screensaver, width, height);
 
@@ -453,9 +453,9 @@ static bool menu_screensaver_update_state(
    }
 
    /* Create font, if required */
-   if ((screensaver->effect != MENU_SCREENSAVER_BLANK) &&
-       !screensaver->font_data.font &&
-       screensaver->font_enabled)
+   if (   (screensaver->effect != MENU_SCREENSAVER_BLANK)
+       && !screensaver->font_data.font
+       &&  screensaver->font_enabled)
    {
       char font_file[PATH_MAX_LENGTH];
 #if defined(HAVE_FREETYPE) || (defined(__APPLE__) && defined(HAVE_CORETEXT)) || defined(HAVE_STB_FONT)
@@ -472,7 +472,7 @@ static bool menu_screensaver_update_state(
       /* Warn if font file is missing */
       if (!path_is_valid(font_file))
       {
-         RARCH_WARN("[Menu Screensaver] Font asset missing: %s\n", font_file);
+         RARCH_WARN("[Screensaver] Font asset missing: %s.\n", font_file);
          screensaver->unicode_enabled = false;
       }
 #else
@@ -496,7 +496,7 @@ static bool menu_screensaver_update_state(
        * further attempts to create fonts */
       else
       {
-         RARCH_WARN("[Menu Screensaver] Failed to initialise font - animation disabled\n");
+         RARCH_WARN("[Screensaver] Failed to initialise font - animation disabled.\n");
          screensaver->font_enabled = false;
          return false;
       }
@@ -518,12 +518,12 @@ void menu_screensaver_iterate(
       uint32_t particle_tint, unsigned width, unsigned height,
       const char *dir_assets)
 {
-   float base_particle_size;
+   size_t i;
    uint32_t tint_r;
    uint32_t tint_g;
    uint32_t tint_b;
+   float base_particle_size;
    float global_speed_factor;
-   size_t i;
 
    if (!screensaver)
       return;
@@ -532,9 +532,9 @@ void menu_screensaver_iterate(
    if (!menu_screensaver_update_state(
          screensaver, p_disp,
          effect, particle_tint,
-         width, height, dir_assets) ||
-       (screensaver->effect == MENU_SCREENSAVER_BLANK) ||
-       !screensaver->particles)
+         width, height, dir_assets)
+       || (screensaver->effect == MENU_SCREENSAVER_BLANK)
+       || !screensaver->particles)
       return;
 
    base_particle_size = screensaver->particle_scale * screensaver->font_size;
@@ -544,7 +544,7 @@ void menu_screensaver_iterate(
 
    /* Set global animation speed */
    global_speed_factor = p_anim->delta_time / MENU_SS_EFFECT_PERIOD;
-   if (effect_speed > 0.0001f) 
+   if (effect_speed > 0.0001f)
       global_speed_factor *= effect_speed;
 
    /* Update particle array */
@@ -623,11 +623,11 @@ void menu_screensaver_iterate(
                /* Reset particle if it has:
                 * - Dropped off the edge of the screen
                 * - Reached the screen depth */
-               if ((particle->x < -particle_size_px) ||
-                   (particle->x > (float)width + particle_size_px) ||
-                   (particle->y < -particle_size_px) ||
-                   (particle->y > (float)height + particle_size_px) ||
-                   (particle->c <= 0.0f))
+               if (   (particle->x < -particle_size_px)
+                   || (particle->x > (float)width + particle_size_px)
+                   || (particle->y < -particle_size_px)
+                   || (particle->y > (float)height + particle_size_px)
+                   || (particle->c <= 0.0f))
                {
                   /* x pos ('physical' space) */
                   particle->a = (float)(rand() % width);
@@ -784,9 +784,9 @@ void menu_screensaver_frame(menu_screensaver_t *screensaver,
        && font
        && screensaver->particles)
    {
+      size_t i;
       float y_centre_offset = screensaver->font_data.y_centre_offset;
       float particle_scale  = screensaver->particle_scale;
-      size_t i;
 
       /* Bind font */
       font_driver_bind_block(font, &screensaver->font_data.raster_block);
