@@ -38,11 +38,13 @@ typedef struct
 {
    char url[PATH_MAX_LENGTH];
    char *last_slash;
+   char post_slash;
    webdav_mkdir_cb_t cb;
    webdav_cb_state_t *cb_st;
 } webdav_mkdir_state_t;
 
-/* TODO: all of this HTTP auth stuff should probably live in libretro-common/net? */
+/* TODO: all of this HTTP auth stuff should
+ * probably live in libretro-common/net? */
 typedef struct
 {
    char url[PATH_MAX_LENGTH];
@@ -70,26 +72,24 @@ webdav_state_t *webdav_state_get_ptr(void)
 
 static char *webdav_create_basic_auth(void)
 {
-   settings_t *settings  = config_get_ptr();
-   size_t      len       = 0;
-   char        userpass[512];
-   char       *base64auth;
    int         flen;
-
+   char       *base64auth;
+   char        userpass[512];
+   settings_t *settings  = config_get_ptr();
+   size_t      _len      = 0;
    if (!string_is_empty(settings->arrays.webdav_username))
-      len += strlcpy(userpass + len, settings->arrays.webdav_username, sizeof(userpass) - len);
-   userpass[len++] = ':';
+      _len += strlcpy(userpass + _len, settings->arrays.webdav_username, sizeof(userpass) - _len);
+   userpass[_len++] = ':';
    if (!string_is_empty(settings->arrays.webdav_password))
-      len += strlcpy(userpass + len, settings->arrays.webdav_password, sizeof(userpass) - len);
-   userpass[len] = '\0';
-   base64auth = base64(userpass, (int)len, &flen);
-   len = strlcpy(userpass, "Authorization: Basic ", sizeof(userpass));
-   len += strlcpy(userpass + len, base64auth, sizeof(userpass) - len);
+      _len += strlcpy(userpass + _len, settings->arrays.webdav_password, sizeof(userpass) - _len);
+   userpass[_len]   = '\0';
+   base64auth = base64(userpass, (int)_len, &flen);
+   _len  = strlcpy(userpass, "Authorization: Basic ", sizeof(userpass));
+   _len += strlcpy(userpass + _len, base64auth, sizeof(userpass) - _len);
    free(base64auth);
-   userpass[len++] = '\r';
-   userpass[len++] = '\n';
-   userpass[len  ] = '\0';
-
+   userpass[_len++] = '\r';
+   userpass[_len++] = '\n';
+   userpass[_len  ] = '\0';
    return strdup(userpass);
 }
 
@@ -123,16 +123,16 @@ static void webdav_cleanup_digest(void)
 
 static char *webdav_create_ha1_hash(char *user, char *realm, char *pass)
 {
-   char           *hash      = malloc(33);
-   MD5_CTX         md5;
-   unsigned char   digest[16];
+   MD5_CTX md5;
+   unsigned char digest[16];
+   char *hash = (char*)malloc(33);
 
    MD5_Init(&md5);
-   MD5_Update(&md5, user, strlen(user));
+   MD5_Update(&md5, user, (unsigned long)strlen(user));
    MD5_Update(&md5, ":", 1);
-   MD5_Update(&md5, realm, strlen(realm));
+   MD5_Update(&md5, realm, (unsigned long)strlen(realm));
    MD5_Update(&md5, ":", 1);
-   MD5_Update(&md5, pass, strlen(pass));
+   MD5_Update(&md5, pass, (unsigned long)strlen(pass));
    MD5_Final(digest, &md5);
 
    snprintf(hash, 33, "%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
@@ -145,14 +145,14 @@ static char *webdav_create_ha1_hash(char *user, char *realm, char *pass)
 
 static bool webdav_create_digest_auth(char *digest)
 {
+   size_t _len;
    webdav_state_t *webdav_st = webdav_state_get_ptr();
    settings_t     *settings  = config_get_ptr();
    char           *ptr       = digest + STRLEN_CONST("WWW-Authenticate: Digest ");
    char           *end       = ptr + strlen(ptr);
-   size_t          sz;
 
-   if (string_is_empty(settings->arrays.webdav_username) &&
-       string_is_empty(settings->arrays.webdav_password))
+   if (   string_is_empty(settings->arrays.webdav_username)
+       && string_is_empty(settings->arrays.webdav_password))
       return false;
 
    webdav_cleanup_digest();
@@ -170,12 +170,14 @@ static bool webdav_create_digest_auth(char *digest)
       if (string_starts_with(ptr, "realm=\""))
       {
          ptr += STRLEN_CONST("realm=\"");
-         sz = strchr(ptr, '"') + 1 - ptr;
-         webdav_st->realm = malloc(sz);
-         strlcpy(webdav_st->realm, ptr, sz);
-         ptr += sz;
+         _len = strchr(ptr, '"') + 1 - ptr;
+         webdav_st->realm = (char*)malloc(_len);
+         strlcpy(webdav_st->realm, ptr, _len);
+         ptr += _len;
 
-         webdav_st->ha1hash = webdav_create_ha1_hash(webdav_st->username, webdav_st->realm, settings->arrays.webdav_password);
+         webdav_st->ha1hash = webdav_create_ha1_hash(
+               webdav_st->username, webdav_st->realm,
+               settings->arrays.webdav_password);
       }
       else if (string_starts_with(ptr, "qop=\""))
       {
@@ -184,8 +186,8 @@ static bool webdav_create_digest_auth(char *digest)
          tail = strchr(ptr, '"');
          while (ptr < tail)
          {
-            if (string_starts_with(ptr, "auth") &&
-                (ptr[4] == ',' || ptr[4] == '"'))
+            if (    string_starts_with(ptr, "auth")
+                && (ptr[4] == ',' || ptr[4] == '"'))
             {
                webdav_st->qop_auth = true;
                break;
@@ -204,20 +206,20 @@ static bool webdav_create_digest_auth(char *digest)
       else if (string_starts_with(ptr, "nonce=\""))
       {
          ptr += STRLEN_CONST("nonce=\"");
-         sz = strchr(ptr, '"') + 1 - ptr;
-         webdav_st->nonce = malloc(sz);
-         strlcpy(webdav_st->nonce, ptr, sz);
-         ptr += sz;
+         _len = strchr(ptr, '"') + 1 - ptr;
+         webdav_st->nonce = (char*)malloc(_len);
+         strlcpy(webdav_st->nonce, ptr, _len);
+         ptr += _len;
       }
       else if (string_starts_with(ptr, "algorithm="))
       {
          ptr += STRLEN_CONST("algorithm=");
          if (strchr(ptr, ','))
          {
-            sz = strchr(ptr, ',') + 1 - ptr;
-            webdav_st->algo = malloc(sz);
-            strlcpy(webdav_st->algo, ptr, sz);
-            ptr += sz;
+            _len = strchr(ptr, ',') + 1 - ptr;
+            webdav_st->algo = (char*)malloc(_len);
+            strlcpy(webdav_st->algo, ptr, _len);
+            ptr += _len;
          }
          else
          {
@@ -228,10 +230,10 @@ static bool webdav_create_digest_auth(char *digest)
       else if (string_starts_with(ptr, "opaque=\""))
       {
          ptr += STRLEN_CONST("opaque=\"");
-         sz = strchr(ptr, '"') + 1 - ptr;
-         webdav_st->opaque = malloc(sz);
-         strlcpy(webdav_st->opaque, ptr, sz);
-         ptr += sz;
+         _len = strchr(ptr, '"') + 1 - ptr;
+         webdav_st->opaque = (char*)malloc(_len);
+         strlcpy(webdav_st->opaque, ptr, _len);
+         ptr += _len;
       }
       else
       {
@@ -277,14 +279,14 @@ static char *webdav_create_ha1(void)
    if (!string_is_equal(webdav_st->algo, "MD5-sess"))
       return strdup(webdav_st->ha1hash);
 
-   hash = malloc(33);
+   hash = (char*)malloc(33);
 
    MD5_Init(&md5);
    MD5_Update(&md5, webdav_st->ha1hash, 32);
    MD5_Update(&md5, ":", 1);
-   MD5_Update(&md5, webdav_st->nonce, strlen(webdav_st->nonce));
+   MD5_Update(&md5, webdav_st->nonce, (unsigned long)strlen(webdav_st->nonce));
    MD5_Update(&md5, ":", 1);
-   MD5_Update(&md5, webdav_st->cnonce, strlen(webdav_st->cnonce));
+   MD5_Update(&md5, webdav_st->cnonce, (unsigned long)strlen(webdav_st->cnonce));
    MD5_Final(digest, &md5);
 
    snprintf(hash, 33, "%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
@@ -297,15 +299,15 @@ static char *webdav_create_ha1(void)
 
 static char *webdav_create_ha2(const char *method, const char *path)
 {
-   /* no attempt at supporting auth-int, everything else uses this */
-   char           *hash      = malloc(33);
    MD5_CTX         md5;
    unsigned char   digest[16];
+   /* no attempt at supporting auth-int, everything else uses this */
+   char           *hash      = (char*)malloc(33);
 
    MD5_Init(&md5);
-   MD5_Update(&md5, method, strlen(method));
+   MD5_Update(&md5, method, (unsigned long)strlen(method));
    MD5_Update(&md5, ":", 1);
-   MD5_Update(&md5, path, strlen(path));
+   MD5_Update(&md5, path, (unsigned long)strlen(path));
    MD5_Final(digest, &md5);
 
    snprintf(hash, 33, "%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
@@ -318,25 +320,25 @@ static char *webdav_create_ha2(const char *method, const char *path)
 
 static char *webdav_create_digest_response(const char *method, const char *path)
 {
+   MD5_CTX         md5;
+   unsigned char   digest[16];
    webdav_state_t *webdav_st = webdav_state_get_ptr();
    char           *ha1       = webdav_create_ha1();
    char           *ha2       = webdav_create_ha2(method, path);
-   char           *hash      = malloc(33);
-   MD5_CTX         md5;
-   unsigned char   digest[16];
+   char           *hash      = (char*)malloc(33);
 
    MD5_Init(&md5);
    MD5_Update(&md5, ha1, 32);
    MD5_Update(&md5, ":", 1);
-   MD5_Update(&md5, webdav_st->nonce, strlen(webdav_st->nonce));
+   MD5_Update(&md5, webdav_st->nonce, (unsigned long)strlen(webdav_st->nonce));
    if (webdav_st->qop_auth)
    {
       char nonceCount[10];
       snprintf(nonceCount, sizeof(nonceCount), "%08x", webdav_st->nc);
       MD5_Update(&md5, ":", 1);
-      MD5_Update(&md5, nonceCount, strlen(nonceCount));
+      MD5_Update(&md5, nonceCount, (unsigned long)strlen(nonceCount));
       MD5_Update(&md5, ":", 1);
-      MD5_Update(&md5, webdav_st->cnonce, strlen(webdav_st->cnonce));
+      MD5_Update(&md5, webdav_st->cnonce, (unsigned long)strlen(webdav_st->cnonce));
       MD5_Update(&md5, ":", 1);
       MD5_Update(&md5, "auth", STRLEN_CONST("auth"));
    }
@@ -357,13 +359,13 @@ static char *webdav_create_digest_response(const char *method, const char *path)
 
 static char *webdav_create_digest_auth_header(const char *method, const char *url)
 {
+   size_t _len, __len;
+   char nonceCount[10];
    webdav_state_t *webdav_st = webdav_state_get_ptr();
-   char           *header;
-   char           *response;
-   char            nonceCount[10];
+   char           *header    = NULL;
+   char           *response  = NULL;
    const char     *path      = url;
    int             count     = 0;
-   size_t          len       = 0;
    size_t          total     = 0;
 
    do
@@ -374,50 +376,49 @@ static char *webdav_create_digest_auth_header(const char *method, const char *ur
    } while (count < 3 && *path != '\0');
 
    response = webdav_create_digest_response(method, path);
-   snprintf(nonceCount, sizeof(nonceCount), "%08x", webdav_st->nc++);
+   __len    = snprintf(nonceCount, sizeof(nonceCount),
+         "%08x", webdav_st->nc++);
 
-   len  = STRLEN_CONST("Authorization: Digest ");
-   len += STRLEN_CONST("username=\"") + strlen(webdav_st->username) + STRLEN_CONST("\", ");
-   len += STRLEN_CONST("realm=\"") + strlen(webdav_st->realm) + STRLEN_CONST("\", ");
-   len += STRLEN_CONST("nonce=\"") + strlen(webdav_st->nonce) + STRLEN_CONST("\", ");
-   len += STRLEN_CONST("uri=\"") + strlen(path) + STRLEN_CONST("\", ");
-   len += STRLEN_CONST("nc=\"") + strlen(nonceCount) + STRLEN_CONST("\", ");
-   len += STRLEN_CONST("cnonce=\"") + strlen(webdav_st->cnonce) + STRLEN_CONST("\", ");
+   _len  = STRLEN_CONST("Authorization: Digest ");
+   _len += STRLEN_CONST("username=\"") + strlen(webdav_st->username) + STRLEN_CONST("\", ");
+   _len += STRLEN_CONST("realm=\"")    + strlen(webdav_st->realm) + STRLEN_CONST("\", ");
+   _len += STRLEN_CONST("nonce=\"")    + strlen(webdav_st->nonce) + STRLEN_CONST("\", ");
+   _len += STRLEN_CONST("uri=\"")      + strlen(path) + STRLEN_CONST("\", ");
+   _len += STRLEN_CONST("nc=\"")       + __len + STRLEN_CONST("\", ");
+   _len += STRLEN_CONST("cnonce=\"")   + strlen(webdav_st->cnonce) + STRLEN_CONST("\", ");
    if (webdav_st->qop_auth)
-      len += STRLEN_CONST("qop=\"auth\", ");
+      _len += STRLEN_CONST("qop=\"auth\", ");
    if (webdav_st->opaque)
-      len += STRLEN_CONST("opaque=\"") + strlen(webdav_st->opaque) + STRLEN_CONST("\", ");
-   len += STRLEN_CONST("response=\"") + strlen(response) + STRLEN_CONST("\"\r\n");
-   len += 1;
+      _len += STRLEN_CONST("opaque=\"") + strlen(webdav_st->opaque) + STRLEN_CONST("\", ");
+   _len += STRLEN_CONST("response=\"")  + strlen(response) + STRLEN_CONST("\"\r\n");
+   _len += 1;
 
-   total = len;
-   len = 0;
-   header = malloc(total);
-   len  = strlcpy(header, "Authorization: Digest username=\"", total - len);
-   len += strlcpy(header + len, webdav_st->username, total - len);
-   len += strlcpy(header + len, "\", realm=\"", total - len);
-   len += strlcpy(header + len, webdav_st->realm, total - len);
-   len += strlcpy(header + len, "\", nonce=\"", total - len);
-   len += strlcpy(header + len, webdav_st->nonce, total - len);
-   len += strlcpy(header + len, "\", uri=\"", total - len);
-   len += strlcpy(header + len, path, total - len);
-   len += strlcpy(header + len, "\", nc=\"", total - len);
-   len += strlcpy(header + len, nonceCount, total - len);
-   len += strlcpy(header + len, "\", cnonce=\"", total - len);
-   len += strlcpy(header + len, webdav_st->cnonce, total - len);
+   total  = _len;
+   _len   = 0;
+   header = (char*)malloc(total);
+   _len   = strlcpy(header, "Authorization: Digest username=\"", total - _len);
+   _len  += strlcpy(header + _len, webdav_st->username, total - _len);
+   _len  += strlcpy(header + _len, "\", realm=\"", total - _len);
+   _len  += strlcpy(header + _len, webdav_st->realm, total - _len);
+   _len  += strlcpy(header + _len, "\", nonce=\"", total - _len);
+   _len  += strlcpy(header + _len, webdav_st->nonce, total - _len);
+   _len  += strlcpy(header + _len, "\", uri=\"", total - _len);
+   _len  += strlcpy(header + _len, path, total - _len);
+   _len  += strlcpy(header + _len, "\", nc=\"", total - _len);
+   _len  += strlcpy(header + _len, nonceCount, total - _len);
+   _len  += strlcpy(header + _len, "\", cnonce=\"", total - _len);
+   _len  += strlcpy(header + _len, webdav_st->cnonce, total - _len);
    if (webdav_st->qop_auth)
-      len += strlcpy(header + len, "\", qop=\"auth", total - len);
+      _len += strlcpy(header + _len, "\", qop=\"auth", total - _len);
    if (webdav_st->opaque)
    {
-      len += strlcpy(header + len, "\", opaque=\"", total - len);
-      len += strlcpy(header + len, webdav_st->opaque, total - len);
+      _len += strlcpy(header + _len, "\", opaque=\"", total - _len);
+      _len += strlcpy(header + _len, webdav_st->opaque, total - _len);
    }
-   len += strlcpy(header + len, "\", response=\"", total - len);
-   len += strlcpy(header + len, response, total - len);
-          strlcpy(header + len, "\"\r\n", total - len);
-
+   _len += strlcpy(header + _len, "\", response=\"", total - _len);
+   _len += strlcpy(header + _len, response, total - _len);
+   strlcpy(header + _len, "\"\r\n", total - _len);
    free(response);
-
    return header;
 }
 
@@ -426,8 +427,8 @@ static char *webdav_get_auth_header(const char *method, const char *url)
    webdav_state_t *webdav_st = webdav_state_get_ptr();
    settings_t     *settings  = config_get_ptr();
 
-   if (string_is_empty(settings->arrays.webdav_username) &&
-       string_is_empty(settings->arrays.webdav_password))
+   if (   string_is_empty(settings->arrays.webdav_username)
+       && string_is_empty(settings->arrays.webdav_password))
       return NULL;
 
    if (webdav_st->basic)
@@ -443,7 +444,7 @@ static char *webdav_get_auth_header(const char *method, const char *url)
 static void webdav_log_http_failure(const char *path, http_transfer_data_t *data)
 {
     size_t i;
-    RARCH_WARN("[webdav] failed: %s: HTTP %d\n", path, data->status);
+    RARCH_WARN("[webdav] Failed: %s: HTTP %d\n", path, data->status);
     for (i = 0; data->headers && i < data->headers->size; i++)
         RARCH_WARN("%s\n", data->headers->elems[i].data);
     if (data->data)
@@ -465,11 +466,10 @@ static bool webdav_needs_reauth(http_transfer_data_t *data)
       if (!string_starts_with(data->headers->elems[i].data, "WWW-Authenticate: Digest "))
          continue;
 
-      RARCH_DBG("[webdav] found WWW-Authenticate: Digest header\n");
+      RARCH_DBG("[webdav] Found WWW-Authenticate: Digest header\n");
       if (webdav_create_digest_auth(data->headers->elems[i].data))
          return true;
-      else
-         RARCH_WARN("[webdav] failure creating WWW-Authenticate: Digest header\n");
+      RARCH_WARN("[webdav] Failure creating WWW-Authenticate: Digest header\n");
    }
 
    return false;
@@ -486,7 +486,7 @@ static void webdav_stat_cb(retro_task_t *task, void *task_data, void *user_data,
       return;
 
    if (!data)
-      RARCH_WARN("[webdav] did not get data for stat, is the server down?\n");
+      RARCH_WARN("[webdav] Did not get data for stat, is the server down?\n");
 
    if (webdav_needs_reauth(data))
    {
@@ -505,11 +505,11 @@ static void webdav_stat_cb(retro_task_t *task, void *task_data, void *user_data,
 
 static bool webdav_sync_begin(cloud_sync_complete_handler_t cb, void *user_data)
 {
+   char *auth_header;
+   size_t _len                  = 0;
    settings_t        *settings  = config_get_ptr();
    const char        *url       = settings->arrays.webdav_url;
    webdav_state_t    *webdav_st = webdav_state_get_ptr();
-   size_t             len       = 0;
-   char              *auth_header;
 
    if (string_is_empty(url))
       return false;
@@ -518,28 +518,27 @@ static bool webdav_sync_begin(cloud_sync_complete_handler_t cb, void *user_data)
    if (strncmp(url, "https", 5) == 0)
       return false;
 #endif
-   /* TODO: LOCK? */
-
+   /* TODO/FIXME: LOCK? */
    if (!strstr(url, "://"))
-       len += strlcpy(webdav_st->url, "http://", STRLEN_CONST("http://"));
-   strlcpy(webdav_st->url + len, url, sizeof(webdav_st->url) - len);
+       _len += strlcpy(webdav_st->url, "http://", STRLEN_CONST("http://"));
+   strlcpy(webdav_st->url + _len, url, sizeof(webdav_st->url) - _len);
    fill_pathname_slash(webdav_st->url, sizeof(webdav_st->url));
 
-   /* url/username/password may have changed, redo auth check */
+   /* URL/username/password may have changed, redo auth check */
    webdav_st->basic = true;
-   auth_header = webdav_get_auth_header(NULL, NULL);
+   auth_header      = webdav_get_auth_header(NULL, NULL);
 
    if (auth_header)
    {
       webdav_cb_state_t *webdav_cb_st = (webdav_cb_state_t*)calloc(1, sizeof(webdav_cb_state_t));
-      webdav_cb_st->cb = cb;
+      webdav_cb_st->cb        = cb;
       webdav_cb_st->user_data = user_data;
       task_push_webdav_stat(webdav_st->url, true, auth_header, webdav_stat_cb, webdav_cb_st);
       free(auth_header);
    }
    else
    {
-      RARCH_WARN("[webdav] no basic auth header, assuming no user, check username/password?\n");
+      RARCH_WARN("[webdav] No basic auth header, assuming no user, check username/password?\n");
       cb(user_data, NULL, true, NULL);
    }
    return true;
@@ -549,7 +548,7 @@ static bool webdav_sync_end(cloud_sync_complete_handler_t cb, void *user_data)
 {
    webdav_state_t *webdav_st = webdav_state_get_ptr();
 
-   /* TODO: UNLOCK? */
+   /* TODO/FIXME: UNLOCK? */
 
    if (webdav_st->basic_auth_header)
       free(webdav_st->basic_auth_header);
@@ -566,10 +565,8 @@ static void webdav_read_cb(retro_task_t *task, void *task_data, void *user_data,
    webdav_cb_state_t    *webdav_cb_st = (webdav_cb_state_t *)user_data;
    http_transfer_data_t *data         = (http_transfer_data_t*)task_data;
    RFILE                *file         = NULL;
-   bool                  success;
-
-   success = (data &&
-              ((data->status >= 200 && data->status < 300) || data->status == 404));
+   bool success = (data
+              && ((data->status >= 200 && data->status < 300) || data->status == 404));
 
    if (!success && data)
        webdav_log_http_failure(webdav_cb_st->path, data);
@@ -593,7 +590,8 @@ static void webdav_read_cb(retro_task_t *task, void *task_data, void *user_data,
 
    if (success && data->data && webdav_cb_st)
    {
-      /* TODO: it would be better if writing to the file happened during the network reads */
+      /* TODO/FIXME: it would be better if writing
+       * to the file happened during the network reads */
       file = filestream_open(webdav_cb_st->file,
                              RETRO_VFS_FILE_ACCESS_READ_WRITE,
                              RETRO_VFS_FILE_ACCESS_HINT_NONE);
@@ -606,39 +604,44 @@ static void webdav_read_cb(retro_task_t *task, void *task_data, void *user_data,
 
    if (webdav_cb_st)
    {
-      webdav_cb_st->cb(webdav_cb_st->user_data, webdav_cb_st->path, success, file);
+      webdav_cb_st->cb(webdav_cb_st->user_data,
+            webdav_cb_st->path, success, file);
       free(webdav_cb_st);
    }
 }
 
-static bool webdav_read(const char *path, const char *file, cloud_sync_complete_handler_t cb, void *user_data)
+static bool webdav_read(const char *path, const char *file,
+      cloud_sync_complete_handler_t cb, void *user_data)
 {
-   webdav_state_t    *webdav_st    = webdav_state_get_ptr();
-   webdav_cb_state_t *webdav_cb_st = (webdav_cb_state_t*)calloc(1, sizeof(webdav_cb_state_t));
+   void              *t;
+   char              *auth_header;
    char               url[PATH_MAX_LENGTH];
    char               url_encoded[PATH_MAX_LENGTH];
-   char              *auth_header;
+   webdav_state_t    *webdav_st    = webdav_state_get_ptr();
+   webdav_cb_state_t *webdav_cb_st = (webdav_cb_state_t*)calloc(1, sizeof(webdav_cb_state_t));
 
    fill_pathname_join_special(url, webdav_st->url, path, sizeof(url));
    net_http_urlencode_full(url_encoded, url, sizeof(url_encoded));
 
-   webdav_cb_st->cb = cb;
+   webdav_cb_st->cb        = cb;
    webdav_cb_st->user_data = user_data;
    strlcpy(webdav_cb_st->path, path, sizeof(webdav_cb_st->path));
    strlcpy(webdav_cb_st->file, file, sizeof(webdav_cb_st->file));
 
    RARCH_DBG("[webdav] GET %s\n", url_encoded);
    auth_header = webdav_get_auth_header("GET", url_encoded);
-   task_push_http_transfer_with_headers(url_encoded, true, NULL, auth_header, webdav_read_cb, webdav_cb_st);
+   t = task_push_http_transfer_with_headers(url_encoded, true, NULL,
+         auth_header, webdav_read_cb, webdav_cb_st);
    free(auth_header);
-   return true;
+   return (t != NULL);
 }
 
-static void webdav_mkdir_cb(retro_task_t *task, void *task_data, void *user_data, const char *err)
+static void webdav_mkdir_cb(retro_task_t *task, void *task_data,
+      void *user_data, const char *err)
 {
+   char *auth_header;
    webdav_mkdir_state_t *webdav_mkdir_st = (webdav_mkdir_state_t *)user_data;
    http_transfer_data_t *data            = (http_transfer_data_t*)task_data;
-   char                 *auth_header;
 
    if (!webdav_mkdir_st)
       return;
@@ -658,17 +661,18 @@ static void webdav_mkdir_cb(retro_task_t *task, void *task_data, void *user_data
       if (data)
          webdav_log_http_failure(webdav_mkdir_st->url, data);
       else
-         RARCH_WARN("[webdav] could not mkdir %s\n", webdav_mkdir_st ? webdav_mkdir_st->url : "<unknown>");
+         RARCH_WARN("[webdav] Could not mkdir %s\n", webdav_mkdir_st ? webdav_mkdir_st->url : "<unknown>");
       webdav_mkdir_st->cb(false, webdav_mkdir_st->cb_st);
       free(webdav_mkdir_st);
       return;
    }
 
-   *webdav_mkdir_st->last_slash++ = '/';
-   webdav_mkdir_st->last_slash = strchr(webdav_mkdir_st->last_slash, '/');
+   webdav_mkdir_st->last_slash[1] = webdav_mkdir_st->post_slash;
+   webdav_mkdir_st->last_slash = strchr(webdav_mkdir_st->last_slash + 1, '/');
    if (webdav_mkdir_st->last_slash)
    {
-      *webdav_mkdir_st->last_slash = '\0';
+      webdav_mkdir_st->post_slash    = webdav_mkdir_st->last_slash[1];
+      webdav_mkdir_st->last_slash[1] = '\0';
       RARCH_DBG("[webdav] MKCOL %s\n", webdav_mkdir_st->url);
       auth_header = webdav_get_auth_header("MKCOL", webdav_mkdir_st->url);
       task_push_webdav_mkdir(webdav_mkdir_st->url, true, auth_header, webdav_mkdir_cb, webdav_mkdir_st);
@@ -682,18 +686,20 @@ static void webdav_mkdir_cb(retro_task_t *task, void *task_data, void *user_data
    }
 }
 
-static void webdav_ensure_dir(const char *dir, webdav_mkdir_cb_t cb, webdav_cb_state_t *webdav_cb_st)
+static void webdav_ensure_dir(const char *dir, webdav_mkdir_cb_t cb,
+      webdav_cb_state_t *webdav_cb_st)
 {
+   char url[PATH_MAX_LENGTH];
+   http_transfer_data_t  data;
    webdav_state_t       *webdav_st       = webdav_state_get_ptr();
    webdav_mkdir_state_t *webdav_mkdir_st = (webdav_mkdir_state_t *)malloc(sizeof(webdav_mkdir_state_t));
-   http_transfer_data_t  data;
-   char                  url[PATH_MAX_LENGTH];
 
    fill_pathname_join_special(url, webdav_st->url, dir, sizeof(url));
    net_http_urlencode_full(webdav_mkdir_st->url, url, sizeof(webdav_mkdir_st->url));
    webdav_mkdir_st->last_slash = strchr(webdav_mkdir_st->url + strlen(webdav_st->url) - 1, '/');
-   webdav_mkdir_st->cb = cb;
-   webdav_mkdir_st->cb_st = webdav_cb_st;
+   webdav_mkdir_st->post_slash = webdav_mkdir_st->last_slash[1];
+   webdav_mkdir_st->cb         = cb;
+   webdav_mkdir_st->cb_st      = webdav_cb_st;
 
    /* this is a recursive callback, set it up so it looks like it's still proceeding */
    data.status = 200;
@@ -701,7 +707,9 @@ static void webdav_ensure_dir(const char *dir, webdav_mkdir_cb_t cb, webdav_cb_s
 }
 
 static void webdav_do_update(bool success, webdav_cb_state_t *webdav_cb_st);
-static void webdav_update_cb(retro_task_t *task, void *task_data, void *user_data, const char *err)
+
+static void webdav_update_cb(retro_task_t *task, void *task_data,
+      void *user_data, const char *err)
 {
    webdav_cb_state_t    *webdav_cb_st = (webdav_cb_state_t *)user_data;
    http_transfer_data_t *data         = (http_transfer_data_t*)task_data;
@@ -710,7 +718,7 @@ static void webdav_update_cb(retro_task_t *task, void *task_data, void *user_dat
    if (!success && data)
        webdav_log_http_failure(webdav_cb_st->path, data);
    else if (!data)
-      RARCH_WARN("[webdav] could not upload %s\n", webdav_cb_st ? webdav_cb_st->path : "<unknown>");
+      RARCH_WARN("[webdav] Could not upload %s\n", webdav_cb_st ? webdav_cb_st->path : "<unknown>");
 
    if (webdav_needs_reauth(data))
    {
@@ -724,7 +732,7 @@ static void webdav_update_cb(retro_task_t *task, void *task_data, void *user_dat
       free(webdav_cb_st);
    }
    else
-      RARCH_WARN("[webdav] missing cb data in update?\n");
+      RARCH_WARN("[webdav] Missing cb data in update?\n");
 }
 
 static void webdav_do_update(bool success, webdav_cb_state_t *webdav_cb_st)
@@ -741,7 +749,7 @@ static void webdav_do_update(bool success, webdav_cb_state_t *webdav_cb_st)
 
    if (!success)
    {
-      RARCH_DBG("[webdav] cannot upload %s\n", webdav_cb_st->path);
+      RARCH_DBG("[webdav] Cannot upload %s\n", webdav_cb_st->path);
       webdav_cb_st->cb(webdav_cb_st->user_data, webdav_cb_st->path, false, webdav_cb_st->rfile);
       free(webdav_cb_st);
       return;
@@ -749,7 +757,7 @@ static void webdav_do_update(bool success, webdav_cb_state_t *webdav_cb_st)
 
    /* TODO: would be better to read file as it's being written to wire, this is very inefficient */
    len = filestream_get_size(webdav_cb_st->rfile);
-   buf = malloc((size_t)(len + 1));
+   buf = (char*)malloc((size_t)(len + 1));
    filestream_read(webdav_cb_st->rfile, buf, len);
 
    fill_pathname_join_special(url, webdav_st->url, webdav_cb_st->path, sizeof(url));
@@ -763,12 +771,13 @@ static void webdav_do_update(bool success, webdav_cb_state_t *webdav_cb_st)
    free(buf);
 }
 
-static bool webdav_update(const char *path, RFILE *rfile, cloud_sync_complete_handler_t cb, void *user_data)
+static bool webdav_update(const char *path, RFILE *rfile,
+      cloud_sync_complete_handler_t cb, void *user_data)
 {
-   webdav_cb_state_t *webdav_cb_st = (webdav_cb_state_t*)calloc(1, sizeof(webdav_cb_state_t));
    char               dir[DIR_MAX_LENGTH];
+   webdav_cb_state_t *webdav_cb_st = (webdav_cb_state_t*)calloc(1, sizeof(webdav_cb_state_t));
 
-   /* TODO: if !settings->bools.cloud_sync_destructive, should move to deleted/ first */
+   /* TODO/FIXME: if !settings->bools.cloud_sync_destructive, should move to deleted/ first */
 
    webdav_cb_st->cb = cb;
    webdav_cb_st->user_data = user_data;
@@ -786,7 +795,8 @@ static bool webdav_update(const char *path, RFILE *rfile, cloud_sync_complete_ha
    return true;
 }
 
-static void webdav_delete_cb(retro_task_t *task, void *task_data, void *user_data, const char *err)
+static void webdav_delete_cb(retro_task_t *task, void *task_data,
+      void *user_data, const char *err)
 {
    webdav_cb_state_t    *webdav_cb_st = (webdav_cb_state_t *)user_data;
    http_transfer_data_t *data         = (http_transfer_data_t*)task_data;
@@ -795,7 +805,7 @@ static void webdav_delete_cb(retro_task_t *task, void *task_data, void *user_dat
    if (!success && data)
       webdav_log_http_failure(webdav_cb_st->path, data);
    else if (!data)
-      RARCH_WARN("[webdav] could not delete %s\n", webdav_cb_st ? webdav_cb_st->path : "<unknown>");
+      RARCH_WARN("[webdav] Could not delete %s\n", webdav_cb_st ? webdav_cb_st->path : "<unknown>");
 
    if (webdav_needs_reauth(data))
    {
@@ -820,11 +830,13 @@ static void webdav_delete_cb(retro_task_t *task, void *task_data, void *user_dat
       free(webdav_cb_st);
    }
    else
-      RARCH_WARN("[webdav] missing cb data in delete?\n");
+      RARCH_WARN("[webdav] Missing cb data in delete?\n");
 }
 
 static void webdav_do_backup(bool success, webdav_cb_state_t *webdav_cb_st);
-static void webdav_backup_cb(retro_task_t *task, void *task_data, void *user_data, const char *err)
+
+static void webdav_backup_cb(retro_task_t *task, void *task_data,
+      void *user_data, const char *err)
 {
    webdav_cb_state_t    *webdav_cb_st = (webdav_cb_state_t *)user_data;
    http_transfer_data_t *data         = (http_transfer_data_t*)task_data;
@@ -833,7 +845,7 @@ static void webdav_backup_cb(retro_task_t *task, void *task_data, void *user_dat
    if (!success && data)
        webdav_log_http_failure(webdav_cb_st->path, data);
    else if (!data)
-      RARCH_WARN("[webdav] could not backup %s\n", webdav_cb_st ? webdav_cb_st->path : "<unknown>");
+      RARCH_WARN("[webdav] Could not backup %s\n", webdav_cb_st ? webdav_cb_st->path : "<unknown>");
 
    if (webdav_needs_reauth(data))
    {
@@ -847,27 +859,27 @@ static void webdav_backup_cb(retro_task_t *task, void *task_data, void *user_dat
       free(webdav_cb_st);
    }
    else
-      RARCH_WARN("[webdav] missing cb data in backup?\n");
+      RARCH_WARN("[webdav] Missing cb data in backup?\n");
 }
 
 static void webdav_do_backup(bool success, webdav_cb_state_t *webdav_cb_st)
 {
+   char *auth_header;
+   size_t          len;
+   struct tm       tm_;
    webdav_state_t *webdav_st = webdav_state_get_ptr();
    char            dest_encoded[PATH_MAX_LENGTH];
    char            dest[PATH_MAX_LENGTH];
    char            url_encoded[PATH_MAX_LENGTH];
    char            url[PATH_MAX_LENGTH];
-   size_t          len;
-   struct tm       tm_;
    time_t          cur_time = time(NULL);
-   char           *auth_header;
 
    if (!webdav_cb_st)
       return;
 
    if (!success)
    {
-      RARCH_DBG("[webdav] cannot backup/delete %s\n", webdav_cb_st->path);
+      RARCH_DBG("[webdav] Cannot backup/delete %s\n", webdav_cb_st->path);
       webdav_cb_st->cb(webdav_cb_st->user_data, webdav_cb_st->path, false, NULL);
       free(webdav_cb_st);
       return;
@@ -893,7 +905,7 @@ static bool webdav_delete(const char *path, cloud_sync_complete_handler_t cb, vo
    webdav_cb_state_t *webdav_cb_st = (webdav_cb_state_t*)calloc(1, sizeof(webdav_cb_state_t));
    settings_t        *settings     = config_get_ptr();
 
-   webdav_cb_st->cb = cb;
+   webdav_cb_st->cb        = cb;
    webdav_cb_st->user_data = user_data;
    strlcpy(webdav_cb_st->path, path, sizeof(webdav_cb_st->path));
 
@@ -904,10 +916,10 @@ static bool webdav_delete(const char *path, cloud_sync_complete_handler_t cb, vo
     */
    if (settings->bools.cloud_sync_destructive)
    {
+      char *auth_header;
+      char url[PATH_MAX_LENGTH];
+      char url_encoded[PATH_MAX_LENGTH];
       webdav_state_t *webdav_st = webdav_state_get_ptr();
-      char            url_encoded[PATH_MAX_LENGTH];
-      char            url[PATH_MAX_LENGTH];
-      char           *auth_header;
 
       fill_pathname_join_special(url, webdav_st->url, path, sizeof(url));
       net_http_urlencode_full(url_encoded, url, sizeof(url_encoded));
