@@ -72,6 +72,8 @@ struct netplay_room
    int  port;
    int  mitm_port;
    int  host_method;
+   int  player_count;
+   int  spectator_count;
    char nickname[NETPLAY_NICK_LEN];
    char frontend[NETPLAY_HOST_STR_LEN];
    char corename[NETPLAY_HOST_STR_LEN];
@@ -195,7 +197,9 @@ void deinit_netplay(void);
 
 bool netplay_driver_ctl(enum rarch_netplay_ctl_state state, void *data);
 
+bool netplay_reinit_serialization(void);
 bool netplay_is_spectating(void);
+void netplay_force_send_savestate(void);
 
 #ifdef HAVE_NETPLAYDISCOVERY
 /** Initialize Netplay discovery */
