@@ -252,8 +252,8 @@ struct runloop
    unsigned fastforward_after_frames;
    unsigned perf_ptr_libretro;
    unsigned subsystem_current_count;
-   unsigned entry_state_slot;
    unsigned video_swap_interval_auto;
+   int16_t entry_state_slot;
 
    fastmotion_overrides_t fastmotion_override; /* float alignment */
 
@@ -394,14 +394,8 @@ float runloop_get_fastforward_ratio(
       struct retro_fastforwarding_override *fastmotion_override);
 
 void runloop_set_video_swap_interval(
-      bool vrr_runloop_enable,
-      bool crt_switching_active,
-      unsigned swap_interval_config,
-      unsigned black_frame_insertion,
-      unsigned shader_subframes,
-      float audio_max_timing_skew,
-      float video_refresh_rate,
-      double input_fps);
+      settings_t *settings);
+
 unsigned runloop_get_video_swap_interval(
       unsigned swap_interval_config);
 
@@ -425,15 +419,13 @@ void runloop_path_set_names(void);
 
 uint32_t runloop_get_flags(void);
 
-bool runloop_get_entry_state_path(char *path, size_t len, unsigned slot);
+bool runloop_get_entry_state_path(char *path, size_t len, int slot);
 
 bool runloop_get_current_savestate_path(char *path, size_t len);
 
 bool runloop_get_savestate_path(char *path, size_t len, int slot);
 
-bool runloop_get_current_replay_path(char *path, size_t len);
-
-bool runloop_get_replay_path(char *path, size_t len, unsigned slot);
+bool runloop_get_replay_path(char *path, size_t len, int slot);
 
 void runloop_state_free(runloop_state_t *runloop_st);
 
