@@ -36,7 +36,6 @@
 #include "core.h"
 #include "core_info.h"
 #include "file_path_special.h"
-#include "configuration.h"
 #include "msg_hash.h"
 #include "runloop.h"
 #include "verbosity.h"
@@ -152,7 +151,7 @@ static void autosave_thread(void *data)
  * autosave_new:
  * @path            : path to autosave file
  * @data            : pointer to buffer
- * @size            : size of @data buffer
+ * @len             : size of @data buffer
  * @interval        : interval at which saves should be performed.
  *
  * Create and initialize autosave object.
@@ -161,7 +160,7 @@ static void autosave_thread(void *data)
  * NULL.
  **/
 static autosave_t *autosave_new(const char *path,
-      const void *data, size_t size,
+      const void *data, size_t len,
       unsigned interval, bool compress)
 {
    void       *buf               = NULL;
@@ -170,14 +169,14 @@ static autosave_t *autosave_new(const char *path,
       return NULL;
 
    handle->flags                 = 0;
-   handle->bufsize               = size;
+   handle->bufsize               = len;
    handle->interval              = interval;
    if (compress)
       handle->flags             |= AUTOSAVE_FLAG_COMPRESS_FILES;
    handle->retro_buffer          = data;
    handle->path                  = path;
 
-   if (!(buf = malloc(size)))
+   if (!(buf = malloc(len)))
    {
       free(handle);
       return NULL;
@@ -218,17 +217,10 @@ static void autosave_free(autosave_t *handle)
    handle->buffer = NULL;
 }
 
-bool autosave_init(void)
+bool autosave_init(bool compress_files, unsigned autosave_interval)
 {
    unsigned i;
    autosave_t **list          = NULL;
-   settings_t *settings       = config_get_ptr();
-   unsigned autosave_interval = settings->uints.autosave_interval;
-#if defined(HAVE_ZLIB)
-   bool compress_files        = settings->bools.save_file_compression;
-#else
-   bool compress_files        = false;
-#endif
 
    if (autosave_interval < 1 || !task_save_files)
       return false;
@@ -261,7 +253,7 @@ bool autosave_init(void)
             autosave_interval,
             compress_files)))
       {
-         RARCH_WARN("%s\n", msg_hash_to_str(MSG_AUTOSAVE_FAILED));
+         RARCH_WARN("[SRAM] %s\n", msg_hash_to_str(MSG_AUTOSAVE_FAILED));
          continue;
       }
 
@@ -381,7 +373,7 @@ static bool content_load_ram_file(unsigned slot)
    {
       if (rc > (ssize_t)mem_info.size)
       {
-         RARCH_WARN("[SRAM]: SRAM is larger than implementation expects, "
+         RARCH_WARN("[SRAM] SRAM is larger than implementation expects, "
                "doing partial load (truncating %u %s %s %u).\n",
                (unsigned)rc,
                msg_hash_to_str(MSG_BYTES),
@@ -407,20 +399,22 @@ static bool content_load_ram_file(unsigned slot)
  * Attempt to save valuable RAM data somewhere.
  **/
 static bool dump_to_file_desperate(const void *data,
-      size_t size, unsigned type)
+      size_t len, unsigned type)
 {
+   size_t _len;
    char path[PATH_MAX_LENGTH + 256 + 32];
-   path            [0]    = '\0';
+   path[0] = '\0';
+   _len    = fill_pathname_application_data(path,
+            sizeof(path));
 
-   if (fill_pathname_application_data(path,
-            sizeof(path)))
+   if (_len)
    {
-      size_t _len;
       time_t time_;
       struct tm tm_;
+
       time(&time_);
       rtime_localtime(&time_, &tm_);
-      _len  = strlcat(path, "/RetroArch-recovery-", sizeof(path));
+      _len += strlcpy(path  + _len, "/RetroArch-recovery-", sizeof(path) - _len);
       _len += snprintf(path + _len, sizeof(path) - _len, "%u", type);
       strftime(path + _len, sizeof(path) - _len,
             "%Y-%m-%d-%H-%M-%S", &tm_);
@@ -434,9 +428,9 @@ static bool dump_to_file_desperate(const void *data,
        * > In this case, we don't want to further
        *   complicate matters by introducing zlib
        *   compression overheads */
-      if (filestream_write_file(path, data, size))
+      if (filestream_write_file(path, data, len))
       {
-         RARCH_WARN("[SRAM]: Succeeded in saving RAM data to \"%s\".\n", path);
+         RARCH_WARN("[SRAM] Succeeded in saving RAM data to \"%s\".\n", path);
          return true;
       }
    }
@@ -460,7 +454,7 @@ static bool content_save_ram_file(unsigned slot, bool compress)
    if (!content_get_memory(&mem_info, &ram, slot))
       return false;
 
-   RARCH_LOG("[SRAM]: %s #%u %s \"%s\".\n",
+   RARCH_LOG("[SRAM] %s #%u %s \"%s\".\n",
          msg_hash_to_str(MSG_SAVING_RAM_TYPE),
          ram.type,
          msg_hash_to_str(MSG_TO),
@@ -481,58 +475,44 @@ static bool content_save_ram_file(unsigned slot, bool compress)
          goto fail;
    }
 
-   RARCH_LOG("[SRAM]: %s \"%s\".\n",
+   RARCH_LOG("[SRAM] %s \"%s\".\n",
          msg_hash_to_str(MSG_SAVED_SUCCESSFULLY_TO),
          ram.path);
 
    return true;
 
 fail:
-   RARCH_ERR("[SRAM]: %s.\n",
+   RARCH_ERR("[SRAM] %s.\n",
          msg_hash_to_str(MSG_FAILED_TO_SAVE_SRAM));
-   RARCH_WARN("[SRAM]: Attempting to recover ...\n");
+   RARCH_WARN("[SRAM] Attempting to recover...\n");
 
    /* In case the file could not be written to,
     * the fallback function 'dump_to_file_desperate'
     * will be called. */
    if (!dump_to_file_desperate(
             mem_info.data, mem_info.size, ram.type))
-      RARCH_WARN("[SRAM]: Failed ... Cannot recover save file.\n");
+      RARCH_WARN("[SRAM] Failed. Cannot recover save file.\n");
    return false;
 }
 
-bool event_save_files(bool is_sram_used)
+bool event_save_files(bool is_sram_used, bool compress_files,
+      const char *path_cheat_database)
 {
    unsigned i;
-   settings_t *settings            = config_get_ptr();
 #ifdef HAVE_CHEATS
-   const char *path_cheat_database = settings->paths.path_cheat_database;
-#endif
-#if defined(HAVE_ZLIB)
-   bool compress_files             = settings->bools.save_file_compression;
-#else
-   bool compress_files             = false;
-#endif
-
-#ifdef HAVE_CHEATS
-   cheat_manager_save_game_specific_cheats(
-         path_cheat_database);
+   cheat_manager_save_game_specific_cheats(path_cheat_database);
 #endif
    if (!task_save_files || !is_sram_used)
       return false;
-
    for (i = 0; i < task_save_files->size; i++)
-   {
       content_save_ram_file(i, compress_files);
-   }
-
    return true;
 }
 
 bool event_load_save_files(bool is_sram_load_disabled)
 {
    unsigned i;
-   bool success = false;
+   bool ret = false;
 
    if (!task_save_files || is_sram_load_disabled)
       return false;
@@ -541,9 +521,9 @@ bool event_load_save_files(bool is_sram_load_disabled)
     * any type of RAM file is found and
     * processed correctly */
    for (i = 0; i < task_save_files->size; i++)
-      success |= content_load_ram_file(i);
+      ret |= content_load_ram_file(i);
 
-   return success;
+   return ret;
 }
 
 void path_init_savefile_rtc(const char *savefile_path)
