@@ -29,7 +29,7 @@ static void task_bluetooth_scan_handler(retro_task_t *task)
    task_set_progress(task, 100);
    task_free_title(task);
    task_set_title(task, strdup(msg_hash_to_str(MSG_BLUETOOTH_SCAN_COMPLETE)));
-   task_set_finished(task, true);
+   task_set_flags(task, RETRO_TASK_FLG_FINISHED, true);
 }
 
 bool task_push_bluetooth_scan(retro_task_callback_t cb)
