@@ -89,12 +89,12 @@ static void task_cloud_sync_begin_handler(void *user_data, const char *path, boo
 
    if (success)
    {
-      RARCH_LOG(CSPFX "begin succeeded\n");
+      RARCH_LOG(CSPFX "Begin succeeded.\n");
       sync_state->phase = CLOUD_SYNC_PHASE_FETCH_SERVER_MANIFEST;
    }
    else
    {
-      RARCH_WARN(CSPFX "begin failed\n");
+      RARCH_WARN(CSPFX "Begin failed.\n");
       task_set_title(task, strdup("Cloud Sync failed"));
       task_set_flags(task, RETRO_TASK_FLG_FINISHED, true);
    }
@@ -153,7 +153,10 @@ static file_list_t *task_cloud_sync_create_manifest(RFILE *file)
       return NULL;
 
    if (!(json = rjson_open_rfile(file)))
+   {
+      free(list);
       return NULL;
+   }
 
    rjson_parse(json, list,
                tcs_object_member_handler,
@@ -170,18 +173,15 @@ static file_list_t *task_cloud_sync_create_manifest(RFILE *file)
 
    file_list_sort_on_alt(list);
 
-   RARCH_LOG(CSPFX "created manifest with %u files\n", list->size);
+   RARCH_LOG(CSPFX "Created manifest with %u files.\n", list->size);
 
    return list;
 }
 
-static void task_cloud_sync_manifest_filename(char *path, size_t len, bool server)
+static void task_cloud_sync_manifest_filename(char *s, size_t len, bool server)
 {
-   settings_t *settings             = config_get_ptr();
-   const char *path_dir_core_assets = settings->paths.directory_core_assets;
-
-   fill_pathname_join_special(path,
-         path_dir_core_assets,
+   const char *path_dir_core_assets = config_get_ptr()->paths.directory_core_assets;
+   fill_pathname_join_special(s, path_dir_core_assets,
          server ? MANIFEST_FILENAME_SERVER : MANIFEST_FILENAME_LOCAL,
          len);
 }
@@ -196,7 +196,7 @@ static void task_cloud_sync_manifest_handler(void *user_data, const char *path,
 
    if (!success)
    {
-      RARCH_WARN(CSPFX "server manifest fetch failed\n");
+      RARCH_WARN(CSPFX "Server manifest fetch failed.\n");
       sync_state->failures = true;
       sync_state->phase    = CLOUD_SYNC_PHASE_END;
       slock_lock(tcs_running_lock);
@@ -205,7 +205,7 @@ static void task_cloud_sync_manifest_handler(void *user_data, const char *path,
       return;
    }
 
-   RARCH_LOG(CSPFX "server manifest fetch succeeded\n");
+   RARCH_LOG(CSPFX "Server manifest fetch succeeded.\n");
    /* it is valid for there not to be a server manifest */
    if (file)
    {
@@ -227,7 +227,7 @@ static void task_cloud_sync_fetch_server_manifest(task_cloud_sync_state_t *sync_
    sync_state->waiting = 1;
    if (!cloud_sync_read(MANIFEST_FILENAME_SERVER, manifest_path, task_cloud_sync_manifest_handler, sync_state))
    {
-      RARCH_WARN(CSPFX "could not read server manifest\n");
+      RARCH_WARN(CSPFX "Could not read server manifest.\n");
       sync_state->waiting = 0;
       sync_state->phase = CLOUD_SYNC_PHASE_END;
    }
@@ -246,7 +246,7 @@ static void task_cloud_sync_read_local_manifest(task_cloud_sync_state_t *sync_st
             RETRO_VFS_FILE_ACCESS_READ, RETRO_VFS_FILE_ACCESS_HINT_NONE);
       if (rfile)
       {
-         RARCH_WARN(CSPFX "opened local manifest\n");
+         RARCH_WARN(CSPFX "Opened local manifest.\n");
          sync_state->local_manifest = task_cloud_sync_create_manifest(rfile);
          filestream_close(rfile);
       }
@@ -417,11 +417,11 @@ static void task_cloud_sync_build_current_manifest(task_cloud_sync_state_t *sync
    /* The paths iterated here are not portable, because they are still used for iterating later on */
    for (i = 0; i < dirlist->size; i++)
       task_cloud_sync_manifest_append_dir(sync_state->current_manifest,
-            dirlist->elems[i].userdata, dirlist->elems[i].data);
+            (const char*)dirlist->elems[i].userdata, dirlist->elems[i].data);
 
    file_list_sort_on_alt(sync_state->current_manifest);
    sync_state->phase = CLOUD_SYNC_PHASE_DIFF;
-   RARCH_LOG(CSPFX "created in-memory manifest of current disk state\n");
+   RARCH_LOG(CSPFX "Created in-memory manifest of current disk state with %d files.\n", sync_state->current_manifest->size);
 }
 
 /**
@@ -489,24 +489,29 @@ static INLINE int task_cloud_sync_key_cmp(struct item_file *left, struct item_fi
 
 static char *task_cloud_sync_md5_rfile(RFILE *file)
 {
-   MD5_CTX       md5;
-   int           rv;
-   char         *hash = malloc(33);
+   int rv;
+   MD5_CTX md5;
    unsigned char buf[4096];
    unsigned char digest[16];
+   libretro_vfs_implementation_file *hfile = filestream_get_vfs_handle(file);
+   char *hash = (char*)malloc(33);
 
    if (!hash)
       return NULL;
 
    MD5_Init(&md5);
 
-   do
+   if (hfile && hfile->mapped)
+      MD5_Update(&md5, hfile->mapped, hfile->size);
+   else
    {
-      rv = (int)filestream_read(file, buf, sizeof(buf));
-      if (rv > 0)
-         MD5_Update(&md5, buf, rv);
-   } while (rv > 0);
-
+      do
+      {
+         rv = (int)filestream_read(file, buf, sizeof(buf));
+         if (rv > 0)
+            MD5_Update(&md5, buf, rv);
+      } while (rv > 0);
+   }
    MD5_Final(digest, &md5);
 
    snprintf(hash, 33, "%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
@@ -525,8 +530,7 @@ static void task_cloud_sync_backup_file(struct item_file *file)
    char        new_dir[DIR_MAX_LENGTH];
    char        backup_dir[DIR_MAX_LENGTH];
    char        new_path[PATH_MAX_LENGTH];
-   settings_t *settings             = config_get_ptr();
-   const char *path_dir_core_assets = settings->paths.directory_core_assets;
+   const char *path_dir_core_assets = config_get_ptr()->paths.directory_core_assets;
    time_t      cur_time             = time(NULL);
    rtime_localtime(&cur_time, &tm_);
 
@@ -539,77 +543,108 @@ static void task_cloud_sync_backup_file(struct item_file *file)
                                     CS_FILE_KEY(file),
                                     sizeof(new_path));
    strftime(new_path + len, sizeof(new_path) - len, "-%y%m%d-%H%M%S", &tm_);
+   pathname_conform_slashes_to_os(new_path);
    fill_pathname_basedir(new_dir, new_path, sizeof(new_dir));
    path_mkdir(new_dir);
    filestream_rename(file->path, new_path);
 }
 
+typedef struct
+{
+   task_cloud_sync_state_t *sync_state;
+   struct item_file        *server_file;
+} task_cloud_sync_fetch_state_t;
+
 static void task_cloud_sync_fetch_cb(void *user_data, const char *path, bool success, RFILE *file)
 {
-   task_cloud_sync_state_t *sync_state = (task_cloud_sync_state_t *)user_data;
-   char                    *hash = NULL;
+   task_cloud_sync_fetch_state_t *fetch_state = (task_cloud_sync_fetch_state_t *)user_data;
+   task_cloud_sync_state_t       *sync_state;
+   struct item_file              *server_file;
+   char                          *hash = NULL;
 
-   if (!sync_state)
+   if (!fetch_state)
       return;
 
+   sync_state = fetch_state->sync_state;
+   server_file = fetch_state->server_file;
+
    if (success && file)
    {
       hash = task_cloud_sync_md5_rfile(file);
       filestream_close(file);
-      RARCH_LOG(CSPFX "successfully fetched %s\n", path);
+      RARCH_LOG(CSPFX "Successfully fetched \"%s\".\n", path);
       task_cloud_sync_add_to_updated_manifest(sync_state, path, hash, false);
+      task_cloud_sync_add_to_updated_manifest(sync_state, path, hash, true);
+      /* if the file fetched from the server does not match its own hash, the manifest needs to be updated */
+      if (!string_is_equal(hash, CS_FILE_HASH(server_file)))
+         sync_state->need_manifest_uploaded = true;
       sync_state->downloads++;
    }
    else
    {
       /* on failure, don't add it to local manifest, that will cause a fetch again next time */
       if (!success)
-         RARCH_WARN(CSPFX "failed to fetch %s\n", path);
+         RARCH_WARN(CSPFX "Failed to fetch \"%s\".\n", path);
       else
-         RARCH_WARN(CSPFX "failed to write file from server: %s\n", path);
+         RARCH_WARN(CSPFX "Failed to write file from server: \"%s\".\n", path);
+      task_cloud_sync_add_to_updated_manifest(sync_state, path, CS_FILE_HASH(server_file), true);
       sync_state->failures = true;
    }
 
    slock_lock(tcs_running_lock);
    sync_state->waiting--;
    slock_unlock(tcs_running_lock);
+
+   free(fetch_state);
 }
 
 static void task_cloud_sync_fetch_server_file(task_cloud_sync_state_t *sync_state)
 {
-   size_t              i;
-   char                filename[PATH_MAX_LENGTH];
-   char                directory[DIR_MAX_LENGTH];
-   struct string_list *dirlist     = task_cloud_sync_directory_map();
-   struct item_file   *server_file = &sync_state->server_manifest->list[sync_state->server_idx];
-   const char         *key         = CS_FILE_KEY(server_file);
-   const char         *path        = strchr(key, PATH_DEFAULT_SLASH_C()) + 1;
-   settings_t         *settings = config_get_ptr();
+   size_t                         i;
+   char                           filename[PATH_MAX_LENGTH];
+   char                           directory[DIR_MAX_LENGTH];
+   struct string_list            *dirlist     = task_cloud_sync_directory_map();
+   struct item_file              *server_file = &sync_state->server_manifest->list[sync_state->server_idx];
+   const char                    *key         = CS_FILE_KEY(server_file);
+   /* the key from the server file is in "portable" format, use '/' */
+   const char                    *path        = strchr(key, '/') + 1;
+   settings_t                    *settings    = config_get_ptr();
+   task_cloud_sync_fetch_state_t *fetch_state;
 
-   /* we're just fetching a file the server has, we can update this now */
-   task_cloud_sync_add_to_updated_manifest(sync_state, key, CS_FILE_HASH(server_file), true);
-   /* no need to mark need_manifest_uploaded, nothing changed */
+   /* there is a weird thing that can happen, where the server file changes but
+    * the manifest does not have the updated hash. in that case when the file is
+    * downloaded we have an opportunity to check that the hash matches and
+    * update the server manifest, and correct the issue. to do this the server
+    * manifest cannot be updated early; only on error or after the download is
+    * successful. on error just add to the updated manifest without marking
+    * need_manifest_uplaod. */
 
    if (task_cloud_sync_should_ignore_file(key))
    {
       /* don't fetch a file we're supposed to ignore, even if the server has it */
-      RARCH_LOG(CSPFX "ignoring %s\n", key);
+      RARCH_LOG(CSPFX "Ignoring %s.\n", key);
+      task_cloud_sync_add_to_updated_manifest(sync_state, key, CS_FILE_HASH(server_file), true);
       return;
    }
-   RARCH_LOG(CSPFX "fetching %s\n", key);
+   RARCH_LOG(CSPFX "Fetching %s.\n", key);
 
    filename[0] = '\0';
    for (i = 0; i < dirlist->size; i++)
    {
       if (!string_starts_with(key, dirlist->elems[i].data))
          continue;
-      fill_pathname_join_special(filename, dirlist->elems[i].userdata, path, sizeof(filename));
+      fill_pathname_join_special(filename,
+            (const char*)dirlist->elems[i].userdata,
+            path, sizeof(filename));
+      pathname_conform_slashes_to_os(filename);
       break;
    }
    if (string_is_empty(filename))
    {
       /* how did this end up here? we don't know where to put it... */
-      RARCH_WARN(CSPFX "don't know where to put %s!\n", key);
+      RARCH_WARN(CSPFX "Don't know where to put %s!\n", key);
+      task_cloud_sync_add_to_updated_manifest(sync_state,
+            key, CS_FILE_HASH(server_file), true);
       return;
    }
 
@@ -622,12 +657,24 @@ static void task_cloud_sync_fetch_server_file(task_cloud_sync_state_t *sync_stat
 
    fill_pathname_basedir(directory, filename, sizeof(directory));
    path_mkdir(directory);
-   if (cloud_sync_read(key, filename, task_cloud_sync_fetch_cb, sync_state))
+   fetch_state = (task_cloud_sync_fetch_state_t*)malloc(sizeof(task_cloud_sync_fetch_state_t));
+   if (!fetch_state)
+   {
+      RARCH_WARN(CSPFX "Wanted to fetch %s but failed to malloc.\n", key);
+      task_cloud_sync_add_to_updated_manifest(sync_state, key, CS_FILE_HASH(server_file), true);
+      sync_state->failures = true;
+      return;
+   }
+   fetch_state->sync_state  = sync_state;
+   fetch_state->server_file = server_file;
+   if (cloud_sync_read(key, filename, task_cloud_sync_fetch_cb, fetch_state))
       sync_state->waiting++;
    else
    {
-      RARCH_WARN(CSPFX "wanted to fetch %s but failed\n", key);
+      RARCH_WARN(CSPFX "Wanted to fetch %s but failed.\n", key);
+      task_cloud_sync_add_to_updated_manifest(sync_state, key, CS_FILE_HASH(server_file), true);
       sync_state->failures = true;
+      free(fetch_state);
    }
 }
 
@@ -642,7 +689,7 @@ static void task_cloud_sync_resolve_conflict(task_cloud_sync_state_t *sync_state
     * If we ignore it then we need to keep it out of the new local manifest
     */
    struct item_file *server_file = &sync_state->server_manifest->list[sync_state->server_idx];
-   RARCH_WARN(CSPFX "conflicting change of %s\n", CS_FILE_KEY(server_file));
+   RARCH_WARN(CSPFX "Conflicting change of %s.\n", CS_FILE_KEY(server_file));
    task_cloud_sync_add_to_updated_manifest(sync_state, CS_FILE_KEY(server_file), CS_FILE_HASH(server_file), true);
    /* no need to mark need_manifest_uploaded, nothing changed */
    sync_state->conflicts = true;
@@ -669,7 +716,7 @@ static void task_cloud_sync_upload_cb(void *user_data, const char *path, bool su
          task_cloud_sync_add_to_updated_manifest(sync_state, path, CS_FILE_HASH(current_file), false);
          sync_state->need_manifest_uploaded = true;
       }
-      RARCH_LOG(CSPFX "uploading %s succeeded\n", path);
+      RARCH_LOG(CSPFX "Uploading \"%s\" succeeded.\n", path);
       sync_state->uploads++;
    }
    else
@@ -680,7 +727,7 @@ static void task_cloud_sync_upload_cb(void *user_data, const char *path, bool su
          struct item_file *local_file = &sync_state->local_manifest->list[idx];
          task_cloud_sync_add_to_updated_manifest(sync_state, path, CS_FILE_HASH(local_file), false);
       }
-      RARCH_WARN(CSPFX "uploading %s failed\n", path);
+      RARCH_WARN(CSPFX "Uploading \"%s\" failed.\n", path);
       sync_state->failures = true;
    }
 
@@ -707,16 +754,16 @@ static void task_cloud_sync_upload_current_file(task_cloud_sync_state_t *sync_st
 
    if (task_cloud_sync_should_ignore_file(path))
    {
-      RARCH_LOG(CSPFX "ignoring %s, not uploading\n", path);
+      RARCH_LOG(CSPFX "Ignoring \"%s\", not uploading.\n", path);
       return;
    }
 
    file = filestream_open(filename,
-         RETRO_VFS_FILE_ACCESS_READ, RETRO_VFS_FILE_ACCESS_HINT_NONE);
+         RETRO_VFS_FILE_ACCESS_READ, RETRO_VFS_FILE_ACCESS_HINT_FREQUENT_ACCESS);
    if (!file)
       return;
 
-   RARCH_LOG(CSPFX "uploading %s\n", path);
+   RARCH_LOG(CSPFX "Uploading \"%s\".\n", path);
 
    item->userdata = task_cloud_sync_md5_rfile(file);
 
@@ -734,18 +781,18 @@ static void task_cloud_sync_upload_current_file(task_cloud_sync_state_t *sync_st
       filestream_close(file);
       sync_state->waiting--;
       sync_state->failures = true;
-      RARCH_WARN(CSPFX "uploading %s failed\n", path);
+      RARCH_WARN(CSPFX "Uploading \"%s\" failed.\n", path);
    }
 }
 
 static void task_cloud_sync_delete_current_file(task_cloud_sync_state_t *sync_state)
 {
-   struct item_file *item     = &sync_state->current_manifest->list[sync_state->current_idx];
-   settings_t       *settings = config_get_ptr();
+   struct item_file *item      = &sync_state->current_manifest->list[sync_state->current_idx];
+   bool cloud_sync_destructive = config_get_ptr()->bools.cloud_sync_destructive;
 
-   RARCH_WARN(CSPFX "server has deleted %s, so shall we\n", CS_FILE_KEY(item));
+   RARCH_WARN(CSPFX "Server has deleted \"%s\", so shall we.\n", CS_FILE_KEY(item));
 
-   if (settings->bools.cloud_sync_destructive)
+   if (cloud_sync_destructive)
       filestream_delete(item->path);
    else
       task_cloud_sync_backup_file(item);
@@ -762,12 +809,12 @@ static void task_cloud_sync_check_server_current(task_cloud_sync_state_t *sync_s
 
    if (task_cloud_sync_should_ignore_file(CS_FILE_KEY(server_file)))
    {
-      RARCH_LOG(CSPFX "ignoring %s (despite possible conflict)\n", CS_FILE_KEY(server_file));
+      RARCH_LOG(CSPFX "Ignoring \"%s\" (despite possible conflict).\n", CS_FILE_KEY(server_file));
       return;
    }
 
    file = filestream_open(filename,
-         RETRO_VFS_FILE_ACCESS_READ, RETRO_VFS_FILE_ACCESS_HINT_NONE);
+         RETRO_VFS_FILE_ACCESS_READ, RETRO_VFS_FILE_ACCESS_HINT_FREQUENT_ACCESS);
    if (!file)
       return;
 
@@ -821,7 +868,7 @@ static void task_cloud_sync_delete_cb(void *user_data, const char *path, bool su
          struct item_file *local_file = &sync_state->local_manifest->list[idx];
          task_cloud_sync_add_to_updated_manifest(sync_state, path, CS_FILE_HASH(local_file), false);
       }
-      RARCH_WARN(CSPFX "deleting %s failed\n", path);
+      RARCH_WARN(CSPFX "Deleting \"%s\" failed.\n", path);
       sync_state->failures = true;
       slock_lock(tcs_running_lock);
       sync_state->waiting--;
@@ -829,7 +876,7 @@ static void task_cloud_sync_delete_cb(void *user_data, const char *path, bool su
       return;
    }
 
-   RARCH_LOG(CSPFX "deleting %s succeeded\n", path);
+   RARCH_LOG(CSPFX "Deleting \"%s\" succeeded.\n", path);
    /* need to update server manifest. we don't set the hash as that indicates a
     * deleted file. need to update the local manifest to indicate we sync'd that
     * it is deleted */
@@ -848,11 +895,11 @@ static void task_cloud_sync_delete_server_file(task_cloud_sync_state_t *sync_sta
 
    if (task_cloud_sync_should_ignore_file(key))
    {
-      RARCH_LOG(CSPFX "ignoring %s, instead of removing from server\n", key);
+      RARCH_LOG(CSPFX "Ignoring \"%s\", instead of removing from server.\n", key);
       return;
    }
 
-   RARCH_LOG(CSPFX "deleting %s\n", key);
+   RARCH_LOG(CSPFX "Deleting \"%s\".\n", key);
 
    sync_state->waiting++;
    if (!cloud_sync_free(key, task_cloud_sync_delete_cb, sync_state))
@@ -870,6 +917,49 @@ static void task_cloud_sync_delete_server_file(task_cloud_sync_state_t *sync_sta
    }
 }
 
+static void task_cloud_sync_maybe_ignore(task_cloud_sync_state_t *sync_state)
+{
+   struct string_list *dirlist = task_cloud_sync_directory_map();
+   size_t i;
+   bool found;
+
+   if (sync_state->local_manifest)
+   {
+      for (found = false; !found && sync_state->local_idx < sync_state->local_manifest->size; )
+      {
+         struct item_file *local_file  = &sync_state->local_manifest->list[sync_state->local_idx];
+         const char *key = CS_FILE_KEY(local_file);
+         for (i = 0; !found && i < dirlist->size; i++)
+            found = string_starts_with(key, dirlist->elems[i].data);
+         /* we have a record of doing a sync for this file but now no longer
+          * wish to sync it. keep the record? might as well, in case the option
+          * gets turned back on later. */
+         if (!found)
+         {
+            task_cloud_sync_add_to_updated_manifest(sync_state, key, CS_FILE_HASH(local_file), false);
+            sync_state->local_idx++;
+         }
+      }
+   }
+
+   if (sync_state->server_manifest)
+   {
+      for (found = false; !found && sync_state->server_idx < sync_state->server_manifest->size; )
+      {
+         struct item_file *server_file  = &sync_state->server_manifest->list[sync_state->server_idx];
+         const char *key = CS_FILE_KEY(server_file);
+         for (i = 0; !found && i < dirlist->size; i++)
+            found = string_starts_with(key, dirlist->elems[i].data);
+         /* must keep the server's manifest complete */
+         if (!found)
+         {
+            task_cloud_sync_add_to_updated_manifest(sync_state, key, CS_FILE_HASH(server_file), true);
+            sync_state->server_idx++;
+         }
+      }
+   }
+}
+
 static void task_cloud_sync_diff_next(task_cloud_sync_state_t *sync_state)
 {
    int server_local_key_cmp;
@@ -879,6 +969,12 @@ static void task_cloud_sync_diff_next(task_cloud_sync_state_t *sync_state)
    struct item_file *local_file   = NULL;
    struct item_file *current_file = NULL;
 
+   /* Move past files that are deliberately not being sync'd. There would not be
+    * any in the current state, but there may be in the server or local state.
+    * If there are in the server state, make sure to leave them in the server's
+    * manifest. */
+   task_cloud_sync_maybe_ignore(sync_state);
+
    if (   sync_state->server_manifest
        && sync_state->server_idx < sync_state->server_manifest->size)
       server_file = &sync_state->server_manifest->list[sync_state->server_idx];
@@ -891,7 +987,7 @@ static void task_cloud_sync_diff_next(task_cloud_sync_state_t *sync_state)
 
    if (!server_file && !local_file && !current_file)
    {
-      RARCH_LOG(CSPFX "finished processing manifests\n");
+      RARCH_LOG(CSPFX "Finished processing manifests.\n");
       sync_state->phase = CLOUD_SYNC_PHASE_UPDATE_MANIFESTS;
       return;
    }
@@ -997,7 +1093,7 @@ static void task_cloud_sync_diff_next(task_cloud_sync_state_t *sync_state)
       {
          /* this is odd, it exists in the last sync manifest but not on the
           * server and not on disk? wtf? */
-         RARCH_WARN(CSPFX "%s only exists in previous manifest? odd\n", CS_FILE_KEY(local_file));
+         RARCH_WARN(CSPFX "%s only exists in previous manifest?\n", CS_FILE_KEY(local_file));
          sync_state->local_idx++;
       }
    }
@@ -1013,7 +1109,7 @@ static void task_cloud_sync_update_manifest_cb(void *user_data, const char *path
    if (!sync_state)
       return;
 
-   RARCH_LOG(CSPFX "uploading updated manifest succeeded\n");
+   RARCH_LOG(CSPFX "Uploading updated manifest succeeded.\n");
    sync_state->phase = CLOUD_SYNC_PHASE_END;
    slock_lock(tcs_running_lock);
    sync_state->waiting = 0;
@@ -1070,7 +1166,7 @@ static RFILE *task_cloud_sync_write_updated_manifest(file_list_t *manifest, char
    rjsonwriter_raw(writer, "\n]\n", 3);
    rjsonwriter_free(writer);
 
-   RARCH_LOG(CSPFX "wrote %s\n", path);
+   RARCH_LOG(CSPFX "Wrote \"%s\".\n", path);
 
    return file;
 }
@@ -1087,14 +1183,14 @@ static void task_cloud_sync_update_manifests(task_cloud_sync_state_t *sync_state
 
    if (sync_state->need_manifest_uploaded)
    {
-      RARCH_LOG(CSPFX "uploading updated manifest to server\n");
+      RARCH_LOG(CSPFX "Uploading updated manifest to server...\n");
       task_cloud_sync_manifest_filename(manifest_path, sizeof(manifest_path), true);
       file = task_cloud_sync_write_updated_manifest(sync_state->updated_server_manifest, manifest_path);
       filestream_seek(file, 0, SEEK_SET);
       sync_state->waiting = 1;
       if (!cloud_sync_update(MANIFEST_FILENAME_SERVER, file, task_cloud_sync_update_manifest_cb, sync_state))
       {
-         RARCH_LOG(CSPFX "uploading updated manifest failed\n");
+         RARCH_ERR(CSPFX "Uploading updated manifest failed.\n");
          filestream_close(file);
          sync_state->waiting = 0;
          sync_state->failures = true;
@@ -1118,20 +1214,20 @@ static void task_cloud_sync_end_handler(void *user_data, const char *path, bool
    if ((sync_state = (task_cloud_sync_state_t *)task->state))
    {
       char title[128];
-      size_t len = strlcpy(title, "Cloud Sync finished", sizeof(title));
+      size_t _len = strlcpy(title, "Cloud Sync finished", sizeof(title));
       if (sync_state->failures || sync_state->conflicts)
-         len += strlcpy(title + len, " with ", sizeof(title) - len);
+         _len += strlcpy(title + _len, " with ", sizeof(title) - _len);
       if (sync_state->failures)
-         len += strlcpy(title + len, "failures", sizeof(title) - len);
+         _len += strlcpy(title + _len, "failures", sizeof(title) - _len);
       if (sync_state->failures && sync_state->conflicts)
-         len += strlcpy(title + len, " and ", sizeof(title) - len);
+         _len += strlcpy(title + _len, " and ", sizeof(title) - _len);
       if (sync_state->conflicts)
-         strlcpy(title + len, "conflicts", sizeof(title) - len);
+         strlcpy(title + _len, "conflicts", sizeof(title) - _len);
       task_set_title(task, strdup(title));
    }
 
 
-   RARCH_LOG(CSPFX "finished after %lld.%06lld seconds, %d files uploaded, %d files downloaded\n",
+   RARCH_LOG(CSPFX "Finished after %lld.%06lld seconds, %d files uploaded, %d files downloaded.\n",
          (end_time - sync_state->start_time) / 1000 / 1000,
          (end_time - sync_state->start_time) % (1000 * 1000),
          sync_state->uploads, sync_state->downloads);
@@ -1151,7 +1247,7 @@ static void task_cloud_sync_task_handler(retro_task_t *task)
 
    slock_lock(tcs_running_lock);
    /* we can transfer more than one file at a time */
-   if (sync_state->waiting > ((sync_state->phase == CLOUD_SYNC_PHASE_DIFF) ? 4 : 0))
+   if (sync_state->waiting > ((sync_state->phase == CLOUD_SYNC_PHASE_DIFF) ? 4U : 0U))
    {
       task->when = cpu_features_get_time_usec() + 17 * 1000; /* 17ms */
       slock_unlock(tcs_running_lock);
@@ -1159,13 +1255,16 @@ static void task_cloud_sync_task_handler(retro_task_t *task)
    }
    slock_unlock(tcs_running_lock);
 
+   if (task->flags & RETRO_TASK_FLG_FINISHED)
+       goto task_finished;
+
    switch (sync_state->phase)
    {
       case CLOUD_SYNC_PHASE_BEGIN:
          sync_state->waiting = 1;
          if (!cloud_sync_begin(task_cloud_sync_begin_handler, task))
          {
-            RARCH_WARN(CSPFX "could not begin\n");
+            RARCH_WARN(CSPFX "Could not begin.\n");
             task_set_title(task, strdup("Cloud Sync failed"));
             goto task_finished;
          }
@@ -1190,7 +1289,7 @@ static void task_cloud_sync_task_handler(retro_task_t *task)
          sync_state->waiting = 1;
          if (!cloud_sync_end(task_cloud_sync_end_handler, task))
          {
-            RARCH_WARN(CSPFX "could not end?!\n");
+            RARCH_WARN(CSPFX "Could not end?!\n");
             goto task_finished;
          }
          break;
@@ -1236,13 +1335,13 @@ static bool task_cloud_sync_task_finder(retro_task_t *task, void *user_data)
 
 void task_push_cloud_sync(void)
 {
-   settings_t              *settings   = config_get_ptr();
+   char task_title[128];
    task_finder_data_t       find_data;
    task_cloud_sync_state_t *sync_state = NULL;
    retro_task_t            *task       = NULL;
-   char                     task_title[128];
+   bool cloud_sync_enable              = config_get_ptr()->bools.cloud_sync_enable;
 
-   if (!settings->bools.cloud_sync_enable)
+   if (!cloud_sync_enable)
       return;
 
    if (!tcs_running_lock)
@@ -1251,7 +1350,7 @@ void task_push_cloud_sync(void)
    find_data.func = task_cloud_sync_task_finder;
    if (task_queue_find(&find_data))
    {
-      RARCH_LOG(CSPFX "already in progress\n");
+      RARCH_LOG(CSPFX "Already in progress.\n");
       return;
    }
 
@@ -1265,7 +1364,7 @@ void task_push_cloud_sync(void)
       return;
    }
 
-   sync_state->phase = CLOUD_SYNC_PHASE_BEGIN;
+   sync_state->phase      = CLOUD_SYNC_PHASE_BEGIN;
    sync_state->start_time = cpu_features_get_time_usec();
 
    strlcpy(task_title, "Cloud Sync in progress", sizeof(task_title));
@@ -1280,10 +1379,11 @@ void task_push_cloud_sync(void)
 
 void task_push_cloud_sync_update_driver(void)
 {
-   char        manifest_path[PATH_MAX_LENGTH];
+   char manifest_path[PATH_MAX_LENGTH];
    settings_t *settings = config_get_ptr();
 
-   cloud_sync_find_driver(settings, "cloud sync driver", verbosity_is_enabled());
+   cloud_sync_find_driver(settings->arrays.cloud_sync_driver,
+         "cloud sync driver", verbosity_is_enabled());
 
    /* The sync does a three-way diff: current local <- last sync -> current server.
     * When the server changes it becomes a four way diff, which can lead to odd
