@@ -102,8 +102,8 @@ static void task_overlay_load_desc_image(
 static void task_overlay_redefine_eightway_direction(
       char *str, input_bits_t *data)
 {
-   char *tok, *save;
    unsigned bit;
+   char *tok, *save = NULL;
 
    BIT256_CLEAR_ALL(*data);
 
@@ -230,7 +230,7 @@ static bool task_overlay_load_desc(
    char overlay_desc_key[32];
    char overlay_key[64];
    char overlay[256];
-   char *tok, *save;
+   char *tok, *save                     = NULL;
    unsigned list_size                   = 0;
    char *elem0                          = NULL;
    char *elem1                          = NULL;
@@ -266,14 +266,14 @@ static bool task_overlay_load_desc(
 
    if (by_pixel && (width == 0 || height == 0))
    {
-      RARCH_ERR("[Overlay]: Base overlay is not set and not using normalized coordinates.\n");
+      RARCH_ERR("[Overlay] Base overlay is not set and not using normalized coordinates.\n");
       ret = false;
       goto end;
    }
 
    if (!config_get_array(conf, overlay_desc_key, overlay, sizeof(overlay)))
    {
-      RARCH_ERR("[Overlay]: Didn't find key: %s.\n", overlay_desc_key);
+      RARCH_ERR("[Overlay] Didn't find key: %s.\n", overlay_desc_key);
       ret = false;
       goto end;
    }
@@ -313,7 +313,7 @@ static bool task_overlay_load_desc(
 
    if (list_size < 6)
    {
-      RARCH_ERR("[Overlay]: Overlay desc is invalid. Requires at least 6 tokens.\n");
+      RARCH_ERR("[Overlay] Overlay desc is invalid. Requires at least 6 tokens.\n");
       ret = false;
       goto end;
    }
@@ -385,7 +385,7 @@ static bool task_overlay_load_desc(
       desc->hitbox = OVERLAY_HITBOX_RECT;
    else
    {
-      RARCH_ERR("[Overlay]: Hitbox type (%s) is invalid. Use \"radial\" or \"rect\".\n", box);
+      RARCH_ERR("[Overlay] Hitbox type (%s) is invalid. Use \"radial\" or \"rect\".\n", box);
       ret = false;
       goto end;
    }
@@ -396,7 +396,7 @@ static bool task_overlay_load_desc(
       case OVERLAY_TYPE_ANALOG_RIGHT:
          if (desc->hitbox != OVERLAY_HITBOX_RADIAL)
          {
-            RARCH_ERR("[Overlay]: Analog hitbox type must be \"radial\".\n");
+            RARCH_ERR("[Overlay] Analog hitbox type must be \"radial\".\n");
             ret = false;
             goto end;
          }
@@ -517,24 +517,21 @@ end:
 }
 
 static ssize_t task_overlay_find_index(const struct overlay *ol,
-      const char *name, size_t size)
+      const char *name, size_t len)
 {
    size_t i;
-
    if (!ol)
       return -1;
-
-   for (i = 0; i < size; i++)
+   for (i = 0; i < len; i++)
    {
       if (string_is_equal(ol[i].name, name))
          return i;
    }
-
    return -1;
 }
 
 static bool task_overlay_resolve_targets(struct overlay *ol,
-      size_t idx, size_t size)
+      size_t idx, size_t len)
 {
    unsigned i;
    struct overlay *current = (struct overlay*)&ol[idx];
@@ -543,15 +540,15 @@ static bool task_overlay_resolve_targets(struct overlay *ol,
    {
       struct overlay_desc *desc = (struct overlay_desc*)&current->descs[i];
       const char *next          = desc->next_index_name;
-      ssize_t         next_idx  = (idx + 1) % size;
+      ssize_t         next_idx  = (idx + 1) % len;
 
       if (!string_is_empty(next))
       {
-         next_idx = task_overlay_find_index(ol, next, size);
+         next_idx = task_overlay_find_index(ol, next, len);
 
          if (next_idx < 0)
          {
-            RARCH_ERR("[Overlay]: Couldn't find overlay called: \"%s\".\n",
+            RARCH_ERR("[Overlay] Couldn't find overlay called: \"%s\".\n",
                   next);
             return false;
          }
@@ -577,7 +574,7 @@ static void task_overlay_resolve_iterate(retro_task_t *task)
    if (!task_overlay_resolve_targets(loader->overlays,
             loader->resolve_pos, loader->size))
    {
-      RARCH_ERR("[Overlay]: Failed to resolve next targets.\n");
+      RARCH_ERR("[Overlay] Failed to resolve next targets.\n");
       task_set_flags(task, RETRO_TASK_FLG_CANCELLED, true);
       loader->state   = OVERLAY_STATUS_DEFERRED_ERROR;
       return;
@@ -643,7 +640,7 @@ static void task_overlay_deferred_loading(retro_task_t *task)
                         overlay->config.normalized,
                         overlay->config.alpha_mod, overlay->config.range_mod))
                {
-                  RARCH_ERR("[Overlay]: Failed to load overlay descs for overlay #%u.\n",
+                  RARCH_ERR("[Overlay] Failed to load overlay descs for overlay #%u.\n",
                         (unsigned)overlay->pos);
                   task_set_flags(task, RETRO_TASK_FLG_CANCELLED, true);
                   loader->state   = OVERLAY_STATUS_DEFERRED_ERROR;
@@ -722,7 +719,7 @@ static void task_overlay_deferred_load(retro_task_t *task)
       if (!config_get_uint(conf, overlay->config.descs.key,
                &overlay->config.descs.size))
       {
-         RARCH_ERR("[Overlay]: Failed to read number of descs from config key: %s.\n",
+         RARCH_ERR("[Overlay] Failed to read number of descs from config key: %s.\n",
                overlay->config.descs.key);
          goto error;
       }
@@ -732,7 +729,7 @@ static void task_overlay_deferred_load(retro_task_t *task)
 
       if (!overlay_desc)
       {
-         RARCH_ERR("[Overlay]: Failed to allocate descs.\n");
+         RARCH_ERR("[Overlay] Failed to allocate descs.\n");
          goto error;
       }
 
@@ -771,7 +768,7 @@ static void task_overlay_deferred_load(retro_task_t *task)
 
       if (!texture_img)
       {
-         RARCH_ERR("[Overlay]: Failed to allocate load_images.\n");
+         RARCH_ERR("[Overlay] Failed to allocate load_images.\n");
          goto error;
       }
 
@@ -798,7 +795,7 @@ static void task_overlay_deferred_load(retro_task_t *task)
 
          if (!image_texture_load(&image_tex, overlay_resolved_path))
          {
-            RARCH_ERR("[Overlay]: Failed to load image: %s.\n",
+            RARCH_ERR("[Overlay] Failed to load image: \"%s\".\n",
                   overlay_resolved_path);
             loader->loading_status = OVERLAY_IMAGE_TRANSFER_ERROR;
             goto error;
@@ -838,7 +835,7 @@ static void task_overlay_deferred_load(retro_task_t *task)
       if (config_get_array(conf, overlay->config.rect.key,
                overlay->config.rect.array, sizeof(overlay->config.rect.array)))
       {
-         char *tok, *save;
+         char *tok, *save         = NULL;
          char *elem0              = NULL;
          char *elem1              = NULL;
          char *elem2              = NULL;
@@ -870,7 +867,7 @@ static void task_overlay_deferred_load(retro_task_t *task)
 
          if (list_size < 4)
          {
-            RARCH_ERR("[Overlay]: Failed to split rect \"%s\" into at least four tokens.\n",
+            RARCH_ERR("[Overlay] Failed to split rect \"%s\" into at least four tokens.\n",
                   overlay->config.rect.array);
             free(elem0);
             free(elem1);
