@@ -160,18 +160,18 @@ bool content_undo_load_state(void)
    size_t temp_data_size;
    bool ret                  = false;
    unsigned num_blocks       = 0;
-   void* temp_data           = NULL;
+   void *temp_data           = NULL;
    struct sram_block *blocks = NULL;
    struct string_list *savefile_list = (struct string_list*)savefile_ptr_get();
 
    if (!core_info_current_supports_savestate())
    {
-      RARCH_LOG("[State]: %s\n",
+      RARCH_LOG("[State] %s\n",
             msg_hash_to_str(MSG_CORE_DOES_NOT_SUPPORT_SAVESTATES));
       return false;
    }
 
-   RARCH_LOG("[State]: %s \"%s\", %u %s.\n",
+   RARCH_LOG("[State] %s \"%s\", %u %s.\n",
          msg_hash_to_str(MSG_LOADING_STATE),
          undo_load_buf.path,
          (unsigned)undo_load_buf.size,
@@ -181,11 +181,11 @@ bool content_undo_load_state(void)
     * the backing up of it and
     * its flushing could all be in their
     * own functions... */
-   if (     config_get_ptr()->bools.block_sram_overwrite
-         && savefile_list
-         && savefile_list->size)
+   if (     savefile_list
+         && savefile_list->size
+         && config_get_ptr()->bools.block_sram_overwrite)
    {
-      RARCH_LOG("[SRAM]: %s.\n",
+      RARCH_LOG("[SRAM] %s.\n",
             msg_hash_to_str(MSG_BLOCKING_SRAM_OVERWRITE));
 
       if ((blocks = (struct sram_block*)
@@ -269,7 +269,7 @@ bool content_undo_load_state(void)
 
    if (!ret)
    {
-      RARCH_ERR("[State]: %s \"%s\".\n",
+      RARCH_ERR("[State] %s \"%s\".\n",
          msg_hash_to_str(MSG_FAILED_TO_UNDO_LOAD_STATE),
          undo_load_buf.path);
       return false;
@@ -354,10 +354,10 @@ static size_t content_get_rastate_size(rastate_size_info_t* size, bool rewind)
 #endif
 #ifdef HAVE_BSV_MOVIE
    /* 8-byte block header + content */
-   if(!rewind)
+   if (!rewind)
    {
       size->replay_size = replay_get_serialize_size();
-      if(size->replay_size > 0)
+      if (size->replay_size > 0)
          size->total_size += 8 + CONTENT_ALIGN_SIZE(size->replay_size);
    }
    else
@@ -371,19 +371,20 @@ size_t content_get_serialized_size(void)
    rastate_size_info_t size;
    return content_get_rastate_size(&size, false);
 }
+
 size_t content_get_serialized_size_rewind(void)
 {
    rastate_size_info_t size;
    return content_get_rastate_size(&size, true);
 }
 
-static void content_write_block_header(unsigned char* output, const char* header, size_t size)
+static void content_write_block_header(unsigned char* output, const char* header, size_t len)
 {
    memcpy(output, header, 4);
-   output[4] = ((size) & 0xFF);
-   output[5] = ((size >> 8) & 0xFF);
-   output[6] = ((size >> 16) & 0xFF);
-   output[7] = ((size >> 24) & 0xFF);
+   output[4] = ((len) & 0xFF);
+   output[5] = ((len >> 8) & 0xFF);
+   output[6] = ((len >> 16) & 0xFF);
+   output[7] = ((len >> 24) & 0xFF);
 }
 
 static bool content_write_serialized_state(void* buffer,
@@ -460,7 +461,7 @@ bool content_serialize_state_rewind(void* buffer, size_t buffer_size)
       if (_len != last_reported_len)
       {
          last_reported_len = _len;
-         RARCH_WARN("Rewind state size exceeds frame size (%zu > %zu).\n", _len, buffer_size);
+         RARCH_WARN("[Rewind] State size exceeds frame size (%zu > %zu).\n", _len, buffer_size);
       }
 #endif
       return false;
@@ -523,9 +524,9 @@ static void task_save_handler(retro_task_t *task)
 
    if (!state->data)
    {
-      size_t size = 0;
-      state->data = content_get_serialized_data(&size);
-      state->size = (ssize_t)size;
+      size_t _len = 0;
+      state->data = content_get_serialized_data(&_len);
+      state->size = (ssize_t)_len;
    }
 
    remaining       = MIN(state->size - state->written, SAVE_STATE_CHUNK);
@@ -549,7 +550,7 @@ static void task_save_handler(retro_task_t *task)
       {
          const char *failed_undo_str = msg_hash_to_str(
                MSG_FAILED_TO_UNDO_SAVE_STATE);
-         RARCH_ERR("[State]: %s \"%s\".\n", failed_undo_str,
+         RARCH_ERR("[State] %s \"%s\".\n", failed_undo_str,
                undo_save_buf.path);
          snprintf(msg, sizeof(msg), "%s \"RAM\".", failed_undo_str);
       }
@@ -557,7 +558,7 @@ static void task_save_handler(retro_task_t *task)
       {
          size_t _len = strlcpy(msg,
                msg_hash_to_str(MSG_FAILED_TO_SAVE_STATE_TO),
-               sizeof(msg));
+               sizeof(msg) - 2);
          msg[  _len] = ' ';
          msg[++_len] = '\0';
          strlcpy(msg + _len, state->path, sizeof(msg) - _len);
@@ -565,10 +566,8 @@ static void task_save_handler(retro_task_t *task)
 
       task_set_error(task, strdup(msg));
       task_save_handler_finished(task, state);
-      return;
    }
-
-   if (state->written == state->size)
+   else if (state->written == state->size)
    {
       char       *msg      = NULL;
 
@@ -608,49 +607,47 @@ static void task_save_handler(retro_task_t *task)
  *
  * Create a new task to undo the last save of the content state.
  **/
-static bool task_push_undo_save_state(const char *path, void *data, size_t size)
+static bool task_push_undo_save_state(const char *path, void *data, size_t len)
 {
-   settings_t     *settings;
    retro_task_t       *task      = task_init();
-   video_driver_state_t *video_st= video_state_get_ptr();
    save_task_state_t *state      = (save_task_state_t*)
       calloc(1, sizeof(*state));
 
-   if (!task || !state)
-      goto error;
+   if (task && state)
+   {
+      settings_t *settings  = config_get_ptr();
+      video_driver_state_t *video_st = video_state_get_ptr();
 
-   settings                      = config_get_ptr();
-
-   strlcpy(state->path, path, sizeof(state->path));
-   state->data                   = data;
-   state->size                   = size;
-   state->flags                 |= SAVE_TASK_FLAG_UNDO_SAVE;
-   state->state_slot             = settings->ints.state_slot;
-   if (video_st->frame_cache_data && (video_st->frame_cache_data == RETRO_HW_FRAME_BUFFER_VALID))
-      state->flags              |= SAVE_TASK_FLAG_HAS_VALID_FB;
+      strlcpy(state->path, path, sizeof(state->path));
+      state->data           = data;
+      state->size           = len;
+      state->flags         |= SAVE_TASK_FLAG_UNDO_SAVE;
+      state->state_slot     = settings->ints.state_slot;
+      if (video_st->frame_cache_data && (video_st->frame_cache_data == RETRO_HW_FRAME_BUFFER_VALID))
+         state->flags      |= SAVE_TASK_FLAG_HAS_VALID_FB;
 #if defined(HAVE_ZLIB)
-   if (settings->bools.savestate_file_compression)
-      state->flags              |= SAVE_TASK_FLAG_COMPRESS_FILES;
+      if (settings->bools.savestate_file_compression)
+         state->flags      |= SAVE_TASK_FLAG_COMPRESS_FILES;
 #endif
-   if (!settings->bools.notification_show_save_state)
-      state->flags              |= SAVE_TASK_FLAG_MUTE;
+      if (!settings->bools.notification_show_save_state)
+         state->flags      |= SAVE_TASK_FLAG_MUTE;
 
-   task->type                    = TASK_TYPE_BLOCKING;
-   task->state                   = state;
-   task->handler                 = task_save_handler;
-   task->callback                = undo_save_state_cb;
-   task->title                   = strdup(msg_hash_to_str(MSG_UNDOING_SAVE_STATE));
+      task->type            = TASK_TYPE_BLOCKING;
+      task->state           = state;
+      task->handler         = task_save_handler;
+      task->callback        = undo_save_state_cb;
+      task->title           = strdup(msg_hash_to_str(MSG_UNDOING_SAVE_STATE));
 
-   if (state->flags & SAVE_TASK_FLAG_MUTE)
-      task->flags               |=  RETRO_TASK_FLG_MUTE;
-   else
-      task->flags               &= ~RETRO_TASK_FLG_MUTE;
+      if (state->flags & SAVE_TASK_FLAG_MUTE)
+         task->flags       |=  RETRO_TASK_FLG_MUTE;
+      else
+         task->flags       &= ~RETRO_TASK_FLG_MUTE;
 
-   task_queue_push(task);
+      task_queue_push(task);
 
-   return true;
+      return true;
+   }
 
-error:
    if (data)
       free(data);
    if (state)
@@ -674,7 +671,7 @@ bool content_undo_save_state(void)
             undo_save_buf.path,
             undo_save_buf.data,
             undo_save_buf.size);
-   RARCH_LOG("[State]: %s\n",
+   RARCH_LOG("[State] %s\n",
          msg_hash_to_str(MSG_CORE_DOES_NOT_SUPPORT_SAVESTATES));
    return false;
 }
@@ -811,7 +808,7 @@ static void task_load_handler(retro_task_t *task)
          task_set_title(task, strdup(msg));
       }
 
-      goto end;
+      task_load_handler_finished(task, state);
    }
 
    return;
@@ -829,9 +826,9 @@ end:
    task_load_handler_finished(task, state);
 }
 
-static bool content_load_rastate1(unsigned char* input, size_t size)
+static bool content_load_rastate1(unsigned char* input, size_t len)
 {
-   unsigned char *stop = input + size;
+   unsigned char *stop = input + len;
    bool seen_core      = false;
 #ifdef HAVE_CHEEVOS
    bool seen_cheevos   = false;
@@ -863,7 +860,6 @@ static bool content_load_rastate1(unsigned char* input, size_t size)
 #else
             bool frame_is_reversed         = false;
 #endif
-
             if (BSV_MOVIE_IS_RECORDING() && !seen_replay && !frame_is_reversed)
             {
                /* TODO OSD message */
@@ -910,10 +906,11 @@ static bool content_load_rastate1(unsigned char* input, size_t size)
       input += CONTENT_ALIGN_SIZE(block_size);
    }
 
-   if (!seen_core) {
-      RARCH_LOG("[State] no core\n");
+   if (!seen_core)
+   {
+      RARCH_LOG("[State] No core.\n");
       return false;
-    }
+   }
 
 #ifdef HAVE_CHEEVOS
    if (!seen_cheevos)
@@ -934,18 +931,16 @@ static bool content_load_rastate1(unsigned char* input, size_t size)
    return true;
 }
 
-bool content_deserialize_state(
-      const void* serialized_data, size_t serialized_size)
+bool content_deserialize_state(const void *s, size_t len)
 {
-   if (memcmp(serialized_data, "RASTATE", 7) != 0)
+   if (memcmp(s, "RASTATE", 7) != 0)
    {
       /* old format is just core data, load it directly */
       retro_ctx_serialize_info_t serial_info;
-      serial_info.data_const = serialized_data;
-      serial_info.size       = serialized_size;
+      serial_info.data_const = s;
+      serial_info.size       = len;
       if (!core_unserialize(&serial_info))
          return false;
-
 #ifdef HAVE_CHEEVOS
       rcheevos_set_serialized_data(NULL);
 #endif
@@ -963,18 +958,17 @@ bool content_deserialize_state(
    }
    else
    {
-      unsigned char* input = (unsigned char*)serialized_data;
+      unsigned char* input = (unsigned char*)s;
       switch (input[7]) /* version */
       {
          case 1:
-            if (content_load_rastate1(input, serialized_size))
+            if (content_load_rastate1(input, len))
                break;
             /* fall-through intentional */
          default:
             return false;
       }
    }
-
    return true;
 }
 
@@ -991,12 +985,10 @@ static void content_load_state_cb(retro_task_t *task,
    unsigned i;
    bool ret;
    load_task_data_t *load_data = (load_task_data_t*)task_data;
-   ssize_t size                = load_data->size;
+   ssize_t _len                = load_data->size;
    unsigned num_blocks         = 0;
    void *buf                   = load_data->data;
    struct sram_block *blocks   = NULL;
-   settings_t *settings        = config_get_ptr();
-   bool block_sram_overwrite   = settings->bools.block_sram_overwrite;
    struct string_list *savefile_list = (struct string_list*)savefile_ptr_get();
 
 #ifdef HAVE_CHEEVOS
@@ -1004,13 +996,13 @@ static void content_load_state_cb(retro_task_t *task,
       goto error;
 #endif
 
-   RARCH_LOG("[State]: %s \"%s\", %u %s.\n",
+   RARCH_LOG("[State] %s \"%s\", %u %s.\n",
          msg_hash_to_str(MSG_LOADING_STATE),
          load_data->path,
-         (unsigned)size,
+         (unsigned)_len,
          msg_hash_to_str(MSG_BYTES));
 
-   if (size < 0 || !buf)
+   if (_len < 0 || !buf)
       goto error;
 
    /* This means we're backing up the file in memory,
@@ -1025,11 +1017,11 @@ static void content_load_state_cb(retro_task_t *task,
          undo_save_buf.data = NULL;
       }
 
-      if (!(undo_save_buf.data = malloc(size)))
+      if (!(undo_save_buf.data = malloc(_len)))
          goto error;
 
-      memcpy(undo_save_buf.data, buf, size);
-      undo_save_buf.size = size;
+      memcpy(undo_save_buf.data, buf, _len);
+      undo_save_buf.size = _len;
       strlcpy(undo_save_buf.path, load_data->path, sizeof(undo_save_buf.path));
 
       free(buf);
@@ -1037,9 +1029,12 @@ static void content_load_state_cb(retro_task_t *task,
       return;
    }
 
-   if (block_sram_overwrite && savefile_list && savefile_list->size)
+   if (     savefile_list
+         && savefile_list->size
+         && config_get_ptr()->bools.block_sram_overwrite
+      )
    {
-      RARCH_LOG("[SRAM]: %s.\n",
+      RARCH_LOG("[SRAM] %s.\n",
             msg_hash_to_str(MSG_BLOCKING_SRAM_OVERWRITE));
 
       if ((blocks = (struct sram_block*)
@@ -1085,7 +1080,7 @@ static void content_load_state_cb(retro_task_t *task,
    /* Backup the current state so we can undo this load */
    content_save_state("RAM", false);
 
-   ret = content_deserialize_state(buf, size);
+   ret = content_deserialize_state(buf, _len);
 
    /* Flush back. */
    for (i = 0; i < num_blocks; i++)
@@ -1117,7 +1112,7 @@ static void content_load_state_cb(retro_task_t *task,
    return;
 
 error:
-   RARCH_ERR("[State]: %s \"%s\".\n",
+   RARCH_ERR("[State] %s \"%s\".\n",
          msg_hash_to_str(MSG_FAILED_TO_LOAD_STATE),
          load_data->path);
    if (buf)
@@ -1137,11 +1132,8 @@ static void save_state_cb(retro_task_t *task,
    save_task_state_t *state   = (save_task_state_t*)task_data;
 #ifdef HAVE_SCREENSHOTS
    char               *path   = strdup(state->path);
-   settings_t     *settings   = config_get_ptr();
-   const char *dir_screenshot = settings->paths.directory_screenshot;
-
    if (state->flags & SAVE_TASK_FLAG_THUMBNAIL_ENABLE)
-      take_screenshot(dir_screenshot,
+      take_screenshot(config_get_ptr()->paths.directory_screenshot,
             path, true,
             state->flags & SAVE_TASK_FLAG_HAS_VALID_FB, false, true);
    free(path);
@@ -1158,7 +1150,7 @@ static void save_state_cb(retro_task_t *task,
  *
  * Create a new task to save the content state.
  **/
-static void task_push_save_state(const char *path, void *data, size_t size, bool autosave)
+static void task_push_save_state(const char *path, void *data, size_t len, bool autosave)
 {
    settings_t     *settings        = config_get_ptr();
    retro_task_t       *task        = task_init();
@@ -1170,11 +1162,11 @@ static void task_push_save_state(const char *path, void *data, size_t size, bool
 
    strlcpy(state->path, path, sizeof(state->path));
    state->data                   = data;
-   state->size                   = size;
+   state->size                   = len;
    /* Don't show OSD messages if we are auto-saving */
    if (autosave)
-      state->flags              |= (SAVE_TASK_FLAG_AUTOSAVE |
-                                    SAVE_TASK_FLAG_MUTE);
+      state->flags              |= (  SAVE_TASK_FLAG_AUTOSAVE
+                                    | SAVE_TASK_FLAG_MUTE);
    if (settings->bools.savestate_thumbnail_enable)
    {
       /* Delay OSD messages and widgets for a few frames
@@ -1264,7 +1256,7 @@ static void content_load_and_save_state_cb(retro_task_t *task,
  * and then save the content state.
  **/
 static void task_push_load_and_save_state(const char *path, void *data,
-      size_t size, bool load_to_backup_buffer, bool autosave)
+      size_t len, bool load_to_backup_buffer, bool autosave)
 {
    retro_task_t      *task         = NULL;
    settings_t        *settings     = config_get_ptr();
@@ -1285,7 +1277,7 @@ static void task_push_load_and_save_state(const char *path, void *data,
    strlcpy(state->path, path, sizeof(state->path));
    if (load_to_backup_buffer)
       state->flags              |= SAVE_TASK_FLAG_LOAD_TO_BACKUP_BUFF;
-   state->undo_size              = size;
+   state->undo_size              = len;
    state->undo_data              = data;
    /* Don't show OSD messages if we are auto-saving */
    if (autosave)
@@ -1337,24 +1329,23 @@ static void task_push_load_and_save_state(const char *path, void *data,
  **/
 bool content_auto_save_state(const char *path)
 {
+   size_t _len;
    settings_t *settings = config_get_ptr();
    void *serial_data  = NULL;
-   size_t serial_size;
    intfstream_t *file = NULL;
 
    if (!core_info_current_supports_savestate())
    {
-      RARCH_LOG("[State]: %s\n",
+      RARCH_LOG("[State] %s\n",
             msg_hash_to_str(MSG_CORE_DOES_NOT_SUPPORT_SAVESTATES));
       return false;
    }
 
-   serial_size = core_serialize_size();
-
-   if (serial_size == 0)
+   _len = core_serialize_size();
+   if (_len == 0)
       return false;
 
-   serial_data = content_get_serialized_data(&serial_size);
+   serial_data = content_get_serialized_data(&_len);
    if (!serial_data)
       return false;
 
@@ -1372,7 +1363,7 @@ bool content_auto_save_state(const char *path)
       return false;
    }
 
-   if (serial_size != (size_t)intfstream_write(file, serial_data, serial_size))
+   if (_len != (size_t)intfstream_write(file, serial_data, _len))
    {
       intfstream_close(file);
       free(serial_data);
@@ -1395,7 +1386,6 @@ bool content_auto_save_state(const char *path)
       take_screenshot(dir_screenshot, path, true, validfb, false, false);
    }
 #endif
-
    return true;
 }
 
@@ -1410,35 +1400,34 @@ bool content_auto_save_state(const char *path)
  **/
 bool content_save_state(const char *path, bool save_to_disk)
 {
-   size_t serial_size;
+   size_t _len;
    void *data  = NULL;
 
    if (!core_info_current_supports_savestate())
    {
-      RARCH_LOG("[State]: %s\n",
+      RARCH_LOG("[State] %s\n",
             msg_hash_to_str(MSG_CORE_DOES_NOT_SUPPORT_SAVESTATES));
       return false;
    }
 
-   serial_size = core_serialize_size();
-
-   if (serial_size == 0)
+   _len = core_serialize_size();
+   if (_len == 0)
       return false;
 
    if (!save_state_in_background)
    {
-      if (!(data = content_get_serialized_data(&serial_size)))
+      if (!(data = content_get_serialized_data(&_len)))
       {
-         RARCH_ERR("[State]: %s \"%s\".\n",
+         RARCH_ERR("[State] %s \"%s\".\n",
                msg_hash_to_str(MSG_FAILED_TO_SAVE_STATE_TO),
                path);
          return false;
       }
 
-      RARCH_LOG("[State]: %s \"%s\", %u %s.\n",
+      RARCH_LOG("[State] %s \"%s\", %u %s.\n",
             msg_hash_to_str(MSG_SAVING_STATE),
             path,
-            (unsigned)serial_size,
+            (unsigned)_len,
             msg_hash_to_str(MSG_BYTES));
    }
 
@@ -1449,20 +1438,20 @@ bool content_save_state(const char *path, bool save_to_disk)
          /* Before overwriting the savestate file, load it into a buffer
          to allow undo_save_state() to work */
          /* TODO/FIXME - Use msg_hash_to_str here */
-         RARCH_LOG("[State]: %s ...\n",
+         RARCH_LOG("[State] %s...\n",
                msg_hash_to_str(MSG_FILE_ALREADY_EXISTS_SAVING_TO_BACKUP_BUFFER));
-         task_push_load_and_save_state(path, data, serial_size, true, false);
+         task_push_load_and_save_state(path, data, _len, true, false);
       }
       else
-         task_push_save_state(path, data, serial_size, false);
+         task_push_save_state(path, data, _len, false);
    }
    else
    {
       if (!data)
       {
-         if (!(data = content_get_serialized_data(&serial_size)))
+         if (!(data = content_get_serialized_data(&_len)))
          {
-            RARCH_ERR("[State]: %s \"%s\".\n",
+            RARCH_ERR("[State] %s \"%s\".\n",
                   msg_hash_to_str(MSG_FAILED_TO_SAVE_STATE_TO),
                   path);
             return false;
@@ -1479,15 +1468,15 @@ bool content_save_state(const char *path, bool save_to_disk)
          undo_load_buf.data = NULL;
       }
 
-      if (!(undo_load_buf.data = malloc(serial_size)))
+      if (!(undo_load_buf.data = malloc(_len)))
       {
          free(data);
          return false;
       }
 
-      memcpy(undo_load_buf.data, data, serial_size);
+      memcpy(undo_load_buf.data, data, _len);
       free(data);
-      undo_load_buf.size = serial_size;
+      undo_load_buf.size = _len;
       strlcpy(undo_load_buf.path, path, sizeof(undo_load_buf.path));
    }
 
@@ -1566,7 +1555,7 @@ bool content_load_state(const char *path,
 
    if (!core_info_current_supports_savestate())
    {
-      RARCH_LOG("[State]: %s\n",
+      RARCH_LOG("[State] %s\n",
             msg_hash_to_str(MSG_CORE_DOES_NOT_SUPPORT_SAVESTATES));
       goto error;
    }
@@ -1624,7 +1613,7 @@ bool content_rename_state(const char *origin, const char *dest)
    if (!filestream_rename(origin, dest))
       return true;
 
-   RARCH_ERR("[State]: Error renaming file \"%s\".\n", origin);
+   RARCH_ERR("[State] Error renaming file \"%s\".\n", origin);
    return false;
 }
 
@@ -1689,7 +1678,7 @@ bool content_load_state_from_ram(void)
 
    if (!core_info_current_supports_savestate())
    {
-      RARCH_LOG("[State]: %s\n",
+      RARCH_LOG("[State] %s\n",
             msg_hash_to_str(MSG_CORE_DOES_NOT_SUPPORT_SAVESTATES));
       return false;
    }
@@ -1697,7 +1686,7 @@ bool content_load_state_from_ram(void)
    if (!ram_buf.state_buf.data)
       return false;
 
-   RARCH_LOG("[State]: %s, %u %s.\n",
+   RARCH_LOG("[State] %s, %u %s.\n",
          msg_hash_to_str(MSG_LOADING_STATE),
          (unsigned)ram_buf.state_buf.size,
          msg_hash_to_str(MSG_BYTES));
@@ -1719,7 +1708,7 @@ bool content_load_state_from_ram(void)
 
    if (!ret)
    {
-      RARCH_ERR("[State]: %s.\n",
+      RARCH_ERR("[State] %s.\n",
          msg_hash_to_str(MSG_FAILED_TO_LOAD_SRAM));
       return false;
    }
@@ -1735,41 +1724,41 @@ bool content_load_state_from_ram(void)
  **/
 bool content_save_state_to_ram(void)
 {
+   size_t _len;
    void *data  = NULL;
-   size_t serial_size;
 
    if (!core_info_current_supports_savestate())
    {
-      RARCH_LOG("[State]: %s\n",
+      RARCH_LOG("[State] %s\n",
             msg_hash_to_str(MSG_CORE_DOES_NOT_SUPPORT_SAVESTATES));
       return false;
    }
 
-   serial_size = core_serialize_size();
+   _len = core_serialize_size();
 
-   if (serial_size == 0)
+   if (_len == 0)
       return false;
 
    if (!save_state_in_background)
    {
-      if (!(data = content_get_serialized_data(&serial_size)))
+      if (!(data = content_get_serialized_data(&_len)))
       {
-         RARCH_ERR("[State]: %s.\n",
+         RARCH_ERR("[State] %s.\n",
                msg_hash_to_str(MSG_FAILED_TO_SAVE_SRAM));
          return false;
       }
 
-      RARCH_LOG("[State]: %s, %u %s.\n",
+      RARCH_LOG("[State] %s, %u %s.\n",
             msg_hash_to_str(MSG_SAVING_STATE),
-            (unsigned)serial_size,
+            (unsigned)_len,
             msg_hash_to_str(MSG_BYTES));
    }
 
    if (!data)
    {
-      if (!(data = content_get_serialized_data(&serial_size)))
+      if (!(data = content_get_serialized_data(&_len)))
       {
-         RARCH_ERR("[State]: %s.\n",
+         RARCH_ERR("[State] %s.\n",
                msg_hash_to_str(MSG_FAILED_TO_SAVE_SRAM));
          return false;
       }
@@ -1782,15 +1771,15 @@ bool content_save_state_to_ram(void)
       ram_buf.state_buf.data = NULL;
    }
 
-   if (!(ram_buf.state_buf.data = malloc(serial_size)))
+   if (!(ram_buf.state_buf.data = malloc(_len)))
    {
       free(data);
       return false;
    }
 
-   memcpy(ram_buf.state_buf.data, data, serial_size);
+   memcpy(ram_buf.state_buf.data, data, _len);
    free(data);
-   ram_buf.state_buf.size = serial_size;
+   ram_buf.state_buf.size = _len;
    ram_buf.to_write_file  = true;
 
    return true;
