@@ -56,7 +56,7 @@ static void task_auto_translate_handler(retro_task_t *task)
    uint32_t runloop_flags      = runloop_get_flags();
    access_state_t *access_st   = access_state_get_ptr();
 #ifdef HAVE_ACCESSIBILITY
-   settings_t *settings        = config_get_ptr();
+   bool accessibility_enable   = config_get_ptr()->bools.accessibility_enable;
 #endif
    uint8_t flg                 = task_get_flags(task);
 
@@ -73,8 +73,7 @@ static void task_auto_translate_handler(retro_task_t *task)
          break;
       case 2: /* Narrator Mode */
 #ifdef HAVE_ACCESSIBILITY
-         if (!is_narrator_running(
-                  settings->bools.accessibility_enable))
+         if (!is_narrator_running(accessibility_enable))
             goto task_finished;
 #endif
          break;
@@ -99,13 +98,9 @@ task_finished:
        free(task->user_data);
 }
 
-static void call_auto_translate_task(
-      settings_t *settings,
-      bool *was_paused)
+static void ai_service_call_auto_translate_task(access_state_t *access_st,
+      int ai_service_mode, bool *was_paused)
 {
-   int ai_service_mode       = settings->uints.ai_service_mode;
-   access_state_t *access_st = access_state_get_ptr();
-
    /*Image Mode*/
    if (ai_service_mode == 0)
    {
@@ -116,21 +111,21 @@ static void call_auto_translate_task(
    }
    else /* Speech or Narrator Mode */
    {
-      int* mode                          = NULL;
-      retro_task_t  *t                   = task_init();
+      int* mode          = NULL;
+      retro_task_t  *t   = task_init();
       if (!t)
          return;
 
-      mode                               = (int*)malloc(sizeof(int));
+      mode               = (int*)malloc(sizeof(int));
 
-      t->user_data                       = NULL;
-      t->handler                         = task_auto_translate_handler;
-      t->flags                          |= RETRO_TASK_FLG_MUTE;
+      t->user_data       = NULL;
+      t->handler         = task_auto_translate_handler;
+      t->flags          |= RETRO_TASK_FLG_MUTE;
 
       if (mode)
       {
-         *mode                           = ai_service_mode;
-         t->user_data                    = mode;
+         *mode           = ai_service_mode;
+         t->user_data    = mode;
       }
 
       task_queue_push(t);
@@ -173,6 +168,8 @@ static void handle_translation_cb(
       VIDEO_FLAG_WIDGETS_PAUSED) ? true : false;
    dispgfx_widget_t *p_dispwidget    = dispwidget_get_ptr();
 #endif
+   bool ai_service_pause             = settings->bools.ai_service_pause;
+   unsigned ai_service_mode          = settings->uints.ai_service_mode;
 #ifdef HAVE_ACCESSIBILITY
    bool accessibility_enable         = settings->bools.accessibility_enable;
    unsigned accessibility_narrator_speech_speed = settings->uints.accessibility_narrator_speech_speed;
@@ -187,7 +184,7 @@ static void handle_translation_cb(
 
 #ifdef DEBUG
    if (access_st->ai_service_auto != 2)
-      RARCH_LOG("RESULT FROM AI SERVICE...\n");
+      RARCH_LOG("[Translation] RESULT FROM AI SERVICE...\n");
 #endif
 
    if (!data || error || !data->data)
@@ -260,7 +257,7 @@ static void handle_translation_cb(
    if (string_is_equal(err_str, "No text found."))
    {
 #ifdef DEBUG
-      RARCH_LOG("No text found...\n");
+      RARCH_LOG("[Translation] No text found.\n");
 #endif
       if (txt_str)
       {
@@ -321,7 +318,7 @@ static void handle_translation_cb(
          else
          {
             /* TODO/FIXME - localize */
-            RARCH_LOG("Invalid image type returned from server.\n");
+            RARCH_LOG("[Translation] Invalid image type returned from server.\n");
             goto finish;
          }
 
@@ -331,7 +328,7 @@ static void handle_translation_cb(
          {
             /* TODO/FIXME - localize */
             const char *_msg = "Video driver not supported.";
-            RARCH_LOG("Video driver not supported for AI Service.");
+            RARCH_LOG("[Translation] Video driver not supported for AI Service.");
             runloop_msg_queue_push(_msg, strlen(_msg), 1, 180, true, NULL,
                   MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
          }
@@ -356,16 +353,16 @@ static void handle_translation_cb(
          {
             /* Get image data (24 bit), and convert to the emulated pixel format */
             image_width    =
-               ((uint32_t) ((uint8_t)raw_image_file_data[21]) << 24) +
-               ((uint32_t) ((uint8_t)raw_image_file_data[20]) << 16) +
-               ((uint32_t) ((uint8_t)raw_image_file_data[19]) << 8) +
-               ((uint32_t) ((uint8_t)raw_image_file_data[18]) << 0);
+                 ((uint32_t) ((uint8_t)raw_image_file_data[21]) << 24)
+               + ((uint32_t) ((uint8_t)raw_image_file_data[20]) << 16)
+               + ((uint32_t) ((uint8_t)raw_image_file_data[19]) << 8)
+               + ((uint32_t) ((uint8_t)raw_image_file_data[18]) << 0);
 
             image_height   =
-               ((uint32_t) ((uint8_t)raw_image_file_data[25]) << 24) +
-               ((uint32_t) ((uint8_t)raw_image_file_data[24]) << 16) +
-               ((uint32_t) ((uint8_t)raw_image_file_data[23]) << 8) +
-               ((uint32_t) ((uint8_t)raw_image_file_data[22]) << 0);
+                 ((uint32_t) ((uint8_t)raw_image_file_data[25]) << 24)
+               + ((uint32_t) ((uint8_t)raw_image_file_data[24]) << 16)
+               + ((uint32_t) ((uint8_t)raw_image_file_data[23]) << 8)
+               + ((uint32_t) ((uint8_t)raw_image_file_data[22]) << 0);
             raw_image_data = (void*)malloc(image_width * image_height * 3 * sizeof(uint8_t));
             if (raw_image_data)
                memcpy(raw_image_data,
@@ -380,15 +377,15 @@ static void handle_translation_cb(
             int retval   = 0;
             rpng_t *rpng = NULL;
             image_width  =
-                ((uint32_t) ((uint8_t)raw_image_file_data[16]) << 24)+
-                ((uint32_t) ((uint8_t)raw_image_file_data[17]) << 16)+
-                ((uint32_t) ((uint8_t)raw_image_file_data[18]) << 8)+
-                ((uint32_t) ((uint8_t)raw_image_file_data[19]) << 0);
+                  ((uint32_t) ((uint8_t)raw_image_file_data[16]) << 24)
+                + ((uint32_t) ((uint8_t)raw_image_file_data[17]) << 16)
+                + ((uint32_t) ((uint8_t)raw_image_file_data[18]) << 8)
+                + ((uint32_t) ((uint8_t)raw_image_file_data[19]) << 0);
             image_height =
-                ((uint32_t) ((uint8_t)raw_image_file_data[20]) << 24)+
-                ((uint32_t) ((uint8_t)raw_image_file_data[21]) << 16)+
-                ((uint32_t) ((uint8_t)raw_image_file_data[22]) << 8)+
-                ((uint32_t) ((uint8_t)raw_image_file_data[23]) << 0);
+                  ((uint32_t) ((uint8_t)raw_image_file_data[20]) << 24)
+                + ((uint32_t) ((uint8_t)raw_image_file_data[21]) << 16)
+                + ((uint32_t) ((uint8_t)raw_image_file_data[22]) << 8)
+                + ((uint32_t) ((uint8_t)raw_image_file_data[23]) << 0);
 
             if (!(rpng = rpng_alloc()))
             {
@@ -421,7 +418,8 @@ static void handle_translation_cb(
                      tc = d % 3;
                      th = image_height-d / (image_width * 3) - 1;
                      tw = (d % (image_width * 3)) / 3;
-                     ((uint8_t*) raw_image_data)[tw * 3 + th * 3 * image_width + tc] = ((uint8_t *)raw_image_data_alpha)[ui];
+                     ((uint8_t*) raw_image_data)[tw * 3 + th * 3 * image_width + tc] =
+                        ((uint8_t *)raw_image_data_alpha)[ui];
                      d += 1;
                   }
                }
@@ -430,7 +428,7 @@ static void handle_translation_cb(
          }
          else
          {
-            RARCH_LOG("Output from URL not a valid file type, or is not supported.\n");
+            RARCH_LOG("[Translation] Output from URL not a valid file type, or is not supported.\n");
             goto finish;
          }
 
@@ -444,7 +442,7 @@ static void handle_translation_cb(
                and translate it, and we have the translated image in
                the raw_image_data buffer.
             */
-            RARCH_LOG("Hardware frame buffer core, but selected video driver isn't supported.\n");
+            RARCH_LOG("[Translation] Hardware frame buffer core, but selected video driver isn't supported.\n");
             goto finish;
          }
 
@@ -588,8 +586,7 @@ static void handle_translation_cb(
 #ifdef HAVE_ACCESSIBILITY
    if (     txt_str
          && is_accessibility_enabled(
-            accessibility_enable,
-            access_st->enabled))
+            accessibility_enable, access_st->enabled))
       accessibility_speak_priority(
             accessibility_enable,
             accessibility_narrator_speech_speed,
@@ -598,7 +595,7 @@ static void handle_translation_cb(
 
 finish:
    if (error)
-      RARCH_ERR("%s: %s\n", msg_hash_to_str(MSG_DOWNLOAD_FAILED), error);
+      RARCH_ERR("[Translation] %s: %s.\n", msg_hash_to_str(MSG_DOWNLOAD_FAILED), error);
 
    if (user_data)
       free(user_data);
@@ -626,8 +623,9 @@ finish:
       {
          bool was_paused = (runloop_flags & RUNLOOP_FLAG_PAUSED) ? true : false;
          if (     (access_st->ai_service_auto != 0)
-               && !settings->bools.ai_service_pause)
-            call_auto_translate_task(settings, &was_paused);
+               && !ai_service_pause)
+            ai_service_call_auto_translate_task(access_st, ai_service_mode,
+                  &was_paused);
       }
       free(auto_str);
    }
@@ -780,7 +778,6 @@ static const char *ai_service_get_str(enum translation_lang id)
 bool run_translation_service(settings_t *settings, bool paused)
 {
    struct video_viewport vp;
-   uint8_t header[54];
    size_t pitch;
    unsigned width, height;
    const void *data                  = NULL;
@@ -894,7 +891,7 @@ bool run_translation_service(settings_t *settings, bool paused)
                && video_st->current_video->read_viewport(
                   video_st->data, bit24_image_prev, false)))
       {
-         RARCH_LOG("Could not read viewport for translation service...\n");
+         RARCH_LOG("[Translation] Could not read viewport for translation service.\n");
          goto finish;
       }
 
@@ -947,11 +944,10 @@ bool run_translation_service(settings_t *settings, bool paused)
         the BMP header as bytes, and then covert that to a
         b64 encoded array for transport in JSON.
       */
-      form_bmp_header(header, width, height, false);
       if (!(bmp_buffer  = (uint8_t*)malloc(width * height * 3 + 54)))
          goto finish;
 
-      memcpy(bmp_buffer, header, 54 * sizeof(uint8_t));
+      form_bmp_header(bmp_buffer, width, height, false);
       memcpy(bmp_buffer + 54,
             bit24_image,
             width * height * 3 * sizeof(uint8_t));
@@ -1025,120 +1021,121 @@ bool run_translation_service(settings_t *settings, bool paused)
    rjsonwriter_raw(jsonwriter, " ", 1);
    rjsonwriter_raw(jsonwriter, "}", 1);
 
-   if (!(json_buffer = rjsonwriter_get_memory_buffer(jsonwriter, NULL)))
-      goto finish; /* ran out of memory */
-
-#ifdef DEBUG
-   if (access_st->ai_service_auto != 2)
-      RARCH_LOG("Request size: %d\n", bmp64_len);
-#endif
+   if ((json_buffer = rjsonwriter_get_memory_buffer(jsonwriter, NULL)))
    {
-      char new_ai_service_url[PATH_MAX_LENGTH];
-      char separator                  = '?';
-      unsigned ai_service_source_lang = settings->uints.ai_service_source_lang;
-      unsigned ai_service_target_lang = settings->uints.ai_service_target_lang;
-      const char *ai_service_url      = settings->arrays.ai_service_url;
-      size_t _len                     = strlcpy(new_ai_service_url,
-            ai_service_url, sizeof(new_ai_service_url));
-
-      /* if query already exists in url, then use &'s instead */
-      if (strrchr(new_ai_service_url, '?'))
-          separator = '&';
-
-      /* source lang */
-      if (ai_service_source_lang != TRANSLATION_LANG_DONT_CARE)
-      {
-         const char *lang_source = ai_service_get_str(
-               (enum translation_lang)ai_service_source_lang);
-
-         if (!string_is_empty(lang_source))
-         {
-            new_ai_service_url[  _len] = separator;
-            new_ai_service_url[++_len] = '\0';
-            _len += strlcpy(new_ai_service_url + _len,
-                  "source_lang=",
-                  sizeof(new_ai_service_url)   - _len);
-            _len += strlcpy(new_ai_service_url + _len,
-                  lang_source,
-                  sizeof(new_ai_service_url)   - _len);
-            separator                  = '&';
-         }
-      }
-
-      /* target lang */
-      if (ai_service_target_lang != TRANSLATION_LANG_DONT_CARE)
-      {
-         const char *lang_target = ai_service_get_str(
-               (enum translation_lang)ai_service_target_lang);
-
-         if (!string_is_empty(lang_target))
-         {
-            new_ai_service_url[  _len] = separator;
-            new_ai_service_url[++_len] = '\0';
-            _len += strlcpy(new_ai_service_url + _len,
-                  "target_lang=",
-                  sizeof(new_ai_service_url)   - _len);
-            _len += strlcpy(new_ai_service_url + _len,
-                  lang_target,
-                  sizeof(new_ai_service_url)   - _len);
-            separator                  = '&';
-         }
-      }
-
-      /* mode */
-      {
-         unsigned ai_service_mode   = settings->uints.ai_service_mode;
-         /*"image" is included for backwards compatibility with
-          * vgtranslate < 1.04 */
-
-         new_ai_service_url[  _len] = separator;
-         new_ai_service_url[++_len] = '\0';
-         _len += strlcpy(new_ai_service_url          + _len,
-               "output=",
-               sizeof(new_ai_service_url)            - _len);
-
-         switch (ai_service_mode)
-         {
-            case 2:
-               strlcpy(new_ai_service_url       + _len,
-                     "text",
-                     sizeof(new_ai_service_url) - _len);
-               break;
-            case 1:
-            case 3:
-               _len += strlcpy(new_ai_service_url    + _len,
-                     "sound,wav",
-                     sizeof(new_ai_service_url)      - _len);
-               if (ai_service_mode == 1)
-                  break;
-               /* fall-through intentional for ai_service_mode == 3 */
-            case 0:
-               _len += strlcpy(new_ai_service_url    + _len,
-                     "image,png",
-                     sizeof(new_ai_service_url)      - _len);
-#ifdef HAVE_GFX_WIDGETS
-               if (     video_st->poke
-                     && video_st->poke->load_texture
-                     && video_st->poke->unload_texture)
-                  strlcpy(new_ai_service_url       + _len,
-                        ",png-a",
-                        sizeof(new_ai_service_url) - _len);
-#endif
-               break;
-            default:
-               break;
-         }
-
-      }
 #ifdef DEBUG
       if (access_st->ai_service_auto != 2)
-         RARCH_LOG("SENDING... %s\n", new_ai_service_url);
+         RARCH_LOG("[Translation] Request size: %d\n", bmp64_len);
 #endif
-      task_push_http_post_transfer(new_ai_service_url,
-            json_buffer, true, NULL, handle_translation_cb, NULL);
+      {
+         char new_ai_service_url[PATH_MAX_LENGTH];
+         char separator                  = '?';
+         unsigned ai_service_source_lang = settings->uints.ai_service_source_lang;
+         unsigned ai_service_target_lang = settings->uints.ai_service_target_lang;
+         const char *ai_service_url      = settings->arrays.ai_service_url;
+         size_t _len                     = strlcpy(new_ai_service_url,
+               ai_service_url, sizeof(new_ai_service_url));
+
+         /* if query already exists in url, then use &'s instead */
+         if (strrchr(new_ai_service_url, '?'))
+            separator = '&';
+
+         /* source lang */
+         if (ai_service_source_lang != TRANSLATION_LANG_DONT_CARE)
+         {
+            const char *lang_source = ai_service_get_str(
+                  (enum translation_lang)ai_service_source_lang);
+
+            if (!string_is_empty(lang_source))
+            {
+               new_ai_service_url[  _len] = separator;
+               new_ai_service_url[++_len] = '\0';
+               _len += strlcpy(new_ai_service_url + _len,
+                     "source_lang=",
+                     sizeof(new_ai_service_url)   - _len);
+               _len += strlcpy(new_ai_service_url + _len,
+                     lang_source,
+                     sizeof(new_ai_service_url)   - _len);
+               separator                  = '&';
+            }
+         }
+
+         /* target lang */
+         if (ai_service_target_lang != TRANSLATION_LANG_DONT_CARE)
+         {
+            const char *lang_target = ai_service_get_str(
+                  (enum translation_lang)ai_service_target_lang);
+
+            if (!string_is_empty(lang_target))
+            {
+               new_ai_service_url[  _len] = separator;
+               new_ai_service_url[++_len] = '\0';
+               _len += strlcpy(new_ai_service_url + _len,
+                     "target_lang=",
+                     sizeof(new_ai_service_url)   - _len);
+               _len += strlcpy(new_ai_service_url + _len,
+                     lang_target,
+                     sizeof(new_ai_service_url)   - _len);
+               separator                  = '&';
+            }
+         }
+
+         /* mode */
+         {
+            unsigned ai_service_mode   = settings->uints.ai_service_mode;
+            /*"image" is included for backwards compatibility with
+             * vgtranslate < 1.04 */
+
+            new_ai_service_url[  _len] = separator;
+            new_ai_service_url[++_len] = '\0';
+            _len += strlcpy(new_ai_service_url          + _len,
+                  "output=",
+                  sizeof(new_ai_service_url)            - _len);
+
+            switch (ai_service_mode)
+            {
+               case 2:
+                  strlcpy(new_ai_service_url       + _len,
+                        "text",
+                        sizeof(new_ai_service_url) - _len);
+                  break;
+               case 1:
+               case 3:
+                  _len += strlcpy(new_ai_service_url    + _len,
+                        "sound,wav",
+                        sizeof(new_ai_service_url)      - _len);
+                  if (ai_service_mode == 1)
+                     break;
+                  /* fall-through intentional for ai_service_mode == 3 */
+               case 0:
+                  _len += strlcpy(new_ai_service_url    + _len,
+                        "image,png",
+                        sizeof(new_ai_service_url)      - _len);
+#ifdef HAVE_GFX_WIDGETS
+                  if (     video_st->poke
+                        && video_st->poke->load_texture
+                        && video_st->poke->unload_texture)
+                     strlcpy(new_ai_service_url       + _len,
+                           ",png-a",
+                           sizeof(new_ai_service_url) - _len);
+#endif
+                  break;
+               default:
+                  break;
+            }
+
+         }
+#ifdef DEBUG
+         if (access_st->ai_service_auto != 2)
+            RARCH_LOG("[Translation] SENDING... %s\n", new_ai_service_url);
+#endif
+         task_push_http_post_transfer(new_ai_service_url,
+               json_buffer, true, NULL, handle_translation_cb, NULL);
+      }
+
+      error = false;
    }
 
-   error = false;
 finish:
    if (bit24_image_prev)
       free(bit24_image_prev);
