@@ -15,6 +15,19 @@ extern void ios_show_file_sheet(void);
 extern bool ios_running_on_ipad(void);
 #endif
 
+#if TARGET_OS_IPHONE
+/* iOS native keyboard support */
+typedef void (*input_keyboard_line_complete_t)(void *userdata, const char *line);
+extern bool ios_keyboard_start(char **buffer_ptr, size_t *size_ptr, const char *label,
+                                input_keyboard_line_complete_t callback, void *userdata);
+extern bool ios_keyboard_active(void);
+extern void ios_keyboard_end(void);
+#endif
+
+#if TARGET_OS_OSX
+extern void osx_show_file_sheet(void);
+#endif
+
 #ifdef __OBJC__
 
 #import <Foundation/Foundation.h>
@@ -56,6 +69,9 @@ typedef enum apple_view_type
  * the displays should not sleep.
  */
 - (bool)setDisableDisplaySleep:(bool)disable;
+#if !defined(HAVE_COCOATOUCH)
+- (void)openDocument:(id)sender;
+#endif
 @end
 
 #endif
@@ -66,7 +82,7 @@ extern id<ApplePlatform> apple_platform;
 extern id apple_platform;
 #endif
 
-#if defined(HAVE_COCOATOUCH)
+#if TARGET_OS_IPHONE && defined(HAVE_COCOATOUCH)
 void rarch_start_draw_observer(void);
 void rarch_stop_draw_observer(void);
 
@@ -93,8 +109,8 @@ UINavigationControllerDelegate> {
 
 - (void)showGameView;
 - (void)supportOtherAudioSessions;
+- (BOOL)openRetroArchURL:(NSURL *)url;
 
-- (void)refreshSystemConfig;
 @end
 
 #else
