@@ -45,7 +45,7 @@ static void cb_extract_thumbnail_pack(retro_task_t *task,
    MainWindow *mainwindow      = (MainWindow*)user_data;
 
    if (err)
-      RARCH_ERR("%s", err);
+      RARCH_ERR("[Qt] %s", err);
 
    if (dec)
    {
@@ -59,7 +59,8 @@ static void cb_extract_thumbnail_pack(retro_task_t *task,
    mainwindow->onThumbnailPackExtractFinished(string_is_empty(err));
 }
 
-void MainWindow::onThumbnailPackDownloadNetworkError(QNetworkReply::NetworkError code)
+void MainWindow::onThumbnailPackDownloadNetworkError(
+      QNetworkReply::NetworkError code)
 {
    QByteArray errorStringArray;
    QNetworkReply *reply        = m_thumbnailPackDownloadReply.data();
@@ -73,19 +74,12 @@ void MainWindow::onThumbnailPackDownloadNetworkError(QNetworkReply::NetworkError
    errorStringArray = reply->errorString().toUtf8();
    errorStringData  = errorStringArray.constData();
 
-   RARCH_ERR("[Qt]: Network error code %d received: %s\n",
+   RARCH_ERR("[Qt] Network error code %d received: %s\n",
          code, errorStringData);
-
-#if 0
-   /* Deleting the reply here seems to cause a strange
-    * heap-use-after-free crash. */
-   reply->disconnect();
-   reply->abort();
-   reply->deleteLater();
-#endif
 }
 
-void MainWindow::onThumbnailPackDownloadNetworkSslErrors(const QList<QSslError> &errors)
+void MainWindow::onThumbnailPackDownloadNetworkSslErrors(
+      const QList<QSslError> &errors)
 {
    QNetworkReply *reply = m_thumbnailPackDownloadReply.data();
    int i;
@@ -97,13 +91,13 @@ void MainWindow::onThumbnailPackDownloadNetworkSslErrors(const QList<QSslError>
    {
       const QSslError &error = errors.at(i);
       QString string         =
-           QString("Ignoring SSL error code ")
+           QStringLiteral("Ignoring SSL error code ")
          + QString::number(error.error())
-         + ": "
+         + QStringLiteral(": ")
          + error.errorString();
       QByteArray stringArray = string.toUtf8();
       const char *stringData = stringArray.constData();
-      RARCH_ERR("[Qt]: %s\n", stringData);
+      RARCH_ERR("[Qt] %s\n", stringData);
    }
 
    /* Ignore all SSL errors for now, like self-signed, expired etc. */
@@ -117,10 +111,10 @@ void MainWindow::onThumbnailPackDownloadCanceled()
 
 void MainWindow::onThumbnailPackDownloadFinished()
 {
+   int code;
    QString system;
    QNetworkReply *reply = m_thumbnailPackDownloadReply.data();
    QNetworkReply::NetworkError error;
-   int code;
 
    m_thumbnailPackDownloadProgressDialog->cancel();
 
@@ -151,7 +145,8 @@ void MainWindow::onThumbnailPackDownloadFinished()
          QByteArray redirectUrlArray = redirectUrl.toString().toUtf8();
          const char *redirectUrlData = redirectUrlArray.constData();
 
-         RARCH_LOG("[Qt]: Thumbnail pack download got redirect with HTTP code %d: %s\n", code, redirectUrlData);
+         RARCH_LOG("[Qt] Thumbnail pack download got redirect with HTTP code %d: \"%s\".\n",
+               code, redirectUrlData);
 
          reply->disconnect();
          reply->abort();
@@ -162,11 +157,14 @@ void MainWindow::onThumbnailPackDownloadFinished()
          return;
       }
 
-      emit showErrorMessageDeferred(QString(msg_hash_to_str(MENU_ENUM_LABEL_VALUE_QT_NETWORK_ERROR)) + ": HTTP Code " + QString::number(code));
+      emit showErrorMessageDeferred(QString(msg_hash_to_str(
+                  MENU_ENUM_LABEL_VALUE_QT_NETWORK_ERROR))
+                + QStringLiteral(": HTTP Code ")
+                + QString::number(code));
 
       m_thumbnailPackDownloadFile.remove();
 
-      RARCH_ERR("[Qt]: Thumbnail pack download failed with HTTP status code: %d\n", code);
+      RARCH_ERR("[Qt] Thumbnail pack download failed with HTTP status code: %d.\n", code);
 
       reply->disconnect();
       reply->abort();
@@ -183,22 +181,23 @@ void MainWindow::onThumbnailPackDownloadFinished()
 
       /* rename() requires the old file to be deleted first if it exists */
       if (newFile.exists() && !newFile.remove())
-         RARCH_ERR("[Qt]: Thumbnail pack download finished, but old file could not be deleted.\n");
+         RARCH_ERR("[Qt] Thumbnail pack download finished, but old file could not be deleted.\n");
       else
       {
          if (m_thumbnailPackDownloadFile.rename(newFileName))
          {
             settings_t *settings = config_get_ptr();
-
             if (settings)
             {
-               RARCH_LOG("[Qt]: Thumbnail pack download finished successfully.\n");
-               emit extractArchiveDeferred(newFileName, settings->paths.directory_thumbnails, TEMP_EXTENSION, cb_extract_thumbnail_pack);
+               RARCH_LOG("[Qt] Thumbnail pack download finished successfully.\n");
+               emit extractArchiveDeferred(newFileName,
+                     settings->paths.directory_thumbnails,
+                     TEMP_EXTENSION, cb_extract_thumbnail_pack);
             }
          }
          else
          {
-            RARCH_ERR("[Qt]: Thumbnail pack download finished, but temp file could not be renamed.\n");
+            RARCH_ERR("[Qt] Thumbnail pack download finished, but temp file could not be renamed.\n");
             emit showErrorMessageDeferred(msg_hash_to_str(MENU_ENUM_LABEL_VALUE_QT_COULD_NOT_RENAME_FILE));
          }
       }
@@ -210,8 +209,13 @@ void MainWindow::onThumbnailPackDownloadFinished()
 
       m_thumbnailPackDownloadFile.remove();
 
-      RARCH_ERR("[Qt]: Thumbnail pack download ended prematurely: %s\n", errorData);
-      emit showErrorMessageDeferred(QString(msg_hash_to_str(MENU_ENUM_LABEL_VALUE_QT_NETWORK_ERROR)) + ": Code " + QString::number(code) + ": " + errorData);
+      RARCH_ERR("[Qt] Thumbnail pack download ended prematurely: %s.\n", errorData);
+      emit showErrorMessageDeferred(QString(msg_hash_to_str(
+                  MENU_ENUM_LABEL_VALUE_QT_NETWORK_ERROR))
+                + QStringLiteral(": Code ")
+                + QString::number(code)
+                + QStringLiteral(": ")
+                + errorData);
    }
 
    reply->disconnect();
@@ -264,7 +268,7 @@ void MainWindow::downloadAllThumbnails(QString system, QUrl url)
 
    if (m_thumbnailPackDownloadFile.isOpen())
    {
-      RARCH_ERR("[Qt]: File is already open.\n");
+      RARCH_ERR("[Qt] File is already open.\n");
       return;
    }
    else
@@ -288,14 +292,16 @@ void MainWindow::downloadAllThumbnails(QString system, QUrl url)
       if (!m_thumbnailPackDownloadFile.open(QIODevice::WriteOnly))
       {
          m_thumbnailPackDownloadProgressDialog->cancel();
-         showMessageBox(msg_hash_to_str(MENU_ENUM_LABEL_VALUE_QT_FILE_WRITE_OPEN_FAILED), MainWindow::MSGBOX_TYPE_ERROR, Qt::ApplicationModal, false);
-         RARCH_ERR("[Qt]: Could not open file for writing: %s\n", fileNameData);
+         showMessageBox(msg_hash_to_str(
+                  MENU_ENUM_LABEL_VALUE_QT_FILE_WRITE_OPEN_FAILED),
+               MainWindow::MSGBOX_TYPE_ERROR, Qt::ApplicationModal, false);
+         RARCH_ERR("[Qt] Could not open file for writing: \"%s\".\n", fileNameData);
          return;
       }
    }
 
-   RARCH_LOG("[Qt]: Starting thumbnail pack download...\n");
-   RARCH_LOG("[Qt]: Downloading URL %s\n", urlData);
+   RARCH_LOG("[Qt] Starting thumbnail pack download...\n");
+   RARCH_LOG("[Qt] Downloading URL \"%s\"\n", urlData);
 
    request.setHeader(QNetworkRequest::UserAgentHeader, USER_AGENT);
 
@@ -305,7 +311,9 @@ void MainWindow::downloadAllThumbnails(QString system, QUrl url)
    m_thumbnailPackDownloadProgressDialog->setAutoClose(true);
    m_thumbnailPackDownloadProgressDialog->setAutoReset(true);
    m_thumbnailPackDownloadProgressDialog->setValue(0);
-   m_thumbnailPackDownloadProgressDialog->setLabelText(QString(msg_hash_to_str(MSG_DOWNLOADING)) + "...");
+   m_thumbnailPackDownloadProgressDialog->setLabelText(QString(
+            msg_hash_to_str(MSG_DOWNLOADING))
+          + QStringLiteral("..."));
    m_thumbnailPackDownloadProgressDialog->setCancelButtonText(tr("Cancel"));
    m_thumbnailPackDownloadProgressDialog->show();
 
@@ -315,14 +323,23 @@ void MainWindow::downloadAllThumbnails(QString system, QUrl url)
    reply->setProperty("system", system);
 
    /* Make sure any previous connection is removed first */
-   disconnect(m_thumbnailPackDownloadProgressDialog, SIGNAL(canceled()), reply, SLOT(abort()));
-   connect(m_thumbnailPackDownloadProgressDialog, SIGNAL(canceled()), reply, SLOT(abort()));
+   disconnect(m_thumbnailPackDownloadProgressDialog,
+         SIGNAL(canceled()), reply, SLOT(abort()));
+   connect(m_thumbnailPackDownloadProgressDialog,
+         SIGNAL(canceled()), reply, SLOT(abort()));
 
-   connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(onThumbnailPackDownloadNetworkError(QNetworkReply::NetworkError)));
-   connect(reply, SIGNAL(sslErrors(const QList<QSslError>&)), this, SLOT(onThumbnailPackDownloadNetworkSslErrors(const QList<QSslError>&)));
-   connect(reply, SIGNAL(finished()), this, SLOT(onThumbnailPackDownloadFinished()));
-   connect(reply, SIGNAL(readyRead()), this, SLOT(onThumbnailPackDownloadReadyRead()));
-   connect(reply, SIGNAL(downloadProgress(qint64, qint64)), this, SLOT(onThumbnailPackDownloadProgress(qint64, qint64)));
+   connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this,
+         SLOT(onThumbnailPackDownloadNetworkError(
+               QNetworkReply::NetworkError)));
+   connect(reply, SIGNAL(sslErrors(const QList<QSslError>&)), this,
+         SLOT(onThumbnailPackDownloadNetworkSslErrors(
+               const QList<QSslError>&)));
+   connect(reply, SIGNAL(finished()), this,
+         SLOT(onThumbnailPackDownloadFinished()));
+   connect(reply, SIGNAL(readyRead()), this,
+         SLOT(onThumbnailPackDownloadReadyRead()));
+   connect(reply, SIGNAL(downloadProgress(qint64, qint64)), this,
+         SLOT(onThumbnailPackDownloadProgress(qint64, qint64)));
 }
 
 void MainWindow::onThumbnailPackExtractFinished(bool success)
@@ -331,14 +348,15 @@ void MainWindow::onThumbnailPackExtractFinished(bool success)
 
    if (!success)
    {
-      RARCH_ERR("[Qt]: Thumbnail pack extraction failed.\n");
+      RARCH_ERR("[Qt] Thumbnail pack extraction failed.\n");
       emit showErrorMessageDeferred(msg_hash_to_str(MSG_DECOMPRESSION_FAILED));
       return;
    }
 
-   RARCH_LOG("[Qt]: Thumbnail pack extracted successfully.\n");
+   RARCH_LOG("[Qt] Thumbnail pack extracted successfully.\n");
 
-   emit showInfoMessageDeferred(msg_hash_to_str(MENU_ENUM_LABEL_VALUE_QT_THUMBNAIL_PACK_DOWNLOADED_SUCCESSFULLY));
+   emit showInfoMessageDeferred(msg_hash_to_str(
+            MENU_ENUM_LABEL_VALUE_QT_THUMBNAIL_PACK_DOWNLOADED_SUCCESSFULLY));
 
    QNetworkReply *reply = m_thumbnailPackDownloadReply.data();
 
@@ -364,16 +382,8 @@ void MainWindow::onThumbnailDownloadNetworkError(QNetworkReply::NetworkError cod
    errorStringArray = reply->errorString().toUtf8();
    errorStringData  = errorStringArray.constData();
 
-   RARCH_ERR("[Qt]: Network error code %d received: %s\n",
+   RARCH_ERR("[Qt] Network error code %d received: %s\n",
          code, errorStringData);
-
-#if 0
-   /* Deleting the reply here seems to cause a strange
-    * heap-use-after-free crash. */
-   reply->disconnect();
-   reply->abort();
-   reply->deleteLater();
-#endif
 }
 
 void MainWindow::onThumbnailDownloadNetworkSslErrors(
@@ -389,13 +399,13 @@ void MainWindow::onThumbnailDownloadNetworkSslErrors(
    {
       const QSslError &error = errors.at(i);
       QString         string =
-           QString("Ignoring SSL error code ")
+           QStringLiteral("Ignoring SSL error code ")
          + QString::number(error.error())
-         + ": "
+         + QStringLiteral(": ")
          + error.errorString();
       QByteArray stringArray = string.toUtf8();
       const char *stringData = stringArray.constData();
-      RARCH_ERR("[Qt]: %s\n", stringData);
+      RARCH_ERR("[Qt] %s\n", stringData);
    }
 
    /* Ignore all SSL errors for now, like self-signed, expired etc. */
@@ -452,7 +462,8 @@ void MainWindow::onThumbnailDownloadFinished()
 
          m_pendingThumbnailDownloadTypes.prepend(downloadType);
 
-         RARCH_LOG("[Qt]: Thumbnail download got redirect with HTTP code %d: %s\n", code, redirectUrlData);
+         RARCH_LOG("[Qt] Thumbnail download got redirect with HTTP code %d: \"%s\".\n",
+               code, redirectUrlData);
 
          reply->disconnect();
          reply->abort();
@@ -465,7 +476,7 @@ void MainWindow::onThumbnailDownloadFinished()
 
       m_thumbnailDownloadFile.remove();
 
-      RARCH_ERR("[Qt]: Thumbnail download failed with HTTP status code: %d\n", code);
+      RARCH_ERR("[Qt] Thumbnail download failed with HTTP status code: %d.\n", code);
 
       reply->disconnect();
       reply->abort();
@@ -486,21 +497,23 @@ void MainWindow::onThumbnailDownloadFinished()
 
       /* rename() requires the old file to be deleted first if it exists */
       if (newFile.exists() && !newFile.remove())
-         RARCH_ERR("[Qt]: Thumbnail download finished, but old file could not be deleted.\n");
+         RARCH_ERR("[Qt] Thumbnail download finished, but old file could not be deleted.\n");
       else
       {
          if (m_thumbnailDownloadFile.rename(newFileName))
          {
-            RARCH_LOG("[Qt]: Thumbnail download finished successfully.\n");
+            RARCH_LOG("[Qt] Thumbnail download finished successfully.\n");
             /* reload thumbnail image */
-            m_playlistModel->reloadThumbnailPath(m_thumbnailDownloadFile.fileName());
+            m_playlistModel->reloadThumbnailPath(
+                  m_thumbnailDownloadFile.fileName());
             updateVisibleItems();
             emit itemChanged();
          }
          else
          {
-            RARCH_ERR("[Qt]: Thumbnail download finished, but temp file could not be renamed.\n");
-            emit showErrorMessageDeferred(msg_hash_to_str(MENU_ENUM_LABEL_VALUE_QT_COULD_NOT_RENAME_FILE));
+            RARCH_ERR("[Qt] Thumbnail download finished, but temp file could not be renamed.\n");
+            emit showErrorMessageDeferred(msg_hash_to_str(
+                     MENU_ENUM_LABEL_VALUE_QT_COULD_NOT_RENAME_FILE));
          }
       }
    }
@@ -511,12 +524,12 @@ void MainWindow::onThumbnailDownloadFinished()
 
       m_thumbnailDownloadFile.remove();
 
-      RARCH_ERR("[Qt]: Thumbnail download ended prematurely: %s\n", errorData);
+      RARCH_ERR("[Qt] Thumbnail download ended prematurely: %s\n", errorData);
       emit showErrorMessageDeferred(
               QString(msg_hash_to_str(MENU_ENUM_LABEL_VALUE_QT_NETWORK_ERROR))
-            + ": Code "
+            + QStringLiteral(": Code ")
             + QString::number(code)
-            + ": "
+            + QStringLiteral(": ")
             + errorData);
    }
 
@@ -569,8 +582,10 @@ void MainWindow::downloadThumbnail(QString system, QString title, QUrl url)
    title                    = getScrubbedString(title);
    downloadType             = m_pendingThumbnailDownloadTypes.takeFirst();
    urlString                = QString(THUMBNAIL_URL_HEADER)
-      + system + "/"
-      + downloadType + "/"
+      + system
+      + QStringLiteral("/")
+      + downloadType
+      + QStringLiteral("/")
       + title
       + THUMBNAIL_IMAGE_EXTENSION;
 
@@ -584,16 +599,20 @@ void MainWindow::downloadThumbnail(QString system, QString title, QUrl url)
 
    if (m_thumbnailDownloadFile.isOpen())
    {
-      RARCH_ERR("[Qt]: File is already open.\n");
+      RARCH_ERR("[Qt] File is already open.\n");
       return;
    }
    else
    {
       QDir dir;
       const char *path_dir_thumbnails = settings->paths.directory_thumbnails;
-      QString               dirString = QString(path_dir_thumbnails) + "/" + system + "/" + downloadType;
+      QString               dirString = QString(path_dir_thumbnails)
+                                      + QStringLiteral("/")
+                                      + system
+                                      + QStringLiteral("/")
+                                      + downloadType;
       QString fileName                = dirString
-         + "/"
+         + QStringLiteral("/")
          + title
          + THUMBNAIL_IMAGE_EXTENSION
          + PARTIAL_EXTENSION;
@@ -607,8 +626,11 @@ void MainWindow::downloadThumbnail(QString system, QString title, QUrl url)
       if (!m_thumbnailDownloadFile.open(QIODevice::WriteOnly))
       {
          m_thumbnailDownloadProgressDialog->cancel();
-         showMessageBox(msg_hash_to_str(MENU_ENUM_LABEL_VALUE_QT_FILE_WRITE_OPEN_FAILED), MainWindow::MSGBOX_TYPE_ERROR, Qt::ApplicationModal, false);
-         RARCH_ERR("[Qt]: Could not open file for writing: %s\n", fileNameData);
+         showMessageBox(msg_hash_to_str(
+                  MENU_ENUM_LABEL_VALUE_QT_FILE_WRITE_OPEN_FAILED),
+               MainWindow::MSGBOX_TYPE_ERROR, Qt::ApplicationModal, false);
+         RARCH_ERR("[Qt] Could not open file for writing: \"%s\".\n",
+               fileNameData);
 
          if (m_thumbnailDownloadReply)
          {
@@ -626,8 +648,8 @@ void MainWindow::downloadThumbnail(QString system, QString title, QUrl url)
       }
    }
 
-   RARCH_LOG("[Qt]: Starting thumbnail download...\n");
-   RARCH_LOG("[Qt]: Downloading URL %s\n", urlData);
+   RARCH_LOG("[Qt] Starting thumbnail download...\n");
+   RARCH_LOG("[Qt] Downloading URL %s\n", urlData);
 
    request.setHeader(QNetworkRequest::UserAgentHeader, USER_AGENT);
 
@@ -637,7 +659,8 @@ void MainWindow::downloadThumbnail(QString system, QString title, QUrl url)
    m_thumbnailDownloadProgressDialog->setAutoClose(true);
    m_thumbnailDownloadProgressDialog->setAutoReset(true);
    m_thumbnailDownloadProgressDialog->setValue(0);
-   m_thumbnailDownloadProgressDialog->setLabelText(QString(msg_hash_to_str(MSG_DOWNLOADING)) + "...");
+   m_thumbnailDownloadProgressDialog->setLabelText(QString(
+            msg_hash_to_str(MSG_DOWNLOADING)) + "...");
    m_thumbnailDownloadProgressDialog->setCancelButtonText(tr("Cancel"));
    m_thumbnailDownloadProgressDialog->show();
 
@@ -649,14 +672,19 @@ void MainWindow::downloadThumbnail(QString system, QString title, QUrl url)
    reply->setProperty("download_type", downloadType);
 
    /* Make sure any previous connection is removed first */
-   disconnect(m_thumbnailDownloadProgressDialog, SIGNAL(canceled()), reply, SLOT(abort()));
-   connect(m_thumbnailDownloadProgressDialog, SIGNAL(canceled()), reply, SLOT(abort()));
+   disconnect(m_thumbnailDownloadProgressDialog, SIGNAL(canceled()),
+         reply, SLOT(abort()));
+   connect(m_thumbnailDownloadProgressDialog, SIGNAL(canceled()),
+         reply, SLOT(abort()));
 
-   connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(onThumbnailDownloadNetworkError(QNetworkReply::NetworkError)));
-   connect(reply, SIGNAL(sslErrors(const QList<QSslError>&)), this, SLOT(onThumbnailDownloadNetworkSslErrors(const QList<QSslError>&)));
+   connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this,
+         SLOT(onThumbnailDownloadNetworkError(QNetworkReply::NetworkError)));
+   connect(reply, SIGNAL(sslErrors(const QList<QSslError>&)), this,
+         SLOT(onThumbnailDownloadNetworkSslErrors(const QList<QSslError>&)));
    connect(reply, SIGNAL(finished()), this, SLOT(onThumbnailDownloadFinished()));
    connect(reply, SIGNAL(readyRead()), this, SLOT(onThumbnailDownloadReadyRead()));
-   connect(reply, SIGNAL(downloadProgress(qint64, qint64)), this, SLOT(onThumbnailDownloadProgress(qint64, qint64)));
+   connect(reply, SIGNAL(downloadProgress(qint64, qint64)), this,
+         SLOT(onThumbnailDownloadProgress(qint64, qint64)));
 }
 
 void MainWindow::onPlaylistThumbnailDownloadNetworkError(QNetworkReply::NetworkError /*code*/)
@@ -675,13 +703,13 @@ void MainWindow::onPlaylistThumbnailDownloadNetworkSslErrors(const QList<QSslErr
    {
       const QSslError &error = errors.at(i);
       QString string         =
-           QString("Ignoring SSL error code ")
+           QStringLiteral("Ignoring SSL error code ")
          + QString::number(error.error())
-         + ": "
+         + QStringLiteral(": ")
          + error.errorString();
       QByteArray stringArray = string.toUtf8();
       const char *stringData = stringArray.constData();
-      RARCH_ERR("[Qt]: %s\n", stringData);
+      RARCH_ERR("[Qt] %s\n", stringData);
    }
 
    /* Ignore all SSL errors for now, like self-signed, expired etc. */
@@ -692,7 +720,7 @@ void MainWindow::onPlaylistThumbnailDownloadCanceled()
 {
    m_playlistThumbnailDownloadProgressDialog->cancel();
    m_playlistThumbnailDownloadWasCanceled = true;
-   RARCH_LOG("[Qt]: Playlist thumbnail download was canceled.\n");
+   RARCH_LOG("[Qt] Playlist thumbnail download was canceled.\n");
 }
 
 void MainWindow::onPlaylistThumbnailDownloadFinished()
@@ -726,7 +754,11 @@ void MainWindow::onPlaylistThumbnailDownloadFinished()
          reply->abort();
          reply->deleteLater();
 
-         downloadNextPlaylistThumbnail(reply->property("system").toString(), reply->property("title").toString(), reply->property("type").toString(), redirectUrl);
+         downloadNextPlaylistThumbnail(
+               reply->property("system").toString(),
+               reply->property("title").toString(),
+               reply->property("type").toString(),
+               redirectUrl);
 
          return;
       }
@@ -745,7 +777,7 @@ void MainWindow::onPlaylistThumbnailDownloadFinished()
       if (newFile.exists() && !newFile.remove())
       {
          m_failedThumbnails++;
-         RARCH_ERR("[Qt]: Thumbnail download finished, but old file could not be deleted.\n");
+         RARCH_ERR("[Qt] Thumbnail download finished, but old file could not be deleted.\n");
       }
       else
       {
@@ -770,11 +802,14 @@ void MainWindow::onPlaylistThumbnailDownloadFinished()
       ViewType viewType = getCurrentViewType();
 
       updateVisibleItems();
-      downloadNextPlaylistThumbnail(nextThumbnail.value("db_name"), nextThumbnail.value("label_noext"), nextThumbnail.value("type"));
+      downloadNextPlaylistThumbnail(
+            nextThumbnail.value("db_name"),
+            nextThumbnail.value("label_noext"),
+            nextThumbnail.value("type"));
    }
    else
    {
-      RARCH_LOG("[Qt]: Playlist thumbnails finished downloading.\n");
+      RARCH_LOG("[Qt] Playlist thumbnails finished downloading.\n");
       /* Update thumbnail */
       emit itemChanged();
    }
@@ -784,15 +819,8 @@ void MainWindow::onPlaylistThumbnailDownloadFinished()
    reply->deleteLater();
 }
 
-void MainWindow::onPlaylistThumbnailDownloadProgress(qint64 bytesReceived, qint64 bytesTotal)
-{
-#if 0
-   QNetworkReply *reply = m_playlistThumbnailDownloadReply.data();
-   int progress         = (bytesReceived / (float)bytesTotal) * 100.0f;
-   if (!reply)
-      return;
-#endif
-}
+void MainWindow::onPlaylistThumbnailDownloadProgress(qint64 bytesReceived,
+      qint64 bytesTotal) { }
 
 void MainWindow::onPlaylistThumbnailDownloadReadyRead()
 {
@@ -817,9 +845,10 @@ void MainWindow::downloadNextPlaylistThumbnail(
 
    urlString            =
         QString(THUMBNAIL_URL_HEADER)
-      + system  + "/"
+      + system
+      + QStringLiteral("/")
       + type
-      + "/"
+      + QStringLiteral("/")
       + title
       + THUMBNAIL_IMAGE_EXTENSION;
 
@@ -830,21 +859,29 @@ void MainWindow::downloadNextPlaylistThumbnail(
 
    if (m_playlistThumbnailDownloadFile.isOpen())
    {
-      RARCH_ERR("[Qt]: File is already open.\n");
+      RARCH_ERR("[Qt] File is already open.\n");
       return;
    }
    else
    {
-      QString dirString = QString(settings->paths.directory_thumbnails);
-      QString fileName = dirString + "/" + system + "/" + type + "/" + title + THUMBNAIL_IMAGE_EXTENSION + PARTIAL_EXTENSION;
-      QByteArray fileNameArray = fileName.toUtf8();
       QDir dir;
+      QString dirString = QString(settings->paths.directory_thumbnails);
+      QString fileName = dirString
+         + QStringLiteral("/")
+         + system
+         + QStringLiteral("/")
+         + type
+         + QStringLiteral("/")
+         + title
+         + THUMBNAIL_IMAGE_EXTENSION
+         + PARTIAL_EXTENSION;
+      QByteArray fileNameArray = fileName.toUtf8();
       const char *fileNameData = fileNameArray.constData();
 
-      dir.mkpath(dirString + "/" + system + "/" + THUMBNAIL_BOXART);
-      dir.mkpath(dirString + "/" + system + "/" + THUMBNAIL_SCREENSHOT);
-      dir.mkpath(dirString + "/" + system + "/" + THUMBNAIL_TITLE);
-      dir.mkpath(dirString + "/" + system + "/" + THUMBNAIL_LOGO);
+      dir.mkpath(dirString + QStringLiteral("/") + system + QStringLiteral("/") + THUMBNAIL_BOXART);
+      dir.mkpath(dirString + QStringLiteral("/") + system + QStringLiteral("/") + THUMBNAIL_SCREENSHOT);
+      dir.mkpath(dirString + QStringLiteral("/") + system + QStringLiteral("/") + THUMBNAIL_TITLE);
+      dir.mkpath(dirString + QStringLiteral("/") + system + QStringLiteral("/") + THUMBNAIL_LOGO);
 
       m_playlistThumbnailDownloadFile.setFileName(fileName);
 
@@ -852,12 +889,15 @@ void MainWindow::downloadNextPlaylistThumbnail(
       {
          m_failedThumbnails++;
 
-         RARCH_ERR("[Qt]: Could not open file for writing: %s\n", fileNameData);
+         RARCH_ERR("[Qt] Could not open file for writing: \"%s\".\n", fileNameData);
 
          if (m_pendingPlaylistThumbnails.count() > 0)
          {
             QHash<QString, QString> nextThumbnail = m_pendingPlaylistThumbnails.takeAt(0);
-            downloadNextPlaylistThumbnail(nextThumbnail.value("db_name"), nextThumbnail.value("label_noext"), nextThumbnail.value("type"));
+            downloadNextPlaylistThumbnail(
+                  nextThumbnail.value("db_name"),
+                  nextThumbnail.value("label_noext"),
+                  nextThumbnail.value("type"));
          }
          else
             m_playlistThumbnailDownloadProgressDialog->cancel();
@@ -876,20 +916,36 @@ void MainWindow::downloadNextPlaylistThumbnail(
    reply->setProperty("type", type);
 
    /* Make sure any previous connection is removed first */
-   disconnect(m_playlistThumbnailDownloadProgressDialog, SIGNAL(canceled()), reply, SLOT(abort()));
-   connect(m_playlistThumbnailDownloadProgressDialog, SIGNAL(canceled()), reply, SLOT(abort()));
+   disconnect(m_playlistThumbnailDownloadProgressDialog, SIGNAL(canceled()),
+         reply, SLOT(abort()));
+   connect(m_playlistThumbnailDownloadProgressDialog, SIGNAL(canceled()),
+         reply, SLOT(abort()));
 
-   connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(onPlaylistThumbnailDownloadNetworkError(QNetworkReply::NetworkError)));
-   connect(reply, SIGNAL(sslErrors(const QList<QSslError>&)), this, SLOT(onPlaylistThumbnailDownloadNetworkSslErrors(const QList<QSslError>&)));
-   connect(reply, SIGNAL(finished()), this, SLOT(onPlaylistThumbnailDownloadFinished()));
-   connect(reply, SIGNAL(readyRead()), this, SLOT(onPlaylistThumbnailDownloadReadyRead()));
-   connect(reply, SIGNAL(downloadProgress(qint64, qint64)), this, SLOT(onPlaylistThumbnailDownloadProgress(qint64, qint64)));
+   connect(reply, SIGNAL(error(QNetworkReply::NetworkError)),
+         this,
+         SLOT(onPlaylistThumbnailDownloadNetworkError(
+               QNetworkReply::NetworkError)));
+   connect(reply, SIGNAL(sslErrors(const QList<QSslError>&)),
+         this,
+         SLOT(onPlaylistThumbnailDownloadNetworkSslErrors(
+               const QList<QSslError>&)));
+   connect(reply, SIGNAL(finished()), this,
+         SLOT(onPlaylistThumbnailDownloadFinished()));
+   connect(reply, SIGNAL(readyRead()), this,
+         SLOT(onPlaylistThumbnailDownloadReadyRead()));
+   connect(reply, SIGNAL(downloadProgress(qint64, qint64)), this,
+         SLOT(onPlaylistThumbnailDownloadProgress(qint64, qint64)));
 
-   m_playlistThumbnailDownloadProgressDialog->setValue(m_playlistThumbnailDownloadProgressDialog->maximum() - m_pendingPlaylistThumbnails.count());
+   m_playlistThumbnailDownloadProgressDialog->setValue(
+           m_playlistThumbnailDownloadProgressDialog->maximum()
+         - m_pendingPlaylistThumbnails.count());
 
    {
-      QString labelText  = QString(msg_hash_to_str(MSG_DOWNLOADING)) + "...\n";
-      QString labelText2 = QString(msg_hash_to_str(MENU_ENUM_LABEL_VALUE_QT_DOWNLOAD_PLAYLIST_THUMBNAIL_PROGRESS)).arg(m_downloadedThumbnails).arg(m_failedThumbnails);
+      QString labelText  = QString(msg_hash_to_str(MSG_DOWNLOADING))
+                         + QStringLiteral("...\n");
+      QString labelText2 = QString(msg_hash_to_str(
+                           MENU_ENUM_LABEL_VALUE_QT_DOWNLOAD_PLAYLIST_THUMBNAIL_PROGRESS)).arg(
+                           m_downloadedThumbnails).arg(m_failedThumbnails);
 
       labelText.append(labelText2);
 
@@ -923,7 +979,8 @@ void MainWindow::downloadPlaylistThumbnails(QString playlistPath)
       QHash<QString, QString> hash2;
       QHash<QString, QString> hash3;
       QHash<QString, QString> hash4;
-      const QHash<QString, QString> &itemHash = m_playlistModel->index(i, 0).data(PlaylistModel::HASH).value< QHash<QString, QString> >();
+      const QHash<QString, QString> &itemHash =
+	      m_playlistModel->index(i, 0).data(PlaylistModel::HASH).value< QHash<QString, QString> >();
 
       hash["db_name"]     = itemHash.value("db_name");
       hash["label_noext"] = itemHash.value("label_noext");
@@ -955,9 +1012,11 @@ void MainWindow::downloadPlaylistThumbnails(QString playlistPath)
 
    {
       QHash<QString, QString> firstThumbnail = m_pendingPlaylistThumbnails.takeAt(0);
-
       /* Start downloading the first thumbnail,
        * the rest will download as each one finishes. */
-      downloadNextPlaylistThumbnail(firstThumbnail.value("db_name"), firstThumbnail.value("label_noext"), firstThumbnail.value("type"));
+      downloadNextPlaylistThumbnail(
+            firstThumbnail.value("db_name"),
+            firstThumbnail.value("label_noext"),
+            firstThumbnail.value("type"));
    }
 }
