@@ -35,9 +35,7 @@ AchievementsCategory::AchievementsCategory(QWidget *parent) :
 QVector<OptionsPage*> AchievementsCategory::pages()
 {
    QVector<OptionsPage*> pages;
-
    pages << new AchievementsPage(this);
-
    return pages;
 }
 
@@ -175,22 +173,32 @@ QWidget *AudioPage::widget()
 
    dspGroup->add(MENU_ENUM_LABEL_AUDIO_DSP_PLUGIN);
 
-   volumeLayout->addWidget(new QLabel(msg_hash_to_str(MENU_ENUM_LABEL_VALUE_AUDIO_VOLUME), widget),
+   volumeLayout->addWidget(new QLabel(
+            msg_hash_to_str(MENU_ENUM_LABEL_VALUE_AUDIO_VOLUME), widget),
          1, 1);
-   volumeLayout->addWidget(new CheckableIcon(MENU_ENUM_LABEL_AUDIO_MUTE, qApp->style()->standardIcon(QStyle::SP_MediaVolumeMuted)),
+   volumeLayout->addWidget(new CheckableIcon(
+            MENU_ENUM_LABEL_AUDIO_MUTE,
+            qApp->style()->standardIcon(QStyle::SP_MediaVolumeMuted)),
          1, 2);
    volumeLayout->addLayout(new FloatSliderAndSpinBox(MENU_ENUM_LABEL_AUDIO_VOLUME),
          1, 3, 1, 1);
 
-   volumeLayout->addWidget(new QLabel(msg_hash_to_str(MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_VOLUME), widget),
+   volumeLayout->addWidget(new QLabel(
+            msg_hash_to_str(MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_VOLUME), widget),
          2, 1);
-   volumeLayout->addWidget(new CheckableIcon(MENU_ENUM_LABEL_AUDIO_MIXER_MUTE, qApp->style()->standardIcon(QStyle::SP_MediaVolumeMuted)),
+   volumeLayout->addWidget(new CheckableIcon(
+            MENU_ENUM_LABEL_AUDIO_MIXER_MUTE,
+            qApp->style()->standardIcon(QStyle::SP_MediaVolumeMuted)),
          2, 2);
-   volumeLayout->addLayout(new FloatSliderAndSpinBox(MENU_ENUM_LABEL_AUDIO_MIXER_VOLUME),
+   volumeLayout->addLayout(new FloatSliderAndSpinBox(
+            MENU_ENUM_LABEL_AUDIO_MIXER_VOLUME),
          2, 3, 1, 1);
 
    volumeGroup->addRow(volumeLayout);
+
    volumeGroup->add(MENU_ENUM_LABEL_AUDIO_FASTFORWARD_MUTE);
+   volumeGroup->add(MENU_ENUM_LABEL_AUDIO_FASTFORWARD_SPEEDUP);
+   volumeGroup->add(MENU_ENUM_LABEL_AUDIO_REWIND_MUTE);
 
    layout->addWidget(outputGroup);
    layout->addWidget(resamplerGroup);
@@ -234,9 +242,7 @@ QVector<OptionsPage*> InputCategory::pages()
 }
 
 InputPage::InputPage(QObject *parent) :
-   OptionsPage(parent)
-{
-}
+   OptionsPage(parent) { }
 
 QWidget *InputPage::widget()
 {
@@ -300,10 +306,7 @@ QWidget *HotkeyBindsPage::widget()
 }
 
 UserBindsPage::UserBindsPage(QObject *parent) :
-   OptionsPage(parent)
-{
-   setDisplayName("User Binds");
-}
+   OptionsPage(parent) { setDisplayName("User Binds"); }
 
 QWidget *UserBindsPage::widget()
 {
@@ -369,16 +372,12 @@ LatencyCategory::LatencyCategory(QWidget *parent) :
 QVector<OptionsPage*> LatencyCategory::pages()
 {
    QVector<OptionsPage*> pages;
-
    pages << new LatencyPage(this);
-
    return pages;
 }
 
 LatencyPage::LatencyPage(QObject *parent) :
-   OptionsPage(parent)
-{
-}
+   OptionsPage(parent) { }
 
 QWidget *LatencyPage::widget()
 {
@@ -494,7 +493,8 @@ QWidget *NetplayPage::widget()
          column = 0;
          row++;
       }
-      requestGrid->addWidget(new CheckBox((enum msg_hash_enums)(MENU_ENUM_LABEL_NETPLAY_REQUEST_DEVICE_1 + i)), row, column);
+      requestGrid->addWidget(new CheckBox((enum msg_hash_enums)(
+                  MENU_ENUM_LABEL_NETPLAY_REQUEST_DEVICE_1 + i)), row, column);
       column++;
    }
 
@@ -547,7 +547,8 @@ QGroupBox *NetplayPage::createMitmServerGroup()
    groupBox->add(MENU_ENUM_LABEL_NETPLAY_CUSTOM_MITM_SERVER);
 
 #if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
-   connect(buttonGroup, &QButtonGroup::idClicked, this, &NetplayPage::onRadioButtonClicked);
+   connect(buttonGroup, &QButtonGroup::idClicked, this,
+         &NetplayPage::onRadioButtonClicked);
 #else
    connect(buttonGroup, SIGNAL(buttonClicked(int)), this,
       SLOT(onRadioButtonClicked(int)));
@@ -606,8 +607,10 @@ QWidget *NotificationsPage::widget()
 {
    QWidget                            *widget = new QWidget;
    QVBoxLayout                        *layout = new QVBoxLayout;
-   CheckableSettingsGroup *notificationsGroup = new CheckableSettingsGroup(MENU_ENUM_LABEL_VIDEO_FONT_ENABLE);
-   CheckableSettingsGroup            *bgGroup = new CheckableSettingsGroup(MENU_ENUM_LABEL_VIDEO_MESSAGE_BGCOLOR_ENABLE);
+   CheckableSettingsGroup *notificationsGroup = new CheckableSettingsGroup(
+         MENU_ENUM_LABEL_VIDEO_FONT_ENABLE);
+   CheckableSettingsGroup            *bgGroup = new CheckableSettingsGroup(
+         MENU_ENUM_LABEL_VIDEO_MESSAGE_BGCOLOR_ENABLE);
 
    notificationsGroup->add(MENU_ENUM_LABEL_FPS_SHOW);
    notificationsGroup->add(MENU_ENUM_LABEL_FPS_UPDATE_INTERVAL);
@@ -642,6 +645,7 @@ QWidget *NotificationsPage::widget()
 #endif
    notificationsGroup->add(MENU_ENUM_LABEL_MENU_SHOW_LOAD_CONTENT_ANIMATION);
    notificationsGroup->add(MENU_ENUM_LABEL_NOTIFICATION_SHOW_AUTOCONFIG);
+   notificationsGroup->add(MENU_ENUM_LABEL_NOTIFICATION_SHOW_AUTOCONFIG_FAILS);
    notificationsGroup->add(MENU_ENUM_LABEL_NOTIFICATION_SHOW_REMAP_LOAD);
    notificationsGroup->add(MENU_ENUM_LABEL_NOTIFICATION_SHOW_CONFIG_OVERRIDE_LOAD);
    notificationsGroup->add(MENU_ENUM_LABEL_NOTIFICATION_SHOW_SET_INITIAL_DISK);
@@ -676,7 +680,8 @@ QWidget *OverlayPage::widget()
 #if defined(HAVE_OVERLAY)
    QVBoxLayout                  *layout = new QVBoxLayout;
 
-   CheckableSettingsGroup *overlayGroup = new CheckableSettingsGroup(MENU_ENUM_LABEL_INPUT_OVERLAY_ENABLE);
+   CheckableSettingsGroup *overlayGroup = new CheckableSettingsGroup(
+         MENU_ENUM_LABEL_INPUT_OVERLAY_ENABLE);
 
    overlayGroup->add(MENU_ENUM_LABEL_OVERLAY_AUTOLOAD_PREFERRED);
    overlayGroup->add(MENU_ENUM_LABEL_INPUT_OVERLAY_AUTO_ROTATE);
@@ -735,16 +740,14 @@ QWidget *PlaylistsPage::widget()
 {
    QWidget *widget                 = new QWidget;
    FormLayout *layout              = new FormLayout;
-   CheckableSettingsGroup *history = new CheckableSettingsGroup(MENU_ENUM_LABEL_HISTORY_LIST_ENABLE);
+   CheckableSettingsGroup *history = new CheckableSettingsGroup(
+         MENU_ENUM_LABEL_HISTORY_LIST_ENABLE);
 
    history->add(MENU_ENUM_LABEL_CONTENT_HISTORY_SIZE);
 
    layout->addRow(history);
 
    layout->add(menu_setting_find_enum(MENU_ENUM_LABEL_PLAYLIST_ENTRY_RENAME));
-#if 0
-   layout->add(menu_setting_find_enum(MENU_ENUM_LABEL_PLAYLIST_ENTRY_REMOVE));
-#endif
    layout->add(menu_setting_find_enum(MENU_ENUM_LABEL_PLAYLIST_SORT_ALPHABETICAL));
    layout->add(menu_setting_find_enum(MENU_ENUM_LABEL_PLAYLIST_USE_OLD_FORMAT));
    layout->add(menu_setting_find_enum(MENU_ENUM_LABEL_PLAYLIST_COMPRESSION));
@@ -840,7 +843,8 @@ QWidget *SavingPage::widget()
    FormLayout                          *layout = new FormLayout;
    SettingsGroup                   *savesGroup = new SettingsGroup("Saves");
    SettingsGroup              *savestatesGroup = new SettingsGroup("Savestates");
-   CheckableSettingsGroup *autoSavestatesGroup = new CheckableSettingsGroup(MENU_ENUM_LABEL_SAVESTATE_AUTO_SAVE);
+   CheckableSettingsGroup *autoSavestatesGroup = new CheckableSettingsGroup(
+         MENU_ENUM_LABEL_SAVESTATE_AUTO_SAVE);
    SettingsGroup                 *saveRamGroup = new SettingsGroup("SaveRAM");
    SettingsGroup          *systemFilesDirGroup = new SettingsGroup("System Files");
    SettingsGroup          *screenshotsDirGroup = new SettingsGroup("Screenshots");
@@ -922,8 +926,10 @@ QWidget *UserInterfacePage::widget()
    SettingsGroup             *menuGroup = new SettingsGroup("Menu");
    SettingsGroup            *inputGroup = new SettingsGroup("Input");
    SettingsGroup             *miscGroup = new SettingsGroup("Miscellaneous");
-   CheckableSettingsGroup *desktopGroup = new CheckableSettingsGroup(MENU_ENUM_LABEL_DESKTOP_MENU_ENABLE);
-   rarch_setting_t           *kioskMode = menu_setting_find_enum(MENU_ENUM_LABEL_MENU_ENABLE_KIOSK_MODE);
+   CheckableSettingsGroup *desktopGroup = new CheckableSettingsGroup(
+         MENU_ENUM_LABEL_DESKTOP_MENU_ENABLE);
+   rarch_setting_t           *kioskMode = menu_setting_find_enum(
+         MENU_ENUM_LABEL_MENU_ENABLE_KIOSK_MODE);
 
    menuGroup->add(MENU_ENUM_LABEL_SHOW_ADVANCED_SETTINGS);
 
@@ -1565,6 +1571,7 @@ QWidget *CrtSwitchresPage::widget()
    layout->add(menu_setting_find_enum(MENU_ENUM_LABEL_CRT_SWITCH_RESOLUTION));
    layout->addRow(msg_hash_to_str(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION_SUPER), m_crtSuperResolutionCombo);
    layout->add(menu_setting_find_enum(MENU_ENUM_LABEL_CRT_SWITCH_X_AXIS_CENTERING));
+   layout->add(menu_setting_find_enum(MENU_ENUM_LABEL_CRT_SWITCH_VERTICAL_ADJUST));
    layout->add(menu_setting_find_enum(MENU_ENUM_LABEL_CRT_SWITCH_RESOLUTION_USE_CUSTOM_REFRESH_RATE));
 
    connect(m_crtSuperResolutionCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(onCrtSuperResolutionComboIndexChanged(int)));
@@ -1730,16 +1737,12 @@ LoggingCategory::LoggingCategory(QWidget *parent) :
 QVector<OptionsPage*> LoggingCategory::pages()
 {
    QVector<OptionsPage*> pages;
-
    pages << new LoggingPage(this);
-
    return pages;
 }
 
 LoggingPage::LoggingPage(QObject *parent) :
-   OptionsPage(parent)
-{
-}
+   OptionsPage(parent) { }
 
 QWidget *LoggingPage::widget()
 {
