@@ -57,16 +57,16 @@ public:
    QString categoryIconName() const { return m_categoryIconName; }
    virtual void load()
    {
-      unsigned i;
-      size_t size = m_pages.size();
-      for (i = 0; i < size; i++)
+      size_t i;
+      size_t _len = m_pages.size();
+      for (i = 0; i < _len; i++)
          m_pages.at(i)->load();
    }
    virtual void apply()
    {
-      unsigned i;
-      size_t size = m_pages.size();
-      for (i = 0; i < size; i++)
+      size_t i;
+      size_t _len = m_pages.size();
+      for (i = 0; i < _len; i++)
          m_pages.at(i)->apply();
    }
 protected:
@@ -96,7 +96,7 @@ public:
 };
 
 /***********************************************************
-   AI Service 
+   AI Service
 ************************************************************/
 class AIServiceCategory : public OptionsCategory
 {
@@ -154,7 +154,8 @@ public:
    VideoPage(QObject *parent = nullptr);
    QWidget *widget();
 private slots:
-   void onResolutionComboIndexChanged(const QString& value);
+   Q_DECL_DEPRECATED void onResolutionComboIndexChanged(const QString& value);
+   void onResolutionComboIndexChanged(int index);
 private:
    QComboBox *m_resolutionCombo;
 };
