@@ -909,27 +909,17 @@ bool _FAT_directory_addEntry (PARTITION* partition, DIR_ENTRY* entry, uint32_t d
 	int lfnLen;
 
 	// Remove trailing spaces
-	for (i = strlen (entry->filename) - 1; (i >= 0) && (entry->filename[i] == ' '); --i) {
+	for (i = strlen (entry->filename) - 1; (i >= 0) && (entry->filename[i] == ' '); --i)
 		entry->filename[i] = '\0';
-	}
-#if 0
-	// Remove leading spaces
-	for (i = 0; entry->filename[i] == ' '; ++i) ;
-	if (i > 0) {
-		memmove (entry->filename, entry->filename + i, strlen (entry->filename + i));
-	}
-#endif
 
 	// Make sure the filename is not 0 length
-	if (strnlen (entry->filename, NAME_MAX) < 1) {
+	if (strnlen (entry->filename, NAME_MAX) < 1)
 		return false;
-	}
 
 	// Make sure the filename is at least a valid LFN
 	lfnLen = _FAT_directory_lfnLength (entry->filename);
-	if (lfnLen < 0) {
+	if (lfnLen < 0)
 		return false;
-	}
 
 	// Remove junk in filename
 	i = strlen (entry->filename);
